/****************************************************************************
** Meta object code from reading C++ file 'openconnectauth.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-nm-6.7.4/vpn/openconnect/openconnectauth.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'openconnectauth.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21OpenconnectAuthWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto OpenconnectAuthWidget::qt_create_metaobjectdata<qt_meta_tag_ZN21OpenconnectAuthWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OpenconnectAuthWidget",
        "writeNewConfig",
        "",
        "validatePeerCert",
        "bool*",
        "processAuthForm",
        "oc_auth_form*",
        "updateLog",
        "logLevelChanged",
        "formLoginClicked",
        "formGroupChanged",
        "workerFinished",
        "viewServerLogToggled",
        "connectHost",
        "initTokens",
        "handleWebEngineCookie",
        "QNetworkCookie",
        "handleWebEngineLoad",
        "QWebEngineLoadingInfo",
        "handleWebEngineUrl",
        "QUrl",
        "url",
        "handleWebAuthUxRequested",
        "QWebEngineWebAuthUxRequest*",
        "request",
        "handleWebAuthUxStateChanged",
        "QWebEngineWebAuthUxRequest::WebAuthUxState",
        "state",
        "openWebEngine",
        "const char*",
        "QSemaphore*"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'writeNewConfig'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'validatePeerCert'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, bool *)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Slot 'processAuthForm'
        QtMocHelpers::SlotData<void(oc_auth_form *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'updateLog'
        QtMocHelpers::SlotData<void(const QString &, const int &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'logLevelChanged'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'formLoginClicked'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'formGroupChanged'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'workerFinished'
        QtMocHelpers::SlotData<void(const int &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'viewServerLogToggled'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'connectHost'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'initTokens'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleWebEngineCookie'
        QtMocHelpers::SlotData<void(const QNetworkCookie &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'handleWebEngineLoad'
        QtMocHelpers::SlotData<void(const QWebEngineLoadingInfo &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Slot 'handleWebEngineUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'handleWebAuthUxRequested'
        QtMocHelpers::SlotData<void(QWebEngineWebAuthUxRequest *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'handleWebAuthUxStateChanged'
        QtMocHelpers::SlotData<void(QWebEngineWebAuthUxRequest::WebAuthUxState)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'openWebEngine'
        QtMocHelpers::SlotData<void(const char *, QSemaphore *)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 }, { 0x80000000 | 30, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OpenconnectAuthWidget, qt_meta_tag_ZN21OpenconnectAuthWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OpenconnectAuthWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<SettingWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21OpenconnectAuthWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21OpenconnectAuthWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21OpenconnectAuthWidgetE_t>.metaTypes,
    nullptr
} };

void OpenconnectAuthWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OpenconnectAuthWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->writeNewConfig((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->validatePeerCert((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[4]))); break;
        case 2: _t->processAuthForm((*reinterpret_cast<std::add_pointer_t<oc_auth_form*>>(_a[1]))); break;
        case 3: _t->updateLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->logLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->formLoginClicked(); break;
        case 6: _t->formGroupChanged(); break;
        case 7: _t->workerFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->viewServerLogToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->connectHost(); break;
        case 10: _t->initTokens(); break;
        case 11: _t->handleWebEngineCookie((*reinterpret_cast<std::add_pointer_t<QNetworkCookie>>(_a[1]))); break;
        case 12: _t->handleWebEngineLoad((*reinterpret_cast<std::add_pointer_t<QWebEngineLoadingInfo>>(_a[1]))); break;
        case 13: _t->handleWebEngineUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 14: _t->handleWebAuthUxRequested((*reinterpret_cast<std::add_pointer_t<QWebEngineWebAuthUxRequest*>>(_a[1]))); break;
        case 15: _t->handleWebAuthUxStateChanged((*reinterpret_cast<std::add_pointer_t<QWebEngineWebAuthUxRequest::WebAuthUxState>>(_a[1]))); break;
        case 16: _t->openWebEngine((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSemaphore*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkCookie >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWebEngineWebAuthUxRequest* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *OpenconnectAuthWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenconnectAuthWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21OpenconnectAuthWidgetE_t>.strings))
        return static_cast<void*>(this);
    return SettingWidget::qt_metacast(_clname);
}

int OpenconnectAuthWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SettingWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
