/********************************************************************************
** Form generated from reading UI file 'ipv4.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IPV4_H
#define UI_IPV4_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_IPv4Widget
{
public:
    QGridLayout *gridLayout_2;
    QLabel *label;
    KComboBox *method;
    QLabel *dnsLabel;
    QHBoxLayout *horizontalLayout_2;
    KLineEdit *dns;
    QPushButton *dnsMorePushButton;
    QLabel *dnsSearchLabel;
    QHBoxLayout *horizontalLayout_5;
    KLineEdit *dnsSearch;
    QPushButton *dnsSearchMorePushButton;
    QLabel *labelDhcpClientId;
    KLineEdit *dhcpClientId;
    QLabel *labelRouteMetric;
    QDoubleSpinBox *routeMetric;
    QGridLayout *gridLayout;
    QPushButton *btnRemove;
    QPushButton *btnAdd;
    QTableView *tableViewAddresses;
    QSpacerItem *verticalSpacer_3;
    QCheckBox *ipv4RequiredCB;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *btnAdvanced;
    QPushButton *btnRoutes;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *IPv4Widget)
    {
        if (IPv4Widget->objectName().isEmpty())
            IPv4Widget->setObjectName("IPv4Widget");
        IPv4Widget->setEnabled(true);
        IPv4Widget->resize(418, 427);
        gridLayout_2 = new QGridLayout(IPv4Widget);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(IPv4Widget);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        method = new KComboBox(IPv4Widget);
        method->addItem(QString());
        method->addItem(QString());
        method->addItem(QString());
        method->addItem(QString());
        method->addItem(QString());
        method->addItem(QString());
        method->setObjectName("method");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(method->sizePolicy().hasHeightForWidth());
        method->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(method, 0, 1, 1, 1);

        dnsLabel = new QLabel(IPv4Widget);
        dnsLabel->setObjectName("dnsLabel");
        sizePolicy.setHeightForWidth(dnsLabel->sizePolicy().hasHeightForWidth());
        dnsLabel->setSizePolicy(sizePolicy);
        dnsLabel->setTextFormat(Qt::AutoText);
        dnsLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(dnsLabel, 1, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        dns = new KLineEdit(IPv4Widget);
        dns->setObjectName("dns");
        sizePolicy1.setHeightForWidth(dns->sizePolicy().hasHeightForWidth());
        dns->setSizePolicy(sizePolicy1);
        dns->setMinimumSize(QSize(250, 0));

        horizontalLayout_2->addWidget(dns);

        dnsMorePushButton = new QPushButton(IPv4Widget);
        dnsMorePushButton->setObjectName("dnsMorePushButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-properties")));
        dnsMorePushButton->setIcon(icon);

        horizontalLayout_2->addWidget(dnsMorePushButton);


        gridLayout_2->addLayout(horizontalLayout_2, 1, 1, 1, 1);

        dnsSearchLabel = new QLabel(IPv4Widget);
        dnsSearchLabel->setObjectName("dnsSearchLabel");
        sizePolicy.setHeightForWidth(dnsSearchLabel->sizePolicy().hasHeightForWidth());
        dnsSearchLabel->setSizePolicy(sizePolicy);
        dnsSearchLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(dnsSearchLabel, 2, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        dnsSearch = new KLineEdit(IPv4Widget);
        dnsSearch->setObjectName("dnsSearch");
        dnsSearch->setMinimumSize(QSize(250, 0));

        horizontalLayout_5->addWidget(dnsSearch);

        dnsSearchMorePushButton = new QPushButton(IPv4Widget);
        dnsSearchMorePushButton->setObjectName("dnsSearchMorePushButton");
        dnsSearchMorePushButton->setIcon(icon);

        horizontalLayout_5->addWidget(dnsSearchMorePushButton);


        gridLayout_2->addLayout(horizontalLayout_5, 2, 1, 1, 1);

        labelDhcpClientId = new QLabel(IPv4Widget);
        labelDhcpClientId->setObjectName("labelDhcpClientId");
        sizePolicy.setHeightForWidth(labelDhcpClientId->sizePolicy().hasHeightForWidth());
        labelDhcpClientId->setSizePolicy(sizePolicy);
        labelDhcpClientId->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(labelDhcpClientId, 3, 0, 1, 1);

        dhcpClientId = new KLineEdit(IPv4Widget);
        dhcpClientId->setObjectName("dhcpClientId");

        gridLayout_2->addWidget(dhcpClientId, 3, 1, 1, 1);

        labelRouteMetric = new QLabel(IPv4Widget);
        labelRouteMetric->setObjectName("labelRouteMetric");
        sizePolicy.setHeightForWidth(labelRouteMetric->sizePolicy().hasHeightForWidth());
        labelRouteMetric->setSizePolicy(sizePolicy);
        labelRouteMetric->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(labelRouteMetric, 4, 0, 1, 1);

        routeMetric = new QDoubleSpinBox(IPv4Widget);
        routeMetric->setObjectName("routeMetric");
        routeMetric->setDecimals(0);
        routeMetric->setMinimum(-1.000000000000000);
        routeMetric->setMaximum(4294967295.000000000000000);

        gridLayout_2->addWidget(routeMetric, 4, 1, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        btnRemove = new QPushButton(IPv4Widget);
        btnRemove->setObjectName("btnRemove");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        btnRemove->setIcon(icon1);

        gridLayout->addWidget(btnRemove, 1, 1, 1, 1);

        btnAdd = new QPushButton(IPv4Widget);
        btnAdd->setObjectName("btnAdd");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("list-add")));
        btnAdd->setIcon(icon2);

        gridLayout->addWidget(btnAdd, 0, 1, 1, 1);

        tableViewAddresses = new QTableView(IPv4Widget);
        tableViewAddresses->setObjectName("tableViewAddresses");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(tableViewAddresses->sizePolicy().hasHeightForWidth());
        tableViewAddresses->setSizePolicy(sizePolicy2);
        tableViewAddresses->setSelectionMode(QAbstractItemView::SingleSelection);
        tableViewAddresses->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableViewAddresses->horizontalHeader()->setStretchLastSection(true);
        tableViewAddresses->verticalHeader()->setVisible(false);

        gridLayout->addWidget(tableViewAddresses, 0, 0, 3, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout->addItem(verticalSpacer_3, 2, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 5, 0, 1, 2);

        ipv4RequiredCB = new QCheckBox(IPv4Widget);
        ipv4RequiredCB->setObjectName("ipv4RequiredCB");
        ipv4RequiredCB->setChecked(true);

        gridLayout_2->addWidget(ipv4RequiredCB, 6, 0, 1, 2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        btnAdvanced = new QPushButton(IPv4Widget);
        btnAdvanced->setObjectName("btnAdvanced");

        horizontalLayout->addWidget(btnAdvanced);

        btnRoutes = new QPushButton(IPv4Widget);
        btnRoutes->setObjectName("btnRoutes");
        btnRoutes->setEnabled(true);
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(btnRoutes->sizePolicy().hasHeightForWidth());
        btnRoutes->setSizePolicy(sizePolicy3);
        btnRoutes->setMaximumSize(QSize(16777215, 16777215));
        btnRoutes->setLayoutDirection(Qt::RightToLeft);

        horizontalLayout->addWidget(btnRoutes);


        gridLayout_2->addLayout(horizontalLayout, 8, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 7, 0, 1, 2);

#if QT_CONFIG(shortcut)
        label->setBuddy(method);
        dnsLabel->setBuddy(dns);
        dnsSearchLabel->setBuddy(dnsSearch);
        labelDhcpClientId->setBuddy(dhcpClientId);
        labelRouteMetric->setBuddy(routeMetric);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(method, dns);
        QWidget::setTabOrder(dns, dnsMorePushButton);
        QWidget::setTabOrder(dnsMorePushButton, dnsSearch);
        QWidget::setTabOrder(dnsSearch, dnsSearchMorePushButton);
        QWidget::setTabOrder(dnsSearchMorePushButton, dhcpClientId);
        QWidget::setTabOrder(dhcpClientId, routeMetric);
        QWidget::setTabOrder(routeMetric, tableViewAddresses);
        QWidget::setTabOrder(tableViewAddresses, btnAdd);
        QWidget::setTabOrder(btnAdd, btnRemove);

        retranslateUi(IPv4Widget);

        QMetaObject::connectSlotsByName(IPv4Widget);
    } // setupUi

    void retranslateUi(QWidget *IPv4Widget)
    {
#if QT_CONFIG(tooltip)
        IPv4Widget->setToolTip(tr2i18n("Advanced IP settings", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Method:", nullptr));
        method->setItemText(0, tr2i18n("Automatic", "Method:"));
        method->setItemText(1, tr2i18n("Automatic (Only addresses)", nullptr));
        method->setItemText(2, tr2i18n("Link-Local", nullptr));
        method->setItemText(3, tr2i18n("Manual", "like in use Manual configuration"));
        method->setItemText(4, tr2i18n("Shared to other computers", nullptr));
        method->setItemText(5, tr2i18n("Disabled", "like in this setting is Disabled"));

#if QT_CONFIG(tooltip)
        method->setToolTip(tr2i18n("How to configure the IPv4 address:\n"
"\342\200\242 Automatic: obtain address and DNS automatically via DHCP\n"
"\342\200\242 Automatic (Only addresses): obtain address via DHCP but configure DNS manually\n"
"\342\200\242 Link-Local: use automatic link-local addressing (169.254.x.x)\n"
"\342\200\242 Manual: enter a static IP address\n"
"\342\200\242 Shared: turn this computer into a router to share internet with other devices\n"
"\342\200\242 Disabled: turn off IPv4", nullptr));
#endif // QT_CONFIG(tooltip)
        dnsLabel->setText(tr2i18n("DNS Servers:", "@info"));
#if QT_CONFIG(tooltip)
        dns->setToolTip(tr2i18n("Use this field to specify the IP address(es) of one or more DNS servers. Use ',' to separate entries.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        dnsMorePushButton->setToolTip(tr2i18n("Edit DNS the list of servers", nullptr));
#endif // QT_CONFIG(tooltip)
        dnsSearchLabel->setText(tr2i18n("Search Domains:", "@info"));
#if QT_CONFIG(tooltip)
        dnsSearch->setToolTip(tr2i18n("Use this field to specify one or more DNS domains to search. Use ',' to separate entries.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        dnsSearchMorePushButton->setToolTip(tr2i18n("Edit the list of DNS domains being searched", nullptr));
#endif // QT_CONFIG(tooltip)
        labelDhcpClientId->setText(tr2i18n("DHCP Client ID:", nullptr));
#if QT_CONFIG(tooltip)
        dhcpClientId->setToolTip(tr2i18n("Use this field to specify the DHCP client ID which is a string sent to the DHCP server\n"
"to identify the local machine that the DHCP server may use to customize the DHCP\n"
"lease and options.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelRouteMetric->setText(tr2i18n("Route Metric:", nullptr));
        routeMetric->setSuffix(QString());
        routeMetric->setPrefix(QString());
#if QT_CONFIG(tooltip)
        routeMetric->setToolTip(tr2i18n("A score that helps choose the best path for data packets to reach their destination,\n"
"based on factors like distance, delay, and reliability.\n"
"\n"
"Default value -1 means that NetworkManager gets to choose and manage the actual metric of the route.", nullptr));
#endif // QT_CONFIG(tooltip)
        btnRemove->setText(tr2i18n("Remove", nullptr));
        btnAdd->setText(tr2i18n("Add", nullptr));
#if QT_CONFIG(tooltip)
        tableViewAddresses->setToolTip(tr2i18n("IP addresses identify your computer on the network. Click the \"Add\" button to add\n"
"an IP address", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        ipv4RequiredCB->setToolTip(tr2i18n("Allows the connection to complete if IPv4 configuration fails\n"
"but IPv6 configuration succeeds", nullptr));
#endif // QT_CONFIG(tooltip)
        ipv4RequiredCB->setText(tr2i18n("IPv4 is required for this connection", nullptr));
        btnAdvanced->setText(tr2i18n("Advanced\342\200\246", nullptr));
        btnRoutes->setText(tr2i18n("Routes\342\200\246", nullptr));
    } // retranslateUi

};

namespace Ui {
    class IPv4Widget: public Ui_IPv4Widget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IPV4_H

