/********************************************************************************
** Form generated from reading UI file 'ipv4routes.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IPV4ROUTES_H
#define UI_IPV4ROUTES_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RoutesIp4Config
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer;
    QCheckBox *cbNeverDefault;
    QSpacerItem *horizontalSpacer;
    QPushButton *pushButtonRemove;
    QTableView *tableViewAddresses;
    QPushButton *pushButtonAdd;
    QCheckBox *cbIgnoreAutoRoutes;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *RoutesIp4Config)
    {
        if (RoutesIp4Config->objectName().isEmpty())
            RoutesIp4Config->setObjectName("RoutesIp4Config");
        RoutesIp4Config->resize(499, 356);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(RoutesIp4Config->sizePolicy().hasHeightForWidth());
        RoutesIp4Config->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(RoutesIp4Config);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        cbNeverDefault = new QCheckBox(RoutesIp4Config);
        cbNeverDefault->setObjectName("cbNeverDefault");

        gridLayout->addWidget(cbNeverDefault, 4, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(119, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 0, 1, 1);

        pushButtonRemove = new QPushButton(RoutesIp4Config);
        pushButtonRemove->setObjectName("pushButtonRemove");
        pushButtonRemove->setEnabled(false);
        pushButtonRemove->setMaximumSize(QSize(16777215, 16777215));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8(""), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        pushButtonRemove->setIcon(icon);

        gridLayout->addWidget(pushButtonRemove, 1, 2, 1, 1);

        tableViewAddresses = new QTableView(RoutesIp4Config);
        tableViewAddresses->setObjectName("tableViewAddresses");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(tableViewAddresses->sizePolicy().hasHeightForWidth());
        tableViewAddresses->setSizePolicy(sizePolicy1);
        tableViewAddresses->setMinimumSize(QSize(150, 50));
        tableViewAddresses->setSelectionMode(QAbstractItemView::SingleSelection);
        tableViewAddresses->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableViewAddresses->setShowGrid(true);
        tableViewAddresses->setGridStyle(Qt::SolidLine);
        tableViewAddresses->horizontalHeader()->setStretchLastSection(true);
        tableViewAddresses->verticalHeader()->setVisible(false);

        gridLayout->addWidget(tableViewAddresses, 0, 0, 1, 3);

        pushButtonAdd = new QPushButton(RoutesIp4Config);
        pushButtonAdd->setObjectName("pushButtonAdd");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8(""), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        pushButtonAdd->setIcon(icon1);

        gridLayout->addWidget(pushButtonAdd, 1, 1, 1, 1);

        cbIgnoreAutoRoutes = new QCheckBox(RoutesIp4Config);
        cbIgnoreAutoRoutes->setObjectName("cbIgnoreAutoRoutes");

        gridLayout->addWidget(cbIgnoreAutoRoutes, 3, 0, 1, 1);

        buttonBox = new QDialogButtonBox(RoutesIp4Config);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 5, 1, 1, 2);

        QWidget::setTabOrder(tableViewAddresses, pushButtonAdd);
        QWidget::setTabOrder(pushButtonAdd, pushButtonRemove);
        QWidget::setTabOrder(pushButtonRemove, cbIgnoreAutoRoutes);
        QWidget::setTabOrder(cbIgnoreAutoRoutes, cbNeverDefault);

        retranslateUi(RoutesIp4Config);

        QMetaObject::connectSlotsByName(RoutesIp4Config);
    } // setupUi

    void retranslateUi(QWidget *RoutesIp4Config)
    {
        RoutesIp4Config->setWindowTitle(tr2i18n("Edit IPv4 Routes", nullptr));
#if QT_CONFIG(tooltip)
        cbNeverDefault->setToolTip(tr2i18n("If enabled, this connection will never be used as the default network connection", nullptr));
#endif // QT_CONFIG(tooltip)
        cbNeverDefault->setText(tr2i18n("Use only for resources on this connection", nullptr));
        pushButtonRemove->setText(tr2i18n("Remove", "Remove a selected row"));
#if QT_CONFIG(tooltip)
        tableViewAddresses->setToolTip(tr2i18n("IP addresses identify your computer on the network. Click the \"Add\" button to add\n"
"an IP address", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonAdd->setText(tr2i18n("Add", "Insert a row"));
#if QT_CONFIG(tooltip)
        cbIgnoreAutoRoutes->setToolTip(tr2i18n("If enabled, automatically configured routes are ignored and only routes specified above are used", nullptr));
#endif // QT_CONFIG(tooltip)
        cbIgnoreAutoRoutes->setText(tr2i18n("Ignore automatically obtained routes", nullptr));
    } // retranslateUi

};

namespace Ui {
    class RoutesIp4Config: public Ui_RoutesIp4Config {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IPV4ROUTES_H

