/********************************************************************************
** Form generated from reading UI file 'iodineauth.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IODINEAUTH_H
#define UI_IODINEAUTH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_IodineAuth
{
public:
    QFormLayout *formLayout;
    QLabel *lbl_password;
    PasswordField *le_password;

    void setupUi(QWidget *IodineAuth)
    {
        if (IodineAuth->objectName().isEmpty())
            IodineAuth->setObjectName("IodineAuth");
        IodineAuth->resize(408, 136);
        formLayout = new QFormLayout(IodineAuth);
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(0);
        lbl_password = new QLabel(IodineAuth);
        lbl_password->setObjectName("lbl_password");
        lbl_password->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lbl_password);

        le_password = new PasswordField(IodineAuth);
        le_password->setObjectName("le_password");
        le_password->setProperty("passwordModeEnabled", QVariant(true));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, le_password);

#if QT_CONFIG(shortcut)
        lbl_password->setBuddy(le_password);
#endif // QT_CONFIG(shortcut)

        retranslateUi(IodineAuth);

        QMetaObject::connectSlotsByName(IodineAuth);
    } // setupUi

    void retranslateUi(QWidget *IodineAuth)
    {
        lbl_password->setText(tr2i18n("Password:", nullptr));
        (void)IodineAuth;
    } // retranslateUi

};

namespace Ui {
    class IodineAuth: public Ui_IodineAuth {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IODINEAUTH_H

