/********************************************************************************
** Form generated from reading UI file '802-1x.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI__802_2D_1X_H
#define UI__802_2D_1X_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"
#include "kurlrequester.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_Security8021x
{
public:
    QFormLayout *formLayout_7;
    QLabel *label;
    KComboBox *auth;
    QLabel *label_2;
    KLineEdit *md5UserName;
    QLabel *label_3;
    PasswordField *md5Password;
    QLabel *label_4;
    KLineEdit *tlsIdentity;
    QLabel *label_32;
    KLineEdit *tlsDomain;
    QLabel *label_5;
    KUrlRequester *tlsUserCert;
    QLabel *label_6;
    KUrlRequester *tlsCACert;
    QLabel *label_27;
    QLineEdit *leTlsSubjectMatch;
    QLabel *label_28;
    QHBoxLayout *horizontalLayout;
    QLineEdit *leTlsAlternativeSubjectMatches;
    QPushButton *btnTlsAltSubjectMatches;
    QLabel *label_29;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *leTlsConnectToServers;
    QPushButton *btnTlsConnectToServers;
    QLabel *label_7;
    KUrlRequester *tlsPrivateKey;
    QLabel *label_8;
    PasswordField *tlsPrivateKeyPassword;
    QLabel *label_9;
    KLineEdit *leapUsername;
    QLabel *label_10;
    PasswordField *leapPassword;
    QLabel *label_33;
    KLineEdit *pwdUsername;
    QLabel *label_34;
    PasswordField *pwdPassword;
    QLabel *label_11;
    KLineEdit *fastAnonIdentity;
    QCheckBox *fastAllowPacProvisioning;
    KComboBox *pacMethod;
    QLabel *label_12;
    KUrlRequester *pacFile;
    QLabel *label_13;
    KComboBox *fastInnerAuth;
    QLabel *label_14;
    KLineEdit *fastUsername;
    QLabel *label_15;
    PasswordField *fastPassword;
    QLabel *label_19;
    KLineEdit *ttlsAnonIdentity;
    QLabel *label_20;
    KUrlRequester *ttlsCACert;
    QLabel *label_16;
    KComboBox *ttlsInnerAuth;
    QLabel *label_17;
    KLineEdit *ttlsUsername;
    QLabel *label_18;
    PasswordField *ttlsPassword;
    QLabel *label_30;
    KLineEdit *ttlsDomain;
    QLabel *label_24;
    KLineEdit *peapAnonIdentity;
    QLabel *label_23;
    KUrlRequester *peapCACert;
    QLabel *label_26;
    KComboBox *peapVersion;
    QLabel *label_22;
    KComboBox *peapInnerAuth;
    QLabel *label_25;
    KLineEdit *peapUsername;
    QLabel *label_21;
    PasswordField *peapPassword;
    QLabel *label_31;
    KLineEdit *peapDomain;

    void setupUi(QWidget *Security8021x)
    {
        if (Security8021x->objectName().isEmpty())
            Security8021x->setObjectName("Security8021x");
        Security8021x->resize(563, 471);
        formLayout_7 = new QFormLayout(Security8021x);
        formLayout_7->setObjectName("formLayout_7");
        formLayout_7->setLabelAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        formLayout_7->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(Security8021x);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        auth = new KComboBox(Security8021x);
        auth->addItem(QString());
        auth->addItem(QString());
        auth->addItem(QString());
        auth->addItem(QString());
        auth->addItem(QString());
        auth->addItem(QString());
        auth->addItem(QString());
        auth->setObjectName("auth");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(auth->sizePolicy().hasHeightForWidth());
        auth->setSizePolicy(sizePolicy);

        formLayout_7->setWidget(0, QFormLayout::ItemRole::FieldRole, auth);

        label_2 = new QLabel(Security8021x);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        md5UserName = new KLineEdit(Security8021x);
        md5UserName->setObjectName("md5UserName");

        formLayout_7->setWidget(1, QFormLayout::ItemRole::FieldRole, md5UserName);

        label_3 = new QLabel(Security8021x);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        md5Password = new PasswordField(Security8021x);
        md5Password->setObjectName("md5Password");
        md5Password->setProperty("passwordModeEnabled", QVariant(true));

        formLayout_7->setWidget(2, QFormLayout::ItemRole::FieldRole, md5Password);

        label_4 = new QLabel(Security8021x);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(3, QFormLayout::ItemRole::LabelRole, label_4);

        tlsIdentity = new KLineEdit(Security8021x);
        tlsIdentity->setObjectName("tlsIdentity");

        formLayout_7->setWidget(3, QFormLayout::ItemRole::FieldRole, tlsIdentity);

        label_32 = new QLabel(Security8021x);
        label_32->setObjectName("label_32");
        label_32->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(4, QFormLayout::ItemRole::LabelRole, label_32);

        tlsDomain = new KLineEdit(Security8021x);
        tlsDomain->setObjectName("tlsDomain");

        formLayout_7->setWidget(4, QFormLayout::ItemRole::FieldRole, tlsDomain);

        label_5 = new QLabel(Security8021x);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(5, QFormLayout::ItemRole::LabelRole, label_5);

        tlsUserCert = new KUrlRequester(Security8021x);
        tlsUserCert->setObjectName("tlsUserCert");

        formLayout_7->setWidget(5, QFormLayout::ItemRole::FieldRole, tlsUserCert);

        label_6 = new QLabel(Security8021x);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(6, QFormLayout::ItemRole::LabelRole, label_6);

        tlsCACert = new KUrlRequester(Security8021x);
        tlsCACert->setObjectName("tlsCACert");

        formLayout_7->setWidget(6, QFormLayout::ItemRole::FieldRole, tlsCACert);

        label_27 = new QLabel(Security8021x);
        label_27->setObjectName("label_27");
        label_27->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(7, QFormLayout::ItemRole::LabelRole, label_27);

        leTlsSubjectMatch = new QLineEdit(Security8021x);
        leTlsSubjectMatch->setObjectName("leTlsSubjectMatch");

        formLayout_7->setWidget(7, QFormLayout::ItemRole::FieldRole, leTlsSubjectMatch);

        label_28 = new QLabel(Security8021x);
        label_28->setObjectName("label_28");
        label_28->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(8, QFormLayout::ItemRole::LabelRole, label_28);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        leTlsAlternativeSubjectMatches = new QLineEdit(Security8021x);
        leTlsAlternativeSubjectMatches->setObjectName("leTlsAlternativeSubjectMatches");

        horizontalLayout->addWidget(leTlsAlternativeSubjectMatches);

        btnTlsAltSubjectMatches = new QPushButton(Security8021x);
        btnTlsAltSubjectMatches->setObjectName("btnTlsAltSubjectMatches");

        horizontalLayout->addWidget(btnTlsAltSubjectMatches);


        formLayout_7->setLayout(8, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_29 = new QLabel(Security8021x);
        label_29->setObjectName("label_29");
        label_29->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(9, QFormLayout::ItemRole::LabelRole, label_29);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        leTlsConnectToServers = new QLineEdit(Security8021x);
        leTlsConnectToServers->setObjectName("leTlsConnectToServers");

        horizontalLayout_2->addWidget(leTlsConnectToServers);

        btnTlsConnectToServers = new QPushButton(Security8021x);
        btnTlsConnectToServers->setObjectName("btnTlsConnectToServers");

        horizontalLayout_2->addWidget(btnTlsConnectToServers);


        formLayout_7->setLayout(9, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        label_7 = new QLabel(Security8021x);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(10, QFormLayout::ItemRole::LabelRole, label_7);

        tlsPrivateKey = new KUrlRequester(Security8021x);
        tlsPrivateKey->setObjectName("tlsPrivateKey");

        formLayout_7->setWidget(10, QFormLayout::ItemRole::FieldRole, tlsPrivateKey);

        label_8 = new QLabel(Security8021x);
        label_8->setObjectName("label_8");
        label_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(11, QFormLayout::ItemRole::LabelRole, label_8);

        tlsPrivateKeyPassword = new PasswordField(Security8021x);
        tlsPrivateKeyPassword->setObjectName("tlsPrivateKeyPassword");
        tlsPrivateKeyPassword->setProperty("passwordModeEnabled", QVariant(true));

        formLayout_7->setWidget(11, QFormLayout::ItemRole::FieldRole, tlsPrivateKeyPassword);

        label_9 = new QLabel(Security8021x);
        label_9->setObjectName("label_9");
        label_9->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(12, QFormLayout::ItemRole::LabelRole, label_9);

        leapUsername = new KLineEdit(Security8021x);
        leapUsername->setObjectName("leapUsername");

        formLayout_7->setWidget(12, QFormLayout::ItemRole::FieldRole, leapUsername);

        label_10 = new QLabel(Security8021x);
        label_10->setObjectName("label_10");
        label_10->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(13, QFormLayout::ItemRole::LabelRole, label_10);

        leapPassword = new PasswordField(Security8021x);
        leapPassword->setObjectName("leapPassword");
        leapPassword->setProperty("passwordModeEnabled", QVariant(true));

        formLayout_7->setWidget(13, QFormLayout::ItemRole::FieldRole, leapPassword);

        label_33 = new QLabel(Security8021x);
        label_33->setObjectName("label_33");
        label_33->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(14, QFormLayout::ItemRole::LabelRole, label_33);

        pwdUsername = new KLineEdit(Security8021x);
        pwdUsername->setObjectName("pwdUsername");

        formLayout_7->setWidget(14, QFormLayout::ItemRole::FieldRole, pwdUsername);

        label_34 = new QLabel(Security8021x);
        label_34->setObjectName("label_34");
        label_34->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(15, QFormLayout::ItemRole::LabelRole, label_34);

        pwdPassword = new PasswordField(Security8021x);
        pwdPassword->setObjectName("pwdPassword");
        pwdPassword->setProperty("passwordModeEnabled", QVariant(true));

        formLayout_7->setWidget(15, QFormLayout::ItemRole::FieldRole, pwdPassword);

        label_11 = new QLabel(Security8021x);
        label_11->setObjectName("label_11");
        label_11->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(16, QFormLayout::ItemRole::LabelRole, label_11);

        fastAnonIdentity = new KLineEdit(Security8021x);
        fastAnonIdentity->setObjectName("fastAnonIdentity");

        formLayout_7->setWidget(16, QFormLayout::ItemRole::FieldRole, fastAnonIdentity);

        fastAllowPacProvisioning = new QCheckBox(Security8021x);
        fastAllowPacProvisioning->setObjectName("fastAllowPacProvisioning");

        formLayout_7->setWidget(17, QFormLayout::ItemRole::LabelRole, fastAllowPacProvisioning);

        pacMethod = new KComboBox(Security8021x);
        pacMethod->addItem(QString());
        pacMethod->addItem(QString());
        pacMethod->addItem(QString());
        pacMethod->setObjectName("pacMethod");
        pacMethod->setEnabled(false);
        sizePolicy.setHeightForWidth(pacMethod->sizePolicy().hasHeightForWidth());
        pacMethod->setSizePolicy(sizePolicy);

        formLayout_7->setWidget(17, QFormLayout::ItemRole::FieldRole, pacMethod);

        label_12 = new QLabel(Security8021x);
        label_12->setObjectName("label_12");
        label_12->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(18, QFormLayout::ItemRole::LabelRole, label_12);

        pacFile = new KUrlRequester(Security8021x);
        pacFile->setObjectName("pacFile");

        formLayout_7->setWidget(18, QFormLayout::ItemRole::FieldRole, pacFile);

        label_13 = new QLabel(Security8021x);
        label_13->setObjectName("label_13");
        label_13->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(19, QFormLayout::ItemRole::LabelRole, label_13);

        fastInnerAuth = new KComboBox(Security8021x);
        fastInnerAuth->addItem(QString());
        fastInnerAuth->addItem(QString());
        fastInnerAuth->setObjectName("fastInnerAuth");
        sizePolicy.setHeightForWidth(fastInnerAuth->sizePolicy().hasHeightForWidth());
        fastInnerAuth->setSizePolicy(sizePolicy);

        formLayout_7->setWidget(19, QFormLayout::ItemRole::FieldRole, fastInnerAuth);

        label_14 = new QLabel(Security8021x);
        label_14->setObjectName("label_14");
        label_14->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(20, QFormLayout::ItemRole::LabelRole, label_14);

        fastUsername = new KLineEdit(Security8021x);
        fastUsername->setObjectName("fastUsername");

        formLayout_7->setWidget(20, QFormLayout::ItemRole::FieldRole, fastUsername);

        label_15 = new QLabel(Security8021x);
        label_15->setObjectName("label_15");
        label_15->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(21, QFormLayout::ItemRole::LabelRole, label_15);

        fastPassword = new PasswordField(Security8021x);
        fastPassword->setObjectName("fastPassword");
        fastPassword->setProperty("passwordModeEnabled", QVariant(true));

        formLayout_7->setWidget(21, QFormLayout::ItemRole::FieldRole, fastPassword);

        label_19 = new QLabel(Security8021x);
        label_19->setObjectName("label_19");
        label_19->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(22, QFormLayout::ItemRole::LabelRole, label_19);

        ttlsAnonIdentity = new KLineEdit(Security8021x);
        ttlsAnonIdentity->setObjectName("ttlsAnonIdentity");

        formLayout_7->setWidget(22, QFormLayout::ItemRole::FieldRole, ttlsAnonIdentity);

        label_20 = new QLabel(Security8021x);
        label_20->setObjectName("label_20");
        label_20->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(23, QFormLayout::ItemRole::LabelRole, label_20);

        ttlsCACert = new KUrlRequester(Security8021x);
        ttlsCACert->setObjectName("ttlsCACert");

        formLayout_7->setWidget(23, QFormLayout::ItemRole::FieldRole, ttlsCACert);

        label_16 = new QLabel(Security8021x);
        label_16->setObjectName("label_16");
        label_16->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(24, QFormLayout::ItemRole::LabelRole, label_16);

        ttlsInnerAuth = new KComboBox(Security8021x);
        ttlsInnerAuth->addItem(QString());
        ttlsInnerAuth->addItem(QString());
        ttlsInnerAuth->addItem(QString());
        ttlsInnerAuth->addItem(QString());
        ttlsInnerAuth->setObjectName("ttlsInnerAuth");
        sizePolicy.setHeightForWidth(ttlsInnerAuth->sizePolicy().hasHeightForWidth());
        ttlsInnerAuth->setSizePolicy(sizePolicy);

        formLayout_7->setWidget(24, QFormLayout::ItemRole::FieldRole, ttlsInnerAuth);

        label_17 = new QLabel(Security8021x);
        label_17->setObjectName("label_17");
        label_17->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(25, QFormLayout::ItemRole::LabelRole, label_17);

        ttlsUsername = new KLineEdit(Security8021x);
        ttlsUsername->setObjectName("ttlsUsername");

        formLayout_7->setWidget(25, QFormLayout::ItemRole::FieldRole, ttlsUsername);

        label_18 = new QLabel(Security8021x);
        label_18->setObjectName("label_18");
        label_18->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(26, QFormLayout::ItemRole::LabelRole, label_18);

        ttlsPassword = new PasswordField(Security8021x);
        ttlsPassword->setObjectName("ttlsPassword");
        ttlsPassword->setProperty("passwordModeEnabled", QVariant(true));

        formLayout_7->setWidget(26, QFormLayout::ItemRole::FieldRole, ttlsPassword);

        label_30 = new QLabel(Security8021x);
        label_30->setObjectName("label_30");
        label_30->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(27, QFormLayout::ItemRole::LabelRole, label_30);

        ttlsDomain = new KLineEdit(Security8021x);
        ttlsDomain->setObjectName("ttlsDomain");

        formLayout_7->setWidget(27, QFormLayout::ItemRole::FieldRole, ttlsDomain);

        label_24 = new QLabel(Security8021x);
        label_24->setObjectName("label_24");
        label_24->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(28, QFormLayout::ItemRole::LabelRole, label_24);

        peapAnonIdentity = new KLineEdit(Security8021x);
        peapAnonIdentity->setObjectName("peapAnonIdentity");

        formLayout_7->setWidget(28, QFormLayout::ItemRole::FieldRole, peapAnonIdentity);

        label_23 = new QLabel(Security8021x);
        label_23->setObjectName("label_23");
        label_23->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(29, QFormLayout::ItemRole::LabelRole, label_23);

        peapCACert = new KUrlRequester(Security8021x);
        peapCACert->setObjectName("peapCACert");

        formLayout_7->setWidget(29, QFormLayout::ItemRole::FieldRole, peapCACert);

        label_26 = new QLabel(Security8021x);
        label_26->setObjectName("label_26");
        label_26->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(30, QFormLayout::ItemRole::LabelRole, label_26);

        peapVersion = new KComboBox(Security8021x);
        peapVersion->addItem(QString());
        peapVersion->addItem(QString());
        peapVersion->addItem(QString());
        peapVersion->setObjectName("peapVersion");
        sizePolicy.setHeightForWidth(peapVersion->sizePolicy().hasHeightForWidth());
        peapVersion->setSizePolicy(sizePolicy);

        formLayout_7->setWidget(30, QFormLayout::ItemRole::FieldRole, peapVersion);

        label_22 = new QLabel(Security8021x);
        label_22->setObjectName("label_22");
        label_22->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(31, QFormLayout::ItemRole::LabelRole, label_22);

        peapInnerAuth = new KComboBox(Security8021x);
        peapInnerAuth->addItem(QString());
        peapInnerAuth->addItem(QString());
        peapInnerAuth->addItem(QString());
        peapInnerAuth->setObjectName("peapInnerAuth");
        sizePolicy.setHeightForWidth(peapInnerAuth->sizePolicy().hasHeightForWidth());
        peapInnerAuth->setSizePolicy(sizePolicy);

        formLayout_7->setWidget(31, QFormLayout::ItemRole::FieldRole, peapInnerAuth);

        label_25 = new QLabel(Security8021x);
        label_25->setObjectName("label_25");
        label_25->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(32, QFormLayout::ItemRole::LabelRole, label_25);

        peapUsername = new KLineEdit(Security8021x);
        peapUsername->setObjectName("peapUsername");

        formLayout_7->setWidget(32, QFormLayout::ItemRole::FieldRole, peapUsername);

        label_21 = new QLabel(Security8021x);
        label_21->setObjectName("label_21");
        label_21->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(33, QFormLayout::ItemRole::LabelRole, label_21);

        peapPassword = new PasswordField(Security8021x);
        peapPassword->setObjectName("peapPassword");
        peapPassword->setProperty("passwordModeEnabled", QVariant(true));

        formLayout_7->setWidget(33, QFormLayout::ItemRole::FieldRole, peapPassword);

        label_31 = new QLabel(Security8021x);
        label_31->setObjectName("label_31");
        label_31->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_7->setWidget(34, QFormLayout::ItemRole::LabelRole, label_31);

        peapDomain = new KLineEdit(Security8021x);
        peapDomain->setObjectName("peapDomain");

        formLayout_7->setWidget(34, QFormLayout::ItemRole::FieldRole, peapDomain);

#if QT_CONFIG(shortcut)
        label->setBuddy(auth);
        label_2->setBuddy(md5UserName);
        label_3->setBuddy(md5Password);
        label_4->setBuddy(tlsIdentity);
        label_5->setBuddy(tlsUserCert);
        label_6->setBuddy(tlsCACert);
        label_27->setBuddy(leTlsSubjectMatch);
        label_28->setBuddy(leTlsAlternativeSubjectMatches);
        label_29->setBuddy(leTlsConnectToServers);
        label_7->setBuddy(tlsPrivateKey);
        label_8->setBuddy(tlsPrivateKeyPassword);
        label_9->setBuddy(leapUsername);
        label_10->setBuddy(leapPassword);
        label_33->setBuddy(md5UserName);
        label_34->setBuddy(md5Password);
        label_11->setBuddy(fastAnonIdentity);
        label_12->setBuddy(pacFile);
        label_13->setBuddy(fastInnerAuth);
        label_14->setBuddy(fastUsername);
        label_15->setBuddy(fastPassword);
        label_19->setBuddy(fastAnonIdentity);
        label_20->setBuddy(tlsCACert);
        label_16->setBuddy(fastInnerAuth);
        label_17->setBuddy(fastUsername);
        label_18->setBuddy(fastPassword);
        label_24->setBuddy(fastAnonIdentity);
        label_23->setBuddy(tlsCACert);
        label_26->setBuddy(peapVersion);
        label_22->setBuddy(fastInnerAuth);
        label_25->setBuddy(fastUsername);
        label_21->setBuddy(fastPassword);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(auth, md5UserName);
        QWidget::setTabOrder(md5UserName, md5Password);
        QWidget::setTabOrder(md5Password, tlsIdentity);
        QWidget::setTabOrder(tlsIdentity, tlsDomain);
        QWidget::setTabOrder(tlsDomain, tlsUserCert);
        QWidget::setTabOrder(tlsUserCert, tlsCACert);
        QWidget::setTabOrder(tlsCACert, leTlsSubjectMatch);
        QWidget::setTabOrder(leTlsSubjectMatch, leTlsAlternativeSubjectMatches);
        QWidget::setTabOrder(leTlsAlternativeSubjectMatches, btnTlsAltSubjectMatches);
        QWidget::setTabOrder(btnTlsAltSubjectMatches, leTlsConnectToServers);
        QWidget::setTabOrder(leTlsConnectToServers, btnTlsConnectToServers);
        QWidget::setTabOrder(btnTlsConnectToServers, tlsPrivateKey);
        QWidget::setTabOrder(tlsPrivateKey, tlsPrivateKeyPassword);
        QWidget::setTabOrder(tlsPrivateKeyPassword, leapUsername);
        QWidget::setTabOrder(leapUsername, leapPassword);
        QWidget::setTabOrder(leapPassword, fastAnonIdentity);
        QWidget::setTabOrder(fastAnonIdentity, fastAllowPacProvisioning);
        QWidget::setTabOrder(fastAllowPacProvisioning, pacMethod);
        QWidget::setTabOrder(pacMethod, pacFile);
        QWidget::setTabOrder(pacFile, fastInnerAuth);
        QWidget::setTabOrder(fastInnerAuth, fastUsername);
        QWidget::setTabOrder(fastUsername, fastPassword);
        QWidget::setTabOrder(fastPassword, ttlsAnonIdentity);
        QWidget::setTabOrder(ttlsAnonIdentity, ttlsDomain);
        QWidget::setTabOrder(ttlsDomain, ttlsCACert);
        QWidget::setTabOrder(ttlsCACert, ttlsInnerAuth);
        QWidget::setTabOrder(ttlsInnerAuth, ttlsUsername);
        QWidget::setTabOrder(ttlsUsername, ttlsPassword);
        QWidget::setTabOrder(ttlsPassword, peapAnonIdentity);
        QWidget::setTabOrder(peapAnonIdentity, peapDomain);
        QWidget::setTabOrder(peapDomain, peapCACert);
        QWidget::setTabOrder(peapCACert, peapVersion);
        QWidget::setTabOrder(peapVersion, peapInnerAuth);
        QWidget::setTabOrder(peapInnerAuth, peapUsername);
        QWidget::setTabOrder(peapUsername, peapPassword);

        retranslateUi(Security8021x);
        QObject::connect(fastAllowPacProvisioning, SIGNAL(toggled(bool)), pacMethod, SLOT(setEnabled(bool)));

        auth->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(Security8021x);
    } // setupUi

    void retranslateUi(QWidget *Security8021x)
    {
        label->setText(tr2i18n("Authentication:", nullptr));
        auth->setItemText(0, tr2i18n("MD5", nullptr));
        auth->setItemText(1, tr2i18n("TLS", nullptr));
        auth->setItemText(2, tr2i18n("LEAP", nullptr));
        auth->setItemText(3, tr2i18n("PWD", nullptr));
        auth->setItemText(4, tr2i18n("FAST", nullptr));
        auth->setItemText(5, tr2i18n("Tunneled TLS (TTLS)", nullptr));
        auth->setItemText(6, tr2i18n("Protected EAP (PEAP)", nullptr));

        label_2->setText(tr2i18n("Username:", nullptr));
        label_3->setText(tr2i18n("Password:", nullptr));
        label_4->setText(tr2i18n("Identity:", nullptr));
        label_32->setText(tr2i18n("Domain:", nullptr));
        label_5->setText(tr2i18n("User certificate:", nullptr));
        tlsUserCert->setNameFilters(QStringList{
            tr2i18n("*.der *.pem *.crt *.cer", nullptr)});
        label_6->setText(tr2i18n("CA certificate:", nullptr));
        tlsCACert->setNameFilters(QStringList{
            tr2i18n("*.der *.pem *.crt *.cer", nullptr)});
        label_27->setText(tr2i18n("Subject match:", nullptr));
        leTlsSubjectMatch->setText(QString());
        label_28->setText(tr2i18n("Alternative subject matches:", nullptr));
        btnTlsAltSubjectMatches->setText(tr2i18n("\342\200\246", nullptr));
        label_29->setText(tr2i18n("Connect to these servers:", nullptr));
        btnTlsConnectToServers->setText(tr2i18n("\342\200\246", nullptr));
        label_7->setText(tr2i18n("Private key:", nullptr));
        tlsPrivateKey->setNameFilters(QStringList{
            tr2i18n("*.der *.pem *.p12 *.key", nullptr)});
        label_8->setText(tr2i18n("Private key password:", nullptr));
        label_9->setText(tr2i18n("Username:", nullptr));
        label_10->setText(tr2i18n("Password:", nullptr));
        label_33->setText(tr2i18n("Username:", nullptr));
        label_34->setText(tr2i18n("Password:", nullptr));
        label_11->setText(tr2i18n("Anonymous identity:", nullptr));
        fastAllowPacProvisioning->setText(tr2i18n("Automatic PAC provisioning", nullptr));
        pacMethod->setItemText(0, tr2i18n("Anonymous", nullptr));
        pacMethod->setItemText(1, tr2i18n("Authenticated", nullptr));
        pacMethod->setItemText(2, tr2i18n("Both", nullptr));

        label_12->setText(tr2i18n("PAC file:", nullptr));
        pacFile->setNameFilters(QStringList{
            tr2i18n("*.pac", nullptr)});
        label_13->setText(tr2i18n("Inner authentication:", nullptr));
        fastInnerAuth->setItemText(0, tr2i18n("GTC", nullptr));
        fastInnerAuth->setItemText(1, tr2i18n("MSCHAPv2", nullptr));

        label_14->setText(tr2i18n("Username:", nullptr));
        label_15->setText(tr2i18n("Password:", nullptr));
        label_19->setText(tr2i18n("Anonymous identity:", nullptr));
        label_20->setText(tr2i18n("CA certificate:", nullptr));
        ttlsCACert->setNameFilters(QStringList{
            tr2i18n("*.der *.pem *.crt *.cer", nullptr)});
        label_16->setText(tr2i18n("Inner authentication:", nullptr));
        ttlsInnerAuth->setItemText(0, tr2i18n("PAP", nullptr));
        ttlsInnerAuth->setItemText(1, tr2i18n("MSCHAP", nullptr));
        ttlsInnerAuth->setItemText(2, tr2i18n("MSCHAPv2", nullptr));
        ttlsInnerAuth->setItemText(3, tr2i18n("CHAP", nullptr));

        label_17->setText(tr2i18n("Username:", nullptr));
        label_18->setText(tr2i18n("Password:", nullptr));
        label_30->setText(tr2i18n("Domain:", nullptr));
        label_24->setText(tr2i18n("Anonymous identity:", nullptr));
        label_23->setText(tr2i18n("CA certificate:", nullptr));
        peapCACert->setNameFilters(QStringList{
            tr2i18n("*.der *.pem *.crt *.cer", nullptr)});
        label_26->setText(tr2i18n("PEAP version:", nullptr));
        peapVersion->setItemText(0, tr2i18n("Automatic", "PEAP version"));
        peapVersion->setItemText(1, tr2i18n("Version 0", nullptr));
        peapVersion->setItemText(2, tr2i18n("Version 1", nullptr));

        label_22->setText(tr2i18n("Inner authentication:", nullptr));
        peapInnerAuth->setItemText(0, tr2i18n("MSCHAPv2", nullptr));
        peapInnerAuth->setItemText(1, tr2i18n("MD5", nullptr));
        peapInnerAuth->setItemText(2, tr2i18n("GTC", nullptr));

        label_25->setText(tr2i18n("Username:", nullptr));
        label_21->setText(tr2i18n("Password:", nullptr));
        label_31->setText(tr2i18n("Domain:", nullptr));
        (void)Security8021x;
    } // retranslateUi

};

namespace Ui {
    class Security8021x: public Ui_Security8021x {};
} // namespace Ui

QT_END_NAMESPACE

#endif // _802_2D_1X_H

