/********************************************************************************
** Form generated from reading UI file 'openconnectprop.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENCONNECTPROP_H
#define UI_OPENCONNECTPROP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_OpenconnectProp
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *grp_general;
    QFormLayout *formLayout;
    QLabel *label_41;
    QLineEdit *leGateway;
    QLabel *label;
    KUrlRequester *leCaCertificate;
    QLabel *label_2;
    QLineEdit *leProxy;
    QLabel *label_3;
    QLineEdit *leUserAgent;
    QLabel *label_4;
    QCheckBox *chkAllowTrojan;
    KUrlRequester *leCsdWrapperScript;
    QLabel *label_7;
    QComboBox *cmbProtocol;
    QLabel *label_9;
    QComboBox *cmbReportedOs;
    QLineEdit *leVersionString;
    QLabel *label_8;
    QGroupBox *groupBox;
    QFormLayout *formLayout_2;
    QLabel *leMcaCertLabel;
    KUrlRequester *leMcaCert;
    QLabel *leMcaPrivateKeyLabel;
    KUrlRequester *leMcaPrivateKey;
    QLabel *label_5;
    KUrlRequester *leUserCert;
    QLabel *label_6;
    KUrlRequester *leUserPrivateKey;
    QCheckBox *chkUseFsid;
    QCheckBox *preventInvalidCert;
    QWidget *widget;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *buTokens;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OpenconnectProp)
    {
        if (OpenconnectProp->objectName().isEmpty())
            OpenconnectProp->setObjectName("OpenconnectProp");
        OpenconnectProp->resize(455, 634);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OpenconnectProp->sizePolicy().hasHeightForWidth());
        OpenconnectProp->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(OpenconnectProp);
        verticalLayout->setObjectName("verticalLayout");
        grp_general = new QGroupBox(OpenconnectProp);
        grp_general->setObjectName("grp_general");
        formLayout = new QFormLayout(grp_general);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout->setVerticalSpacing(6);
        label_41 = new QLabel(grp_general);
        label_41->setObjectName("label_41");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_41);

        leGateway = new QLineEdit(grp_general);
        leGateway->setObjectName("leGateway");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, leGateway);

        label = new QLabel(grp_general);
        label->setObjectName("label");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label);

        leCaCertificate = new KUrlRequester(grp_general);
        leCaCertificate->setObjectName("leCaCertificate");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, leCaCertificate);

        label_2 = new QLabel(grp_general);
        label_2->setObjectName("label_2");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_2);

        leProxy = new QLineEdit(grp_general);
        leProxy->setObjectName("leProxy");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, leProxy);

        label_3 = new QLabel(grp_general);
        label_3->setObjectName("label_3");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_3);

        leUserAgent = new QLineEdit(grp_general);
        leUserAgent->setObjectName("leUserAgent");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, leUserAgent);

        label_4 = new QLabel(grp_general);
        label_4->setObjectName("label_4");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_4);

        chkAllowTrojan = new QCheckBox(grp_general);
        chkAllowTrojan->setObjectName("chkAllowTrojan");

        formLayout->setWidget(7, QFormLayout::ItemRole::SpanningRole, chkAllowTrojan);

        leCsdWrapperScript = new KUrlRequester(grp_general);
        leCsdWrapperScript->setObjectName("leCsdWrapperScript");

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, leCsdWrapperScript);

        label_7 = new QLabel(grp_general);
        label_7->setObjectName("label_7");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_7);

        cmbProtocol = new QComboBox(grp_general);
        cmbProtocol->addItem(QString());
        cmbProtocol->addItem(QString());
        cmbProtocol->addItem(QString());
        cmbProtocol->addItem(QString());
        cmbProtocol->addItem(QString());
        cmbProtocol->addItem(QString());
        cmbProtocol->addItem(QString());
        cmbProtocol->setObjectName("cmbProtocol");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cmbProtocol->sizePolicy().hasHeightForWidth());
        cmbProtocol->setSizePolicy(sizePolicy1);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, cmbProtocol);

        label_9 = new QLabel(grp_general);
        label_9->setObjectName("label_9");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_9);

        cmbReportedOs = new QComboBox(grp_general);
        cmbReportedOs->addItem(QString());
        cmbReportedOs->addItem(QString());
        cmbReportedOs->addItem(QString());
        cmbReportedOs->addItem(QString());
        cmbReportedOs->addItem(QString());
        cmbReportedOs->addItem(QString());
        cmbReportedOs->addItem(QString());
        cmbReportedOs->setObjectName("cmbReportedOs");
        sizePolicy1.setHeightForWidth(cmbReportedOs->sizePolicy().hasHeightForWidth());
        cmbReportedOs->setSizePolicy(sizePolicy1);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, cmbReportedOs);

        leVersionString = new QLineEdit(grp_general);
        leVersionString->setObjectName("leVersionString");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, leVersionString);

        label_8 = new QLabel(grp_general);
        label_8->setObjectName("label_8");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_8);


        verticalLayout->addWidget(grp_general);

        groupBox = new QGroupBox(OpenconnectProp);
        groupBox->setObjectName("groupBox");
        formLayout_2 = new QFormLayout(groupBox);
        formLayout_2->setObjectName("formLayout_2");
        leMcaCertLabel = new QLabel(groupBox);
        leMcaCertLabel->setObjectName("leMcaCertLabel");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, leMcaCertLabel);

        leMcaCert = new KUrlRequester(groupBox);
        leMcaCert->setObjectName("leMcaCert");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, leMcaCert);

        leMcaPrivateKeyLabel = new QLabel(groupBox);
        leMcaPrivateKeyLabel->setObjectName("leMcaPrivateKeyLabel");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, leMcaPrivateKeyLabel);

        leMcaPrivateKey = new KUrlRequester(groupBox);
        leMcaPrivateKey->setObjectName("leMcaPrivateKey");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, leMcaPrivateKey);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_5);

        leUserCert = new KUrlRequester(groupBox);
        leUserCert->setObjectName("leUserCert");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, leUserCert);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_6);

        leUserPrivateKey = new KUrlRequester(groupBox);
        leUserPrivateKey->setObjectName("leUserPrivateKey");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, leUserPrivateKey);

        chkUseFsid = new QCheckBox(groupBox);
        chkUseFsid->setObjectName("chkUseFsid");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::SpanningRole, chkUseFsid);

        preventInvalidCert = new QCheckBox(groupBox);
        preventInvalidCert->setObjectName("preventInvalidCert");

        formLayout_2->setWidget(5, QFormLayout::ItemRole::SpanningRole, preventInvalidCert);


        verticalLayout->addWidget(groupBox);

        widget = new QWidget(OpenconnectProp);
        widget->setObjectName("widget");
        horizontalLayout = new QHBoxLayout(widget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(278, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        buTokens = new QPushButton(widget);
        buTokens->setObjectName("buTokens");

        horizontalLayout->addWidget(buTokens);


        verticalLayout->addWidget(widget);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label_41->setBuddy(leGateway);
        label->setBuddy(leCaCertificate);
        label_2->setBuddy(leProxy);
        label_3->setBuddy(leUserAgent);
        label_4->setBuddy(leCsdWrapperScript);
        label_7->setBuddy(cmbProtocol);
        leMcaCertLabel->setBuddy(leMcaCert);
        leMcaPrivateKeyLabel->setBuddy(leMcaPrivateKey);
        label_5->setBuddy(leUserCert);
        label_6->setBuddy(leUserPrivateKey);
#endif // QT_CONFIG(shortcut)

        retranslateUi(OpenconnectProp);

        QMetaObject::connectSlotsByName(OpenconnectProp);
    } // setupUi

    void retranslateUi(QWidget *OpenconnectProp)
    {
        OpenconnectProp->setWindowTitle(tr2i18n("OpenConnect Settings", nullptr));
        grp_general->setTitle(tr2i18n("General", "like in General settings"));
        label_41->setText(tr2i18n("Gateway:", nullptr));
        label->setText(tr2i18n("CA Certificate:", nullptr));
        leCaCertificate->setNameFilters(QStringList{
            tr2i18n("*.pem *.crt *.key", nullptr)});
        label_2->setText(tr2i18n("Proxy:", nullptr));
        label_3->setText(tr2i18n("User Agent:", nullptr));
        label_4->setText(tr2i18n("CSD Wrapper Script:", nullptr));
        chkAllowTrojan->setText(tr2i18n("Allow Cisco Secure Desktop trojan", nullptr));
        label_7->setText(tr2i18n("VPN Protocol:", nullptr));
        cmbProtocol->setItemText(0, tr2i18n("Cisco AnyConnect", nullptr));
        cmbProtocol->setItemText(1, tr2i18n("Juniper Network Connect", nullptr));
        cmbProtocol->setItemText(2, tr2i18n("PAN Global Protect", nullptr));
        cmbProtocol->setItemText(3, tr2i18n("Pulse Connect Secure", nullptr));
        cmbProtocol->setItemText(4, tr2i18n("F5 BIG-IP SSL VPN", nullptr));
        cmbProtocol->setItemText(5, tr2i18n("Fortinet SSL VPN", nullptr));
        cmbProtocol->setItemText(6, tr2i18n("Array SSL VPN", nullptr));

        label_9->setText(tr2i18n("Reported OS:", nullptr));
        cmbReportedOs->setItemText(0, QString());
        cmbReportedOs->setItemText(1, tr2i18n("GNU/Linux", nullptr));
        cmbReportedOs->setItemText(2, tr2i18n("GNU/Linux 64-bit", nullptr));
        cmbReportedOs->setItemText(3, tr2i18n("Windows", nullptr));
        cmbReportedOs->setItemText(4, tr2i18n("Mac OS X", nullptr));
        cmbReportedOs->setItemText(5, tr2i18n("Android", nullptr));
        cmbReportedOs->setItemText(6, tr2i18n("Apple iOS", nullptr));

        label_8->setText(tr2i18n("Reported Version", nullptr));
        groupBox->setTitle(tr2i18n("Certificate Authentication", nullptr));
        leMcaCertLabel->setText(tr2i18n("Machine Certificate:", nullptr));
        leMcaCert->setNameFilters(QStringList{
            tr2i18n("*.pem *.crt *.key", nullptr)});
        leMcaPrivateKeyLabel->setText(tr2i18n("Machine Private Key:", nullptr));
        leMcaPrivateKey->setNameFilters(QStringList{
            tr2i18n("*.pem *.crt *.key", nullptr)});
        label_5->setText(tr2i18n("User Certificate:", nullptr));
        leUserCert->setNameFilters(QStringList{
            tr2i18n("*.pem *.crt *.key", nullptr)});
        label_6->setText(tr2i18n("User Private Key:", nullptr));
        leUserPrivateKey->setNameFilters(QStringList{
            tr2i18n("*.pem *.crt *.key", nullptr)});
        chkUseFsid->setText(tr2i18n("Use FSID for key passphrase", nullptr));
        preventInvalidCert->setText(tr2i18n("Prevent user from manually accepting invalid certificates", nullptr));
        buTokens->setText(tr2i18n("Token Authentication", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpenconnectProp: public Ui_OpenconnectProp {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPENCONNECTPROP_H

