/********************************************************************************
** Form generated from reading UI file 'fortisslvpn.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FORTISSLVPN_H
#define UI_FORTISSLVPN_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_FortisslvpnWidget
{
public:
    QFormLayout *formLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *advancedButton;
    QSpacerItem *verticalSpacer;
    QGroupBox *generalGroupBox;
    QGridLayout *gridLayout_2;
    QGridLayout *gridLayout;
    QLabel *gatewayLabel;
    QLineEdit *gateway;
    QGroupBox *authenticationGroupBox;
    QFormLayout *formLayout_2;
    QLabel *usernameLabel;
    QLineEdit *username;
    QLabel *passwordLabel;
    PasswordField *password;
    QLabel *caCertLabel;
    KUrlRequester *caCert;
    QLabel *userCertLabel;
    KUrlRequester *userCert;
    QLabel *userKeyLabel;
    KUrlRequester *userKey;

    void setupUi(QWidget *FortisslvpnWidget)
    {
        if (FortisslvpnWidget->objectName().isEmpty())
            FortisslvpnWidget->setObjectName("FortisslvpnWidget");
        FortisslvpnWidget->resize(419, 390);
        formLayout = new QFormLayout(FortisslvpnWidget);
        formLayout->setObjectName("formLayout");
        horizontalSpacer = new QSpacerItem(314, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        formLayout->setItem(2, QFormLayout::ItemRole::LabelRole, horizontalSpacer);

        advancedButton = new QPushButton(FortisslvpnWidget);
        advancedButton->setObjectName("advancedButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(advancedButton->sizePolicy().hasHeightForWidth());
        advancedButton->setSizePolicy(sizePolicy);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, advancedButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(3, QFormLayout::ItemRole::FieldRole, verticalSpacer);

        generalGroupBox = new QGroupBox(FortisslvpnWidget);
        generalGroupBox->setObjectName("generalGroupBox");
        gridLayout_2 = new QGridLayout(generalGroupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gatewayLabel = new QLabel(generalGroupBox);
        gatewayLabel->setObjectName("gatewayLabel");
        gatewayLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(gatewayLabel, 0, 0, 1, 1);

        gateway = new QLineEdit(generalGroupBox);
        gateway->setObjectName("gateway");

        gridLayout->addWidget(gateway, 0, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 0, 0, 1, 1);


        formLayout->setWidget(0, QFormLayout::ItemRole::SpanningRole, generalGroupBox);

        authenticationGroupBox = new QGroupBox(FortisslvpnWidget);
        authenticationGroupBox->setObjectName("authenticationGroupBox");
        formLayout_2 = new QFormLayout(authenticationGroupBox);
        formLayout_2->setObjectName("formLayout_2");
        usernameLabel = new QLabel(authenticationGroupBox);
        usernameLabel->setObjectName("usernameLabel");
        usernameLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, usernameLabel);

        username = new QLineEdit(authenticationGroupBox);
        username->setObjectName("username");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, username);

        passwordLabel = new QLabel(authenticationGroupBox);
        passwordLabel->setObjectName("passwordLabel");
        passwordLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, passwordLabel);

        password = new PasswordField(authenticationGroupBox);
        password->setObjectName("password");
        password->setProperty("passwordModeEnabled", QVariant(true));

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, password);

        caCertLabel = new QLabel(authenticationGroupBox);
        caCertLabel->setObjectName("caCertLabel");
        caCertLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, caCertLabel);

        caCert = new KUrlRequester(authenticationGroupBox);
        caCert->setObjectName("caCert");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, caCert);

        userCertLabel = new QLabel(authenticationGroupBox);
        userCertLabel->setObjectName("userCertLabel");
        userCertLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, userCertLabel);

        userCert = new KUrlRequester(authenticationGroupBox);
        userCert->setObjectName("userCert");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, userCert);

        userKeyLabel = new QLabel(authenticationGroupBox);
        userKeyLabel->setObjectName("userKeyLabel");
        userKeyLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, userKeyLabel);

        userKey = new KUrlRequester(authenticationGroupBox);
        userKey->setObjectName("userKey");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, userKey);


        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, authenticationGroupBox);


        retranslateUi(FortisslvpnWidget);

        QMetaObject::connectSlotsByName(FortisslvpnWidget);
    } // setupUi

    void retranslateUi(QWidget *FortisslvpnWidget)
    {
        advancedButton->setText(tr2i18n("Advanced", nullptr));
        generalGroupBox->setTitle(tr2i18n("General", nullptr));
        gatewayLabel->setText(tr2i18n("Gateway:", nullptr));
#if QT_CONFIG(tooltip)
        gateway->setToolTip(tr2i18n("SSLVPN server IP or name.", nullptr));
#endif // QT_CONFIG(tooltip)
        authenticationGroupBox->setTitle(tr2i18n("Authentication", nullptr));
        usernameLabel->setText(tr2i18n("User name:", nullptr));
#if QT_CONFIG(tooltip)
        username->setToolTip(tr2i18n("Set the name used for authenticating the local system to the peer to <name>.", nullptr));
#endif // QT_CONFIG(tooltip)
        passwordLabel->setText(tr2i18n("Password:", nullptr));
#if QT_CONFIG(tooltip)
        password->setToolTip(tr2i18n("Password passed to SSLVPN when prompted for it.", nullptr));
#endif // QT_CONFIG(tooltip)
        caCertLabel->setText(tr2i18n("CA Certificate:", nullptr));
        userCertLabel->setText(tr2i18n("User Certificate:", nullptr));
        userKeyLabel->setText(tr2i18n("User Key:", nullptr));
        (void)FortisslvpnWidget;
    } // retranslateUi

};

namespace Ui {
    class FortisslvpnWidget: public Ui_FortisslvpnWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FORTISSLVPN_H

