/********************************************************************************
** Form generated from reading UI file 'pppoe.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PPPOE_H
#define UI_PPPOE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_PppoeWidget
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    KLineEdit *service;
    QLabel *label_2;
    KLineEdit *username;
    QLabel *label_3;
    PasswordField *password;

    void setupUi(QWidget *PppoeWidget)
    {
        if (PppoeWidget->objectName().isEmpty())
            PppoeWidget->setObjectName("PppoeWidget");
        PppoeWidget->resize(400, 300);
        formLayout = new QFormLayout(PppoeWidget);
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(6);
        label = new QLabel(PppoeWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        service = new KLineEdit(PppoeWidget);
        service->setObjectName("service");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, service);

        label_2 = new QLabel(PppoeWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        username = new KLineEdit(PppoeWidget);
        username->setObjectName("username");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, username);

        label_3 = new QLabel(PppoeWidget);
        label_3->setObjectName("label_3");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        password = new PasswordField(PppoeWidget);
        password->setObjectName("password");
        password->setPasswordModeEnabled(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, password);

#if QT_CONFIG(shortcut)
        label->setBuddy(service);
        label_2->setBuddy(username);
        label_3->setBuddy(password);
#endif // QT_CONFIG(shortcut)

        retranslateUi(PppoeWidget);

        QMetaObject::connectSlotsByName(PppoeWidget);
    } // setupUi

    void retranslateUi(QWidget *PppoeWidget)
    {
        label->setText(tr2i18n("Service:", nullptr));
#if QT_CONFIG(tooltip)
        service->setToolTip(tr2i18n("If specified, instruct PPPoE to only initiate sessions with access concentrators that provide the specified service. For most providers, this should be left blank. It is only required if there are multiple access concentrators or a specific service is known to be required.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Username:", nullptr));
        label_3->setText(tr2i18n("Password:", nullptr));
        (void)PppoeWidget;
    } // retranslateUi

};

namespace Ui {
    class PppoeWidget: public Ui_PppoeWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PPPOE_H

