/********************************************************************************
** Form generated from reading UI file 'pptpauth.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PPTPAUTH_H
#define UI_PPTPAUTH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_PptpAuthenticationWidget
{
public:
    QFormLayout *formLayout;
    QLabel *textLabel1;
    PasswordField *lePassword;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *PptpAuthenticationWidget)
    {
        if (PptpAuthenticationWidget->objectName().isEmpty())
            PptpAuthenticationWidget->setObjectName("PptpAuthenticationWidget");
        PptpAuthenticationWidget->resize(372, 85);
        formLayout = new QFormLayout(PptpAuthenticationWidget);
        formLayout->setSpacing(6);
        formLayout->setContentsMargins(11, 11, 11, 11);
        formLayout->setObjectName("formLayout");
        formLayout->setSizeConstraint(QLayout::SetMinimumSize);
        formLayout->setVerticalSpacing(0);
        formLayout->setContentsMargins(0, 0, 0, 0);
        textLabel1 = new QLabel(PptpAuthenticationWidget);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel1);

        lePassword = new PasswordField(PptpAuthenticationWidget);
        lePassword->setObjectName("lePassword");
        lePassword->setProperty("passwordModeEnabled", QVariant(true));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, lePassword);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(1, QFormLayout::ItemRole::FieldRole, verticalSpacer);

#if QT_CONFIG(shortcut)
        textLabel1->setBuddy(lePassword);
#endif // QT_CONFIG(shortcut)

        retranslateUi(PptpAuthenticationWidget);

        QMetaObject::connectSlotsByName(PptpAuthenticationWidget);
    } // setupUi

    void retranslateUi(QWidget *PptpAuthenticationWidget)
    {
        PptpAuthenticationWidget->setWindowTitle(tr2i18n("PPTPAuthentication", nullptr));
        textLabel1->setText(tr2i18n("Password:", nullptr));
#if QT_CONFIG(tooltip)
        lePassword->setToolTip(tr2i18n("Password passed to PPTP when prompted for it.", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class PptpAuthenticationWidget: public Ui_PptpAuthenticationWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PPTPAUTH_H

