/********************************************************************************
** Form generated from reading UI file 'wifisecurity.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIFISECURITY_H
#define UI_WIFISECURITY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_WifiSecurity
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    KComboBox *securityCombo;
    QLabel *label_2;
    PasswordField *wepKey;
    QLabel *label_3;
    KComboBox *wepIndex;
    QLabel *label_4;
    KComboBox *wepAuth;
    QLabel *label_8;
    KLineEdit *leapUsername;
    QLabel *label_9;
    PasswordField *leapPassword;
    QLabel *label_10;
    PasswordField *psk;

    void setupUi(QWidget *WifiSecurity)
    {
        if (WifiSecurity->objectName().isEmpty())
            WifiSecurity->setObjectName("WifiSecurity");
        WifiSecurity->resize(489, 374);
        formLayout = new QFormLayout(WifiSecurity);
        formLayout->setObjectName("formLayout");
        formLayout->setLabelAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        formLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(WifiSecurity);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        securityCombo = new KComboBox(WifiSecurity);
        securityCombo->addItem(QString());
        securityCombo->addItem(QString());
        securityCombo->addItem(QString());
        securityCombo->addItem(QString());
        securityCombo->addItem(QString());
        securityCombo->addItem(QString());
        securityCombo->addItem(QString());
        securityCombo->addItem(QString());
        securityCombo->addItem(QString());
        securityCombo->addItem(QString());
        securityCombo->setObjectName("securityCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(securityCombo->sizePolicy().hasHeightForWidth());
        securityCombo->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, securityCombo);

        label_2 = new QLabel(WifiSecurity);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        wepKey = new PasswordField(WifiSecurity);
        wepKey->setObjectName("wepKey");
        wepKey->setMaxLength(26);
        wepKey->setProperty("passwordModeEnabled", QVariant(true));

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, wepKey);

        label_3 = new QLabel(WifiSecurity);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        wepIndex = new KComboBox(WifiSecurity);
        wepIndex->addItem(QString());
        wepIndex->addItem(QString());
        wepIndex->addItem(QString());
        wepIndex->addItem(QString());
        wepIndex->setObjectName("wepIndex");
        sizePolicy.setHeightForWidth(wepIndex->sizePolicy().hasHeightForWidth());
        wepIndex->setSizePolicy(sizePolicy);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, wepIndex);

        label_4 = new QLabel(WifiSecurity);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_4);

        wepAuth = new KComboBox(WifiSecurity);
        wepAuth->addItem(QString());
        wepAuth->addItem(QString());
        wepAuth->setObjectName("wepAuth");
        sizePolicy.setHeightForWidth(wepAuth->sizePolicy().hasHeightForWidth());
        wepAuth->setSizePolicy(sizePolicy);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, wepAuth);

        label_8 = new QLabel(WifiSecurity);
        label_8->setObjectName("label_8");
        label_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_8);

        leapUsername = new KLineEdit(WifiSecurity);
        leapUsername->setObjectName("leapUsername");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, leapUsername);

        label_9 = new QLabel(WifiSecurity);
        label_9->setObjectName("label_9");
        label_9->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_9);

        leapPassword = new PasswordField(WifiSecurity);
        leapPassword->setObjectName("leapPassword");
        leapPassword->setProperty("passwordModeEnabled", QVariant(true));

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, leapPassword);

        label_10 = new QLabel(WifiSecurity);
        label_10->setObjectName("label_10");
        label_10->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_10);

        psk = new PasswordField(WifiSecurity);
        psk->setObjectName("psk");
        psk->setProperty("passwordModeEnabled", QVariant(true));

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, psk);

#if QT_CONFIG(shortcut)
        label->setBuddy(securityCombo);
        label_2->setBuddy(wepKey);
        label_3->setBuddy(wepIndex);
        label_4->setBuddy(wepAuth);
        label_8->setBuddy(leapUsername);
        label_9->setBuddy(leapPassword);
        label_10->setBuddy(psk);
#endif // QT_CONFIG(shortcut)

        retranslateUi(WifiSecurity);

        QMetaObject::connectSlotsByName(WifiSecurity);
    } // setupUi

    void retranslateUi(QWidget *WifiSecurity)
    {
        WifiSecurity->setWindowTitle(tr2i18n("Wifi Security", nullptr));
        label->setText(tr2i18n("Security:", nullptr));
        securityCombo->setItemText(0, tr2i18n("None", "no security"));
        securityCombo->setItemText(1, tr2i18n("WEP key 40/128 bits (Hex or ASCII)", nullptr));
        securityCombo->setItemText(2, tr2i18n("WEP key 128 bits", nullptr));
        securityCombo->setItemText(3, tr2i18n("LEAP", nullptr));
        securityCombo->setItemText(4, tr2i18n("Dynamic WEP (802.1x)", nullptr));
        securityCombo->setItemText(5, tr2i18n("WPA2/WPA3 Personal", nullptr));
        securityCombo->setItemText(6, tr2i18n("WPA2/WPA3 Enterprise", nullptr));
        securityCombo->setItemText(7, tr2i18n("WPA3 Personal", nullptr));
        securityCombo->setItemText(8, tr2i18n("WPA3 Enterprise 192-bit", nullptr));
        securityCombo->setItemText(9, tr2i18n("Enhanced Open (OWE)", nullptr));

        label_2->setText(tr2i18n("Key:", nullptr));
        label_3->setText(tr2i18n("WEP index:", nullptr));
        wepIndex->setItemText(0, tr2i18n("1 (default)", nullptr));
        wepIndex->setItemText(1, tr2i18n("2", nullptr));
        wepIndex->setItemText(2, tr2i18n("3", nullptr));
        wepIndex->setItemText(3, tr2i18n("4", nullptr));

        label_4->setText(tr2i18n("Authentication:", nullptr));
        wepAuth->setItemText(0, tr2i18n("Open System", nullptr));
        wepAuth->setItemText(1, tr2i18n("Shared Key", nullptr));

        label_8->setText(tr2i18n("Username:", nullptr));
        label_9->setText(tr2i18n("Password:", nullptr));
        label_10->setText(tr2i18n("Password:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class WifiSecurity: public Ui_WifiSecurity {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WIFISECURITY_H

