/********************************************************************************
** Form generated from reading UI file 'libreswan.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LIBRESWAN_H
#define UI_LIBRESWAN_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_LibreswanWidget
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QLineEdit *gateway;
    QLabel *label_2;
    QLineEdit *groupname;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout;
    PasswordField *userPassword;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_2;
    PasswordField *groupPassword;
    QSpacerItem *verticalSpacer;
    QLabel *label_3;
    QLineEdit *username;
    QLabel *label_6;
    QLineEdit *phase1;
    QLabel *label_7;
    QLineEdit *phase2;
    QLabel *label_8;
    QLineEdit *domain;

    void setupUi(QWidget *LibreswanWidget)
    {
        if (LibreswanWidget->objectName().isEmpty())
            LibreswanWidget->setObjectName("LibreswanWidget");
        LibreswanWidget->resize(446, 300);
        formLayout = new QFormLayout(LibreswanWidget);
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(6);
        label = new QLabel(LibreswanWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        gateway = new QLineEdit(LibreswanWidget);
        gateway->setObjectName("gateway");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, gateway);

        label_2 = new QLabel(LibreswanWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        groupname = new QLineEdit(LibreswanWidget);
        groupname->setObjectName("groupname");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, groupname);

        label_4 = new QLabel(LibreswanWidget);
        label_4->setObjectName("label_4");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_4);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        userPassword = new PasswordField(LibreswanWidget);
        userPassword->setObjectName("userPassword");
        userPassword->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout->addWidget(userPassword);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_5 = new QLabel(LibreswanWidget);
        label_5->setObjectName("label_5");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_5);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        groupPassword = new PasswordField(LibreswanWidget);
        groupPassword->setObjectName("groupPassword");
        groupPassword->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_2->addWidget(groupPassword);


        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 28, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(4, QFormLayout::ItemRole::FieldRole, verticalSpacer);

        label_3 = new QLabel(LibreswanWidget);
        label_3->setObjectName("label_3");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_3);

        username = new QLineEdit(LibreswanWidget);
        username->setObjectName("username");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, username);

        label_6 = new QLabel(LibreswanWidget);
        label_6->setObjectName("label_6");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_6);

        phase1 = new QLineEdit(LibreswanWidget);
        phase1->setObjectName("phase1");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, phase1);

        label_7 = new QLabel(LibreswanWidget);
        label_7->setObjectName("label_7");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_7);

        phase2 = new QLineEdit(LibreswanWidget);
        phase2->setObjectName("phase2");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, phase2);

        label_8 = new QLabel(LibreswanWidget);
        label_8->setObjectName("label_8");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_8);

        domain = new QLineEdit(LibreswanWidget);
        domain->setObjectName("domain");

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, domain);

        QWidget::setTabOrder(gateway, groupname);
        QWidget::setTabOrder(groupname, userPassword);
        QWidget::setTabOrder(userPassword, groupPassword);
        QWidget::setTabOrder(groupPassword, username);
        QWidget::setTabOrder(username, phase1);
        QWidget::setTabOrder(phase1, phase2);
        QWidget::setTabOrder(phase2, domain);

        retranslateUi(LibreswanWidget);

        QMetaObject::connectSlotsByName(LibreswanWidget);
    } // setupUi

    void retranslateUi(QWidget *LibreswanWidget)
    {
        label->setText(tr2i18n("Gateway:", nullptr));
        label_2->setText(tr2i18n("Group name:", nullptr));
        label_4->setText(tr2i18n("User password:", nullptr));
        label_5->setText(tr2i18n("Group password:", nullptr));
        label_3->setText(tr2i18n("User name:", nullptr));
        label_6->setText(tr2i18n("Phase1 algorithms:", nullptr));
        label_7->setText(tr2i18n("Phase2 algorithms:", nullptr));
        label_8->setText(tr2i18n("Domain:", nullptr));
        (void)LibreswanWidget;
    } // retranslateUi

};

namespace Ui {
    class LibreswanWidget: public Ui_LibreswanWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LIBRESWAN_H

