/********************************************************************************
** Form generated from reading UI file 'vlan.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VLAN_H
#define UI_VLAN_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_VlanWidget
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    KComboBox *parent;
    QLabel *label_2;
    QSpinBox *id;
    QLabel *label_3;
    KLineEdit *ifaceName;
    QCheckBox *reorderHeaders;
    QCheckBox *gvrp;
    QCheckBox *looseBinding;

    void setupUi(QWidget *VlanWidget)
    {
        if (VlanWidget->objectName().isEmpty())
            VlanWidget->setObjectName("VlanWidget");
        VlanWidget->resize(412, 193);
        formLayout = new QFormLayout(VlanWidget);
        formLayout->setObjectName("formLayout");
        label = new QLabel(VlanWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        parent = new KComboBox(VlanWidget);
        parent->setObjectName("parent");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(parent->sizePolicy().hasHeightForWidth());
        parent->setSizePolicy(sizePolicy);
        parent->setEditable(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, parent);

        label_2 = new QLabel(VlanWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        id = new QSpinBox(VlanWidget);
        id->setObjectName("id");
        sizePolicy.setHeightForWidth(id->sizePolicy().hasHeightForWidth());
        id->setSizePolicy(sizePolicy);
        id->setMaximum(999999999);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, id);

        label_3 = new QLabel(VlanWidget);
        label_3->setObjectName("label_3");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        ifaceName = new KLineEdit(VlanWidget);
        ifaceName->setObjectName("ifaceName");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, ifaceName);

        reorderHeaders = new QCheckBox(VlanWidget);
        reorderHeaders->setObjectName("reorderHeaders");

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, reorderHeaders);

        gvrp = new QCheckBox(VlanWidget);
        gvrp->setObjectName("gvrp");

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, gvrp);

        looseBinding = new QCheckBox(VlanWidget);
        looseBinding->setObjectName("looseBinding");

        formLayout->setWidget(5, QFormLayout::ItemRole::SpanningRole, looseBinding);

#if QT_CONFIG(shortcut)
        label->setBuddy(parent);
        label_2->setBuddy(id);
        label_3->setBuddy(ifaceName);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(parent, id);
        QWidget::setTabOrder(id, ifaceName);

        retranslateUi(VlanWidget);

        QMetaObject::connectSlotsByName(VlanWidget);
    } // setupUi

    void retranslateUi(QWidget *VlanWidget)
    {
        label->setText(tr2i18n("Parent interface:", nullptr));
        label_2->setText(tr2i18n("VLAN id:", nullptr));
        label_3->setText(tr2i18n("VLAN interface name:", nullptr));
        reorderHeaders->setText(tr2i18n("Output packet headers reordering", nullptr));
#if QT_CONFIG(tooltip)
        gvrp->setToolTip(tr2i18n("GARP VLAN Registration Protocol", nullptr));
#endif // QT_CONFIG(tooltip)
        gvrp->setText(tr2i18n("GVRP", nullptr));
        looseBinding->setText(tr2i18n("Loose binding", nullptr));
        (void)VlanWidget;
    } // retranslateUi

};

namespace Ui {
    class VlanWidget: public Ui_VlanWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VLAN_H

