/****************************************************************************
** Meta object code from reading C++ file 'openconnectauthworkerthread.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-nm-6.7.4/vpn/openconnect/openconnectauthworkerthread.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'openconnectauthworkerthread.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN27OpenconnectAuthWorkerThreadE_t {};
} // unnamed namespace

template <> constexpr inline auto OpenconnectAuthWorkerThread::qt_create_metaobjectdata<qt_meta_tag_ZN27OpenconnectAuthWorkerThreadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OpenconnectAuthWorkerThread",
        "validatePeerCert",
        "",
        "bool*",
        "processAuthForm",
        "oc_auth_form*",
        "updateLog",
        "writeNewConfig",
        "cookieObtained",
        "initTokens",
        "openWebEngine",
        "const char*",
        "QSemaphore*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'validatePeerCert'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, bool *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { 0x80000000 | 3, 2 },
        }}),
        // Signal 'processAuthForm'
        QtMocHelpers::SignalData<void(oc_auth_form *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'updateLog'
        QtMocHelpers::SignalData<void(const QString &, const int &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'writeNewConfig'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'cookieObtained'
        QtMocHelpers::SignalData<void(const int &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'initTokens'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openWebEngine'
        QtMocHelpers::SignalData<void(const char *, QSemaphore *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 }, { 0x80000000 | 12, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OpenconnectAuthWorkerThread, qt_meta_tag_ZN27OpenconnectAuthWorkerThreadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OpenconnectAuthWorkerThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27OpenconnectAuthWorkerThreadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27OpenconnectAuthWorkerThreadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27OpenconnectAuthWorkerThreadE_t>.metaTypes,
    nullptr
} };

void OpenconnectAuthWorkerThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OpenconnectAuthWorkerThread *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->validatePeerCert((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[4]))); break;
        case 1: _t->processAuthForm((*reinterpret_cast<std::add_pointer_t<oc_auth_form*>>(_a[1]))); break;
        case 2: _t->updateLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->writeNewConfig((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->cookieObtained((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->initTokens(); break;
        case 6: _t->openWebEngine((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSemaphore*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OpenconnectAuthWorkerThread::*)(const QString & , const QString & , const QString & , bool * )>(_a, &OpenconnectAuthWorkerThread::validatePeerCert, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OpenconnectAuthWorkerThread::*)(oc_auth_form * )>(_a, &OpenconnectAuthWorkerThread::processAuthForm, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OpenconnectAuthWorkerThread::*)(const QString & , const int & )>(_a, &OpenconnectAuthWorkerThread::updateLog, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OpenconnectAuthWorkerThread::*)(const QString & )>(_a, &OpenconnectAuthWorkerThread::writeNewConfig, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OpenconnectAuthWorkerThread::*)(const int & )>(_a, &OpenconnectAuthWorkerThread::cookieObtained, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OpenconnectAuthWorkerThread::*)()>(_a, &OpenconnectAuthWorkerThread::initTokens, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OpenconnectAuthWorkerThread::*)(const char * , QSemaphore * )>(_a, &OpenconnectAuthWorkerThread::openWebEngine, 6))
            return;
    }
}

const QMetaObject *OpenconnectAuthWorkerThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenconnectAuthWorkerThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27OpenconnectAuthWorkerThreadE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int OpenconnectAuthWorkerThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void OpenconnectAuthWorkerThread::validatePeerCert(const QString & _t1, const QString & _t2, const QString & _t3, bool * _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void OpenconnectAuthWorkerThread::processAuthForm(oc_auth_form * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void OpenconnectAuthWorkerThread::updateLog(const QString & _t1, const int & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void OpenconnectAuthWorkerThread::writeNewConfig(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OpenconnectAuthWorkerThread::cookieObtained(const int & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void OpenconnectAuthWorkerThread::initTokens()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void OpenconnectAuthWorkerThread::openWebEngine(const char * _t1, QSemaphore * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}
QT_WARNING_POP
