/********************************************************************************
** Form generated from reading UI file 'connectioneditortabwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONNECTIONEDITORTABWIDGET_H
#define UI_CONNECTIONEDITORTABWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ConnectionEditorTabWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *connectionName;
    QTabWidget *tabWidget;

    void setupUi(QWidget *ConnectionEditorTabWidget)
    {
        if (ConnectionEditorTabWidget->objectName().isEmpty())
            ConnectionEditorTabWidget->setObjectName("ConnectionEditorTabWidget");
        ConnectionEditorTabWidget->resize(498, 427);
        gridLayout = new QGridLayout(ConnectionEditorTabWidget);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(ConnectionEditorTabWidget);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        connectionName = new QLineEdit(ConnectionEditorTabWidget);
        connectionName->setObjectName("connectionName");

        gridLayout->addWidget(connectionName, 0, 1, 1, 1);

        tabWidget = new QTabWidget(ConnectionEditorTabWidget);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setElideMode(Qt::ElideRight);

        gridLayout->addWidget(tabWidget, 1, 0, 1, 2);

#if QT_CONFIG(shortcut)
        label->setBuddy(connectionName);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ConnectionEditorTabWidget);

        tabWidget->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(ConnectionEditorTabWidget);
    } // setupUi

    void retranslateUi(QWidget *ConnectionEditorTabWidget)
    {
        label->setText(tr2i18n("Connection name:", nullptr));
        (void)ConnectionEditorTabWidget;
    } // retranslateUi

};

namespace Ui {
    class ConnectionEditorTabWidget: public Ui_ConnectionEditorTabWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONNECTIONEDITORTABWIDGET_H

