/********************************************************************************
** Form generated from reading UI file 'bond.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BOND_H
#define UI_BOND_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_BondWidget
{
public:
    QFormLayout *formLayout_2;
    QLabel *label;
    KLineEdit *ifaceName;
    QLabel *label_2;
    QGridLayout *gridLayout;
    QListWidget *bonds;
    QPushButton *btnAdd;
    QPushButton *btnEdit;
    QPushButton *btnDelete;
    QSpacerItem *verticalSpacer;
    QLabel *label_3;
    KComboBox *mode;
    QLabel *label_4;
    KComboBox *linkMonitoring;
    QLabel *label_5;
    QSpinBox *monitorFreq;
    QStackedWidget *monitorStack;
    QWidget *miiPage;
    QFormLayout *formLayout;
    QLabel *label_6;
    QSpinBox *upDelay;
    QLabel *label_7;
    QSpinBox *downDelay;
    QWidget *arpPage;
    QFormLayout *formLayout_3;
    QLabel *label_8;
    KLineEdit *arpTargets;

    void setupUi(QWidget *BondWidget)
    {
        if (BondWidget->objectName().isEmpty())
            BondWidget->setObjectName("BondWidget");
        BondWidget->resize(473, 417);
        formLayout_2 = new QFormLayout(BondWidget);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setVerticalSpacing(6);
        label = new QLabel(BondWidget);
        label->setObjectName("label");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        ifaceName = new KLineEdit(BondWidget);
        ifaceName->setObjectName("ifaceName");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, ifaceName);

        label_2 = new QLabel(BondWidget);
        label_2->setObjectName("label_2");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        bonds = new QListWidget(BondWidget);
        bonds->setObjectName("bonds");
        bonds->setEditTriggers(QAbstractItemView::NoEditTriggers);
        bonds->setAlternatingRowColors(true);
        bonds->setUniformItemSizes(true);

        gridLayout->addWidget(bonds, 0, 0, 4, 1);

        btnAdd = new QPushButton(BondWidget);
        btnAdd->setObjectName("btnAdd");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        btnAdd->setIcon(icon);

        gridLayout->addWidget(btnAdd, 0, 1, 1, 1);

        btnEdit = new QPushButton(BondWidget);
        btnEdit->setObjectName("btnEdit");
        btnEdit->setEnabled(false);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("configure")));
        btnEdit->setIcon(icon1);

        gridLayout->addWidget(btnEdit, 1, 1, 1, 1);

        btnDelete = new QPushButton(BondWidget);
        btnDelete->setObjectName("btnDelete");
        btnDelete->setEnabled(false);
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        btnDelete->setIcon(icon2);

        gridLayout->addWidget(btnDelete, 2, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 1, 1, 1);


        formLayout_2->setLayout(2, QFormLayout::ItemRole::SpanningRole, gridLayout);

        label_3 = new QLabel(BondWidget);
        label_3->setObjectName("label_3");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_3);

        mode = new KComboBox(BondWidget);
        mode->setObjectName("mode");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mode->sizePolicy().hasHeightForWidth());
        mode->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, mode);

        label_4 = new QLabel(BondWidget);
        label_4->setObjectName("label_4");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, label_4);

        linkMonitoring = new KComboBox(BondWidget);
        linkMonitoring->setObjectName("linkMonitoring");
        sizePolicy.setHeightForWidth(linkMonitoring->sizePolicy().hasHeightForWidth());
        linkMonitoring->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, linkMonitoring);

        label_5 = new QLabel(BondWidget);
        label_5->setObjectName("label_5");

        formLayout_2->setWidget(5, QFormLayout::ItemRole::LabelRole, label_5);

        monitorFreq = new QSpinBox(BondWidget);
        monitorFreq->setObjectName("monitorFreq");
        monitorFreq->setMinimum(1);
        monitorFreq->setMaximum(999999999);
        monitorFreq->setValue(100);

        formLayout_2->setWidget(5, QFormLayout::ItemRole::FieldRole, monitorFreq);

        monitorStack = new QStackedWidget(BondWidget);
        monitorStack->setObjectName("monitorStack");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(monitorStack->sizePolicy().hasHeightForWidth());
        monitorStack->setSizePolicy(sizePolicy1);
        miiPage = new QWidget();
        miiPage->setObjectName("miiPage");
        formLayout = new QFormLayout(miiPage);
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(6);
        label_6 = new QLabel(miiPage);
        label_6->setObjectName("label_6");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_6);

        upDelay = new QSpinBox(miiPage);
        upDelay->setObjectName("upDelay");
        upDelay->setMaximum(999999999);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, upDelay);

        label_7 = new QLabel(miiPage);
        label_7->setObjectName("label_7");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_7);

        downDelay = new QSpinBox(miiPage);
        downDelay->setObjectName("downDelay");
        downDelay->setMaximum(999999999);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, downDelay);

        monitorStack->addWidget(miiPage);
        arpPage = new QWidget();
        arpPage->setObjectName("arpPage");
        formLayout_3 = new QFormLayout(arpPage);
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setVerticalSpacing(0);
        label_8 = new QLabel(arpPage);
        label_8->setObjectName("label_8");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_8);

        arpTargets = new KLineEdit(arpPage);
        arpTargets->setObjectName("arpTargets");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, arpTargets);

        monitorStack->addWidget(arpPage);

        formLayout_2->setWidget(6, QFormLayout::ItemRole::SpanningRole, monitorStack);

#if QT_CONFIG(shortcut)
        label->setBuddy(ifaceName);
        label_2->setBuddy(bonds);
        label_3->setBuddy(mode);
        label_4->setBuddy(linkMonitoring);
        label_5->setBuddy(monitorFreq);
        label_6->setBuddy(upDelay);
        label_7->setBuddy(downDelay);
        label_8->setBuddy(arpTargets);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(ifaceName, bonds);
        QWidget::setTabOrder(bonds, btnAdd);
        QWidget::setTabOrder(btnAdd, btnEdit);
        QWidget::setTabOrder(btnEdit, btnDelete);
        QWidget::setTabOrder(btnDelete, mode);
        QWidget::setTabOrder(mode, linkMonitoring);
        QWidget::setTabOrder(linkMonitoring, monitorFreq);
        QWidget::setTabOrder(monitorFreq, upDelay);
        QWidget::setTabOrder(upDelay, downDelay);
        QWidget::setTabOrder(downDelay, arpTargets);

        retranslateUi(BondWidget);
        QObject::connect(linkMonitoring, SIGNAL(currentIndexChanged(int)), monitorStack, SLOT(setCurrentIndex(int)));

        monitorStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(BondWidget);
    } // setupUi

    void retranslateUi(QWidget *BondWidget)
    {
        label->setText(tr2i18n("Interface name:", nullptr));
        label_2->setText(tr2i18n("Bonded connections:", nullptr));
        btnAdd->setText(tr2i18n("Add\342\200\246", nullptr));
        btnEdit->setText(tr2i18n("Edit\342\200\246", nullptr));
        btnDelete->setText(tr2i18n("Delete", nullptr));
        label_3->setText(tr2i18n("Mode:", nullptr));
        label_4->setText(tr2i18n("Link monitoring:", nullptr));
        label_5->setText(tr2i18n("Monitoring frequency:", nullptr));
        monitorFreq->setSuffix(tr2i18n(" ms", nullptr));
        label_6->setText(tr2i18n("Link up delay:", nullptr));
        upDelay->setSuffix(tr2i18n(" ms", nullptr));
        label_7->setText(tr2i18n("Link down delay:", nullptr));
        downDelay->setSuffix(tr2i18n(" ms", nullptr));
        label_8->setText(tr2i18n("ARP targets:", nullptr));
#if QT_CONFIG(tooltip)
        arpTargets->setToolTip(tr2i18n("An IP address or comma-separated list of addresses.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)BondWidget;
    } // retranslateUi

};

namespace Ui {
    class BondWidget: public Ui_BondWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BOND_H

