// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "plasma_nm_openconnect.h"


Q_LOGGING_CATEGORY(PLASMA_NM_OPENCONNECT_LOG, "org.kde.plasma.nm.openconnect", QtInfoMsg)

