/********************************************************************************
** Form generated from reading UI file 'advancedpermissionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADVANCEDPERMISSIONSWIDGET_H
#define UI_ADVANCEDPERMISSIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_AdvancedPermissions
{
public:
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QTreeWidget *availUsers;
    QVBoxLayout *verticalLayout_3;
    QSpacerItem *verticalSpacer;
    QPushButton *arrowRight;
    QPushButton *arrowLeft;
    QSpacerItem *verticalSpacer_2;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_2;
    QTreeWidget *currentUsers;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AdvancedPermissions)
    {
        if (AdvancedPermissions->objectName().isEmpty())
            AdvancedPermissions->setObjectName("AdvancedPermissions");
        AdvancedPermissions->resize(654, 349);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(AdvancedPermissions->sizePolicy().hasHeightForWidth());
        AdvancedPermissions->setSizePolicy(sizePolicy);
        AdvancedPermissions->setMinimumSize(QSize(0, 0));
        verticalLayout_4 = new QVBoxLayout(AdvancedPermissions);
        verticalLayout_4->setObjectName("verticalLayout_4");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(AdvancedPermissions);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        availUsers = new QTreeWidget(AdvancedPermissions);
        availUsers->setObjectName("availUsers");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(availUsers->sizePolicy().hasHeightForWidth());
        availUsers->setSizePolicy(sizePolicy1);
        availUsers->setMinimumSize(QSize(100, 80));
        availUsers->setEditTriggers(QAbstractItemView::NoEditTriggers);
        availUsers->setProperty("showDropIndicator", QVariant(false));
        availUsers->setAlternatingRowColors(true);
        availUsers->setSelectionMode(QAbstractItemView::ExtendedSelection);
        availUsers->setRootIsDecorated(false);
        availUsers->setUniformRowHeights(true);
        availUsers->setItemsExpandable(false);
        availUsers->setAllColumnsShowFocus(true);
        availUsers->setColumnCount(2);
        availUsers->header()->setDefaultSectionSize(100);

        verticalLayout->addWidget(availUsers);


        horizontalLayout->addLayout(verticalLayout);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        arrowRight = new QPushButton(AdvancedPermissions);
        arrowRight->setObjectName("arrowRight");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(arrowRight->sizePolicy().hasHeightForWidth());
        arrowRight->setSizePolicy(sizePolicy2);
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("arrow-right");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8(""), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        arrowRight->setIcon(icon);

        verticalLayout_3->addWidget(arrowRight);

        arrowLeft = new QPushButton(AdvancedPermissions);
        arrowLeft->setObjectName("arrowLeft");
        sizePolicy2.setHeightForWidth(arrowLeft->sizePolicy().hasHeightForWidth());
        arrowLeft->setSizePolicy(sizePolicy2);
        QIcon icon1;
        iconThemeName = QString::fromUtf8("arrow-left");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8(""), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        arrowLeft->setIcon(icon1);

        verticalLayout_3->addWidget(arrowLeft);

        verticalSpacer_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);


        horizontalLayout->addLayout(verticalLayout_3);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_2 = new QLabel(AdvancedPermissions);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        verticalLayout_2->addWidget(label_2);

        currentUsers = new QTreeWidget(AdvancedPermissions);
        currentUsers->setObjectName("currentUsers");
        sizePolicy1.setHeightForWidth(currentUsers->sizePolicy().hasHeightForWidth());
        currentUsers->setSizePolicy(sizePolicy1);
        currentUsers->setMinimumSize(QSize(100, 80));
        currentUsers->setEditTriggers(QAbstractItemView::NoEditTriggers);
        currentUsers->setProperty("showDropIndicator", QVariant(false));
        currentUsers->setAlternatingRowColors(true);
        currentUsers->setSelectionMode(QAbstractItemView::ExtendedSelection);
        currentUsers->setRootIsDecorated(false);
        currentUsers->setUniformRowHeights(true);
        currentUsers->setItemsExpandable(false);
        currentUsers->setAllColumnsShowFocus(true);
        currentUsers->setColumnCount(2);
        currentUsers->header()->setDefaultSectionSize(100);

        verticalLayout_2->addWidget(currentUsers);


        horizontalLayout->addLayout(verticalLayout_2);


        verticalLayout_4->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(AdvancedPermissions);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_4->addWidget(buttonBox);


        retranslateUi(AdvancedPermissions);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AdvancedPermissions, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AdvancedPermissions, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AdvancedPermissions);
    } // setupUi

    void retranslateUi(QDialog *AdvancedPermissions)
    {
        label->setText(tr2i18n("Available Users", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = availUsers->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Username", "like in Username for athentication"));
        ___qtreewidgetitem->setText(0, tr2i18n("Real Name", nullptr));
        label_2->setText(tr2i18n("Users allowed to activate the connection", nullptr));
        QTreeWidgetItem *___qtreewidgetitem1 = currentUsers->headerItem();
        ___qtreewidgetitem1->setText(1, tr2i18n("Username", "like in Username for athentication"));
        ___qtreewidgetitem1->setText(0, tr2i18n("Real Name", nullptr));
        (void)AdvancedPermissions;
    } // retranslateUi

};

namespace Ui {
    class AdvancedPermissions: public Ui_AdvancedPermissions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ADVANCEDPERMISSIONSWIDGET_H

