/********************************************************************************
** Form generated from reading UI file 'connectionwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONNECTIONWIDGET_H
#define UI_CONNECTIONWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ConnectionWidget
{
public:
    QFormLayout *formLayout;
    QCheckBox *autoconnect;
    QSpinBox *prioritySpin;
    QCheckBox *allUsers;
    QPushButton *pushButtonPermissions;
    QCheckBox *autoconnectVpn;
    KComboBox *vpnCombobox;
    QLabel *firewallZoneLabel;
    KComboBox *firewallZone;
    QLabel *meteredLabel;
    KComboBox *metered;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ConnectionWidget)
    {
        if (ConnectionWidget->objectName().isEmpty())
            ConnectionWidget->setObjectName("ConnectionWidget");
        ConnectionWidget->resize(471, 262);
        formLayout = new QFormLayout(ConnectionWidget);
        formLayout->setObjectName("formLayout");
        autoconnect = new QCheckBox(ConnectionWidget);
        autoconnect->setObjectName("autoconnect");
        autoconnect->setChecked(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, autoconnect);

        prioritySpin = new QSpinBox(ConnectionWidget);
        prioritySpin->setObjectName("prioritySpin");
        prioritySpin->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(prioritySpin->sizePolicy().hasHeightForWidth());
        prioritySpin->setSizePolicy(sizePolicy);
        prioritySpin->setMinimum(-100);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, prioritySpin);

        allUsers = new QCheckBox(ConnectionWidget);
        allUsers->setObjectName("allUsers");
        allUsers->setChecked(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, allUsers);

        pushButtonPermissions = new QPushButton(ConnectionWidget);
        pushButtonPermissions->setObjectName("pushButtonPermissions");
        sizePolicy.setHeightForWidth(pushButtonPermissions->sizePolicy().hasHeightForWidth());
        pushButtonPermissions->setSizePolicy(sizePolicy);
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("preferences-desktop-user")));
        pushButtonPermissions->setIcon(icon);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, pushButtonPermissions);

        autoconnectVpn = new QCheckBox(ConnectionWidget);
        autoconnectVpn->setObjectName("autoconnectVpn");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, autoconnectVpn);

        vpnCombobox = new KComboBox(ConnectionWidget);
        vpnCombobox->setObjectName("vpnCombobox");
        vpnCombobox->setEnabled(false);
        sizePolicy.setHeightForWidth(vpnCombobox->sizePolicy().hasHeightForWidth());
        vpnCombobox->setSizePolicy(sizePolicy);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, vpnCombobox);

        firewallZoneLabel = new QLabel(ConnectionWidget);
        firewallZoneLabel->setObjectName("firewallZoneLabel");
        firewallZoneLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, firewallZoneLabel);

        firewallZone = new KComboBox(ConnectionWidget);
        firewallZone->setObjectName("firewallZone");
        sizePolicy.setHeightForWidth(firewallZone->sizePolicy().hasHeightForWidth());
        firewallZone->setSizePolicy(sizePolicy);
        firewallZone->setEditable(true);
        firewallZone->setInsertPolicy(QComboBox::InsertAlphabetically);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, firewallZone);

        meteredLabel = new QLabel(ConnectionWidget);
        meteredLabel->setObjectName("meteredLabel");
        meteredLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, meteredLabel);

        metered = new KComboBox(ConnectionWidget);
        metered->addItem(QString());
        metered->addItem(QString());
        metered->addItem(QString());
        metered->setObjectName("metered");
        sizePolicy.setHeightForWidth(metered->sizePolicy().hasHeightForWidth());
        metered->setSizePolicy(sizePolicy);
        metered->setEditable(false);
        metered->setInsertPolicy(QComboBox::InsertAlphabetically);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, metered);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(5, QFormLayout::ItemRole::LabelRole, verticalSpacer);

#if QT_CONFIG(shortcut)
        firewallZoneLabel->setBuddy(firewallZone);
        meteredLabel->setBuddy(firewallZone);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(autoconnect, allUsers);
        QWidget::setTabOrder(allUsers, pushButtonPermissions);
        QWidget::setTabOrder(pushButtonPermissions, autoconnectVpn);
        QWidget::setTabOrder(autoconnectVpn, vpnCombobox);
        QWidget::setTabOrder(vpnCombobox, firewallZone);

        retranslateUi(ConnectionWidget);
        QObject::connect(allUsers, &QCheckBox::toggled, pushButtonPermissions, &QPushButton::setDisabled);
        QObject::connect(autoconnect, &QCheckBox::toggled, prioritySpin, &QSpinBox::setEnabled);

        QMetaObject::connectSlotsByName(ConnectionWidget);
    } // setupUi

    void retranslateUi(QWidget *ConnectionWidget)
    {
        autoconnect->setText(tr2i18n("Connect automatically with priority", nullptr));
#if QT_CONFIG(tooltip)
        prioritySpin->setToolTip(tr2i18n("If the connection is set to autoconnect, connections with higher priority will be preferred. Defaults to 0.\n"
"The higher number means higher priority. A negative number can be used to indicate priority lower than the default.", nullptr));
#endif // QT_CONFIG(tooltip)
        allUsers->setText(tr2i18n("All users may connect to this network", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonPermissions->setToolTip(tr2i18n("Edit advanced permissions for this connection", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        pushButtonPermissions->setWhatsThis(tr2i18n("Fine-grained permissions editor for this connection. It lets you choose which users can activate/modify/delete this connection.", nullptr));
#endif // QT_CONFIG(whatsthis)
        pushButtonPermissions->setText(tr2i18n("Advanced\342\200\246", nullptr));
        autoconnectVpn->setText(tr2i18n("Automatically connect to VPN", nullptr));
#if QT_CONFIG(tooltip)
        vpnCombobox->setToolTip(tr2i18n("Choose which VPN connection to automatically activate when this connection is established", nullptr));
#endif // QT_CONFIG(tooltip)
        firewallZoneLabel->setText(tr2i18n("Firewall zone:", nullptr));
#if QT_CONFIG(tooltip)
        firewallZone->setToolTip(tr2i18n("Assign this connection to a firewall zone to control network access and security rules", nullptr));
#endif // QT_CONFIG(tooltip)
        meteredLabel->setText(tr2i18n("Metered:", nullptr));
        metered->setItemText(0, tr2i18n("Automatic", "Item in the Metered: list"));
        metered->setItemText(1, tr2i18n("Yes", nullptr));
        metered->setItemText(2, tr2i18n("No", nullptr));

#if QT_CONFIG(tooltip)
        metered->setToolTip(tr2i18n("Indicates to applications whether the connection is metered and therefore\n"
"data usage should be restricted.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)ConnectionWidget;
    } // retranslateUi

};

namespace Ui {
    class ConnectionWidget: public Ui_ConnectionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONNECTIONWIDGET_H

