/********************************************************************************
** Form generated from reading UI file 'pptpprop.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PPTPPROP_H
#define UI_PPTPPROP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_PptpProp
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *grp_general;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout_3;
    QLabel *lbl_gateway;
    QLineEdit *edt_gateway;
    QGroupBox *grp_additional;
    QFormLayout *formLayout;
    QLabel *lbl_login;
    QLineEdit *edt_login;
    QLabel *lbl_password;
    PasswordField *edt_password;
    QLabel *lbl_ntdomain;
    QLineEdit *edt_ntDomain;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *btnAdvanced;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *PptpProp)
    {
        if (PptpProp->objectName().isEmpty())
            PptpProp->setObjectName("PptpProp");
        PptpProp->resize(361, 341);
        verticalLayout_2 = new QVBoxLayout(PptpProp);
        verticalLayout_2->setObjectName("verticalLayout_2");
        grp_general = new QGroupBox(PptpProp);
        grp_general->setObjectName("grp_general");
        grp_general->setMaximumSize(QSize(16777215, 100));
        gridLayout_3 = new QGridLayout(grp_general);
        gridLayout_3->setObjectName("gridLayout_3");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        lbl_gateway = new QLabel(grp_general);
        lbl_gateway->setObjectName("lbl_gateway");
        lbl_gateway->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_3->addWidget(lbl_gateway);

        edt_gateway = new QLineEdit(grp_general);
        edt_gateway->setObjectName("edt_gateway");
        edt_gateway->setClearButtonEnabled(true);

        horizontalLayout_3->addWidget(edt_gateway);


        gridLayout_3->addLayout(horizontalLayout_3, 0, 0, 1, 1);


        verticalLayout_2->addWidget(grp_general);

        grp_additional = new QGroupBox(PptpProp);
        grp_additional->setObjectName("grp_additional");
        formLayout = new QFormLayout(grp_additional);
        formLayout->setObjectName("formLayout");
        lbl_login = new QLabel(grp_additional);
        lbl_login->setObjectName("lbl_login");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lbl_login->sizePolicy().hasHeightForWidth());
        lbl_login->setSizePolicy(sizePolicy);
        lbl_login->setMinimumSize(QSize(90, 0));
        lbl_login->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lbl_login);

        edt_login = new QLineEdit(grp_additional);
        edt_login->setObjectName("edt_login");
        edt_login->setClearButtonEnabled(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, edt_login);

        lbl_password = new QLabel(grp_additional);
        lbl_password->setObjectName("lbl_password");
        sizePolicy.setHeightForWidth(lbl_password->sizePolicy().hasHeightForWidth());
        lbl_password->setSizePolicy(sizePolicy);
        lbl_password->setMinimumSize(QSize(90, 0));
        lbl_password->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, lbl_password);

        edt_password = new PasswordField(grp_additional);
        edt_password->setObjectName("edt_password");
        edt_password->setEnabled(true);
        edt_password->setProperty("passwordModeEnabled", QVariant(true));

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, edt_password);

        lbl_ntdomain = new QLabel(grp_additional);
        lbl_ntdomain->setObjectName("lbl_ntdomain");
        sizePolicy.setHeightForWidth(lbl_ntdomain->sizePolicy().hasHeightForWidth());
        lbl_ntdomain->setSizePolicy(sizePolicy);
        lbl_ntdomain->setMinimumSize(QSize(90, 0));
        lbl_ntdomain->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, lbl_ntdomain);

        edt_ntDomain = new QLineEdit(grp_additional);
        edt_ntDomain->setObjectName("edt_ntDomain");
        edt_ntDomain->setClearButtonEnabled(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, edt_ntDomain);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 30, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        btnAdvanced = new QPushButton(grp_additional);
        btnAdvanced->setObjectName("btnAdvanced");
        btnAdvanced->setFlat(false);

        horizontalLayout->addWidget(btnAdvanced);


        formLayout->setLayout(3, QFormLayout::ItemRole::SpanningRole, horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 31, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(4, QFormLayout::ItemRole::FieldRole, verticalSpacer);


        verticalLayout_2->addWidget(grp_additional);

#if QT_CONFIG(shortcut)
        lbl_gateway->setBuddy(edt_gateway);
        lbl_login->setBuddy(edt_login);
        lbl_password->setBuddy(edt_password);
        lbl_ntdomain->setBuddy(edt_ntDomain);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(edt_gateway, edt_login);
        QWidget::setTabOrder(edt_login, edt_password);
        QWidget::setTabOrder(edt_password, edt_ntDomain);

        retranslateUi(PptpProp);

        QMetaObject::connectSlotsByName(PptpProp);
    } // setupUi

    void retranslateUi(QWidget *PptpProp)
    {
        PptpProp->setWindowTitle(tr2i18n("PPTP Settings", nullptr));
        grp_general->setTitle(tr2i18n("General", "like in General settings"));
        lbl_gateway->setText(tr2i18n("Gateway:", nullptr));
#if QT_CONFIG(tooltip)
        edt_gateway->setToolTip(tr2i18n("PPTP server IP or name.", nullptr));
#endif // QT_CONFIG(tooltip)
        grp_additional->setTitle(tr2i18n("Additional", "like in Additional settings"));
        lbl_login->setText(tr2i18n("Login:", nullptr));
#if QT_CONFIG(tooltip)
        edt_login->setToolTip(tr2i18n("Set the name used for authenticating the local system to the peer to <name>.", nullptr));
#endif // QT_CONFIG(tooltip)
        lbl_password->setText(tr2i18n("Password:", nullptr));
#if QT_CONFIG(tooltip)
        edt_password->setToolTip(tr2i18n("Password passed to PPTP when prompted for it.", nullptr));
#endif // QT_CONFIG(tooltip)
        lbl_ntdomain->setText(tr2i18n("NT Domain:", nullptr));
#if QT_CONFIG(tooltip)
        edt_ntDomain->setToolTip(tr2i18n("Append the domain name <domain> to the local host name for\n"
"authenticating purposes.", nullptr));
#endif // QT_CONFIG(tooltip)
        btnAdvanced->setText(tr2i18n("Advanced\342\200\246", "like in Advanced settings"));
    } // retranslateUi

};

namespace Ui {
    class PptpProp: public Ui_PptpProp {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PPTPPROP_H

