/********************************************************************************
** Form generated from reading UI file 'bridge.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BRIDGE_H
#define UI_BRIDGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_BridgeWidget
{
public:
    QGridLayout *gridLayout_2;
    QLabel *label;
    KLineEdit *ifaceName;
    QLabel *label_7;
    QGridLayout *gridLayout;
    QListWidget *bridges;
    QPushButton *btnAdd;
    QPushButton *btnEdit;
    QPushButton *btnDelete;
    QSpacerItem *verticalSpacer;
    QLabel *label_2;
    QSpinBox *agingTime;
    QGroupBox *stpGroup;
    QFormLayout *formLayout;
    QLabel *label_3;
    QSpinBox *priority;
    QLabel *label_4;
    QSpinBox *forwardDelay;
    QLabel *label_5;
    QSpinBox *helloTime;
    QLabel *label_6;
    QSpinBox *maxAge;

    void setupUi(QWidget *BridgeWidget)
    {
        if (BridgeWidget->objectName().isEmpty())
            BridgeWidget->setObjectName("BridgeWidget");
        BridgeWidget->resize(436, 449);
        gridLayout_2 = new QGridLayout(BridgeWidget);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(BridgeWidget);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        ifaceName = new KLineEdit(BridgeWidget);
        ifaceName->setObjectName("ifaceName");

        gridLayout_2->addWidget(ifaceName, 0, 1, 1, 2);

        label_7 = new QLabel(BridgeWidget);
        label_7->setObjectName("label_7");

        gridLayout_2->addWidget(label_7, 1, 0, 1, 3);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        bridges = new QListWidget(BridgeWidget);
        bridges->setObjectName("bridges");
        bridges->setEditTriggers(QAbstractItemView::NoEditTriggers);
        bridges->setAlternatingRowColors(true);
        bridges->setUniformItemSizes(true);

        gridLayout->addWidget(bridges, 0, 0, 4, 1);

        btnAdd = new QPushButton(BridgeWidget);
        btnAdd->setObjectName("btnAdd");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        btnAdd->setIcon(icon);

        gridLayout->addWidget(btnAdd, 0, 1, 1, 1);

        btnEdit = new QPushButton(BridgeWidget);
        btnEdit->setObjectName("btnEdit");
        btnEdit->setEnabled(false);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("configure")));
        btnEdit->setIcon(icon1);

        gridLayout->addWidget(btnEdit, 1, 1, 1, 1);

        btnDelete = new QPushButton(BridgeWidget);
        btnDelete->setObjectName("btnDelete");
        btnDelete->setEnabled(false);
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        btnDelete->setIcon(icon2);

        gridLayout->addWidget(btnDelete, 2, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 2, 0, 1, 3);

        label_2 = new QLabel(BridgeWidget);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 3, 0, 1, 2);

        agingTime = new QSpinBox(BridgeWidget);
        agingTime->setObjectName("agingTime");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(agingTime->sizePolicy().hasHeightForWidth());
        agingTime->setSizePolicy(sizePolicy);
        agingTime->setMaximum(999999999);
        agingTime->setValue(300);

        gridLayout_2->addWidget(agingTime, 3, 2, 1, 1);

        stpGroup = new QGroupBox(BridgeWidget);
        stpGroup->setObjectName("stpGroup");
        stpGroup->setCheckable(true);
        formLayout = new QFormLayout(stpGroup);
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(6);
        label_3 = new QLabel(stpGroup);
        label_3->setObjectName("label_3");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        priority = new QSpinBox(stpGroup);
        priority->setObjectName("priority");
        sizePolicy.setHeightForWidth(priority->sizePolicy().hasHeightForWidth());
        priority->setSizePolicy(sizePolicy);
        priority->setMaximum(999999999);
        priority->setValue(128);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, priority);

        label_4 = new QLabel(stpGroup);
        label_4->setObjectName("label_4");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_4);

        forwardDelay = new QSpinBox(stpGroup);
        forwardDelay->setObjectName("forwardDelay");
        sizePolicy.setHeightForWidth(forwardDelay->sizePolicy().hasHeightForWidth());
        forwardDelay->setSizePolicy(sizePolicy);
        forwardDelay->setMaximum(999999999);
        forwardDelay->setValue(15);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, forwardDelay);

        label_5 = new QLabel(stpGroup);
        label_5->setObjectName("label_5");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_5);

        helloTime = new QSpinBox(stpGroup);
        helloTime->setObjectName("helloTime");
        sizePolicy.setHeightForWidth(helloTime->sizePolicy().hasHeightForWidth());
        helloTime->setSizePolicy(sizePolicy);
        helloTime->setMaximum(999999999);
        helloTime->setValue(2);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, helloTime);

        label_6 = new QLabel(stpGroup);
        label_6->setObjectName("label_6");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_6);

        maxAge = new QSpinBox(stpGroup);
        maxAge->setObjectName("maxAge");
        sizePolicy.setHeightForWidth(maxAge->sizePolicy().hasHeightForWidth());
        maxAge->setSizePolicy(sizePolicy);
        maxAge->setMaximum(999999999);
        maxAge->setValue(20);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, maxAge);


        gridLayout_2->addWidget(stpGroup, 4, 0, 1, 3);

#if QT_CONFIG(shortcut)
        label->setBuddy(ifaceName);
        label_7->setBuddy(bridges);
        label_2->setBuddy(agingTime);
        label_3->setBuddy(priority);
        label_4->setBuddy(forwardDelay);
        label_5->setBuddy(helloTime);
        label_6->setBuddy(maxAge);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(ifaceName, bridges);
        QWidget::setTabOrder(bridges, btnAdd);
        QWidget::setTabOrder(btnAdd, btnEdit);
        QWidget::setTabOrder(btnEdit, btnDelete);
        QWidget::setTabOrder(btnDelete, agingTime);
        QWidget::setTabOrder(agingTime, stpGroup);
        QWidget::setTabOrder(stpGroup, priority);
        QWidget::setTabOrder(priority, forwardDelay);
        QWidget::setTabOrder(forwardDelay, helloTime);
        QWidget::setTabOrder(helloTime, maxAge);

        retranslateUi(BridgeWidget);

        QMetaObject::connectSlotsByName(BridgeWidget);
    } // setupUi

    void retranslateUi(QWidget *BridgeWidget)
    {
        label->setText(tr2i18n("Interface name:", nullptr));
        label_7->setText(tr2i18n("Bridged connections:", nullptr));
        btnAdd->setText(tr2i18n("Add\342\200\246", nullptr));
        btnEdit->setText(tr2i18n("Edit\342\200\246", nullptr));
        btnDelete->setText(tr2i18n("Delete", nullptr));
        label_2->setText(tr2i18n("Aging time:", nullptr));
        agingTime->setSuffix(tr2i18n(" s", "seconds"));
        stpGroup->setTitle(tr2i18n("Enable STP (Spanning Tree Protocol)", nullptr));
        label_3->setText(tr2i18n("Priority:", nullptr));
        label_4->setText(tr2i18n("Forward delay:", nullptr));
        forwardDelay->setSuffix(tr2i18n(" s", "seconds"));
        label_5->setText(tr2i18n("Hello time:", nullptr));
        helloTime->setSuffix(tr2i18n(" s", "seconds"));
        label_6->setText(tr2i18n("Max age:", nullptr));
        maxAge->setSuffix(tr2i18n(" s", "seconds"));
        (void)BridgeWidget;
    } // retranslateUi

};

namespace Ui {
    class BridgeWidget: public Ui_BridgeWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BRIDGE_H

