/********************************************************************************
** Form generated from reading UI file 'kcm.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KCM_H
#define UI_KCM_H

#include <QtCore/QVariant>
#include <QtQuickWidgets/QQuickWidget>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KCMForm
{
public:
    QHBoxLayout *horizontalLayout;
    QQuickWidget *connectionView;

    void setupUi(QWidget *KCMForm)
    {
        if (KCMForm->objectName().isEmpty())
            KCMForm->setObjectName("KCMForm");
        KCMForm->resize(800, 500);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KCMForm->sizePolicy().hasHeightForWidth());
        KCMForm->setSizePolicy(sizePolicy);
        KCMForm->setMinimumSize(QSize(800, 500));
        horizontalLayout = new QHBoxLayout(KCMForm);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName("horizontalLayout");
        connectionView = new QQuickWidget(KCMForm);
        connectionView->setObjectName("connectionView");
        connectionView->setResizeMode(QQuickWidget::SizeRootObjectToView);

        horizontalLayout->addWidget(connectionView);


        retranslateUi(KCMForm);

        QMetaObject::connectSlotsByName(KCMForm);
    } // setupUi

    void retranslateUi(QWidget *KCMForm)
    {
        (void)KCMForm;
    } // retranslateUi

};

namespace Ui {
    class KCMForm: public Ui_KCMForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KCM_H

