/********************************************************************************
** Form generated from reading UI file 'wificonnectionwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIFICONNECTIONWIDGET_H
#define UI_WIFICONNECTIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "bssidcombobox.h"
#include "hwaddrcombobox.h"
#include "kcombobox.h"
#include "klineedit.h"
#include "ssidcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_WifiConnectionWidget
{
public:
    QFormLayout *formLayout;
    QLabel *connectionSectionLabel;
    QLabel *SSIDLabel;
    SsidComboBox *SSIDCombo;
    QLabel *modeLabel;
    KComboBox *modeComboBox;
    QLabel *advancedSectionLabel;
    QLabel *BSSIDLabel;
    BssidComboBox *BSSIDCombo;
    QLabel *bandLabel;
    KComboBox *band;
    QLabel *channelLabel;
    KComboBox *channel;
    QLabel *label;
    HwAddrComboBox *macAddress;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout;
    KLineEdit *clonedMacAddress;
    QPushButton *btnRandomMacAddr;
    QLabel *label_3;
    QSpinBox *mtu;
    QLabel *label_4;
    QCheckBox *hiddenNetwork;
    QLabel *securitySectionLabel;

    void setupUi(QWidget *WifiConnectionWidget)
    {
        if (WifiConnectionWidget->objectName().isEmpty())
            WifiConnectionWidget->setObjectName("WifiConnectionWidget");
        WifiConnectionWidget->resize(401, 334);
        WifiConnectionWidget->setMinimumSize(QSize(250, 0));
        formLayout = new QFormLayout(WifiConnectionWidget);
        formLayout->setObjectName("formLayout");
        connectionSectionLabel = new QLabel(WifiConnectionWidget);
        connectionSectionLabel->setObjectName("connectionSectionLabel");
        QFont font;
        font.setBold(true);
        connectionSectionLabel->setFont(font);
        connectionSectionLabel->setAlignment(Qt::AlignCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::SpanningRole, connectionSectionLabel);

        SSIDLabel = new QLabel(WifiConnectionWidget);
        SSIDLabel->setObjectName("SSIDLabel");
        SSIDLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, SSIDLabel);

        SSIDCombo = new SsidComboBox(WifiConnectionWidget);
        SSIDCombo->setObjectName("SSIDCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SSIDCombo->sizePolicy().hasHeightForWidth());
        SSIDCombo->setSizePolicy(sizePolicy);
        SSIDCombo->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, SSIDCombo);

        modeLabel = new QLabel(WifiConnectionWidget);
        modeLabel->setObjectName("modeLabel");
        modeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, modeLabel);

        modeComboBox = new KComboBox(WifiConnectionWidget);
        modeComboBox->addItem(QString());
        modeComboBox->addItem(QString());
        modeComboBox->addItem(QString());
        modeComboBox->setObjectName("modeComboBox");
        sizePolicy.setHeightForWidth(modeComboBox->sizePolicy().hasHeightForWidth());
        modeComboBox->setSizePolicy(sizePolicy);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, modeComboBox);

        advancedSectionLabel = new QLabel(WifiConnectionWidget);
        advancedSectionLabel->setObjectName("advancedSectionLabel");
        advancedSectionLabel->setFont(font);
        advancedSectionLabel->setAlignment(Qt::AlignCenter);

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, advancedSectionLabel);

        BSSIDLabel = new QLabel(WifiConnectionWidget);
        BSSIDLabel->setObjectName("BSSIDLabel");
        BSSIDLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, BSSIDLabel);

        BSSIDCombo = new BssidComboBox(WifiConnectionWidget);
        BSSIDCombo->setObjectName("BSSIDCombo");
        sizePolicy.setHeightForWidth(BSSIDCombo->sizePolicy().hasHeightForWidth());
        BSSIDCombo->setSizePolicy(sizePolicy);
        BSSIDCombo->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, BSSIDCombo);

        bandLabel = new QLabel(WifiConnectionWidget);
        bandLabel->setObjectName("bandLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(bandLabel->sizePolicy().hasHeightForWidth());
        bandLabel->setSizePolicy(sizePolicy1);
        bandLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, bandLabel);

        band = new KComboBox(WifiConnectionWidget);
        band->addItem(QString());
        band->addItem(QString());
        band->addItem(QString());
        band->setObjectName("band");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(band->sizePolicy().hasHeightForWidth());
        band->setSizePolicy(sizePolicy2);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, band);

        channelLabel = new QLabel(WifiConnectionWidget);
        channelLabel->setObjectName("channelLabel");
        channelLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, channelLabel);

        channel = new KComboBox(WifiConnectionWidget);
        channel->setObjectName("channel");
        sizePolicy.setHeightForWidth(channel->sizePolicy().hasHeightForWidth());
        channel->setSizePolicy(sizePolicy);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, channel);

        label = new QLabel(WifiConnectionWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label);

        macAddress = new HwAddrComboBox(WifiConnectionWidget);
        macAddress->setObjectName("macAddress");
        sizePolicy.setHeightForWidth(macAddress->sizePolicy().hasHeightForWidth());
        macAddress->setSizePolicy(sizePolicy);

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, macAddress);

        label_2 = new QLabel(WifiConnectionWidget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        clonedMacAddress = new KLineEdit(WifiConnectionWidget);
        clonedMacAddress->setObjectName("clonedMacAddress");
        sizePolicy.setHeightForWidth(clonedMacAddress->sizePolicy().hasHeightForWidth());
        clonedMacAddress->setSizePolicy(sizePolicy);
        clonedMacAddress->setInputMask(QString::fromUtf8("HH:HH:HH:HH:HH:HH;_"));
        clonedMacAddress->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout->addWidget(clonedMacAddress);

        btnRandomMacAddr = new QPushButton(WifiConnectionWidget);
        btnRandomMacAddr->setObjectName("btnRandomMacAddr");

        horizontalLayout->addWidget(btnRandomMacAddr);


        formLayout->setLayout(8, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_3 = new QLabel(WifiConnectionWidget);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(9, QFormLayout::ItemRole::LabelRole, label_3);

        mtu = new QSpinBox(WifiConnectionWidget);
        mtu->setObjectName("mtu");
        sizePolicy.setHeightForWidth(mtu->sizePolicy().hasHeightForWidth());
        mtu->setSizePolicy(sizePolicy);
        mtu->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        mtu->setMaximum(10000);

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, mtu);

        label_4 = new QLabel(WifiConnectionWidget);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(10, QFormLayout::ItemRole::LabelRole, label_4);

        hiddenNetwork = new QCheckBox(WifiConnectionWidget);
        hiddenNetwork->setObjectName("hiddenNetwork");

        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, hiddenNetwork);

        securitySectionLabel = new QLabel(WifiConnectionWidget);
        securitySectionLabel->setObjectName("securitySectionLabel");
        securitySectionLabel->setFont(font);
        securitySectionLabel->setAlignment(Qt::AlignCenter);

        formLayout->setWidget(11, QFormLayout::ItemRole::SpanningRole, securitySectionLabel);

#if QT_CONFIG(shortcut)
        SSIDLabel->setBuddy(SSIDCombo);
        modeLabel->setBuddy(modeComboBox);
        BSSIDLabel->setBuddy(BSSIDCombo);
        bandLabel->setBuddy(band);
        channelLabel->setBuddy(channel);
        label->setBuddy(macAddress);
        label_2->setBuddy(clonedMacAddress);
        label_3->setBuddy(mtu);
        label_4->setBuddy(hiddenNetwork);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(SSIDCombo, modeComboBox);
        QWidget::setTabOrder(modeComboBox, BSSIDCombo);
        QWidget::setTabOrder(BSSIDCombo, band);
        QWidget::setTabOrder(band, channel);
        QWidget::setTabOrder(channel, macAddress);
        QWidget::setTabOrder(macAddress, clonedMacAddress);
        QWidget::setTabOrder(clonedMacAddress, btnRandomMacAddr);
        QWidget::setTabOrder(btnRandomMacAddr, mtu);
        QWidget::setTabOrder(mtu, hiddenNetwork);

        retranslateUi(WifiConnectionWidget);

        QMetaObject::connectSlotsByName(WifiConnectionWidget);
    } // setupUi

    void retranslateUi(QWidget *WifiConnectionWidget)
    {
        connectionSectionLabel->setText(tr2i18n("Connection", nullptr));
        SSIDLabel->setText(tr2i18n("SSID:", nullptr));
#if QT_CONFIG(tooltip)
        SSIDCombo->setToolTip(tr2i18n("The name of the Wi-Fi network to connect to", nullptr));
#endif // QT_CONFIG(tooltip)
        modeLabel->setText(tr2i18n("Mode:", nullptr));
        modeComboBox->setItemText(0, tr2i18n("Infrastructure", nullptr));
        modeComboBox->setItemText(1, tr2i18n("Ad-hoc", nullptr));
        modeComboBox->setItemText(2, tr2i18n("Access Point", nullptr));

#if QT_CONFIG(tooltip)
        modeComboBox->setToolTip(tr2i18n("Wi-Fi network mode:\n"
"\342\200\242 Infrastructure: connect to a Wi-Fi router (normal mode)\n"
"\342\200\242 Ad-hoc: create a direct peer-to-peer network\n"
"\342\200\242 Access Point: turn this computer into a Wi-Fi hotspot", nullptr));
#endif // QT_CONFIG(tooltip)
        advancedSectionLabel->setText(tr2i18n("Advanced", nullptr));
        BSSIDLabel->setText(tr2i18n("Restrict to BSSID:", nullptr));
#if QT_CONFIG(tooltip)
        BSSIDCombo->setToolTip(tr2i18n("Lock this connection to a specific access point. Enter the BSSID (MAC address) of the access point.", nullptr));
#endif // QT_CONFIG(tooltip)
        bandLabel->setText(tr2i18n("Band:", nullptr));
        band->setItemText(0, tr2i18n("Automatic", "Band:"));
        band->setItemText(1, tr2i18n("A (5 GHz)", nullptr));
        band->setItemText(2, tr2i18n("B/G (2.4 GHz)", nullptr));

#if QT_CONFIG(tooltip)
        band->setToolTip(tr2i18n("This option locks the connection to the Wi-Fi network associated to the specified band. This setting depends\n"
" on specific driver capability and may not work with all drivers", nullptr));
#endif // QT_CONFIG(tooltip)
        channelLabel->setText(tr2i18n("Channel:", nullptr));
#if QT_CONFIG(tooltip)
        channel->setToolTip(tr2i18n("Wireless channel to use for the Wi-Fi connection. The device will only join (or create for Ad-Hoc networks)\n"
"a Wi-Fi network on the specified channel", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Restrict to network adapter:", nullptr));
#if QT_CONFIG(tooltip)
        macAddress->setToolTip(tr2i18n("Lock this connection to a particular network adapter by specifying its MAC address.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Cloned MAC address:", nullptr));
#if QT_CONFIG(tooltip)
        clonedMacAddress->setToolTip(tr2i18n("Use a different MAC address instead of your network adapter's real address.", nullptr));
#endif // QT_CONFIG(tooltip)
        btnRandomMacAddr->setText(tr2i18n("Random\342\200\246", nullptr));
        label_3->setText(tr2i18n("MTU:", nullptr));
        mtu->setSpecialValueText(tr2i18n("Automatic", "MTU:"));
        mtu->setSuffix(tr2i18n(" bytes", nullptr));
        mtu->setPrefix(QString());
#if QT_CONFIG(tooltip)
        mtu->setToolTip(tr2i18n("Maximum Transmission Unit: the largest packet size that can be sent without fragmentation. Larger packets will be broken into smaller frames.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_4->setToolTip(tr2i18n("Create a connection for a hidden network", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Visibility:", nullptr));
#if QT_CONFIG(tooltip)
        hiddenNetwork->setToolTip(tr2i18n("Create a connection for a hidden network", nullptr));
#endif // QT_CONFIG(tooltip)
        hiddenNetwork->setText(tr2i18n("Hidden network", nullptr));
        securitySectionLabel->setText(tr2i18n("Security", nullptr));
        (void)WifiConnectionWidget;
    } // retranslateUi

};

namespace Ui {
    class WifiConnectionWidget: public Ui_WifiConnectionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WIFICONNECTIONWIDGET_H

