/****************************************************************************
** Meta object code from reading C++ file 'cellularmodemdetails.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-nm-6.7.4/libs/cellular/cellularmodemdetails.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cellularmodemdetails.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24CellularAvailableNetworkE_t {};
} // unnamed namespace

template <> constexpr inline auto CellularAvailableNetwork::qt_create_metaobjectdata<qt_meta_tag_ZN24CellularAvailableNetworkE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CellularAvailableNetwork",
        "QML.Element",
        "auto",
        "isCurrentlyUsedChanged",
        "",
        "operatorLongChanged",
        "operatorShortChanged",
        "operatorCodeChanged",
        "accessTechnologyChanged",
        "registerToNetwork",
        "isCurrentlyUsed",
        "operatorLong",
        "operatorShort",
        "operatorCode",
        "accessTechnology"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'isCurrentlyUsedChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'operatorLongChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'operatorShortChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'operatorCodeChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accessTechnologyChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'registerToNetwork'
        QtMocHelpers::MethodData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isCurrentlyUsed'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'operatorLong'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'operatorShort'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'operatorCode'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'accessTechnology'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<CellularAvailableNetwork, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CellularAvailableNetwork::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24CellularAvailableNetworkE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24CellularAvailableNetworkE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24CellularAvailableNetworkE_t>.metaTypes,
    nullptr
} };

void CellularAvailableNetwork::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CellularAvailableNetwork *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->isCurrentlyUsedChanged(); break;
        case 1: _t->operatorLongChanged(); break;
        case 2: _t->operatorShortChanged(); break;
        case 3: _t->operatorCodeChanged(); break;
        case 4: _t->accessTechnologyChanged(); break;
        case 5: _t->registerToNetwork(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CellularAvailableNetwork::*)()>(_a, &CellularAvailableNetwork::isCurrentlyUsedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularAvailableNetwork::*)()>(_a, &CellularAvailableNetwork::operatorLongChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularAvailableNetwork::*)()>(_a, &CellularAvailableNetwork::operatorShortChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularAvailableNetwork::*)()>(_a, &CellularAvailableNetwork::operatorCodeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularAvailableNetwork::*)()>(_a, &CellularAvailableNetwork::accessTechnologyChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isCurrentlyUsed(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->operatorLong(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->operatorShort(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->operatorCode(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->accessTechnology(); break;
        default: break;
        }
    }
}

const QMetaObject *CellularAvailableNetwork::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CellularAvailableNetwork::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24CellularAvailableNetworkE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CellularAvailableNetwork::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void CellularAvailableNetwork::isCurrentlyUsedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CellularAvailableNetwork::operatorLongChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CellularAvailableNetwork::operatorShortChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CellularAvailableNetwork::operatorCodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void CellularAvailableNetwork::accessTechnologyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
namespace {
struct qt_meta_tag_ZN20CellularModemDetailsE_t {};
} // unnamed namespace

template <> constexpr inline auto CellularModemDetails::qt_create_metaobjectdata<qt_meta_tag_ZN20CellularModemDetailsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CellularModemDetails",
        "QML.Element",
        "auto",
        "accessTechnologiesChanged",
        "",
        "deviceChanged",
        "deviceIdentifierChanged",
        "driversChanged",
        "equipmentIdentifierChanged",
        "isEnabledChanged",
        "manufacturerChanged",
        "modelChanged",
        "ownNumbersChanged",
        "pluginChanged",
        "powerStateChanged",
        "revisionChanged",
        "signalQualityChanged",
        "simPathChanged",
        "stateChanged",
        "stateFailedReasonChanged",
        "operatorCodeChanged",
        "operatorNameChanged",
        "registrationStateChanged",
        "networksChanged",
        "isScanningNetworksChanged",
        "firmwareVersionChanged",
        "interfaceNameChanged",
        "meteredChanged",
        "errorOccurred",
        "message",
        "scanNetworks",
        "accessTechnologies",
        "device",
        "deviceIdentifier",
        "drivers",
        "equipmentIdentifier",
        "isEnabled",
        "manufacturer",
        "model",
        "ownNumbers",
        "plugin",
        "powerState",
        "revision",
        "signalQuality",
        "simPath",
        "state",
        "stateFailedReason",
        "operatorCode",
        "operatorName",
        "registrationState",
        "networks",
        "QList<CellularAvailableNetwork*>",
        "isScanningNetworks",
        "firmwareVersion",
        "interfaceName",
        "metered"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accessTechnologiesChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deviceChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deviceIdentifierChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'driversChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'equipmentIdentifierChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isEnabledChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'manufacturerChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ownNumbersChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pluginChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'powerStateChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'revisionChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalQualityChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'simPathChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateFailedReasonChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'operatorCodeChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'operatorNameChanged'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'registrationStateChanged'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'networksChanged'
        QtMocHelpers::SignalData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isScanningNetworksChanged'
        QtMocHelpers::SignalData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'firmwareVersionChanged'
        QtMocHelpers::SignalData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interfaceNameChanged'
        QtMocHelpers::SignalData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'meteredChanged'
        QtMocHelpers::SignalData<void()>(27, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void(const QString &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Method 'scanNetworks'
        QtMocHelpers::MethodData<void()>(30, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'accessTechnologies'
        QtMocHelpers::PropertyData<QStringList>(31, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'device'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'deviceIdentifier'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'drivers'
        QtMocHelpers::PropertyData<QStringList>(34, QMetaType::QStringList, QMC::DefaultPropertyFlags, 3),
        // property 'equipmentIdentifier'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'isEnabled'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'manufacturer'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'model'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'ownNumbers'
        QtMocHelpers::PropertyData<QStringList>(39, QMetaType::QStringList, QMC::DefaultPropertyFlags, 8),
        // property 'plugin'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'powerState'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags, 10),
        // property 'revision'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'signalQuality'
        QtMocHelpers::PropertyData<uint>(43, QMetaType::UInt, QMC::DefaultPropertyFlags, 12),
        // property 'simPath'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags, 13),
        // property 'state'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'stateFailedReason'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags, 15),
        // property 'operatorCode'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags, 16),
        // property 'operatorName'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags, 17),
        // property 'registrationState'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags, 18),
        // property 'networks'
        QtMocHelpers::PropertyData<QList<CellularAvailableNetwork*>>(50, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 19),
        // property 'isScanningNetworks'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags, 20),
        // property 'firmwareVersion'
        QtMocHelpers::PropertyData<QString>(53, QMetaType::QString, QMC::DefaultPropertyFlags, 21),
        // property 'interfaceName'
        QtMocHelpers::PropertyData<QString>(54, QMetaType::QString, QMC::DefaultPropertyFlags, 22),
        // property 'metered'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags, 23),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<CellularModemDetails, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CellularModemDetails::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CellularModemDetailsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CellularModemDetailsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20CellularModemDetailsE_t>.metaTypes,
    nullptr
} };

void CellularModemDetails::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CellularModemDetails *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accessTechnologiesChanged(); break;
        case 1: _t->deviceChanged(); break;
        case 2: _t->deviceIdentifierChanged(); break;
        case 3: _t->driversChanged(); break;
        case 4: _t->equipmentIdentifierChanged(); break;
        case 5: _t->isEnabledChanged(); break;
        case 6: _t->manufacturerChanged(); break;
        case 7: _t->modelChanged(); break;
        case 8: _t->ownNumbersChanged(); break;
        case 9: _t->pluginChanged(); break;
        case 10: _t->powerStateChanged(); break;
        case 11: _t->revisionChanged(); break;
        case 12: _t->signalQualityChanged(); break;
        case 13: _t->simPathChanged(); break;
        case 14: _t->stateChanged(); break;
        case 15: _t->stateFailedReasonChanged(); break;
        case 16: _t->operatorCodeChanged(); break;
        case 17: _t->operatorNameChanged(); break;
        case 18: _t->registrationStateChanged(); break;
        case 19: _t->networksChanged(); break;
        case 20: _t->isScanningNetworksChanged(); break;
        case 21: _t->firmwareVersionChanged(); break;
        case 22: _t->interfaceNameChanged(); break;
        case 23: _t->meteredChanged(); break;
        case 24: _t->errorOccurred((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->scanNetworks(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::accessTechnologiesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::deviceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::deviceIdentifierChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::driversChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::equipmentIdentifierChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::isEnabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::manufacturerChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::modelChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::ownNumbersChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::pluginChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::powerStateChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::revisionChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::signalQualityChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::simPathChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::stateChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::stateFailedReasonChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::operatorCodeChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::operatorNameChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::registrationStateChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::networksChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::isScanningNetworksChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::firmwareVersionChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::interfaceNameChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)()>(_a, &CellularModemDetails::meteredChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModemDetails::*)(const QString & )>(_a, &CellularModemDetails::errorOccurred, 24))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 19:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<CellularAvailableNetwork*> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->accessTechnologies(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->device(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->deviceIdentifier(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->drivers(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->equipmentIdentifier(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->manufacturer(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->model(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->ownNumbers(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->plugin(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->powerState(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->revision(); break;
        case 12: *reinterpret_cast<uint*>(_v) = _t->signalQuality(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->simPath(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->state(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->stateFailedReason(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->operatorCode(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->operatorName(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->registrationState(); break;
        case 19: *reinterpret_cast<QList<CellularAvailableNetwork*>*>(_v) = _t->networks(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->isScanningNetworks(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->firmwareVersion(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->interfaceName(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->metered(); break;
        default: break;
        }
    }
}

const QMetaObject *CellularModemDetails::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CellularModemDetails::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CellularModemDetailsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CellularModemDetails::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void CellularModemDetails::accessTechnologiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CellularModemDetails::deviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CellularModemDetails::deviceIdentifierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CellularModemDetails::driversChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void CellularModemDetails::equipmentIdentifierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CellularModemDetails::isEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void CellularModemDetails::manufacturerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void CellularModemDetails::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void CellularModemDetails::ownNumbersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void CellularModemDetails::pluginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void CellularModemDetails::powerStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void CellularModemDetails::revisionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void CellularModemDetails::signalQualityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void CellularModemDetails::simPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void CellularModemDetails::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void CellularModemDetails::stateFailedReasonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void CellularModemDetails::operatorCodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void CellularModemDetails::operatorNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void CellularModemDetails::registrationStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void CellularModemDetails::networksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void CellularModemDetails::isScanningNetworksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void CellularModemDetails::firmwareVersionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void CellularModemDetails::interfaceNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void CellularModemDetails::meteredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void CellularModemDetails::errorOccurred(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}
QT_WARNING_POP
