/****************************************************************************
** Meta object code from reading C++ file 'enums.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-nm-6.7.4/libs/enums.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'enums.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5EnumsE_t {};
} // unnamed namespace

template <> constexpr inline auto Enums::qt_create_metaobjectdata<qt_meta_tag_ZN5EnumsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Enums",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "ConnectionStatus",
        "UnknownState",
        "Activating",
        "Activated",
        "Deactivating",
        "Deactivated",
        "ConnectionType",
        "UnknownConnectionType",
        "Adsl",
        "Bluetooth",
        "Bond",
        "Bridge",
        "Cdma",
        "Gsm",
        "Infiniband",
        "OLPCMesh",
        "Pppoe",
        "Vlan",
        "Vpn",
        "Wimax",
        "Wired",
        "Wireless",
        "SecurityType",
        "UnknownSecurity",
        "NoneSecurity",
        "StaticWep",
        "DynamicWep",
        "Leap",
        "WpaPsk",
        "WpaEap",
        "Wpa2Psk",
        "Wpa2Eap",
        "SAE",
        "Wpa3SuiteB192",
        "OWE"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ConnectionStatus'
        QtMocHelpers::EnumData<enum ConnectionStatus>(7, 7, QMC::EnumFlags{}).add({
            {    8, ConnectionStatus::UnknownState },
            {    9, ConnectionStatus::Activating },
            {   10, ConnectionStatus::Activated },
            {   11, ConnectionStatus::Deactivating },
            {   12, ConnectionStatus::Deactivated },
        }),
        // enum 'ConnectionType'
        QtMocHelpers::EnumData<enum ConnectionType>(13, 13, QMC::EnumFlags{}).add({
            {   14, ConnectionType::UnknownConnectionType },
            {   15, ConnectionType::Adsl },
            {   16, ConnectionType::Bluetooth },
            {   17, ConnectionType::Bond },
            {   18, ConnectionType::Bridge },
            {   19, ConnectionType::Cdma },
            {   20, ConnectionType::Gsm },
            {   21, ConnectionType::Infiniband },
            {   22, ConnectionType::OLPCMesh },
            {   23, ConnectionType::Pppoe },
            {   24, ConnectionType::Vlan },
            {   25, ConnectionType::Vpn },
            {   26, ConnectionType::Wimax },
            {   27, ConnectionType::Wired },
            {   28, ConnectionType::Wireless },
        }),
        // enum 'SecurityType'
        QtMocHelpers::EnumData<enum SecurityType>(29, 29, QMC::EnumFlags{}).add({
            {   30, SecurityType::UnknownSecurity },
            {   31, SecurityType::NoneSecurity },
            {   32, SecurityType::StaticWep },
            {   33, SecurityType::DynamicWep },
            {   34, SecurityType::Leap },
            {   35, SecurityType::WpaPsk },
            {   36, SecurityType::WpaEap },
            {   37, SecurityType::Wpa2Psk },
            {   38, SecurityType::Wpa2Eap },
            {   39, SecurityType::SAE },
            {   40, SecurityType::Wpa3SuiteB192 },
            {   41, SecurityType::OWE },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Enums, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Enums::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5EnumsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5EnumsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5EnumsE_t>.metaTypes,
    nullptr
} };

void Enums::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Enums *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Enums::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Enums::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5EnumsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Enums::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
