/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<cellularconnectionprofile.h>)
#  include <cellularconnectionprofile.h>
#endif
#if __has_include(<cellularmodem.h>)
#  include <cellularmodem.h>
#endif
#if __has_include(<cellularmodemdetails.h>)
#  include <cellularmodemdetails.h>
#endif
#if __has_include(<cellularmodemlist.h>)
#  include <cellularmodemlist.h>
#endif
#if __has_include(<cellularsim.h>)
#  include <cellularsim.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_networkmanagement_cellular()
{
    qmlRegisterModule("org.kde.plasma.networkmanagement.cellular", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<CellularAvailableNetwork>("org.kde.plasma.networkmanagement.cellular", 254);
    qmlRegisterTypesAndRevisions<CellularConnectionProfile>("org.kde.plasma.networkmanagement.cellular", 254);
    qmlRegisterEnum<CellularConnectionProfile::ItemRole>("CellularConnectionProfile::ItemRole");
    qmlRegisterTypesAndRevisions<CellularModem>("org.kde.plasma.networkmanagement.cellular", 254);
    qmlRegisterTypesAndRevisions<CellularModemDetails>("org.kde.plasma.networkmanagement.cellular", 254);
    qmlRegisterTypesAndRevisions<CellularModemList>("org.kde.plasma.networkmanagement.cellular", 254);
    qmlRegisterTypesAndRevisions<CellularSim>("org.kde.plasma.networkmanagement.cellular", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.networkmanagement.cellular", 254, 254);
}

static const QQmlModuleRegistration orgkdeplasmanetworkmanagementcellularRegistration("org.kde.plasma.networkmanagement.cellular", qml_register_types_org_kde_plasma_networkmanagement_cellular);
