/********************************************************************************
** Form generated from reading UI file 'sshwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SSHWIDGET_H
#define UI_SSHWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_SshWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *lbl_gateway;
    QLineEdit *le_gateway;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_2;
    QLabel *lbl_remoteIp;
    QLineEdit *le_remoteIp;
    QLabel *lbl_localIp;
    QLineEdit *le_localIp;
    QLabel *lbl_netmask;
    QLineEdit *le_netmask;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_3;
    QCheckBox *chk_useIpv6;
    QLabel *lbl_remoteIpv6;
    QLineEdit *le_remoteIpv6;
    QLabel *lbl_localIpv6;
    QLineEdit *le_localIpv6;
    QLabel *lbl_netmaskIpv6;
    QLineEdit *le_netmaskIpv6;
    QGroupBox *groupBox_4;
    QGridLayout *gridLayout_4;
    QStackedWidget *stackedWidget;
    QWidget *passwordWidget;
    QFormLayout *formLayout;
    QLabel *lbl_password;
    PasswordField *le_password;
    QWidget *sshKeyFile;
    QFormLayout *formLayout_2;
    QLabel *lbl_sshKeyFile;
    KUrlRequester *kurl_sshKeyFile;
    QHBoxLayout *horizontalLayout_3;
    QLabel *lbl_authType;
    QComboBox *cmb_authType;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *btn_advancedOption;

    void setupUi(QWidget *SshWidget)
    {
        if (SshWidget->objectName().isEmpty())
            SshWidget->setObjectName("SshWidget");
        SshWidget->resize(467, 571);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SshWidget->sizePolicy().hasHeightForWidth());
        SshWidget->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(SshWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        scrollArea = new QScrollArea(SshWidget);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::NoFrame);
        scrollArea->setFrameShadow(QFrame::Plain);
        scrollArea->setLineWidth(0);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, -19, 435, 594));
        verticalLayout = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(scrollAreaWidgetContents);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        lbl_gateway = new QLabel(groupBox);
        lbl_gateway->setObjectName("lbl_gateway");
        lbl_gateway->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_2->addWidget(lbl_gateway);

        le_gateway = new QLineEdit(groupBox);
        le_gateway->setObjectName("le_gateway");

        horizontalLayout_2->addWidget(le_gateway);


        gridLayout->addLayout(horizontalLayout_2, 0, 0, 1, 1);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(scrollAreaWidgetContents);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_2 = new QGridLayout(groupBox_2);
        gridLayout_2->setObjectName("gridLayout_2");
        lbl_remoteIp = new QLabel(groupBox_2);
        lbl_remoteIp->setObjectName("lbl_remoteIp");
        lbl_remoteIp->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(lbl_remoteIp, 0, 0, 1, 1);

        le_remoteIp = new QLineEdit(groupBox_2);
        le_remoteIp->setObjectName("le_remoteIp");

        gridLayout_2->addWidget(le_remoteIp, 0, 1, 1, 1);

        lbl_localIp = new QLabel(groupBox_2);
        lbl_localIp->setObjectName("lbl_localIp");
        lbl_localIp->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(lbl_localIp, 1, 0, 1, 1);

        le_localIp = new QLineEdit(groupBox_2);
        le_localIp->setObjectName("le_localIp");

        gridLayout_2->addWidget(le_localIp, 1, 1, 1, 1);

        lbl_netmask = new QLabel(groupBox_2);
        lbl_netmask->setObjectName("lbl_netmask");
        lbl_netmask->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(lbl_netmask, 2, 0, 1, 1);

        le_netmask = new QLineEdit(groupBox_2);
        le_netmask->setObjectName("le_netmask");

        gridLayout_2->addWidget(le_netmask, 2, 1, 1, 1);


        verticalLayout->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(scrollAreaWidgetContents);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout_3 = new QGridLayout(groupBox_3);
        gridLayout_3->setObjectName("gridLayout_3");
        chk_useIpv6 = new QCheckBox(groupBox_3);
        chk_useIpv6->setObjectName("chk_useIpv6");

        gridLayout_3->addWidget(chk_useIpv6, 0, 0, 1, 1);

        lbl_remoteIpv6 = new QLabel(groupBox_3);
        lbl_remoteIpv6->setObjectName("lbl_remoteIpv6");
        lbl_remoteIpv6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(lbl_remoteIpv6, 1, 0, 1, 1);

        le_remoteIpv6 = new QLineEdit(groupBox_3);
        le_remoteIpv6->setObjectName("le_remoteIpv6");
        le_remoteIpv6->setEnabled(false);

        gridLayout_3->addWidget(le_remoteIpv6, 1, 1, 1, 1);

        lbl_localIpv6 = new QLabel(groupBox_3);
        lbl_localIpv6->setObjectName("lbl_localIpv6");
        lbl_localIpv6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(lbl_localIpv6, 2, 0, 1, 1);

        le_localIpv6 = new QLineEdit(groupBox_3);
        le_localIpv6->setObjectName("le_localIpv6");
        le_localIpv6->setEnabled(false);

        gridLayout_3->addWidget(le_localIpv6, 2, 1, 1, 1);

        lbl_netmaskIpv6 = new QLabel(groupBox_3);
        lbl_netmaskIpv6->setObjectName("lbl_netmaskIpv6");
        lbl_netmaskIpv6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(lbl_netmaskIpv6, 3, 0, 1, 1);

        le_netmaskIpv6 = new QLineEdit(groupBox_3);
        le_netmaskIpv6->setObjectName("le_netmaskIpv6");
        le_netmaskIpv6->setEnabled(false);

        gridLayout_3->addWidget(le_netmaskIpv6, 3, 1, 1, 1);


        verticalLayout->addWidget(groupBox_3);

        groupBox_4 = new QGroupBox(scrollAreaWidgetContents);
        groupBox_4->setObjectName("groupBox_4");
        gridLayout_4 = new QGridLayout(groupBox_4);
        gridLayout_4->setObjectName("gridLayout_4");
        stackedWidget = new QStackedWidget(groupBox_4);
        stackedWidget->setObjectName("stackedWidget");
        stackedWidget->setEnabled(true);
        passwordWidget = new QWidget();
        passwordWidget->setObjectName("passwordWidget");
        formLayout = new QFormLayout(passwordWidget);
        formLayout->setObjectName("formLayout");
        lbl_password = new QLabel(passwordWidget);
        lbl_password->setObjectName("lbl_password");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lbl_password);

        le_password = new PasswordField(passwordWidget);
        le_password->setObjectName("le_password");
        le_password->setProperty("passwordModeEnabled", QVariant(true));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, le_password);

        stackedWidget->addWidget(passwordWidget);
        sshKeyFile = new QWidget();
        sshKeyFile->setObjectName("sshKeyFile");
        formLayout_2 = new QFormLayout(sshKeyFile);
        formLayout_2->setObjectName("formLayout_2");
        lbl_sshKeyFile = new QLabel(sshKeyFile);
        lbl_sshKeyFile->setObjectName("lbl_sshKeyFile");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, lbl_sshKeyFile);

        kurl_sshKeyFile = new KUrlRequester(sshKeyFile);
        kurl_sshKeyFile->setObjectName("kurl_sshKeyFile");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, kurl_sshKeyFile);

        stackedWidget->addWidget(sshKeyFile);

        gridLayout_4->addWidget(stackedWidget, 1, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        lbl_authType = new QLabel(groupBox_4);
        lbl_authType->setObjectName("lbl_authType");
        lbl_authType->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_3->addWidget(lbl_authType);

        cmb_authType = new QComboBox(groupBox_4);
        cmb_authType->addItem(QString());
        cmb_authType->addItem(QString());
        cmb_authType->addItem(QString());
        cmb_authType->setObjectName("cmb_authType");

        horizontalLayout_3->addWidget(cmb_authType);


        gridLayout_4->addLayout(horizontalLayout_3, 0, 0, 1, 1);


        verticalLayout->addWidget(groupBox_4);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        btn_advancedOption = new QPushButton(scrollAreaWidgetContents);
        btn_advancedOption->setObjectName("btn_advancedOption");

        horizontalLayout->addWidget(btn_advancedOption);


        verticalLayout->addLayout(horizontalLayout);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_2->addWidget(scrollArea);

        QWidget::setTabOrder(le_gateway, le_remoteIp);
        QWidget::setTabOrder(le_remoteIp, le_localIp);
        QWidget::setTabOrder(le_localIp, le_netmask);
        QWidget::setTabOrder(le_netmask, chk_useIpv6);
        QWidget::setTabOrder(chk_useIpv6, le_remoteIpv6);
        QWidget::setTabOrder(le_remoteIpv6, le_localIpv6);
        QWidget::setTabOrder(le_localIpv6, le_netmaskIpv6);
        QWidget::setTabOrder(le_netmaskIpv6, le_password);
        QWidget::setTabOrder(le_password, kurl_sshKeyFile);
        QWidget::setTabOrder(kurl_sshKeyFile, cmb_authType);
        QWidget::setTabOrder(cmb_authType, btn_advancedOption);

        retranslateUi(SshWidget);
        QObject::connect(chk_useIpv6, &QCheckBox::toggled, le_localIpv6, &QLineEdit::setEnabled);
        QObject::connect(chk_useIpv6, &QCheckBox::toggled, le_netmaskIpv6, &QLineEdit::setEnabled);
        QObject::connect(chk_useIpv6, &QCheckBox::toggled, le_remoteIpv6, &QLineEdit::setEnabled);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SshWidget);
    } // setupUi

    void retranslateUi(QWidget *SshWidget)
    {
        groupBox->setTitle(tr2i18n("General", nullptr));
        lbl_gateway->setText(tr2i18n("Gateway:", nullptr));
        groupBox_2->setTitle(tr2i18n("Network Settings", nullptr));
        lbl_remoteIp->setText(tr2i18n("Remote IP Address:", nullptr));
        lbl_localIp->setText(tr2i18n("Local IP Address:", nullptr));
        lbl_netmask->setText(tr2i18n("Netmask:", nullptr));
        groupBox_3->setTitle(tr2i18n("IPv6 Network Settings", nullptr));
        chk_useIpv6->setText(tr2i18n("Use IPv6", nullptr));
        lbl_remoteIpv6->setText(tr2i18n("Remote IP Address:", nullptr));
        lbl_localIpv6->setText(tr2i18n("Local IP Address:", nullptr));
        lbl_netmaskIpv6->setText(tr2i18n("Prefix:", nullptr));
        groupBox_4->setTitle(tr2i18n("Authentication", nullptr));
        lbl_password->setText(tr2i18n("Password:", nullptr));
        lbl_sshKeyFile->setText(tr2i18n("SSH Key File:", nullptr));
        lbl_authType->setText(tr2i18n("Type:", nullptr));
        cmb_authType->setItemText(0, tr2i18n("SSH Agent", nullptr));
        cmb_authType->setItemText(1, tr2i18n("Password", nullptr));
        cmb_authType->setItemText(2, tr2i18n("Key authentication", nullptr));

        btn_advancedOption->setText(tr2i18n("Advanced\342\200\246", nullptr));
        (void)SshWidget;
    } // retranslateUi

};

namespace Ui {
    class SshWidget: public Ui_SshWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SSHWIDGET_H

