/********************************************************************************
** Form generated from reading UI file 'ipv6.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IPV6_H
#define UI_IPV6_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_IPv6Widget
{
public:
    QGridLayout *gridLayout_2;
    QCheckBox *ipv6RequiredCB;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    KLineEdit *dns;
    QPushButton *dnsMorePushButton;
    QGridLayout *gridLayout;
    QPushButton *btnRemove;
    QPushButton *btnAdd;
    QTableView *tableViewAddresses;
    QSpacerItem *verticalSpacer_3;
    QLabel *dnsLabel;
    KComboBox *privacyCombo;
    KComboBox *method;
    QHBoxLayout *horizontalLayout_5;
    KLineEdit *dnsSearch;
    QPushButton *dnsSearchMorePushButton;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *btnRoutes;
    QLabel *labelPrivacy;
    QLabel *dnsSearchLabel;
    QLabel *labelRouteMetric;
    QDoubleSpinBox *routeMetric;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *IPv6Widget)
    {
        if (IPv6Widget->objectName().isEmpty())
            IPv6Widget->setObjectName("IPv6Widget");
        IPv6Widget->resize(418, 434);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(IPv6Widget->sizePolicy().hasHeightForWidth());
        IPv6Widget->setSizePolicy(sizePolicy);
        IPv6Widget->setLayoutDirection(Qt::LeftToRight);
        gridLayout_2 = new QGridLayout(IPv6Widget);
        gridLayout_2->setObjectName("gridLayout_2");
        ipv6RequiredCB = new QCheckBox(IPv6Widget);
        ipv6RequiredCB->setObjectName("ipv6RequiredCB");
        ipv6RequiredCB->setChecked(true);

        gridLayout_2->addWidget(ipv6RequiredCB, 6, 0, 1, 2);

        label = new QLabel(IPv6Widget);
        label->setObjectName("label");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy1);
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        dns = new KLineEdit(IPv6Widget);
        dns->setObjectName("dns");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(dns->sizePolicy().hasHeightForWidth());
        dns->setSizePolicy(sizePolicy2);
        dns->setMinimumSize(QSize(250, 0));

        horizontalLayout_2->addWidget(dns);

        dnsMorePushButton = new QPushButton(IPv6Widget);
        dnsMorePushButton->setObjectName("dnsMorePushButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-properties")));
        dnsMorePushButton->setIcon(icon);

        horizontalLayout_2->addWidget(dnsMorePushButton);


        gridLayout_2->addLayout(horizontalLayout_2, 1, 1, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        btnRemove = new QPushButton(IPv6Widget);
        btnRemove->setObjectName("btnRemove");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        btnRemove->setIcon(icon1);

        gridLayout->addWidget(btnRemove, 1, 1, 1, 1);

        btnAdd = new QPushButton(IPv6Widget);
        btnAdd->setObjectName("btnAdd");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("list-add")));
        btnAdd->setIcon(icon2);

        gridLayout->addWidget(btnAdd, 0, 1, 1, 1);

        tableViewAddresses = new QTableView(IPv6Widget);
        tableViewAddresses->setObjectName("tableViewAddresses");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(tableViewAddresses->sizePolicy().hasHeightForWidth());
        tableViewAddresses->setSizePolicy(sizePolicy3);
        tableViewAddresses->setSelectionMode(QAbstractItemView::SingleSelection);
        tableViewAddresses->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableViewAddresses->horizontalHeader()->setStretchLastSection(true);
        tableViewAddresses->verticalHeader()->setVisible(false);

        gridLayout->addWidget(tableViewAddresses, 0, 0, 3, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout->addItem(verticalSpacer_3, 2, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 5, 0, 1, 2);

        dnsLabel = new QLabel(IPv6Widget);
        dnsLabel->setObjectName("dnsLabel");
        sizePolicy1.setHeightForWidth(dnsLabel->sizePolicy().hasHeightForWidth());
        dnsLabel->setSizePolicy(sizePolicy1);
        dnsLabel->setTextFormat(Qt::AutoText);
        dnsLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(dnsLabel, 1, 0, 1, 1);

        privacyCombo = new KComboBox(IPv6Widget);
        privacyCombo->addItem(QString());
        privacyCombo->addItem(QString());
        privacyCombo->addItem(QString());
        privacyCombo->addItem(QString());
        privacyCombo->setObjectName("privacyCombo");
        sizePolicy2.setHeightForWidth(privacyCombo->sizePolicy().hasHeightForWidth());
        privacyCombo->setSizePolicy(sizePolicy2);

        gridLayout_2->addWidget(privacyCombo, 3, 1, 1, 1);

        method = new KComboBox(IPv6Widget);
        method->addItem(QString());
        method->addItem(QString());
        method->addItem(QString());
        method->addItem(QString());
        method->addItem(QString());
        method->addItem(QString());
        method->addItem(QString());
        method->setObjectName("method");
        sizePolicy2.setHeightForWidth(method->sizePolicy().hasHeightForWidth());
        method->setSizePolicy(sizePolicy2);

        gridLayout_2->addWidget(method, 0, 1, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        dnsSearch = new KLineEdit(IPv6Widget);
        dnsSearch->setObjectName("dnsSearch");
        dnsSearch->setMinimumSize(QSize(250, 0));

        horizontalLayout_5->addWidget(dnsSearch);

        dnsSearchMorePushButton = new QPushButton(IPv6Widget);
        dnsSearchMorePushButton->setObjectName("dnsSearchMorePushButton");
        dnsSearchMorePushButton->setIcon(icon);

        horizontalLayout_5->addWidget(dnsSearchMorePushButton);


        gridLayout_2->addLayout(horizontalLayout_5, 2, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        btnRoutes = new QPushButton(IPv6Widget);
        btnRoutes->setObjectName("btnRoutes");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(btnRoutes->sizePolicy().hasHeightForWidth());
        btnRoutes->setSizePolicy(sizePolicy4);
        btnRoutes->setMaximumSize(QSize(16777215, 16777215));

        horizontalLayout->addWidget(btnRoutes);


        gridLayout_2->addLayout(horizontalLayout, 8, 0, 1, 2);

        labelPrivacy = new QLabel(IPv6Widget);
        labelPrivacy->setObjectName("labelPrivacy");
        sizePolicy1.setHeightForWidth(labelPrivacy->sizePolicy().hasHeightForWidth());
        labelPrivacy->setSizePolicy(sizePolicy1);
        labelPrivacy->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(labelPrivacy, 3, 0, 1, 1);

        dnsSearchLabel = new QLabel(IPv6Widget);
        dnsSearchLabel->setObjectName("dnsSearchLabel");
        sizePolicy1.setHeightForWidth(dnsSearchLabel->sizePolicy().hasHeightForWidth());
        dnsSearchLabel->setSizePolicy(sizePolicy1);
        dnsSearchLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(dnsSearchLabel, 2, 0, 1, 1);

        labelRouteMetric = new QLabel(IPv6Widget);
        labelRouteMetric->setObjectName("labelRouteMetric");
        sizePolicy1.setHeightForWidth(labelRouteMetric->sizePolicy().hasHeightForWidth());
        labelRouteMetric->setSizePolicy(sizePolicy1);
        labelRouteMetric->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(labelRouteMetric, 4, 0, 1, 1);

        routeMetric = new QDoubleSpinBox(IPv6Widget);
        routeMetric->setObjectName("routeMetric");
        routeMetric->setDecimals(0);
        routeMetric->setMinimum(-1.000000000000000);
        routeMetric->setMaximum(4294967295.000000000000000);

        gridLayout_2->addWidget(routeMetric, 4, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 7, 0, 1, 2);

        labelPrivacy->raise();
        ipv6RequiredCB->raise();
        method->raise();
        dnsLabel->raise();
        dnsSearchLabel->raise();
        privacyCombo->raise();
        label->raise();
#if QT_CONFIG(shortcut)
        label->setBuddy(method);
        dnsLabel->setBuddy(dns);
        labelPrivacy->setBuddy(privacyCombo);
        dnsSearchLabel->setBuddy(dnsSearch);
        labelRouteMetric->setBuddy(routeMetric);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(method, dns);
        QWidget::setTabOrder(dns, dnsMorePushButton);
        QWidget::setTabOrder(dnsMorePushButton, dnsSearch);
        QWidget::setTabOrder(dnsSearch, dnsSearchMorePushButton);
        QWidget::setTabOrder(dnsSearchMorePushButton, privacyCombo);
        QWidget::setTabOrder(privacyCombo, routeMetric);
        QWidget::setTabOrder(routeMetric, tableViewAddresses);
        QWidget::setTabOrder(tableViewAddresses, btnAdd);
        QWidget::setTabOrder(btnAdd, btnRemove);
        QWidget::setTabOrder(btnRemove, btnRoutes);

        retranslateUi(IPv6Widget);

        QMetaObject::connectSlotsByName(IPv6Widget);
    } // setupUi

    void retranslateUi(QWidget *IPv6Widget)
    {
#if QT_CONFIG(tooltip)
        IPv6Widget->setToolTip(tr2i18n("Advanced IP settings", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        ipv6RequiredCB->setToolTip(tr2i18n("When connecting to IPv4-capable networks, allows the connection to complete if\n"
"IPv6 configuration fails but IPv4 configuration succeeds", nullptr));
#endif // QT_CONFIG(tooltip)
        ipv6RequiredCB->setText(tr2i18n("IPv6 is required for this connection", nullptr));
        label->setText(tr2i18n("Method:", nullptr));
#if QT_CONFIG(tooltip)
        dns->setToolTip(tr2i18n("Use this field to specify the IP address(es) of one or more DNS servers. Use ',' to separate entries.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        dnsMorePushButton->setToolTip(tr2i18n("Edit the list of DNS servers", nullptr));
#endif // QT_CONFIG(tooltip)
        btnRemove->setText(tr2i18n("Remove", nullptr));
        btnAdd->setText(tr2i18n("Add", nullptr));
#if QT_CONFIG(tooltip)
        tableViewAddresses->setToolTip(tr2i18n("IP addresses identify your computer on the network. Click the \"Add\" button to add\n"
"an IP address", nullptr));
#endif // QT_CONFIG(tooltip)
        dnsLabel->setText(tr2i18n("DNS Servers:", "@info"));
        privacyCombo->setItemText(0, tr2i18n("Default", nullptr));
        privacyCombo->setItemText(1, tr2i18n("Disabled", "privacy disabled"));
        privacyCombo->setItemText(2, tr2i18n("Enabled (prefer public address)", nullptr));
        privacyCombo->setItemText(3, tr2i18n("Enabled (prefer temporary addresses)", nullptr));

#if QT_CONFIG(tooltip)
        privacyCombo->setToolTip(tr2i18n("Configure IPv6 Privacy Extensions for SLAAC, described in RFC4941. If enabled, it makes the kernel generate\n"
"a temporary IPv6 address in addition to the public one generated from MAC address via modified EUI-64.", nullptr));
#endif // QT_CONFIG(tooltip)
        method->setItemText(0, tr2i18n("Automatic", "Method:"));
        method->setItemText(1, tr2i18n("Automatic (Only addresses)", nullptr));
        method->setItemText(2, tr2i18n("Automatic (Only DHCP)", nullptr));
        method->setItemText(3, tr2i18n("Link-Local", nullptr));
        method->setItemText(4, tr2i18n("Manual", "like in use Manual configuration"));
        method->setItemText(5, tr2i18n("Ignored", "like in this setting is Disabled"));
        method->setItemText(6, tr2i18n("Disabled", nullptr));

#if QT_CONFIG(tooltip)
        method->setToolTip(tr2i18n("How to configure the IPv6 address:\n"
"\342\200\242 Automatic: obtain address and DNS automatically (via SLAAC and/or DHCPv6)\n"
"\342\200\242 Automatic (Only addresses): obtain address automatically but configure DNS manually\n"
"\342\200\242 Automatic (Only DHCP): obtain address and DNS via DHCPv6 only (ignore SLAAC)\n"
"\342\200\242 Link-Local: use automatic link-local addressing (fe80::/10)\n"
"\342\200\242 Manual: enter a static IP address\n"
"\342\200\242 Ignored: skip IPv6 configuration but allow connection\n"
"\342\200\242 Disabled: turn off IPv6 completely", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        dnsSearch->setToolTip(tr2i18n("Use this field to specify one or more DNS domains to search. Use ',' to separate entries.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        dnsSearchMorePushButton->setToolTip(tr2i18n("Edit the list of DNS domains being searched", nullptr));
#endif // QT_CONFIG(tooltip)
        btnRoutes->setText(tr2i18n("Routes\342\200\246", nullptr));
        labelPrivacy->setText(tr2i18n("Privacy:", nullptr));
        dnsSearchLabel->setText(tr2i18n("Search Domains:", "@info"));
        labelRouteMetric->setText(tr2i18n("Route Metric:", nullptr));
        routeMetric->setSuffix(QString());
        routeMetric->setPrefix(QString());
#if QT_CONFIG(tooltip)
        routeMetric->setToolTip(tr2i18n("A score that helps choose the best path for data packets to reach their destination,\n"
"based on factors like distance, delay, and reliability.\n"
"\n"
"Default value -1 means that NetworkManager gets to choose and manage the actual metric of the route.", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class IPv6Widget: public Ui_IPv6Widget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IPV6_H

