/********************************************************************************
** Form generated from reading UI file 'fortisslvpnauth.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FORTISSLVPNAUTH_H
#define UI_FORTISSLVPNAUTH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_FortisslvpnAuth
{
public:
    QVBoxLayout *verticalLayout;
    QFrame *passwordFrame;
    QHBoxLayout *horizontalLayout;
    QLabel *passwordLabel;
    PasswordField *password;
    QFrame *otpFrame;
    QGridLayout *gridLayout;
    QLabel *labelOtp;
    QLabel *otpLabel;
    PasswordField *otp;

    void setupUi(QWidget *FortisslvpnAuth)
    {
        if (FortisslvpnAuth->objectName().isEmpty())
            FortisslvpnAuth->setObjectName("FortisslvpnAuth");
        FortisslvpnAuth->resize(408, 136);
        verticalLayout = new QVBoxLayout(FortisslvpnAuth);
        verticalLayout->setObjectName("verticalLayout");
        passwordFrame = new QFrame(FortisslvpnAuth);
        passwordFrame->setObjectName("passwordFrame");
        passwordFrame->setFrameShape(QFrame::StyledPanel);
        passwordFrame->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(passwordFrame);
        horizontalLayout->setObjectName("horizontalLayout");
        passwordLabel = new QLabel(passwordFrame);
        passwordLabel->setObjectName("passwordLabel");
        passwordLabel->setWordWrap(false);

        horizontalLayout->addWidget(passwordLabel);

        password = new PasswordField(passwordFrame);
        password->setObjectName("password");
        password->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout->addWidget(password);


        verticalLayout->addWidget(passwordFrame);

        otpFrame = new QFrame(FortisslvpnAuth);
        otpFrame->setObjectName("otpFrame");
        otpFrame->setFrameShape(QFrame::StyledPanel);
        otpFrame->setFrameShadow(QFrame::Raised);
        gridLayout = new QGridLayout(otpFrame);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setVerticalSpacing(0);
        labelOtp = new QLabel(otpFrame);
        labelOtp->setObjectName("labelOtp");

        gridLayout->addWidget(labelOtp, 0, 1, 1, 1);

        otpLabel = new QLabel(otpFrame);
        otpLabel->setObjectName("otpLabel");

        gridLayout->addWidget(otpLabel, 1, 0, 1, 1);

        otp = new PasswordField(otpFrame);
        otp->setObjectName("otp");

        gridLayout->addWidget(otp, 1, 1, 1, 1);


        verticalLayout->addWidget(otpFrame);

#if QT_CONFIG(shortcut)
        passwordLabel->setBuddy(password);
#endif // QT_CONFIG(shortcut)

        retranslateUi(FortisslvpnAuth);

        QMetaObject::connectSlotsByName(FortisslvpnAuth);
    } // setupUi

    void retranslateUi(QWidget *FortisslvpnAuth)
    {
        passwordLabel->setText(tr2i18n("Password:", nullptr));
        labelOtp->setText(tr2i18n("One Time Password", nullptr));
        otpLabel->setText(tr2i18n("Token:", nullptr));
        (void)FortisslvpnAuth;
    } // retranslateUi

};

namespace Ui {
    class FortisslvpnAuth: public Ui_FortisslvpnAuth {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FORTISSLVPNAUTH_H

