/********************************************************************************
** Form generated from reading UI file 'sshadvanced.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SSHADVANCED_H
#define UI_SSHADVANCED_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SshAdvanced
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QCheckBox *chk_useCustomGatewayPort;
    QSpinBox *sb_useCustomGatewayPort;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *chk_useCustomTunnelMtu;
    QSpinBox *sb_useCustomTunnelMtu;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *chk_extraSshOptions;
    QLineEdit *le_extraSshOptions;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *chk_remoteDeviceNumber;
    QSpinBox *sb_remoteDeviceNumber;
    QCheckBox *chk_useTapDevice;
    QHBoxLayout *horizontalLayout_5;
    QCheckBox *chk_remoteUsername;
    QLineEdit *le_remoteUsername;
    QCheckBox *chk_doNotReplaceDefaultRoute;

    void setupUi(QWidget *SshAdvanced)
    {
        if (SshAdvanced->objectName().isEmpty())
            SshAdvanced->setObjectName("SshAdvanced");
        SshAdvanced->resize(597, 290);
        verticalLayout = new QVBoxLayout(SshAdvanced);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        chk_useCustomGatewayPort = new QCheckBox(SshAdvanced);
        chk_useCustomGatewayPort->setObjectName("chk_useCustomGatewayPort");

        horizontalLayout->addWidget(chk_useCustomGatewayPort);

        sb_useCustomGatewayPort = new QSpinBox(SshAdvanced);
        sb_useCustomGatewayPort->setObjectName("sb_useCustomGatewayPort");
        sb_useCustomGatewayPort->setEnabled(false);
        sb_useCustomGatewayPort->setMinimum(0);
        sb_useCustomGatewayPort->setMaximum(65535);
        sb_useCustomGatewayPort->setValue(0);

        horizontalLayout->addWidget(sb_useCustomGatewayPort);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        chk_useCustomTunnelMtu = new QCheckBox(SshAdvanced);
        chk_useCustomTunnelMtu->setObjectName("chk_useCustomTunnelMtu");

        horizontalLayout_2->addWidget(chk_useCustomTunnelMtu);

        sb_useCustomTunnelMtu = new QSpinBox(SshAdvanced);
        sb_useCustomTunnelMtu->setObjectName("sb_useCustomTunnelMtu");
        sb_useCustomTunnelMtu->setEnabled(false);
        sb_useCustomTunnelMtu->setMinimum(0);
        sb_useCustomTunnelMtu->setMaximum(999999999);

        horizontalLayout_2->addWidget(sb_useCustomTunnelMtu);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        chk_extraSshOptions = new QCheckBox(SshAdvanced);
        chk_extraSshOptions->setObjectName("chk_extraSshOptions");

        horizontalLayout_3->addWidget(chk_extraSshOptions);

        le_extraSshOptions = new QLineEdit(SshAdvanced);
        le_extraSshOptions->setObjectName("le_extraSshOptions");
        le_extraSshOptions->setEnabled(false);

        horizontalLayout_3->addWidget(le_extraSshOptions);


        verticalLayout->addLayout(horizontalLayout_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        chk_remoteDeviceNumber = new QCheckBox(SshAdvanced);
        chk_remoteDeviceNumber->setObjectName("chk_remoteDeviceNumber");

        horizontalLayout_4->addWidget(chk_remoteDeviceNumber);

        sb_remoteDeviceNumber = new QSpinBox(SshAdvanced);
        sb_remoteDeviceNumber->setObjectName("sb_remoteDeviceNumber");
        sb_remoteDeviceNumber->setEnabled(false);
        sb_remoteDeviceNumber->setMaximum(999999999);

        horizontalLayout_4->addWidget(sb_remoteDeviceNumber);


        verticalLayout->addLayout(horizontalLayout_4);

        chk_useTapDevice = new QCheckBox(SshAdvanced);
        chk_useTapDevice->setObjectName("chk_useTapDevice");

        verticalLayout->addWidget(chk_useTapDevice);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        chk_remoteUsername = new QCheckBox(SshAdvanced);
        chk_remoteUsername->setObjectName("chk_remoteUsername");

        horizontalLayout_5->addWidget(chk_remoteUsername);

        le_remoteUsername = new QLineEdit(SshAdvanced);
        le_remoteUsername->setObjectName("le_remoteUsername");
        le_remoteUsername->setEnabled(false);

        horizontalLayout_5->addWidget(le_remoteUsername);


        verticalLayout->addLayout(horizontalLayout_5);

        chk_doNotReplaceDefaultRoute = new QCheckBox(SshAdvanced);
        chk_doNotReplaceDefaultRoute->setObjectName("chk_doNotReplaceDefaultRoute");

        verticalLayout->addWidget(chk_doNotReplaceDefaultRoute);


        retranslateUi(SshAdvanced);
        QObject::connect(chk_useCustomGatewayPort, &QCheckBox::toggled, sb_useCustomGatewayPort, &QSpinBox::setEnabled);
        QObject::connect(chk_useCustomTunnelMtu, &QCheckBox::toggled, sb_useCustomTunnelMtu, &QSpinBox::setEnabled);
        QObject::connect(chk_extraSshOptions, &QCheckBox::toggled, le_extraSshOptions, &QLineEdit::setEnabled);
        QObject::connect(chk_remoteDeviceNumber, &QCheckBox::toggled, sb_remoteDeviceNumber, &QSpinBox::setEnabled);
        QObject::connect(chk_remoteUsername, &QCheckBox::toggled, le_remoteUsername, &QLineEdit::setEnabled);

        QMetaObject::connectSlotsByName(SshAdvanced);
    } // setupUi

    void retranslateUi(QWidget *SshAdvanced)
    {
        chk_useCustomGatewayPort->setText(tr2i18n("Use custom gateway port:", nullptr));
        chk_useCustomTunnelMtu->setText(tr2i18n("Use custom tunnel Maximum Transmission Unit (MTU):", nullptr));
        chk_extraSshOptions->setText(tr2i18n("Extra SSH options:", nullptr));
        chk_remoteDeviceNumber->setText(tr2i18n("Remote device number:", nullptr));
        chk_useTapDevice->setText(tr2i18n("Use a TAP device", nullptr));
        chk_remoteUsername->setText(tr2i18n("Remote username", nullptr));
        chk_doNotReplaceDefaultRoute->setText(tr2i18n("Do not replace default route", nullptr));
        (void)SshAdvanced;
    } // retranslateUi

};

namespace Ui {
    class SshAdvanced: public Ui_SshAdvanced {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SSHADVANCED_H

