/****************************************************************************
** Meta object code from reading C++ file 'notification.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-nm-6.7.4/kded/notification.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notification.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12NotificationE_t {};
} // unnamed namespace

template <> constexpr inline auto Notification::qt_create_metaobjectdata<qt_meta_tag_ZN12NotificationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Notification",
        "connectionDeactivatedPreparingForSleep",
        "",
        "deviceAdded",
        "uni",
        "addDevice",
        "NetworkManager::Device::Ptr",
        "device",
        "stateChanged",
        "NetworkManager::Device::State",
        "newstate",
        "oldstate",
        "NetworkManager::Device::StateChangeReason",
        "reason",
        "addActiveConnection",
        "path",
        "NetworkManager::ActiveConnection::Ptr",
        "ac",
        "onActiveConnectionStateChanged",
        "NetworkManager::ActiveConnection::State",
        "state",
        "onVpnConnectionStateChanged",
        "NetworkManager::VpnConnection::State",
        "NetworkManager::VpnConnection::StateChangeReason",
        "notificationClosed",
        "onPrepareForSleep",
        "sleep",
        "onCheckActiveConnectionOnResume"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connectionDeactivatedPreparingForSleep'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deviceAdded'
        QtMocHelpers::SlotData<void(const QString &)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'addDevice'
        QtMocHelpers::SlotData<void(const NetworkManager::Device::Ptr &)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'stateChanged'
        QtMocHelpers::SlotData<void(NetworkManager::Device::State, NetworkManager::Device::State, NetworkManager::Device::StateChangeReason)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 9, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'addActiveConnection'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'addActiveConnection'
        QtMocHelpers::SlotData<void(const NetworkManager::ActiveConnection::Ptr &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'onActiveConnectionStateChanged'
        QtMocHelpers::SlotData<void(NetworkManager::ActiveConnection::State)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'onVpnConnectionStateChanged'
        QtMocHelpers::SlotData<void(NetworkManager::VpnConnection::State, NetworkManager::VpnConnection::StateChangeReason)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 20 }, { 0x80000000 | 23, 13 },
        }}),
        // Slot 'notificationClosed'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPrepareForSleep'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'onCheckActiveConnectionOnResume'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Notification, qt_meta_tag_ZN12NotificationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Notification::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NotificationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NotificationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12NotificationE_t>.metaTypes,
    nullptr
} };

void Notification::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Notification *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connectionDeactivatedPreparingForSleep(); break;
        case 1: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->addDevice((*reinterpret_cast<std::add_pointer_t<NetworkManager::Device::Ptr>>(_a[1]))); break;
        case 3: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::Device::State>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetworkManager::Device::State>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<NetworkManager::Device::StateChangeReason>>(_a[3]))); break;
        case 4: _t->addActiveConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->addActiveConnection((*reinterpret_cast<std::add_pointer_t<NetworkManager::ActiveConnection::Ptr>>(_a[1]))); break;
        case 6: _t->onActiveConnectionStateChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::ActiveConnection::State>>(_a[1]))); break;
        case 7: _t->onVpnConnectionStateChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::VpnConnection::State>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetworkManager::VpnConnection::StateChangeReason>>(_a[2]))); break;
        case 8: _t->notificationClosed(); break;
        case 9: _t->onPrepareForSleep((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->onCheckActiveConnectionOnResume(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Notification::*)()>(_a, &Notification::connectionDeactivatedPreparingForSleep, 0))
            return;
    }
}

const QMetaObject *Notification::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Notification::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NotificationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Notification::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Notification::connectionDeactivatedPreparingForSleep()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
