/****************************************************************************
** Meta object code from reading C++ file 'cellularsim.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-nm-6.7.4/libs/cellular/cellularsim.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cellularsim.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11CellularSimE_t {};
} // unnamed namespace

template <> constexpr inline auto CellularSim::qt_create_metaobjectdata<qt_meta_tag_ZN11CellularSimE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CellularSim",
        "QML.Element",
        "auto",
        "enabledChanged",
        "",
        "pinEnabledChanged",
        "unlockRetriesLeftChanged",
        "lockedChanged",
        "lockedReasonChanged",
        "imsiChanged",
        "eidChanged",
        "operatorIdentifierChanged",
        "operatorNameChanged",
        "simIdentifierChanged",
        "emergencyNumbersChanged",
        "uniChanged",
        "displayIdChanged",
        "modemChanged",
        "errorOccurred",
        "message",
        "togglePinEnabled",
        "QCoro::Task<void>",
        "pin",
        "changePin",
        "oldPin",
        "newPin",
        "sendPin",
        "sendPuk",
        "puk",
        "enabled",
        "pinEnabled",
        "unlockRetriesLeft",
        "locked",
        "lockedReason",
        "imsi",
        "eid",
        "operatorIdentifier",
        "operatorName",
        "simIdentifier",
        "emergencyNumbers",
        "uni",
        "displayId",
        "modem",
        "CellularModem*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pinEnabledChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unlockRetriesLeftChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lockedChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lockedReasonChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imsiChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'eidChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'operatorIdentifierChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'operatorNameChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'simIdentifierChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emergencyNumbersChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uniChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayIdChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modemChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void(const QString &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Method 'togglePinEnabled'
        QtMocHelpers::MethodData<QCoro::Task<void>(const QString &)>(20, 4, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'changePin'
        QtMocHelpers::MethodData<QCoro::Task<void>(const QString &, const QString &)>(23, 4, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 25 },
        }}),
        // Method 'sendPin'
        QtMocHelpers::MethodData<QCoro::Task<void>(const QString &)>(26, 4, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'sendPuk'
        QtMocHelpers::MethodData<QCoro::Task<void>(const QString &, const QString &)>(27, 4, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'pinEnabled'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'unlockRetriesLeft'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'locked'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'lockedReason'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'imsi'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'eid'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'operatorIdentifier'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'operatorName'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'simIdentifier'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'emergencyNumbers'
        QtMocHelpers::PropertyData<QStringList>(39, QMetaType::QStringList, QMC::DefaultPropertyFlags, 10),
        // property 'uni'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'displayId'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'modem'
        QtMocHelpers::PropertyData<CellularModem*>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 13),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<CellularSim, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CellularSim::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11CellularSimE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11CellularSimE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11CellularSimE_t>.metaTypes,
    nullptr
} };

void CellularSim::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CellularSim *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged(); break;
        case 1: _t->pinEnabledChanged(); break;
        case 2: _t->unlockRetriesLeftChanged(); break;
        case 3: _t->lockedChanged(); break;
        case 4: _t->lockedReasonChanged(); break;
        case 5: _t->imsiChanged(); break;
        case 6: _t->eidChanged(); break;
        case 7: _t->operatorIdentifierChanged(); break;
        case 8: _t->operatorNameChanged(); break;
        case 9: _t->simIdentifierChanged(); break;
        case 10: _t->emergencyNumbersChanged(); break;
        case 11: _t->uniChanged(); break;
        case 12: _t->displayIdChanged(); break;
        case 13: _t->modemChanged(); break;
        case 14: _t->errorOccurred((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: { QCoro::Task<void> _r = _t->togglePinEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QCoro::Task<void> _r = _t->changePin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QCoro::Task<void> _r = _t->sendPin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QCoro::Task<void> _r = _t->sendPuk((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::pinEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::unlockRetriesLeftChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::lockedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::lockedReasonChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::imsiChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::eidChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::operatorIdentifierChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::operatorNameChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::simIdentifierChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::emergencyNumbersChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::uniChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::displayIdChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)()>(_a, &CellularSim::modemChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularSim::*)(const QString & )>(_a, &CellularSim::errorOccurred, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->pinEnabled(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->unlockRetriesLeft(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->lockedReason(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->imsi(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->eid(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->operatorIdentifier(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->operatorName(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->simIdentifier(); break;
        case 10: *reinterpret_cast<QStringList*>(_v) = _t->emergencyNumbers(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->uni(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->displayId(); break;
        case 13: *reinterpret_cast<CellularModem**>(_v) = _t->modem(); break;
        default: break;
        }
    }
}

const QMetaObject *CellularSim::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CellularSim::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11CellularSimE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CellularSim::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void CellularSim::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CellularSim::pinEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CellularSim::unlockRetriesLeftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CellularSim::lockedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void CellularSim::lockedReasonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CellularSim::imsiChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void CellularSim::eidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void CellularSim::operatorIdentifierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void CellularSim::operatorNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void CellularSim::simIdentifierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void CellularSim::emergencyNumbersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void CellularSim::uniChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void CellularSim::displayIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void CellularSim::modemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void CellularSim::errorOccurred(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}
QT_WARNING_POP
