/********************************************************************************
** Form generated from reading UI file 'openconnectwebauthdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENCONNECTWEBAUTHDIALOG_H
#define UI_OPENCONNECTWEBAUTHDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpenconnectWebAuthDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *headingLabel;
    QLabel *description;
    QVBoxLayout *mainVerticalLayout;
    QGroupBox *pinGroupBox;
    QFormLayout *formLayout;
    QLabel *pinLabel;
    QLineEdit *pinLineEdit;
    QLabel *confirmPinLabel;
    QLineEdit *confirmPinLineEdit;
    QLabel *pinEntryErrorLabel;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *Dialog)
    {
        if (Dialog->objectName().isEmpty())
            Dialog->setObjectName("Dialog");
        Dialog->resize(480, 195);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Dialog->sizePolicy().hasHeightForWidth());
        Dialog->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(Dialog);
        verticalLayout->setObjectName("verticalLayout");
        headingLabel = new QLabel(Dialog);
        headingLabel->setObjectName("headingLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(headingLabel->sizePolicy().hasHeightForWidth());
        headingLabel->setSizePolicy(sizePolicy1);
        headingLabel->setWordWrap(false);

        verticalLayout->addWidget(headingLabel);

        description = new QLabel(Dialog);
        description->setObjectName("description");
        sizePolicy1.setHeightForWidth(description->sizePolicy().hasHeightForWidth());
        description->setSizePolicy(sizePolicy1);
        description->setWordWrap(false);

        verticalLayout->addWidget(description);

        mainVerticalLayout = new QVBoxLayout();
        mainVerticalLayout->setObjectName("mainVerticalLayout");
        mainVerticalLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        pinGroupBox = new QGroupBox(Dialog);
        pinGroupBox->setObjectName("pinGroupBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(pinGroupBox->sizePolicy().hasHeightForWidth());
        pinGroupBox->setSizePolicy(sizePolicy2);
        pinGroupBox->setFlat(true);
        formLayout = new QFormLayout(pinGroupBox);
        formLayout->setObjectName("formLayout");
        pinLabel = new QLabel(pinGroupBox);
        pinLabel->setObjectName("pinLabel");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(pinLabel->sizePolicy().hasHeightForWidth());
        pinLabel->setSizePolicy(sizePolicy3);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, pinLabel);

        pinLineEdit = new QLineEdit(pinGroupBox);
        pinLineEdit->setObjectName("pinLineEdit");
        pinLineEdit->setInputMethodHints(Qt::ImhHiddenText|Qt::ImhNoAutoUppercase|Qt::ImhNoPredictiveText|Qt::ImhSensitiveData);
        pinLineEdit->setEchoMode(QLineEdit::Password);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, pinLineEdit);

        confirmPinLabel = new QLabel(pinGroupBox);
        confirmPinLabel->setObjectName("confirmPinLabel");
        sizePolicy3.setHeightForWidth(confirmPinLabel->sizePolicy().hasHeightForWidth());
        confirmPinLabel->setSizePolicy(sizePolicy3);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, confirmPinLabel);

        confirmPinLineEdit = new QLineEdit(pinGroupBox);
        confirmPinLineEdit->setObjectName("confirmPinLineEdit");
        confirmPinLineEdit->setInputMethodHints(Qt::ImhHiddenText|Qt::ImhNoAutoUppercase|Qt::ImhNoPredictiveText|Qt::ImhSensitiveData);
        confirmPinLineEdit->setEchoMode(QLineEdit::Password);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, confirmPinLineEdit);

        pinEntryErrorLabel = new QLabel(pinGroupBox);
        pinEntryErrorLabel->setObjectName("pinEntryErrorLabel");
        sizePolicy1.setHeightForWidth(pinEntryErrorLabel->sizePolicy().hasHeightForWidth());
        pinEntryErrorLabel->setSizePolicy(sizePolicy1);

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, pinEntryErrorLabel);


        mainVerticalLayout->addWidget(pinGroupBox);


        verticalLayout->addLayout(mainVerticalLayout);

        buttonBox = new QDialogButtonBox(Dialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Retry);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(Dialog);

        QMetaObject::connectSlotsByName(Dialog);
    } // setupUi

    void retranslateUi(QDialog *Dialog)
    {
        Dialog->setWindowTitle(tr2i18n("WebAuth", nullptr));
        headingLabel->setText(tr2i18n("Heading", nullptr));
        description->setText(tr2i18n("Description", nullptr));
        pinGroupBox->setTitle(QString());
        pinLabel->setText(tr2i18n("PIN", nullptr));
        confirmPinLabel->setText(tr2i18n("Confirm PIN", nullptr));
        pinEntryErrorLabel->setText(tr2i18n("TextLabel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpenconnectWebAuthDialog: public Ui_OpenconnectWebAuthDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPENCONNECTWEBAUTHDIALOG_H

