/********************************************************************************
** Form generated from reading UI file 'iodine.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IODINE_H
#define UI_IODINE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_IodineWidget
{
public:
    QFormLayout *formLayout;
    QLabel *lbl_toplevelDomain;
    QLineEdit *le_toplevelDomain;
    QLabel *lbl_nameserver;
    QLineEdit *le_nameserver;
    QLabel *lbl_password;
    PasswordField *le_password;
    QLabel *lbl_fragmentSize;
    QSpinBox *sb_fragmentSize;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *IodineWidget)
    {
        if (IodineWidget->objectName().isEmpty())
            IodineWidget->setObjectName("IodineWidget");
        IodineWidget->resize(387, 214);
        formLayout = new QFormLayout(IodineWidget);
        formLayout->setObjectName("formLayout");
        lbl_toplevelDomain = new QLabel(IodineWidget);
        lbl_toplevelDomain->setObjectName("lbl_toplevelDomain");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lbl_toplevelDomain);

        le_toplevelDomain = new QLineEdit(IodineWidget);
        le_toplevelDomain->setObjectName("le_toplevelDomain");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, le_toplevelDomain);

        lbl_nameserver = new QLabel(IodineWidget);
        lbl_nameserver->setObjectName("lbl_nameserver");
        lbl_nameserver->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, lbl_nameserver);

        le_nameserver = new QLineEdit(IodineWidget);
        le_nameserver->setObjectName("le_nameserver");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, le_nameserver);

        lbl_password = new QLabel(IodineWidget);
        lbl_password->setObjectName("lbl_password");
        lbl_password->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, lbl_password);

        le_password = new PasswordField(IodineWidget);
        le_password->setObjectName("le_password");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, le_password);

        lbl_fragmentSize = new QLabel(IodineWidget);
        lbl_fragmentSize->setObjectName("lbl_fragmentSize");
        lbl_fragmentSize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, lbl_fragmentSize);

        sb_fragmentSize = new QSpinBox(IodineWidget);
        sb_fragmentSize->setObjectName("sb_fragmentSize");
        sb_fragmentSize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        sb_fragmentSize->setMaximum(10000);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, sb_fragmentSize);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(4, QFormLayout::ItemRole::FieldRole, verticalSpacer);


        retranslateUi(IodineWidget);

        QMetaObject::connectSlotsByName(IodineWidget);
    } // setupUi

    void retranslateUi(QWidget *IodineWidget)
    {
        lbl_toplevelDomain->setText(tr2i18n("Toplevel Domain:", nullptr));
        lbl_nameserver->setText(tr2i18n("Nameserver:", nullptr));
        lbl_password->setText(tr2i18n("Password:", nullptr));
        le_password->setText(QString());
        lbl_fragmentSize->setText(tr2i18n("Fragment Size:", nullptr));
        sb_fragmentSize->setSpecialValueText(tr2i18n("Automatic", nullptr));
        sb_fragmentSize->setSuffix(tr2i18n(" bytes", nullptr));
        (void)IodineWidget;
    } // retranslateUi

};

namespace Ui {
    class IodineWidget: public Ui_IodineWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IODINE_H

