/****************************************************************************
** Meta object code from reading C++ file 'networkstatus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-nm-6.7.4/libs/networkstatus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'networkstatus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13NetworkStatusE_t {};
} // unnamed namespace

template <> constexpr inline auto NetworkStatus::qt_create_metaobjectdata<qt_meta_tag_ZN13NetworkStatusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NetworkStatus",
        "QML.Element",
        "auto",
        "activeConnectionsChanged",
        "",
        "activeConnections",
        "connectivityChanged",
        "NetworkManager::Connectivity",
        "connectivity",
        "networkCheckUrlChanged",
        "defaultChanged",
        "statusChanged",
        "NetworkManager::Status",
        "status",
        "changeActiveConnections",
        "checkUnknownReason",
        "networkCheckUrl",
        "QUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activeConnectionsChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'connectivityChanged'
        QtMocHelpers::SignalData<void(NetworkManager::Connectivity)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'networkCheckUrlChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activeConnectionsChanged'
        QtMocHelpers::SlotData<void()>(3, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'defaultChanged'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'statusChanged'
        QtMocHelpers::SlotData<void(NetworkManager::Status)>(11, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'changeActiveConnections'
        QtMocHelpers::SlotData<void()>(14, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'checkUnknownReason'
        QtMocHelpers::MethodData<QString() const>(15, 4, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'activeConnections'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'networkCheckUrl'
        QtMocHelpers::PropertyData<QUrl>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'connectivity'
        QtMocHelpers::PropertyData<NetworkManager::Connectivity>(8, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<NetworkStatus, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN13NetworkStatusE[] = {
    QMetaObject::SuperData::link<NetworkManager::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject NetworkStatus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13NetworkStatusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13NetworkStatusE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN13NetworkStatusE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13NetworkStatusE_t>.metaTypes,
    nullptr
} };

void NetworkStatus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetworkStatus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activeConnectionsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->connectivityChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::Connectivity>>(_a[1]))); break;
        case 2: _t->networkCheckUrlChanged(); break;
        case 3: _t->activeConnectionsChanged(); break;
        case 4: _t->defaultChanged(); break;
        case 5: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::Status>>(_a[1]))); break;
        case 6: _t->changeActiveConnections(); break;
        case 7: { QString _r = _t->checkUnknownReason();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetworkStatus::*)(const QString & )>(_a, &NetworkStatus::activeConnectionsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkStatus::*)(NetworkManager::Connectivity )>(_a, &NetworkStatus::connectivityChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkStatus::*)()>(_a, &NetworkStatus::networkCheckUrlChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->activeConnections(); break;
        case 1: *reinterpret_cast<QUrl*>(_v) = _t->networkCheckUrl(); break;
        case 2: *reinterpret_cast<NetworkManager::Connectivity*>(_v) = _t->connectivity(); break;
        default: break;
        }
    }
}

const QMetaObject *NetworkStatus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NetworkStatus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13NetworkStatusE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int NetworkStatus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void NetworkStatus::activeConnectionsChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void NetworkStatus::connectivityChanged(NetworkManager::Connectivity _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void NetworkStatus::networkCheckUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
