/********************************************************************************
** Form generated from reading UI file 'bt.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BT_H
#define UI_BT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "hwaddrcombobox.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_BtWidget
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    HwAddrComboBox *bdaddr;
    QLabel *label_2;
    KComboBox *type;

    void setupUi(QWidget *BtWidget)
    {
        if (BtWidget->objectName().isEmpty())
            BtWidget->setObjectName("BtWidget");
        BtWidget->resize(400, 300);
        formLayout = new QFormLayout(BtWidget);
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(6);
        label = new QLabel(BtWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        bdaddr = new HwAddrComboBox(BtWidget);
        bdaddr->setObjectName("bdaddr");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(bdaddr->sizePolicy().hasHeightForWidth());
        bdaddr->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, bdaddr);

        label_2 = new QLabel(BtWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        type = new KComboBox(BtWidget);
        type->setObjectName("type");
        sizePolicy.setHeightForWidth(type->sizePolicy().hasHeightForWidth());
        type->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, type);

#if QT_CONFIG(shortcut)
        label->setBuddy(bdaddr);
        label_2->setBuddy(type);
#endif // QT_CONFIG(shortcut)

        retranslateUi(BtWidget);

        QMetaObject::connectSlotsByName(BtWidget);
    } // setupUi

    void retranslateUi(QWidget *BtWidget)
    {
        label->setText(tr2i18n("Address of the device:", nullptr));
        label_2->setText(tr2i18n("Connection type:", nullptr));
        (void)BtWidget;
    } // retranslateUi

};

namespace Ui {
    class BtWidget: public Ui_BtWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BT_H

