/********************************************************************************
** Form generated from reading UI file 'openconnectauth.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENCONNECTAUTH_H
#define UI_OPENCONNECTAUTH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpenconnectAuth
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_3;
    QComboBox *cmbHosts;
    QPushButton *btnConnect;
    QCheckBox *chkAutoconnect;
    QCheckBox *chkStorePasswords;
    QCheckBox *chkStorePlaintextCookies;
    QGroupBox *loginBox;
    QVBoxLayout *loginBoxLayout;
    QGroupBox *serverLogBox;
    QVBoxLayout *logLayout;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *viewServerLog;
    QLabel *lblLogLevel;
    QComboBox *cmbLogLevel;
    QTextBrowser *serverLog;
    QSpacerItem *bottomSpacer;

    void setupUi(QWidget *OpenconnectAuth)
    {
        if (OpenconnectAuth->objectName().isEmpty())
            OpenconnectAuth->setObjectName("OpenconnectAuth");
        OpenconnectAuth->resize(366, 360);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OpenconnectAuth->sizePolicy().hasHeightForWidth());
        OpenconnectAuth->setSizePolicy(sizePolicy);
        OpenconnectAuth->setMinimumSize(QSize(0, 0));
        verticalLayout = new QVBoxLayout(OpenconnectAuth);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setSizeConstraint(QLayout::SizeConstraint::SetMinimumSize);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_3 = new QLabel(OpenconnectAuth);
        label_3->setObjectName("label_3");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy1);

        horizontalLayout_3->addWidget(label_3);

        cmbHosts = new QComboBox(OpenconnectAuth);
        cmbHosts->setObjectName("cmbHosts");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cmbHosts->sizePolicy().hasHeightForWidth());
        cmbHosts->setSizePolicy(sizePolicy2);
        cmbHosts->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContentsOnFirstShow);

        horizontalLayout_3->addWidget(cmbHosts);

        btnConnect = new QPushButton(OpenconnectAuth);
        btnConnect->setObjectName("btnConnect");
        sizePolicy1.setHeightForWidth(btnConnect->sizePolicy().hasHeightForWidth());
        btnConnect->setSizePolicy(sizePolicy1);
        btnConnect->setAutoDefault(false);
        btnConnect->setFlat(false);
        btnConnect->setProperty("isDragEnabled", QVariant(false));

        horizontalLayout_3->addWidget(btnConnect);


        verticalLayout->addLayout(horizontalLayout_3);

        chkAutoconnect = new QCheckBox(OpenconnectAuth);
        chkAutoconnect->setObjectName("chkAutoconnect");

        verticalLayout->addWidget(chkAutoconnect);

        chkStorePasswords = new QCheckBox(OpenconnectAuth);
        chkStorePasswords->setObjectName("chkStorePasswords");

        verticalLayout->addWidget(chkStorePasswords);

        chkStorePlaintextCookies = new QCheckBox(OpenconnectAuth);
        chkStorePlaintextCookies->setObjectName("chkStorePlaintextCookies");

        verticalLayout->addWidget(chkStorePlaintextCookies);

        loginBox = new QGroupBox(OpenconnectAuth);
        loginBox->setObjectName("loginBox");
        loginBox->setMinimumSize(QSize(0, 0));
        loginBox->setTitle(QString::fromUtf8(""));
        loginBoxLayout = new QVBoxLayout(loginBox);
        loginBoxLayout->setObjectName("loginBoxLayout");

        verticalLayout->addWidget(loginBox);

        serverLogBox = new QGroupBox(OpenconnectAuth);
        serverLogBox->setObjectName("serverLogBox");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(serverLogBox->sizePolicy().hasHeightForWidth());
        serverLogBox->setSizePolicy(sizePolicy3);
        logLayout = new QVBoxLayout(serverLogBox);
        logLayout->setObjectName("logLayout");
        logLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        viewServerLog = new QCheckBox(serverLogBox);
        viewServerLog->setObjectName("viewServerLog");
        viewServerLog->setChecked(true);

        horizontalLayout_2->addWidget(viewServerLog);

        lblLogLevel = new QLabel(serverLogBox);
        lblLogLevel->setObjectName("lblLogLevel");
        lblLogLevel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_2->addWidget(lblLogLevel);

        cmbLogLevel = new QComboBox(serverLogBox);
        cmbLogLevel->addItem(QString());
        cmbLogLevel->addItem(QString());
        cmbLogLevel->addItem(QString());
        cmbLogLevel->addItem(QString());
        cmbLogLevel->setObjectName("cmbLogLevel");

        horizontalLayout_2->addWidget(cmbLogLevel);


        logLayout->addLayout(horizontalLayout_2);

        serverLog = new QTextBrowser(serverLogBox);
        serverLog->setObjectName("serverLog");
        serverLog->setEnabled(true);
        serverLog->setFrameShape(QFrame::Shape::StyledPanel);
        serverLog->setFrameShadow(QFrame::Shadow::Sunken);
        serverLog->setAcceptRichText(false);
        serverLog->setTextInteractionFlags(Qt::TextInteractionFlag::TextSelectableByMouse);
        serverLog->setOpenLinks(false);

        logLayout->addWidget(serverLog);


        verticalLayout->addWidget(serverLogBox);

        bottomSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(bottomSpacer);


        retranslateUi(OpenconnectAuth);

        btnConnect->setDefault(true);


        QMetaObject::connectSlotsByName(OpenconnectAuth);
    } // setupUi

    void retranslateUi(QWidget *OpenconnectAuth)
    {
        OpenconnectAuth->setWindowTitle(tr2i18n("OpenConnect VPN Authentication", nullptr));
        label_3->setText(tr2i18n("VPN Host", nullptr));
        btnConnect->setText(tr2i18n("Connect", nullptr));
        chkAutoconnect->setText(tr2i18n("Automatically start connecting next time", nullptr));
        chkStorePasswords->setText(tr2i18n("Store passwords", nullptr));
        chkStorePlaintextCookies->setText(tr2i18n("Store browser cookies in plain-text", nullptr));
        viewServerLog->setText(tr2i18n("View Log", nullptr));
        lblLogLevel->setText(tr2i18n("Log Level:", nullptr));
        cmbLogLevel->setItemText(0, tr2i18n("Error", nullptr));
        cmbLogLevel->setItemText(1, tr2i18n("Info", nullptr));
        cmbLogLevel->setItemText(2, tr2i18n("Debug", "like in Debug log level"));
        cmbLogLevel->setItemText(3, tr2i18n("Trace", nullptr));

    } // retranslateUi

};

namespace Ui {
    class OpenconnectAuth: public Ui_OpenconnectAuth {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPENCONNECTAUTH_H

