/********************************************************************************
** Form generated from reading UI file 'openvpnadvanced.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENVPNADVANCED_H
#define UI_OPENVPNADVANCED_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_OpenVpnAdvancedWidget
{
public:
    QGridLayout *gridLayout;
    QDialogButtonBox *buttonBox;
    QTabWidget *tabWidget;
    QWidget *generalTab;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *chkCustomPort;
    QSpinBox *sbCustomPort;
    QHBoxLayout *horizontalLayout_9;
    QCheckBox *chkUseCustomReneg;
    QSpinBox *sbCustomReneg;
    QHBoxLayout *horizontalLayout_12;
    QCheckBox *chkUseCompression;
    QComboBox *cmbUseCompression;
    QHBoxLayout *horizontalLayout_19;
    QCheckBox *chkUseAsymCompression;
    QCheckBox *chkUseTCP;
    QHBoxLayout *horizontalLayout_10;
    QCheckBox *chkUseVirtualDeviceType;
    QComboBox *cmbDeviceType;
    QHBoxLayout *horizontalLayout_11;
    QCheckBox *chkUseVirtualDeviceName;
    QLineEdit *leVirtualDeviceName;
    QHBoxLayout *horizontalLayout_7;
    QCheckBox *chkMtu;
    QSpinBox *sbMtu;
    QHBoxLayout *horizontalLayout_8;
    QCheckBox *chkCustomFragmentSize;
    QSpinBox *sbCustomFragmentSize;
    QCheckBox *chkMssRestrict;
    QHBoxLayout *horizontalLayout_mtuDisc;
    QCheckBox *chkMtuDisc;
    QComboBox *cmbMtuDisc;
    QCheckBox *chkRandRemHosts;
    QCheckBox *chkRandRemHostname;
    QHBoxLayout *horizontalLayout_connectTimeout;
    QLabel *lblConnectTimeout;
    QSpinBox *sbConnectTimeout;
    QCheckBox *chkAllowPullFqdn;
    QCheckBox *chkPushPeerInfo;
    QCheckBox *chkIpv6TunLink;
    QHBoxLayout *horizontalLayout_13;
    QCheckBox *chkPingInterval;
    QSpinBox *sbPingInterval;
    QHBoxLayout *horizontalLayout_15;
    QCheckBox *chkSpecifyExitRestartPing;
    QComboBox *cbSpecifyExitRestartPing;
    QSpinBox *sbSpecifyExitRestartPing;
    QCheckBox *chkAcceptAuthenticatedPackets;
    QHBoxLayout *horizontalLayout_16;
    QCheckBox *chkMaxRoutes;
    QSpinBox *sbMaxRoutes;
    QSpacerItem *verticalSpacer_5;
    QWidget *securityTab;
    QVBoxLayout *verticalLayout_7;
    QHBoxLayout *horizontalLayout;
    QLabel *label_3;
    QComboBox *cboCipher;
    QHBoxLayout *horizontalLayout_dataCiphers;
    QLabel *labelDataCiphers;
    QComboBox *cboDataCiphers;
    QHBoxLayout *horizontalLayout_dataCiphersFallback;
    QLabel *labelDataCiphersFallback;
    QComboBox *cboDataCiphersFallback;
    QCheckBox *chkDisableCipherNegotiation;
    QHBoxLayout *horizontalLayout_6;
    QCheckBox *chkUseCustomCipherKey;
    QSpinBox *sbCustomCipherKey;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_4;
    QComboBox *cboHmac;
    QSpacerItem *verticalSpacer_6;
    QWidget *tlsTab;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_18;
    QLabel *lblCertCheck;
    QComboBox *cbCertCheck;
    QHBoxLayout *horizontalLayout_3;
    QLabel *lbSubjectMatch;
    QLineEdit *subjectMatch;
    QCheckBox *chkRemoteCertTls;
    QHBoxLayout *horizontalLayout_4;
    QLabel *labelRemoteCertTls;
    QComboBox *cmbRemoteCertTls;
    QCheckBox *chkNsCertType;
    QHBoxLayout *horizontalLayout_17;
    QLabel *lblNsCertType;
    QComboBox *cmbNsCertType;
    QGroupBox *useExtraTlsAuth;
    QGridLayout *gridLayout_2;
    QLabel *label;
    QComboBox *cboTLSMode;
    QLabel *textLabel4_3;
    KUrlRequester *kurlTlsAuthKey;
    QLabel *label_extraCerts;
    KUrlRequester *kurlExtraCerts;
    QLabel *textLabel1;
    QComboBox *cboDirection;
    QLabel *lblTlsVersionMin;
    QHBoxLayout *horizontalLayout_tlsMin;
    QLineEdit *leTlsVersionMin;
    QCheckBox *chkTlsVersionMinOrHighest;
    QLabel *lblTlsVersionMax;
    QLineEdit *leTlsVersionMax;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_crlFile;
    QLabel *lblCrlVerifyFile;
    KUrlRequester *kurlCrlVerifyFile;
    QHBoxLayout *horizontalLayout_crlDir;
    QLabel *lblCrlVerifyDir;
    KUrlRequester *kurlCrlVerifyDir;
    QWidget *proxyTab;
    QFormLayout *formLayout_2;
    QLabel *label_11;
    QComboBox *cmbProxyType;
    QLabel *lbProxyType;
    QLabel *label_12;
    QLineEdit *proxyServerAddress;
    QLabel *label_13;
    QSpinBox *sbProxyPort;
    QLabel *label_14;
    PasswordField *proxyUsername;
    QLabel *label_15;
    QHBoxLayout *horizontalLayout_14;
    PasswordField *proxyPassword;
    QCheckBox *chkProxyRetry;

    void setupUi(QWidget *OpenVpnAdvancedWidget)
    {
        if (OpenVpnAdvancedWidget->objectName().isEmpty())
            OpenVpnAdvancedWidget->setObjectName("OpenVpnAdvancedWidget");
        OpenVpnAdvancedWidget->resize(703, 838);
        gridLayout = new QGridLayout(OpenVpnAdvancedWidget);
        gridLayout->setObjectName("gridLayout");
        buttonBox = new QDialogButtonBox(OpenVpnAdvancedWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        gridLayout->addWidget(buttonBox, 2, 0, 1, 1);

        tabWidget = new QTabWidget(OpenVpnAdvancedWidget);
        tabWidget->setObjectName("tabWidget");
        generalTab = new QWidget();
        generalTab->setObjectName("generalTab");
        verticalLayout_2 = new QVBoxLayout(generalTab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        chkCustomPort = new QCheckBox(generalTab);
        chkCustomPort->setObjectName("chkCustomPort");

        horizontalLayout_2->addWidget(chkCustomPort);

        sbCustomPort = new QSpinBox(generalTab);
        sbCustomPort->setObjectName("sbCustomPort");
        sbCustomPort->setEnabled(false);
        sbCustomPort->setMinimum(1);
        sbCustomPort->setMaximum(65535);
        sbCustomPort->setValue(1194);

        horizontalLayout_2->addWidget(sbCustomPort);


        verticalLayout_2->addLayout(horizontalLayout_2);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        chkUseCustomReneg = new QCheckBox(generalTab);
        chkUseCustomReneg->setObjectName("chkUseCustomReneg");

        horizontalLayout_9->addWidget(chkUseCustomReneg);

        sbCustomReneg = new QSpinBox(generalTab);
        sbCustomReneg->setObjectName("sbCustomReneg");
        sbCustomReneg->setEnabled(false);

        horizontalLayout_9->addWidget(sbCustomReneg);


        verticalLayout_2->addLayout(horizontalLayout_9);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        chkUseCompression = new QCheckBox(generalTab);
        chkUseCompression->setObjectName("chkUseCompression");

        horizontalLayout_12->addWidget(chkUseCompression);

        cmbUseCompression = new QComboBox(generalTab);
        cmbUseCompression->addItem(QString());
        cmbUseCompression->addItem(QString());
        cmbUseCompression->addItem(QString());
        cmbUseCompression->addItem(QString());
        cmbUseCompression->addItem(QString());
        cmbUseCompression->addItem(QString());
        cmbUseCompression->setObjectName("cmbUseCompression");
        cmbUseCompression->setEnabled(false);

        horizontalLayout_12->addWidget(cmbUseCompression);


        verticalLayout_2->addLayout(horizontalLayout_12);

        horizontalLayout_19 = new QHBoxLayout();
        horizontalLayout_19->setObjectName("horizontalLayout_19");
        chkUseAsymCompression = new QCheckBox(generalTab);
        chkUseAsymCompression->setObjectName("chkUseAsymCompression");
        chkUseAsymCompression->setEnabled(false);

        horizontalLayout_19->addWidget(chkUseAsymCompression);


        verticalLayout_2->addLayout(horizontalLayout_19);

        chkUseTCP = new QCheckBox(generalTab);
        chkUseTCP->setObjectName("chkUseTCP");

        verticalLayout_2->addWidget(chkUseTCP);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        chkUseVirtualDeviceType = new QCheckBox(generalTab);
        chkUseVirtualDeviceType->setObjectName("chkUseVirtualDeviceType");

        horizontalLayout_10->addWidget(chkUseVirtualDeviceType);

        cmbDeviceType = new QComboBox(generalTab);
        cmbDeviceType->addItem(QString());
        cmbDeviceType->addItem(QString());
        cmbDeviceType->setObjectName("cmbDeviceType");
        cmbDeviceType->setEnabled(false);

        horizontalLayout_10->addWidget(cmbDeviceType);


        verticalLayout_2->addLayout(horizontalLayout_10);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        chkUseVirtualDeviceName = new QCheckBox(generalTab);
        chkUseVirtualDeviceName->setObjectName("chkUseVirtualDeviceName");

        horizontalLayout_11->addWidget(chkUseVirtualDeviceName);

        leVirtualDeviceName = new QLineEdit(generalTab);
        leVirtualDeviceName->setObjectName("leVirtualDeviceName");
        leVirtualDeviceName->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(leVirtualDeviceName->sizePolicy().hasHeightForWidth());
        leVirtualDeviceName->setSizePolicy(sizePolicy);

        horizontalLayout_11->addWidget(leVirtualDeviceName);


        verticalLayout_2->addLayout(horizontalLayout_11);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        chkMtu = new QCheckBox(generalTab);
        chkMtu->setObjectName("chkMtu");

        horizontalLayout_7->addWidget(chkMtu);

        sbMtu = new QSpinBox(generalTab);
        sbMtu->setObjectName("sbMtu");
        sbMtu->setEnabled(false);
        sbMtu->setMinimum(1);
        sbMtu->setMaximum(65535);
        sbMtu->setValue(1500);

        horizontalLayout_7->addWidget(sbMtu);


        verticalLayout_2->addLayout(horizontalLayout_7);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        chkCustomFragmentSize = new QCheckBox(generalTab);
        chkCustomFragmentSize->setObjectName("chkCustomFragmentSize");

        horizontalLayout_8->addWidget(chkCustomFragmentSize);

        sbCustomFragmentSize = new QSpinBox(generalTab);
        sbCustomFragmentSize->setObjectName("sbCustomFragmentSize");
        sbCustomFragmentSize->setEnabled(false);
        sbCustomFragmentSize->setMaximum(65535);
        sbCustomFragmentSize->setValue(1300);

        horizontalLayout_8->addWidget(sbCustomFragmentSize);


        verticalLayout_2->addLayout(horizontalLayout_8);

        chkMssRestrict = new QCheckBox(generalTab);
        chkMssRestrict->setObjectName("chkMssRestrict");

        verticalLayout_2->addWidget(chkMssRestrict);

        horizontalLayout_mtuDisc = new QHBoxLayout();
        horizontalLayout_mtuDisc->setObjectName("horizontalLayout_mtuDisc");
        chkMtuDisc = new QCheckBox(generalTab);
        chkMtuDisc->setObjectName("chkMtuDisc");

        horizontalLayout_mtuDisc->addWidget(chkMtuDisc);

        cmbMtuDisc = new QComboBox(generalTab);
        cmbMtuDisc->addItem(QString());
        cmbMtuDisc->addItem(QString());
        cmbMtuDisc->addItem(QString());
        cmbMtuDisc->setObjectName("cmbMtuDisc");
        cmbMtuDisc->setEnabled(false);

        horizontalLayout_mtuDisc->addWidget(cmbMtuDisc);


        verticalLayout_2->addLayout(horizontalLayout_mtuDisc);

        chkRandRemHosts = new QCheckBox(generalTab);
        chkRandRemHosts->setObjectName("chkRandRemHosts");

        verticalLayout_2->addWidget(chkRandRemHosts);

        chkRandRemHostname = new QCheckBox(generalTab);
        chkRandRemHostname->setObjectName("chkRandRemHostname");

        verticalLayout_2->addWidget(chkRandRemHostname);

        horizontalLayout_connectTimeout = new QHBoxLayout();
        horizontalLayout_connectTimeout->setObjectName("horizontalLayout_connectTimeout");
        lblConnectTimeout = new QLabel(generalTab);
        lblConnectTimeout->setObjectName("lblConnectTimeout");
        lblConnectTimeout->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_connectTimeout->addWidget(lblConnectTimeout);

        sbConnectTimeout = new QSpinBox(generalTab);
        sbConnectTimeout->setObjectName("sbConnectTimeout");
        sbConnectTimeout->setMinimum(0);
        sbConnectTimeout->setMaximum(1000000);
        sbConnectTimeout->setValue(0);

        horizontalLayout_connectTimeout->addWidget(sbConnectTimeout);


        verticalLayout_2->addLayout(horizontalLayout_connectTimeout);

        chkAllowPullFqdn = new QCheckBox(generalTab);
        chkAllowPullFqdn->setObjectName("chkAllowPullFqdn");

        verticalLayout_2->addWidget(chkAllowPullFqdn);

        chkPushPeerInfo = new QCheckBox(generalTab);
        chkPushPeerInfo->setObjectName("chkPushPeerInfo");

        verticalLayout_2->addWidget(chkPushPeerInfo);

        chkIpv6TunLink = new QCheckBox(generalTab);
        chkIpv6TunLink->setObjectName("chkIpv6TunLink");

        verticalLayout_2->addWidget(chkIpv6TunLink);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        chkPingInterval = new QCheckBox(generalTab);
        chkPingInterval->setObjectName("chkPingInterval");

        horizontalLayout_13->addWidget(chkPingInterval);

        sbPingInterval = new QSpinBox(generalTab);
        sbPingInterval->setObjectName("sbPingInterval");
        sbPingInterval->setEnabled(false);
        sbPingInterval->setMinimum(1);
        sbPingInterval->setMaximum(65535);
        sbPingInterval->setValue(30);

        horizontalLayout_13->addWidget(sbPingInterval);


        verticalLayout_2->addLayout(horizontalLayout_13);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        chkSpecifyExitRestartPing = new QCheckBox(generalTab);
        chkSpecifyExitRestartPing->setObjectName("chkSpecifyExitRestartPing");

        horizontalLayout_15->addWidget(chkSpecifyExitRestartPing);

        cbSpecifyExitRestartPing = new QComboBox(generalTab);
        cbSpecifyExitRestartPing->addItem(QString());
        cbSpecifyExitRestartPing->addItem(QString());
        cbSpecifyExitRestartPing->setObjectName("cbSpecifyExitRestartPing");
        cbSpecifyExitRestartPing->setEnabled(false);

        horizontalLayout_15->addWidget(cbSpecifyExitRestartPing);

        sbSpecifyExitRestartPing = new QSpinBox(generalTab);
        sbSpecifyExitRestartPing->setObjectName("sbSpecifyExitRestartPing");
        sbSpecifyExitRestartPing->setEnabled(false);
        sbSpecifyExitRestartPing->setMinimum(1);
        sbSpecifyExitRestartPing->setMaximum(65535);
        sbSpecifyExitRestartPing->setValue(30);

        horizontalLayout_15->addWidget(sbSpecifyExitRestartPing);


        verticalLayout_2->addLayout(horizontalLayout_15);

        chkAcceptAuthenticatedPackets = new QCheckBox(generalTab);
        chkAcceptAuthenticatedPackets->setObjectName("chkAcceptAuthenticatedPackets");

        verticalLayout_2->addWidget(chkAcceptAuthenticatedPackets);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        chkMaxRoutes = new QCheckBox(generalTab);
        chkMaxRoutes->setObjectName("chkMaxRoutes");

        horizontalLayout_16->addWidget(chkMaxRoutes);

        sbMaxRoutes = new QSpinBox(generalTab);
        sbMaxRoutes->setObjectName("sbMaxRoutes");
        sbMaxRoutes->setEnabled(false);
        sbMaxRoutes->setMaximum(100000000);
        sbMaxRoutes->setValue(100);

        horizontalLayout_16->addWidget(sbMaxRoutes);


        verticalLayout_2->addLayout(horizontalLayout_16);

        verticalSpacer_5 = new QSpacerItem(303, 11, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_5);

        tabWidget->addTab(generalTab, QString());
        securityTab = new QWidget();
        securityTab->setObjectName("securityTab");
        verticalLayout_7 = new QVBoxLayout(securityTab);
        verticalLayout_7->setObjectName("verticalLayout_7");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_3 = new QLabel(securityTab);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout->addWidget(label_3);

        cboCipher = new QComboBox(securityTab);
        cboCipher->addItem(QString());
        cboCipher->setObjectName("cboCipher");
        cboCipher->setEnabled(false);
        sizePolicy.setHeightForWidth(cboCipher->sizePolicy().hasHeightForWidth());
        cboCipher->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(cboCipher);


        verticalLayout_7->addLayout(horizontalLayout);

        horizontalLayout_dataCiphers = new QHBoxLayout();
        horizontalLayout_dataCiphers->setObjectName("horizontalLayout_dataCiphers");
        labelDataCiphers = new QLabel(securityTab);
        labelDataCiphers->setObjectName("labelDataCiphers");
        labelDataCiphers->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_dataCiphers->addWidget(labelDataCiphers);

        cboDataCiphers = new QComboBox(securityTab);
        cboDataCiphers->addItem(QString());
        cboDataCiphers->setObjectName("cboDataCiphers");
        cboDataCiphers->setEnabled(false);

        horizontalLayout_dataCiphers->addWidget(cboDataCiphers);


        verticalLayout_7->addLayout(horizontalLayout_dataCiphers);

        horizontalLayout_dataCiphersFallback = new QHBoxLayout();
        horizontalLayout_dataCiphersFallback->setObjectName("horizontalLayout_dataCiphersFallback");
        labelDataCiphersFallback = new QLabel(securityTab);
        labelDataCiphersFallback->setObjectName("labelDataCiphersFallback");
        labelDataCiphersFallback->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_dataCiphersFallback->addWidget(labelDataCiphersFallback);

        cboDataCiphersFallback = new QComboBox(securityTab);
        cboDataCiphersFallback->addItem(QString());
        cboDataCiphersFallback->setObjectName("cboDataCiphersFallback");
        cboDataCiphersFallback->setEnabled(false);

        horizontalLayout_dataCiphersFallback->addWidget(cboDataCiphersFallback);


        verticalLayout_7->addLayout(horizontalLayout_dataCiphersFallback);

        chkDisableCipherNegotiation = new QCheckBox(securityTab);
        chkDisableCipherNegotiation->setObjectName("chkDisableCipherNegotiation");

        verticalLayout_7->addWidget(chkDisableCipherNegotiation);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        chkUseCustomCipherKey = new QCheckBox(securityTab);
        chkUseCustomCipherKey->setObjectName("chkUseCustomCipherKey");
        chkUseCustomCipherKey->setLayoutDirection(Qt::LayoutDirection::LeftToRight);

        horizontalLayout_6->addWidget(chkUseCustomCipherKey);

        sbCustomCipherKey = new QSpinBox(securityTab);
        sbCustomCipherKey->setObjectName("sbCustomCipherKey");
        sbCustomCipherKey->setEnabled(false);
        sbCustomCipherKey->setMinimum(1);
        sbCustomCipherKey->setMaximum(65535);
        sbCustomCipherKey->setValue(128);

        horizontalLayout_6->addWidget(sbCustomCipherKey);


        verticalLayout_7->addLayout(horizontalLayout_6);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        label_4 = new QLabel(securityTab);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_5->addWidget(label_4);

        cboHmac = new QComboBox(securityTab);
        cboHmac->addItem(QString());
        cboHmac->addItem(QString());
        cboHmac->addItem(QString());
        cboHmac->addItem(QString());
        cboHmac->addItem(QString());
        cboHmac->addItem(QString());
        cboHmac->addItem(QString());
        cboHmac->addItem(QString());
        cboHmac->addItem(QString());
        cboHmac->addItem(QString());
        cboHmac->setObjectName("cboHmac");
        sizePolicy.setHeightForWidth(cboHmac->sizePolicy().hasHeightForWidth());
        cboHmac->setSizePolicy(sizePolicy);

        horizontalLayout_5->addWidget(cboHmac);


        verticalLayout_7->addLayout(horizontalLayout_5);

        verticalSpacer_6 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_7->addItem(verticalSpacer_6);

        tabWidget->addTab(securityTab, QString());
        tlsTab = new QWidget();
        tlsTab->setObjectName("tlsTab");
        verticalLayout = new QVBoxLayout(tlsTab);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_18 = new QHBoxLayout();
        horizontalLayout_18->setObjectName("horizontalLayout_18");
        lblCertCheck = new QLabel(tlsTab);
        lblCertCheck->setObjectName("lblCertCheck");

        horizontalLayout_18->addWidget(lblCertCheck);

        cbCertCheck = new QComboBox(tlsTab);
        cbCertCheck->addItem(QString());
        cbCertCheck->addItem(QString());
        cbCertCheck->addItem(QString());
        cbCertCheck->addItem(QString());
        cbCertCheck->addItem(QString());
        cbCertCheck->setObjectName("cbCertCheck");

        horizontalLayout_18->addWidget(cbCertCheck);

        horizontalLayout_18->setStretch(0, 2);
        horizontalLayout_18->setStretch(1, 3);

        verticalLayout->addLayout(horizontalLayout_18);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        lbSubjectMatch = new QLabel(tlsTab);
        lbSubjectMatch->setObjectName("lbSubjectMatch");
        lbSubjectMatch->setEnabled(false);

        horizontalLayout_3->addWidget(lbSubjectMatch);

        subjectMatch = new QLineEdit(tlsTab);
        subjectMatch->setObjectName("subjectMatch");
        subjectMatch->setEnabled(false);
        subjectMatch->setClearButtonEnabled(true);

        horizontalLayout_3->addWidget(subjectMatch);


        verticalLayout->addLayout(horizontalLayout_3);

        chkRemoteCertTls = new QCheckBox(tlsTab);
        chkRemoteCertTls->setObjectName("chkRemoteCertTls");

        verticalLayout->addWidget(chkRemoteCertTls);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        labelRemoteCertTls = new QLabel(tlsTab);
        labelRemoteCertTls->setObjectName("labelRemoteCertTls");
        labelRemoteCertTls->setEnabled(false);

        horizontalLayout_4->addWidget(labelRemoteCertTls);

        cmbRemoteCertTls = new QComboBox(tlsTab);
        cmbRemoteCertTls->addItem(QString());
        cmbRemoteCertTls->addItem(QString());
        cmbRemoteCertTls->setObjectName("cmbRemoteCertTls");
        cmbRemoteCertTls->setEnabled(false);

        horizontalLayout_4->addWidget(cmbRemoteCertTls);


        verticalLayout->addLayout(horizontalLayout_4);

        chkNsCertType = new QCheckBox(tlsTab);
        chkNsCertType->setObjectName("chkNsCertType");

        verticalLayout->addWidget(chkNsCertType);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        lblNsCertType = new QLabel(tlsTab);
        lblNsCertType->setObjectName("lblNsCertType");
        lblNsCertType->setEnabled(false);

        horizontalLayout_17->addWidget(lblNsCertType);

        cmbNsCertType = new QComboBox(tlsTab);
        cmbNsCertType->addItem(QString());
        cmbNsCertType->addItem(QString());
        cmbNsCertType->setObjectName("cmbNsCertType");
        cmbNsCertType->setEnabled(false);

        horizontalLayout_17->addWidget(cmbNsCertType);


        verticalLayout->addLayout(horizontalLayout_17);

        useExtraTlsAuth = new QGroupBox(tlsTab);
        useExtraTlsAuth->setObjectName("useExtraTlsAuth");
        useExtraTlsAuth->setCheckable(false);
        useExtraTlsAuth->setChecked(false);
        gridLayout_2 = new QGridLayout(useExtraTlsAuth);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(useExtraTlsAuth);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        cboTLSMode = new QComboBox(useExtraTlsAuth);
        cboTLSMode->addItem(QString());
        cboTLSMode->addItem(QString());
        cboTLSMode->addItem(QString());
        cboTLSMode->addItem(QString());
        cboTLSMode->setObjectName("cboTLSMode");

        gridLayout_2->addWidget(cboTLSMode, 0, 1, 1, 1);

        textLabel4_3 = new QLabel(useExtraTlsAuth);
        textLabel4_3->setObjectName("textLabel4_3");
        textLabel4_3->setWordWrap(false);

        gridLayout_2->addWidget(textLabel4_3, 1, 0, 1, 1);

        kurlTlsAuthKey = new KUrlRequester(useExtraTlsAuth);
        kurlTlsAuthKey->setObjectName("kurlTlsAuthKey");
        kurlTlsAuthKey->setEnabled(false);

        gridLayout_2->addWidget(kurlTlsAuthKey, 1, 1, 1, 1);

        label_extraCerts = new QLabel(useExtraTlsAuth);
        label_extraCerts->setObjectName("label_extraCerts");

        gridLayout_2->addWidget(label_extraCerts, 2, 0, 1, 1);

        kurlExtraCerts = new KUrlRequester(useExtraTlsAuth);
        kurlExtraCerts->setObjectName("kurlExtraCerts");
        kurlExtraCerts->setMode(KFile::Mode::ExistingOnly|KFile::Mode::File|KFile::Mode::LocalOnly);

        gridLayout_2->addWidget(kurlExtraCerts, 2, 1, 1, 1);

        textLabel1 = new QLabel(useExtraTlsAuth);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        gridLayout_2->addWidget(textLabel1, 3, 0, 1, 1);

        cboDirection = new QComboBox(useExtraTlsAuth);
        cboDirection->addItem(QString());
        cboDirection->addItem(QString());
        cboDirection->addItem(QString());
        cboDirection->setObjectName("cboDirection");
        cboDirection->setEnabled(false);

        gridLayout_2->addWidget(cboDirection, 3, 1, 1, 1);

        lblTlsVersionMin = new QLabel(useExtraTlsAuth);
        lblTlsVersionMin->setObjectName("lblTlsVersionMin");

        gridLayout_2->addWidget(lblTlsVersionMin, 4, 0, 1, 1);

        horizontalLayout_tlsMin = new QHBoxLayout();
        horizontalLayout_tlsMin->setObjectName("horizontalLayout_tlsMin");
        leTlsVersionMin = new QLineEdit(useExtraTlsAuth);
        leTlsVersionMin->setObjectName("leTlsVersionMin");
        leTlsVersionMin->setClearButtonEnabled(true);

        horizontalLayout_tlsMin->addWidget(leTlsVersionMin);

        chkTlsVersionMinOrHighest = new QCheckBox(useExtraTlsAuth);
        chkTlsVersionMinOrHighest->setObjectName("chkTlsVersionMinOrHighest");

        horizontalLayout_tlsMin->addWidget(chkTlsVersionMinOrHighest);


        gridLayout_2->addLayout(horizontalLayout_tlsMin, 4, 1, 1, 1);

        lblTlsVersionMax = new QLabel(useExtraTlsAuth);
        lblTlsVersionMax->setObjectName("lblTlsVersionMax");

        gridLayout_2->addWidget(lblTlsVersionMax, 5, 0, 1, 1);

        leTlsVersionMax = new QLineEdit(useExtraTlsAuth);
        leTlsVersionMax->setObjectName("leTlsVersionMax");
        leTlsVersionMax->setClearButtonEnabled(true);

        gridLayout_2->addWidget(leTlsVersionMax, 5, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 100, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 6, 1, 1, 1);


        verticalLayout->addWidget(useExtraTlsAuth);

        horizontalLayout_crlFile = new QHBoxLayout();
        horizontalLayout_crlFile->setObjectName("horizontalLayout_crlFile");
        lblCrlVerifyFile = new QLabel(tlsTab);
        lblCrlVerifyFile->setObjectName("lblCrlVerifyFile");

        horizontalLayout_crlFile->addWidget(lblCrlVerifyFile);

        kurlCrlVerifyFile = new KUrlRequester(tlsTab);
        kurlCrlVerifyFile->setObjectName("kurlCrlVerifyFile");
        kurlCrlVerifyFile->setMode(KFile::Mode::ExistingOnly|KFile::Mode::File|KFile::Mode::LocalOnly);

        horizontalLayout_crlFile->addWidget(kurlCrlVerifyFile);


        verticalLayout->addLayout(horizontalLayout_crlFile);

        horizontalLayout_crlDir = new QHBoxLayout();
        horizontalLayout_crlDir->setObjectName("horizontalLayout_crlDir");
        lblCrlVerifyDir = new QLabel(tlsTab);
        lblCrlVerifyDir->setObjectName("lblCrlVerifyDir");

        horizontalLayout_crlDir->addWidget(lblCrlVerifyDir);

        kurlCrlVerifyDir = new KUrlRequester(tlsTab);
        kurlCrlVerifyDir->setObjectName("kurlCrlVerifyDir");
        kurlCrlVerifyDir->setMode(KFile::Mode::Directory|KFile::Mode::ExistingOnly|KFile::Mode::LocalOnly);

        horizontalLayout_crlDir->addWidget(kurlCrlVerifyDir);


        verticalLayout->addLayout(horizontalLayout_crlDir);

        tabWidget->addTab(tlsTab, QString());
        proxyTab = new QWidget();
        proxyTab->setObjectName("proxyTab");
        formLayout_2 = new QFormLayout(proxyTab);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::ExpandingFieldsGrow);
        formLayout_2->setVerticalSpacing(6);
        label_11 = new QLabel(proxyTab);
        label_11->setObjectName("label_11");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_11);

        cmbProxyType = new QComboBox(proxyTab);
        cmbProxyType->addItem(QString());
        cmbProxyType->addItem(QString());
        cmbProxyType->addItem(QString());
        cmbProxyType->setObjectName("cmbProxyType");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cmbProxyType->sizePolicy().hasHeightForWidth());
        cmbProxyType->setSizePolicy(sizePolicy1);
        cmbProxyType->setMinimumSize(QSize(0, 0));

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, cmbProxyType);

        lbProxyType = new QLabel(proxyTab);
        lbProxyType->setObjectName("lbProxyType");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(lbProxyType->sizePolicy().hasHeightForWidth());
        lbProxyType->setSizePolicy(sizePolicy2);
        QFont font;
        font.setItalic(true);
        lbProxyType->setFont(font);
        lbProxyType->setWordWrap(true);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, lbProxyType);

        label_12 = new QLabel(proxyTab);
        label_12->setObjectName("label_12");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_12);

        proxyServerAddress = new QLineEdit(proxyTab);
        proxyServerAddress->setObjectName("proxyServerAddress");
        proxyServerAddress->setClearButtonEnabled(true);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, proxyServerAddress);

        label_13 = new QLabel(proxyTab);
        label_13->setObjectName("label_13");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, label_13);

        sbProxyPort = new QSpinBox(proxyTab);
        sbProxyPort->setObjectName("sbProxyPort");
        sizePolicy1.setHeightForWidth(sbProxyPort->sizePolicy().hasHeightForWidth());
        sbProxyPort->setSizePolicy(sizePolicy1);
        sbProxyPort->setMaximum(65535);

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, sbProxyPort);

        label_14 = new QLabel(proxyTab);
        label_14->setObjectName("label_14");

        formLayout_2->setWidget(8, QFormLayout::ItemRole::LabelRole, label_14);

        proxyUsername = new PasswordField(proxyTab);
        proxyUsername->setObjectName("proxyUsername");
        proxyUsername->setProperty("passwordModeEnabled", QVariant(true));

        formLayout_2->setWidget(8, QFormLayout::ItemRole::FieldRole, proxyUsername);

        label_15 = new QLabel(proxyTab);
        label_15->setObjectName("label_15");

        formLayout_2->setWidget(9, QFormLayout::ItemRole::LabelRole, label_15);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        proxyPassword = new PasswordField(proxyTab);
        proxyPassword->setObjectName("proxyPassword");
        proxyPassword->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_14->addWidget(proxyPassword);


        formLayout_2->setLayout(9, QFormLayout::ItemRole::FieldRole, horizontalLayout_14);

        chkProxyRetry = new QCheckBox(proxyTab);
        chkProxyRetry->setObjectName("chkProxyRetry");

        formLayout_2->setWidget(7, QFormLayout::ItemRole::FieldRole, chkProxyRetry);

        tabWidget->addTab(proxyTab, QString());

        gridLayout->addWidget(tabWidget, 1, 0, 1, 1);

#if QT_CONFIG(shortcut)
        lblConnectTimeout->setBuddy(sbConnectTimeout);
        label_3->setBuddy(cboCipher);
        labelDataCiphers->setBuddy(cboDataCiphers);
        labelDataCiphersFallback->setBuddy(cboDataCiphersFallback);
        label_4->setBuddy(cboHmac);
        lbSubjectMatch->setBuddy(subjectMatch);
        textLabel4_3->setBuddy(kurlTlsAuthKey);
        label_extraCerts->setBuddy(kurlExtraCerts);
        textLabel1->setBuddy(cboDirection);
        lblTlsVersionMin->setBuddy(leTlsVersionMin);
        lblTlsVersionMax->setBuddy(leTlsVersionMax);
        lblCrlVerifyFile->setBuddy(kurlCrlVerifyFile);
        lblCrlVerifyDir->setBuddy(kurlCrlVerifyDir);
        label_11->setBuddy(cmbProxyType);
        label_12->setBuddy(proxyServerAddress);
        label_13->setBuddy(sbProxyPort);
        label_14->setBuddy(proxyUsername);
        label_15->setBuddy(proxyPassword);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(sbCustomPort, sbMtu);
        QWidget::setTabOrder(sbMtu, sbCustomFragmentSize);
        QWidget::setTabOrder(sbCustomFragmentSize, chkUseCustomReneg);
        QWidget::setTabOrder(chkUseCustomReneg, sbCustomReneg);
        QWidget::setTabOrder(sbCustomReneg, chkUseVirtualDeviceType);
        QWidget::setTabOrder(chkUseVirtualDeviceType, cmbDeviceType);
        QWidget::setTabOrder(cmbDeviceType, chkUseVirtualDeviceName);
        QWidget::setTabOrder(chkUseVirtualDeviceName, leVirtualDeviceName);
        QWidget::setTabOrder(leVirtualDeviceName, chkUseCompression);
        QWidget::setTabOrder(chkUseCompression, chkUseTCP);
        QWidget::setTabOrder(chkUseTCP, chkMssRestrict);
        QWidget::setTabOrder(chkMssRestrict, chkMtuDisc);
        QWidget::setTabOrder(chkMtuDisc, cmbMtuDisc);
        QWidget::setTabOrder(cmbMtuDisc, chkRandRemHosts);
        QWidget::setTabOrder(chkRandRemHosts, chkPushPeerInfo);
        QWidget::setTabOrder(chkPushPeerInfo, cboCipher);
        QWidget::setTabOrder(cboCipher, chkUseCustomCipherKey);
        QWidget::setTabOrder(chkUseCustomCipherKey, sbCustomCipherKey);
        QWidget::setTabOrder(sbCustomCipherKey, cboHmac);
        QWidget::setTabOrder(cboHmac, cboDataCiphers);
        QWidget::setTabOrder(cboDataCiphers, cboDataCiphersFallback);
        QWidget::setTabOrder(cboDataCiphersFallback, chkDisableCipherNegotiation);
        QWidget::setTabOrder(chkDisableCipherNegotiation, subjectMatch);
        QWidget::setTabOrder(subjectMatch, chkRemoteCertTls);
        QWidget::setTabOrder(chkRemoteCertTls, cmbRemoteCertTls);
        QWidget::setTabOrder(cmbRemoteCertTls, useExtraTlsAuth);
        QWidget::setTabOrder(useExtraTlsAuth, kurlTlsAuthKey);
        QWidget::setTabOrder(kurlTlsAuthKey, kurlExtraCerts);
        QWidget::setTabOrder(kurlExtraCerts, cboDirection);
        QWidget::setTabOrder(cboDirection, leTlsVersionMin);
        QWidget::setTabOrder(leTlsVersionMin, chkTlsVersionMinOrHighest);
        QWidget::setTabOrder(chkTlsVersionMinOrHighest, leTlsVersionMax);
        QWidget::setTabOrder(leTlsVersionMax, kurlCrlVerifyFile);
        QWidget::setTabOrder(kurlCrlVerifyFile, kurlCrlVerifyDir);
        QWidget::setTabOrder(kurlCrlVerifyDir, cmbProxyType);
        QWidget::setTabOrder(cmbProxyType, proxyServerAddress);
        QWidget::setTabOrder(proxyServerAddress, sbProxyPort);
        QWidget::setTabOrder(sbProxyPort, chkProxyRetry);
        QWidget::setTabOrder(chkProxyRetry, proxyUsername);
        QWidget::setTabOrder(proxyUsername, proxyPassword);

        retranslateUi(OpenVpnAdvancedWidget);
        QObject::connect(chkUseCustomReneg, &QCheckBox::toggled, sbCustomReneg, &QSpinBox::setEnabled);
        QObject::connect(chkRemoteCertTls, &QCheckBox::toggled, cmbRemoteCertTls, &QComboBox::setEnabled);
        QObject::connect(chkRemoteCertTls, &QCheckBox::toggled, labelRemoteCertTls, &QLabel::setEnabled);
        QObject::connect(chkUseVirtualDeviceType, &QCheckBox::toggled, cmbDeviceType, &QComboBox::setEnabled);
        QObject::connect(chkUseVirtualDeviceName, &QCheckBox::toggled, leVirtualDeviceName, &QLineEdit::setEnabled);
        QObject::connect(chkUseCustomCipherKey, &QCheckBox::toggled, sbCustomCipherKey, &QSpinBox::setEnabled);
        QObject::connect(chkMtu, &QCheckBox::toggled, sbMtu, &QSpinBox::setEnabled);
        QObject::connect(chkPingInterval, &QCheckBox::toggled, sbPingInterval, &QSpinBox::setEnabled);
        QObject::connect(chkSpecifyExitRestartPing, &QCheckBox::toggled, sbSpecifyExitRestartPing, &QSpinBox::setEnabled);
        QObject::connect(chkSpecifyExitRestartPing, &QCheckBox::toggled, cbSpecifyExitRestartPing, &QComboBox::setEnabled);
        QObject::connect(chkMaxRoutes, &QCheckBox::toggled, sbMaxRoutes, &QSpinBox::setEnabled);
        QObject::connect(chkCustomFragmentSize, &QCheckBox::toggled, sbCustomFragmentSize, &QSpinBox::setEnabled);
        QObject::connect(chkUseCompression, &QCheckBox::toggled, cmbUseCompression, &QComboBox::setEnabled);
        QObject::connect(chkCustomPort, &QCheckBox::toggled, sbCustomPort, &QSpinBox::setEnabled);
        QObject::connect(chkMtuDisc, &QCheckBox::toggled, cmbMtuDisc, &QComboBox::setEnabled);
        QObject::connect(chkNsCertType, &QCheckBox::toggled, cmbNsCertType, &QComboBox::setEnabled);
        QObject::connect(chkNsCertType, &QCheckBox::toggled, lblNsCertType, &QLabel::setEnabled);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(OpenVpnAdvancedWidget);
    } // setupUi

    void retranslateUi(QWidget *OpenVpnAdvancedWidget)
    {
#if QT_CONFIG(tooltip)
        chkCustomPort->setToolTip(tr2i18n("TCP/UDP port number for peer. (Default value when there is no port for gateway).", nullptr));
#endif // QT_CONFIG(tooltip)
        chkCustomPort->setText(tr2i18n("Use custom gateway port:", nullptr));
#if QT_CONFIG(tooltip)
        sbCustomPort->setToolTip(tr2i18n("TCP/UDP port number for peer. (Default value when there is no port for gateway).", nullptr));
#endif // QT_CONFIG(tooltip)
        sbCustomPort->setSpecialValueText(tr2i18n("Automatic", "like in use Automatic configuration"));
#if QT_CONFIG(tooltip)
        chkUseCustomReneg->setToolTip(tr2i18n("Renegotiate data channel key after the specified number of seconds.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkUseCustomReneg->setText(tr2i18n("Use custom renegotiation interval:", nullptr));
#if QT_CONFIG(tooltip)
        sbCustomReneg->setToolTip(tr2i18n("Renegotiate data channel key after the specified number of seconds.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        chkUseCompression->setToolTip(tr2i18n("Use compression.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkUseCompression->setText(tr2i18n("Use compression", nullptr));
        cmbUseCompression->setItemText(0, tr2i18n("No", nullptr));
        cmbUseCompression->setItemText(1, tr2i18n("LZO", nullptr));
        cmbUseCompression->setItemText(2, tr2i18n("LZ4", nullptr));
        cmbUseCompression->setItemText(3, tr2i18n("LZ4 v2", nullptr));
        cmbUseCompression->setItemText(4, tr2i18n("Adaptive", nullptr));
        cmbUseCompression->setItemText(5, tr2i18n("Automatic", nullptr));

#if QT_CONFIG(tooltip)
        cmbUseCompression->setToolTip(tr2i18n("Use compression.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkUseAsymCompression->setText(tr2i18n("Use asymetric compression", nullptr));
#if QT_CONFIG(tooltip)
        chkUseTCP->setToolTip(tr2i18n("Use TCP for communicating with remote host.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkUseTCP->setText(tr2i18n("Use a TCP connection", nullptr));
#if QT_CONFIG(tooltip)
        chkUseVirtualDeviceType->setToolTip(tr2i18n("Explicitly set virtual device type (TUN/TAP).", nullptr));
#endif // QT_CONFIG(tooltip)
        chkUseVirtualDeviceType->setText(tr2i18n("Set virtual device type:", nullptr));
        cmbDeviceType->setItemText(0, tr2i18n("TUN", nullptr));
        cmbDeviceType->setItemText(1, tr2i18n("TAP", nullptr));

#if QT_CONFIG(tooltip)
        cmbDeviceType->setToolTip(tr2i18n("Explicitly set virtual device type (TUN/TAP).", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        chkUseVirtualDeviceName->setToolTip(tr2i18n("Use custom name for TUN/TAP virtual device (instead of default \"tun\" or \"tap\").", nullptr));
#endif // QT_CONFIG(tooltip)
        chkUseVirtualDeviceName->setText(tr2i18n("Set virtual device name:", nullptr));
#if QT_CONFIG(tooltip)
        leVirtualDeviceName->setToolTip(tr2i18n("Use custom name for TUN/TAP virtual device (instead of default \"tun\" or \"tap\").", nullptr));
#endif // QT_CONFIG(tooltip)
        leVirtualDeviceName->setPlaceholderText(tr2i18n("Automatic", nullptr));
#if QT_CONFIG(tooltip)
        chkMtu->setToolTip(tr2i18n("Take the TUN device MTU to be specified value and derive the link MTU from it.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkMtu->setText(tr2i18n("Use custom tunnel Maximum Transmission Unit (MTU):", nullptr));
#if QT_CONFIG(tooltip)
        sbMtu->setToolTip(tr2i18n("Take the TUN device MTU to be specified value and derive the link MTU from it.", nullptr));
#endif // QT_CONFIG(tooltip)
        sbMtu->setSpecialValueText(tr2i18n("Automatic", "like in use Automatic configuration"));
#if QT_CONFIG(tooltip)
        chkCustomFragmentSize->setToolTip(tr2i18n("Enable internal datagram fragmentation with this maximum size.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkCustomFragmentSize->setText(tr2i18n("Use custom UDP fragment size:", nullptr));
#if QT_CONFIG(tooltip)
        sbCustomFragmentSize->setToolTip(tr2i18n("Enable internal datagram fragmentation with this maximum size.", nullptr));
#endif // QT_CONFIG(tooltip)
        sbCustomFragmentSize->setSpecialValueText(tr2i18n("Automatic", "like in use Automatic configuration"));
#if QT_CONFIG(tooltip)
        chkMssRestrict->setToolTip(tr2i18n("Restrict tunnel TCP maximum segment size.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkMssRestrict->setText(tr2i18n("Restrict TCP maximum segment size (MSS)", nullptr));
#if QT_CONFIG(tooltip)
        chkMtuDisc->setToolTip(tr2i18n("Control Path MTU discovery behavior.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkMtuDisc->setText(tr2i18n("Specify Path MTU discovery:", nullptr));
        cmbMtuDisc->setItemText(0, tr2i18n("No", nullptr));
        cmbMtuDisc->setItemText(1, tr2i18n("Maybe", nullptr));
        cmbMtuDisc->setItemText(2, tr2i18n("Yes", nullptr));

#if QT_CONFIG(tooltip)
        chkRandRemHosts->setToolTip(tr2i18n("Randomize the order of gateways list (remote) as a kind of basic load-\n"
"balancing measure.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkRandRemHosts->setText(tr2i18n("Randomize remote hosts", nullptr));
        chkRandRemHostname->setText(tr2i18n("Prefix remote DNS name with random string", nullptr));
#if QT_CONFIG(tooltip)
        lblConnectTimeout->setToolTip(tr2i18n("Time in seconds to wait for the initial connection before failing.", nullptr));
#endif // QT_CONFIG(tooltip)
        lblConnectTimeout->setText(tr2i18n("Connect timeout:", nullptr));
#if QT_CONFIG(tooltip)
        sbConnectTimeout->setToolTip(tr2i18n("Time in seconds to wait for the initial connection before failing.", nullptr));
#endif // QT_CONFIG(tooltip)
        sbConnectTimeout->setSpecialValueText(tr2i18n("None", nullptr));
        sbConnectTimeout->setSuffix(tr2i18n("s", nullptr));
#if QT_CONFIG(tooltip)
        chkAllowPullFqdn->setToolTip(tr2i18n("Allow pulling of peer DNS names (FQDN) sent by the server.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkAllowPullFqdn->setText(tr2i18n("Allow pull of peer DNS names (FQDN)", nullptr));
#if QT_CONFIG(tooltip)
        chkPushPeerInfo->setToolTip(tr2i18n("Push client information to the server for diagnostics.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkPushPeerInfo->setText(tr2i18n("push peer info", nullptr));
#if QT_CONFIG(tooltip)
        chkIpv6TunLink->setToolTip(tr2i18n("Build a tun link capable of forwarding IPv6 traffic.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkIpv6TunLink->setText(tr2i18n("IPv6 tun link", nullptr));
#if QT_CONFIG(tooltip)
        chkPingInterval->setToolTip(tr2i18n("Ping remote over the TCP/UDP control channel if no packets have been sent for at least n seconds.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkPingInterval->setText(tr2i18n("Specify ping interval:", nullptr));
#if QT_CONFIG(tooltip)
        sbPingInterval->setToolTip(tr2i18n("Ping remote over the TCP/UDP control channel if no packets have been sent for at least n seconds.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        chkSpecifyExitRestartPing->setToolTip(tr2i18n("Exit or restart after n seconds pass without reception of a ping or other packet from remote.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkSpecifyExitRestartPing->setText(tr2i18n("Specify exit or restart ping:", nullptr));
        cbSpecifyExitRestartPing->setItemText(0, tr2i18n("ping-exit", nullptr));
        cbSpecifyExitRestartPing->setItemText(1, tr2i18n("ping-restart", nullptr));

#if QT_CONFIG(tooltip)
        cbSpecifyExitRestartPing->setToolTip(tr2i18n("Exit or restart after n seconds pass without reception of a ping or other packet from remote.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        sbSpecifyExitRestartPing->setToolTip(tr2i18n("Exit or restart after n seconds pass without reception of a ping or other packet from remote.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        chkAcceptAuthenticatedPackets->setToolTip(tr2i18n("Allow remote peer to change its IP address and/or port number such as due to\n"
"DHCP (this is the default if --remote is not used). --float when specified with --remote\n"
"allows an OpenVPN session to initially connect to a peer at a known address,\n"
"however if packets arrive from a new address and pass all authentication tests, the\n"
"new address will take control of the session. This is useful when you are connecting\n"
"to a peer which holds a dynamic address such as a dial-in user or DHCP client.\n"
"\n"
"\n"
"Essentially, --float tells OpenVPN to accept authenticated packets from any address,\n"
"not only the address which was specified in the --remote option.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkAcceptAuthenticatedPackets->setText(tr2i18n("Accept authenticated packets from any address (Float)", nullptr));
#if QT_CONFIG(tooltip)
        chkMaxRoutes->setToolTip(tr2i18n("Specify the maximum number of routes the server is allowed to specify.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkMaxRoutes->setText(tr2i18n("Specify max routes:", nullptr));
#if QT_CONFIG(tooltip)
        sbMaxRoutes->setToolTip(tr2i18n("Specify the maximum number of routes the server is allowed to specify.", nullptr));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(generalTab), tr2i18n("General", nullptr));
#if QT_CONFIG(tooltip)
        label_3->setToolTip(tr2i18n("Encrypt packets with cipher algorithm. The default is BF-CBC (Blowfish in Cipher\n"
"Block Chaining mode).", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Cipher:", nullptr));
        cboCipher->setItemText(0, tr2i18n("Obtaining available ciphers\342\200\246", nullptr));

#if QT_CONFIG(tooltip)
        cboCipher->setToolTip(tr2i18n("Encrypt packets with cipher algorithm. The default is BF-CBC (Blowfish in Cipher\n"
"Block Chaining mode).", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        labelDataCiphers->setToolTip(tr2i18n("Data channel cipher list to negotiate (OpenVPN 2.5+).", nullptr));
#endif // QT_CONFIG(tooltip)
        labelDataCiphers->setText(tr2i18n("Data Ciphers:", nullptr));
        cboDataCiphers->setItemText(0, tr2i18n("Obtaining available ciphers\342\200\246", nullptr));

#if QT_CONFIG(tooltip)
        labelDataCiphersFallback->setToolTip(tr2i18n("Fallback data cipher if negotiation fails (OpenVPN 2.5+).", nullptr));
#endif // QT_CONFIG(tooltip)
        labelDataCiphersFallback->setText(tr2i18n("Data Ciphers Fallback:", nullptr));
        cboDataCiphersFallback->setItemText(0, tr2i18n("Obtaining available ciphers\342\200\246", nullptr));

#if QT_CONFIG(tooltip)
        chkDisableCipherNegotiation->setToolTip(tr2i18n("Disable OpenVPN NCP (cipher negotiation). Requires OpenVPN 2.4+.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkDisableCipherNegotiation->setText(tr2i18n("Disable cipher negotiation", nullptr));
#if QT_CONFIG(tooltip)
        chkUseCustomCipherKey->setToolTip(tr2i18n("Set cipher key size to a custom value. If unspecified, it defaults to cipher-specific size.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkUseCustomCipherKey->setText(tr2i18n("Use custom size of cipher key:", nullptr));
#if QT_CONFIG(tooltip)
        sbCustomCipherKey->setToolTip(tr2i18n("Set cipher key size to a custom value. If unspecified, it defaults to cipher-specific size.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_4->setToolTip(tr2i18n("Authenticate packets with HMAC using message digest algorithm. The default is SHA1.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("HMAC Authentication:", nullptr));
        cboHmac->setItemText(0, tr2i18n("Default", "like in use Default configuration"));
        cboHmac->setItemText(1, tr2i18n("None", "like in None setting selected"));
        cboHmac->setItemText(2, tr2i18n("MD-4", nullptr));
        cboHmac->setItemText(3, tr2i18n("MD-5", nullptr));
        cboHmac->setItemText(4, tr2i18n("SHA-1", nullptr));
        cboHmac->setItemText(5, tr2i18n("SHA-224", nullptr));
        cboHmac->setItemText(6, tr2i18n("SHA-256", nullptr));
        cboHmac->setItemText(7, tr2i18n("SHA-384", nullptr));
        cboHmac->setItemText(8, tr2i18n("SHA-512", nullptr));
        cboHmac->setItemText(9, tr2i18n("RIPEMD-160", nullptr));

#if QT_CONFIG(tooltip)
        cboHmac->setToolTip(tr2i18n("Authenticate packets with HMAC using message digest algorithm. The default is SHA1.", nullptr));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(securityTab), tr2i18n("Security", nullptr));
#if QT_CONFIG(tooltip)
        lblCertCheck->setToolTip(tr2i18n("Verify server certificate identification.\n"
"\n"
"When enabled, connection will only succeed if the server certificate matches\n"
"some expected properties.\n"
"Matching can either apply to the whole certificate subject (all the fields),\n"
"or just the Common Name (CN field).\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
        lblCertCheck->setText(tr2i18n("Server Certificate Check:", nullptr));
        cbCertCheck->setItemText(0, tr2i18n("Don't verify certificate identification", nullptr));
        cbCertCheck->setItemText(1, tr2i18n("Verify whole subject exactly", nullptr));
        cbCertCheck->setItemText(2, tr2i18n("Verify name exactly", nullptr));
        cbCertCheck->setItemText(3, tr2i18n("Verify name by prefix", nullptr));
        cbCertCheck->setItemText(4, tr2i18n("Verify subject partially (legacy mode, strongly discouraged)", nullptr));

#if QT_CONFIG(tooltip)
        cbCertCheck->setToolTip(tr2i18n("Verify server certificate identification.\n"
"\n"
"When enabled, connection will only succeed if the server certificate matches\n"
"some expected properties.\n"
"Matching can either apply to the whole certificate subject (all the fields),\n"
"or just the Common Name (CN field).\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        lbSubjectMatch->setToolTip(tr2i18n("Subject or Common Name to verify server certificate information against.", nullptr));
#endif // QT_CONFIG(tooltip)
        lbSubjectMatch->setText(tr2i18n("Subject Match:", nullptr));
#if QT_CONFIG(tooltip)
        subjectMatch->setToolTip(tr2i18n("Subject or Common Name to verify server certificate information against.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        subjectMatch->setWhatsThis(tr2i18n("Connect only to servers whose certificate matches the given subject. Example: /CN=myvpn.company.com", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        chkRemoteCertTls->setToolTip(tr2i18n("Require that peer certificate was signed with an explicit key usage and extended\n"
"key usage based on RFC3280 TLS rules.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkRemoteCertTls->setText(tr2i18n("Verify peer (server) certificate usage signature", nullptr));
#if QT_CONFIG(tooltip)
        labelRemoteCertTls->setToolTip(tr2i18n("Require that peer certificate was signed with an explicit key usage and extended\n"
"key usage based on RFC3280 TLS rules.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelRemoteCertTls->setText(tr2i18n("Remote peer certificate TLS type:", nullptr));
        cmbRemoteCertTls->setItemText(0, tr2i18n("Server", nullptr));
        cmbRemoteCertTls->setItemText(1, tr2i18n("Client", nullptr));

#if QT_CONFIG(tooltip)
        cmbRemoteCertTls->setToolTip(tr2i18n("Require that peer certificate was signed with an explicit key usage and extended\n"
"key usage based on RFC3280 TLS rules.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        chkNsCertType->setToolTip(tr2i18n("Require that peer certificate was signed with an explicit nsCertType designation.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkNsCertType->setText(tr2i18n("Verify peer (server) certificate nsCertType designation", nullptr));
#if QT_CONFIG(tooltip)
        lblNsCertType->setToolTip(tr2i18n("Require that peer certificate was signed with an explicit nsCertType designation.", nullptr));
#endif // QT_CONFIG(tooltip)
        lblNsCertType->setText(tr2i18n("Remote peer certificate nsCert designation:", nullptr));
        cmbNsCertType->setItemText(0, tr2i18n("Server", nullptr));
        cmbNsCertType->setItemText(1, tr2i18n("Client", nullptr));

#if QT_CONFIG(tooltip)
        cmbNsCertType->setToolTip(tr2i18n("Require that peer certificate was signed with an explicit nsCertType designation.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        useExtraTlsAuth->setToolTip(tr2i18n("Add an additional layer of HMAC authentication.", nullptr));
#endif // QT_CONFIG(tooltip)
        useExtraTlsAuth->setTitle(QString());
        label->setText(tr2i18n("Mode:", nullptr));
        cboTLSMode->setItemText(0, tr2i18n("None", nullptr));
        cboTLSMode->setItemText(1, tr2i18n("TLS-Auth", nullptr));
        cboTLSMode->setItemText(2, tr2i18n("TLS-Crypt", nullptr));
        cboTLSMode->setItemText(3, tr2i18n("TLS-Crypt v2", nullptr));

#if QT_CONFIG(tooltip)
        textLabel4_3->setToolTip(tr2i18n("Add an additional layer of HMAC authentication on top of the TLS control channel\n"
"to protect against DoS attacks.", nullptr));
#endif // QT_CONFIG(tooltip)
        textLabel4_3->setText(tr2i18n("Key File:", nullptr));
#if QT_CONFIG(tooltip)
        kurlTlsAuthKey->setToolTip(tr2i18n("Add an additional layer of HMAC authentication on top of the TLS control channel\n"
"to protect against DoS attacks.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_extraCerts->setToolTip(tr2i18n("Additional local certificate file to help verify the peer certificate chain.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_extraCerts->setText(tr2i18n("Extra certificates file:", nullptr));
#if QT_CONFIG(tooltip)
        kurlExtraCerts->setToolTip(tr2i18n("Additional local certificate file to help verify the peer certificate chain.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        textLabel1->setToolTip(tr2i18n("Direction parameter for static key mode.", nullptr));
#endif // QT_CONFIG(tooltip)
        textLabel1->setText(tr2i18n("Key Direction:", nullptr));
        cboDirection->setItemText(0, tr2i18n("None", "like in None setting selected"));
        cboDirection->setItemText(1, tr2i18n("Server (0)", nullptr));
        cboDirection->setItemText(2, tr2i18n("Client (1)", nullptr));

#if QT_CONFIG(tooltip)
        cboDirection->setToolTip(tr2i18n("Direction parameter for static key mode.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        lblTlsVersionMin->setToolTip(tr2i18n("Minimum TLS version (e.g. 1.2). Optional.", nullptr));
#endif // QT_CONFIG(tooltip)
        lblTlsVersionMin->setText(tr2i18n("TLS version minimum:", nullptr));
#if QT_CONFIG(tooltip)
        leTlsVersionMin->setToolTip(tr2i18n("Minimum TLS version (e.g. 1.2). Leave empty for default.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        chkTlsVersionMinOrHighest->setToolTip(tr2i18n("Allow negotiating higher TLS version than the minimum.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkTlsVersionMinOrHighest->setText(tr2i18n("or highest", nullptr));
#if QT_CONFIG(tooltip)
        lblTlsVersionMax->setToolTip(tr2i18n("Maximum TLS version (e.g. 1.3). Optional.", nullptr));
#endif // QT_CONFIG(tooltip)
        lblTlsVersionMax->setText(tr2i18n("TLS version maximum:", nullptr));
#if QT_CONFIG(tooltip)
        leTlsVersionMax->setToolTip(tr2i18n("Maximum TLS version (e.g. 1.3). Leave empty for default.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        lblCrlVerifyFile->setToolTip(tr2i18n("Path to a local Certificate Revocation List (CRL) file to verify peer certificates.", nullptr));
#endif // QT_CONFIG(tooltip)
        lblCrlVerifyFile->setText(tr2i18n("CRL verify file:", nullptr));
#if QT_CONFIG(tooltip)
        kurlCrlVerifyFile->setToolTip(tr2i18n("Path to a local Certificate Revocation List (CRL) file to verify peer certificates.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        lblCrlVerifyDir->setToolTip(tr2i18n("Path to a local directory containing Certificate Revocation List (CRL) files.", nullptr));
#endif // QT_CONFIG(tooltip)
        lblCrlVerifyDir->setText(tr2i18n("CRL verify directory:", nullptr));
#if QT_CONFIG(tooltip)
        kurlCrlVerifyDir->setToolTip(tr2i18n("Path to a local directory containing Certificate Revocation List (CRL) files.", nullptr));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(tlsTab), tr2i18n("TLS Settings", nullptr));
#if QT_CONFIG(tooltip)
        label_11->setToolTip(tr2i18n("Proxy type: HTTP or SOCKS", nullptr));
#endif // QT_CONFIG(tooltip)
        label_11->setText(tr2i18n("Proxy Type:", nullptr));
        cmbProxyType->setItemText(0, tr2i18n("Not Required", nullptr));
        cmbProxyType->setItemText(1, tr2i18n("HTTP", nullptr));
        cmbProxyType->setItemText(2, tr2i18n("SOCKS", nullptr));

#if QT_CONFIG(tooltip)
        cmbProxyType->setToolTip(tr2i18n("Proxy type: HTTP or SOCKS", nullptr));
#endif // QT_CONFIG(tooltip)
        lbProxyType->setText(tr2i18n("Select this option if your organization requires the use of a proxy server to access the Internet.", nullptr));
#if QT_CONFIG(tooltip)
        label_12->setToolTip(tr2i18n("Connect to remote host through a proxy with this address.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_12->setText(tr2i18n("Server Address:", nullptr));
#if QT_CONFIG(tooltip)
        proxyServerAddress->setToolTip(tr2i18n("Connect to remote host through a proxy with this address.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_13->setToolTip(tr2i18n("Connect to remote host through a proxy with this port.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_13->setText(tr2i18n("Port:", nullptr));
#if QT_CONFIG(tooltip)
        sbProxyPort->setToolTip(tr2i18n("Connect to remote host through a proxy with this port.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_14->setToolTip(tr2i18n("HTTP/SOCKS proxy username passed to OpenVPN when prompted for it.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_14->setText(tr2i18n("Proxy Username:", nullptr));
#if QT_CONFIG(tooltip)
        proxyUsername->setToolTip(tr2i18n("HTTP/SOCKS proxy username passed to OpenVPN when prompted for it.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_15->setToolTip(tr2i18n("HTTP/SOCKS proxy password passed to OpenVPN when prompted for it.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_15->setText(tr2i18n("Proxy Password:", nullptr));
#if QT_CONFIG(tooltip)
        proxyPassword->setToolTip(tr2i18n("HTTP/SOCKS proxy password passed to OpenVPN when prompted for it.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        chkProxyRetry->setToolTip(tr2i18n("Retry indefinitely on proxy errors. It simulates a SIGUSR1 reset.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkProxyRetry->setText(tr2i18n("Retry indefinitely when errors occur", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(proxyTab), tr2i18n("Proxies", nullptr));
        (void)OpenVpnAdvancedWidget;
    } // retranslateUi

};

namespace Ui {
    class OpenVpnAdvancedWidget: public Ui_OpenVpnAdvancedWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPENVPNADVANCED_H

