/********************************************************************************
** Form generated from reading UI file 'l2tpipsec.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_L2TPIPSEC_H
#define UI_L2TPIPSEC_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_L2tpIpsecWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *gbEnableTunnelToHost;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *gbAuthentication;
    QVBoxLayout *verticalLayout_3;
    QFormLayout *formLayout;
    QLabel *labelAuthType;
    QComboBox *cmbAuthType;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QFormLayout *formLayout_5;
    QLabel *label;
    QHBoxLayout *horizontalLayout_3;
    PasswordField *presharedKey;
    QWidget *page_1;
    QFormLayout *formLayout_2;
    KUrlRequester *machineCA;
    QLabel *label_3;
    KUrlRequester *machineCert;
    QLabel *label_4;
    KUrlRequester *machineKey;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_2;
    PasswordField *machineKeyPassword;
    QLabel *label_2;
    QGroupBox *gbAdvanced;
    QGridLayout *gridLayout;
    QLabel *label_7;
    QLabel *label_8;
    QLineEdit *esp;
    QTimeEdit *ikelifetime;
    QCheckBox *cbIkelifetime;
    QLineEdit *ike;
    QCheckBox *cbSalifetime;
    QTimeEdit *salifetime;
    QLineEdit *remoteId;
    QCheckBox *cbIPComp;
    QCheckBox *cbIKEv2;
    QCheckBox *cbPFS;
    QCheckBox *cbForceEncaps;
    QLabel *label_6;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *L2tpIpsecWidget)
    {
        if (L2tpIpsecWidget->objectName().isEmpty())
            L2tpIpsecWidget->setObjectName("L2tpIpsecWidget");
        L2tpIpsecWidget->resize(538, 722);
        verticalLayout = new QVBoxLayout(L2tpIpsecWidget);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        gbEnableTunnelToHost = new QGroupBox(L2tpIpsecWidget);
        gbEnableTunnelToHost->setObjectName("gbEnableTunnelToHost");
        gbEnableTunnelToHost->setEnabled(true);
        gbEnableTunnelToHost->setCheckable(true);
        gbEnableTunnelToHost->setChecked(true);
        verticalLayout_2 = new QVBoxLayout(gbEnableTunnelToHost);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName("verticalLayout_2");
        gbAuthentication = new QGroupBox(gbEnableTunnelToHost);
        gbAuthentication->setObjectName("gbAuthentication");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(gbAuthentication->sizePolicy().hasHeightForWidth());
        gbAuthentication->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(gbAuthentication);
        verticalLayout_3->setSpacing(6);
        verticalLayout_3->setContentsMargins(11, 11, 11, 11);
        verticalLayout_3->setObjectName("verticalLayout_3");
        formLayout = new QFormLayout();
        formLayout->setSpacing(6);
        formLayout->setObjectName("formLayout");
        labelAuthType = new QLabel(gbAuthentication);
        labelAuthType->setObjectName("labelAuthType");
        labelAuthType->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelAuthType->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelAuthType);

        cmbAuthType = new QComboBox(gbAuthentication);
        cmbAuthType->addItem(QString());
        cmbAuthType->addItem(QString());
        cmbAuthType->setObjectName("cmbAuthType");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cmbAuthType->sizePolicy().hasHeightForWidth());
        cmbAuthType->setSizePolicy(sizePolicy1);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, cmbAuthType);


        verticalLayout_3->addLayout(formLayout);

        stackedWidget = new QStackedWidget(gbAuthentication);
        stackedWidget->setObjectName("stackedWidget");
        page = new QWidget();
        page->setObjectName("page");
        formLayout_5 = new QFormLayout(page);
        formLayout_5->setSpacing(6);
        formLayout_5->setContentsMargins(11, 11, 11, 11);
        formLayout_5->setObjectName("formLayout_5");
        label = new QLabel(page);
        label->setObjectName("label");

        formLayout_5->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(6);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        presharedKey = new PasswordField(page);
        presharedKey->setObjectName("presharedKey");
        presharedKey->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_3->addWidget(presharedKey);


        formLayout_5->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);

        stackedWidget->addWidget(page);
        page_1 = new QWidget();
        page_1->setObjectName("page_1");
        formLayout_2 = new QFormLayout(page_1);
        formLayout_2->setSpacing(6);
        formLayout_2->setContentsMargins(11, 11, 11, 11);
        formLayout_2->setObjectName("formLayout_2");
        machineCA = new KUrlRequester(page_1);
        machineCA->setObjectName("machineCA");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, machineCA);

        label_3 = new QLabel(page_1);
        label_3->setObjectName("label_3");
        label_3->setWordWrap(false);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        machineCert = new KUrlRequester(page_1);
        machineCert->setObjectName("machineCert");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, machineCert);

        label_4 = new QLabel(page_1);
        label_4->setObjectName("label_4");
        label_4->setWordWrap(false);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_4);

        machineKey = new KUrlRequester(page_1);
        machineKey->setObjectName("machineKey");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, machineKey);

        label_5 = new QLabel(page_1);
        label_5->setObjectName("label_5");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_5);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        machineKeyPassword = new PasswordField(page_1);
        machineKeyPassword->setObjectName("machineKeyPassword");
        machineKeyPassword->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_2->addWidget(machineKeyPassword);


        formLayout_2->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        label_2 = new QLabel(page_1);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(false);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        stackedWidget->addWidget(page_1);

        verticalLayout_3->addWidget(stackedWidget);


        verticalLayout_2->addWidget(gbAuthentication);

        gbAdvanced = new QGroupBox(gbEnableTunnelToHost);
        gbAdvanced->setObjectName("gbAdvanced");
        gridLayout = new QGridLayout(gbAdvanced);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        label_7 = new QLabel(gbAdvanced);
        label_7->setObjectName("label_7");

        gridLayout->addWidget(label_7, 1, 0, 1, 1);

        label_8 = new QLabel(gbAdvanced);
        label_8->setObjectName("label_8");

        gridLayout->addWidget(label_8, 2, 0, 1, 1);

        esp = new QLineEdit(gbAdvanced);
        esp->setObjectName("esp");

        gridLayout->addWidget(esp, 2, 1, 1, 1);

        ikelifetime = new QTimeEdit(gbAdvanced);
        ikelifetime->setObjectName("ikelifetime");
        ikelifetime->setEnabled(false);

        gridLayout->addWidget(ikelifetime, 3, 1, 1, 1);

        cbIkelifetime = new QCheckBox(gbAdvanced);
        cbIkelifetime->setObjectName("cbIkelifetime");

        gridLayout->addWidget(cbIkelifetime, 3, 0, 1, 1);

        ike = new QLineEdit(gbAdvanced);
        ike->setObjectName("ike");

        gridLayout->addWidget(ike, 1, 1, 1, 1);

        cbSalifetime = new QCheckBox(gbAdvanced);
        cbSalifetime->setObjectName("cbSalifetime");

        gridLayout->addWidget(cbSalifetime, 4, 0, 1, 1);

        salifetime = new QTimeEdit(gbAdvanced);
        salifetime->setObjectName("salifetime");
        salifetime->setEnabled(false);

        gridLayout->addWidget(salifetime, 4, 1, 1, 1);

        remoteId = new QLineEdit(gbAdvanced);
        remoteId->setObjectName("remoteId");

        gridLayout->addWidget(remoteId, 0, 1, 1, 1);

        cbIPComp = new QCheckBox(gbAdvanced);
        cbIPComp->setObjectName("cbIPComp");

        gridLayout->addWidget(cbIPComp, 6, 0, 1, 2);

        cbIKEv2 = new QCheckBox(gbAdvanced);
        cbIKEv2->setObjectName("cbIKEv2");

        gridLayout->addWidget(cbIKEv2, 7, 0, 1, 2);

        cbPFS = new QCheckBox(gbAdvanced);
        cbPFS->setObjectName("cbPFS");

        gridLayout->addWidget(cbPFS, 8, 0, 1, 2);

        cbForceEncaps = new QCheckBox(gbAdvanced);
        cbForceEncaps->setObjectName("cbForceEncaps");
        cbForceEncaps->setChecked(false);

        gridLayout->addWidget(cbForceEncaps, 5, 0, 1, 2);

        label_6 = new QLabel(gbAdvanced);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 0, 0, 1, 1);


        verticalLayout_2->addWidget(gbAdvanced);

        verticalSpacer = new QSpacerItem(510, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        verticalLayout->addWidget(gbEnableTunnelToHost);

        buttonBox = new QDialogButtonBox(L2tpIpsecWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        buttonBox->raise();
        gbEnableTunnelToHost->raise();
#if QT_CONFIG(shortcut)
        labelAuthType->setBuddy(cmbAuthType);
        label->setBuddy(presharedKey);
        label_3->setBuddy(machineCert);
        label_4->setBuddy(machineKey);
        label_5->setBuddy(machineKeyPassword);
        label_2->setBuddy(machineCA);
        label_7->setBuddy(ike);
        label_8->setBuddy(esp);
        label_6->setBuddy(remoteId);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(gbEnableTunnelToHost, cmbAuthType);
        QWidget::setTabOrder(cmbAuthType, presharedKey);
        QWidget::setTabOrder(presharedKey, machineCA);
        QWidget::setTabOrder(machineCA, machineCert);
        QWidget::setTabOrder(machineCert, machineKey);
        QWidget::setTabOrder(machineKey, machineKeyPassword);
        QWidget::setTabOrder(machineKeyPassword, remoteId);
        QWidget::setTabOrder(remoteId, ike);
        QWidget::setTabOrder(ike, esp);
        QWidget::setTabOrder(esp, cbIkelifetime);
        QWidget::setTabOrder(cbIkelifetime, ikelifetime);
        QWidget::setTabOrder(ikelifetime, cbSalifetime);
        QWidget::setTabOrder(cbSalifetime, salifetime);
        QWidget::setTabOrder(salifetime, cbForceEncaps);
        QWidget::setTabOrder(cbForceEncaps, cbIPComp);
        QWidget::setTabOrder(cbIPComp, cbIKEv2);
        QWidget::setTabOrder(cbIKEv2, cbPFS);

        retranslateUi(L2tpIpsecWidget);
        QObject::connect(cmbAuthType, &QComboBox::currentIndexChanged, stackedWidget, &QStackedWidget::setCurrentIndex);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, L2tpIpsecWidget, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, L2tpIpsecWidget, qOverload<>(&QDialog::reject));
        QObject::connect(cbIkelifetime, &QCheckBox::toggled, ikelifetime, &QTimeEdit::setEnabled);
        QObject::connect(cbSalifetime, &QCheckBox::toggled, salifetime, &QTimeEdit::setEnabled);

        QMetaObject::connectSlotsByName(L2tpIpsecWidget);
    } // setupUi

    void retranslateUi(QDialog *L2tpIpsecWidget)
    {
        gbEnableTunnelToHost->setTitle(tr2i18n("Enable IPsec tunnel to L2TP host", nullptr));
        gbAuthentication->setTitle(tr2i18n("Machine Authentication", nullptr));
        labelAuthType->setText(tr2i18n("Type:", nullptr));
        cmbAuthType->setItemText(0, tr2i18n("Pre-shared Key (PSK)", nullptr));
        cmbAuthType->setItemText(1, tr2i18n("Certificates (TLS)", nullptr));

#if QT_CONFIG(tooltip)
        cmbAuthType->setToolTip(tr2i18n("Select an authentication mode.", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Pre-shared Key:", nullptr));
#if QT_CONFIG(tooltip)
        presharedKey->setToolTip(tr2i18n("<html><head/><body><p>Pre-shared key (PSK) secret.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        machineCA->setToolTip(tr2i18n("<html><head/><body><p>Certificate authority (CA) file in .pem, .der, .crt, .cer or .p12 formats.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        machineCA->setNameFilters(QStringList{
            tr2i18n("*.pem *.der *.crt *.cer *.p12", nullptr)});
        label_3->setText(tr2i18n("Machine Certificate:", nullptr));
#if QT_CONFIG(tooltip)
        machineCert->setToolTip(tr2i18n("<html><head/><body><p>Certificate in .pem, .der or .p12 formats.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        machineCert->setNameFilters(QStringList{
            tr2i18n("*.pem *.der *.crt *.cer *.p12", nullptr)});
        label_4->setText(tr2i18n("Private Key:", nullptr));
#if QT_CONFIG(tooltip)
        machineKey->setToolTip(tr2i18n("<html><head/><body><p>Private key in .pem, .der, .key, .pk8 or .p12 formats.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        machineKey->setNameFilters(QStringList{
            tr2i18n("*.pem *.der *.key *.pk8 *.p12", nullptr)});
        label_5->setText(tr2i18n("Private Key Password:", nullptr));
#if QT_CONFIG(tooltip)
        machineKeyPassword->setToolTip(tr2i18n("<html><head/><body><p>Password for private key or PKCS#12 certificate.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("CA Certificate:", nullptr));
        gbAdvanced->setTitle(tr2i18n("Advanced", nullptr));
        label_7->setText(tr2i18n("Phase1 Algorithms:", nullptr));
        label_8->setText(tr2i18n("Phase2 Algorithms:", nullptr));
#if QT_CONFIG(tooltip)
        esp->setToolTip(tr2i18n("<html><head/><body><p>Optional. A list of proposals for ESP - Quick Mode. The format is \342\200\234enc-integ,enc-integ, \342\200\246\342\200\235.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        ikelifetime->setToolTip(tr2i18n("<html><head/><body><p>How long the keying channel of a connection should last before being renegotiated.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        ikelifetime->setDisplayFormat(tr2i18n("hh:mm:ss", nullptr));
        cbIkelifetime->setText(tr2i18n("Phase1 Lifetime:", nullptr));
#if QT_CONFIG(tooltip)
        ike->setToolTip(tr2i18n("<html><head/><body><p>Optional. A list of proposals for IKE - Main Mode. The format is \342\200\234enc-integ-group,enc-integ-group, \342\200\246\342\200\235.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        cbSalifetime->setText(tr2i18n("Phase2 Lifetime:", nullptr));
#if QT_CONFIG(tooltip)
        salifetime->setToolTip(tr2i18n("<html><head/><body><p>How long a particular instance of a connection (a set of encryption/authentication keys for user packets) should last, from successful negotiation to expiry.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        salifetime->setDisplayFormat(tr2i18n("hh:mm:ss", nullptr));
#if QT_CONFIG(tooltip)
        remoteId->setToolTip(tr2i18n("<html><head/><body><p>Optional. How the IPsec server should be identified for authentication. Sometimes referred to as Peer ID or Gateway ID, also referred to as rightid by strongSwan, Libreswan, Openswan and FreeS/WAN. See strongSwan or Libreswan documentation for leftid/rightid syntax and identity parsing.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        cbIPComp->setToolTip(tr2i18n("<html><head/><body><p>IPComp compresses raw IP packets before they get encrypted. This saves some bandwidth, but uses more processing power.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        cbIPComp->setText(tr2i18n("Use IP compression", nullptr));
        cbIKEv2->setText(tr2i18n("Use IKEv2 key exchange", nullptr));
#if QT_CONFIG(tooltip)
        cbPFS->setToolTip(tr2i18n("<html><head/><body><p>Disable perfect forward secrecy. Enable this option only if the server doesn\342\200\231t support PFS.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        cbPFS->setText(tr2i18n("Disable PFS", nullptr));
#if QT_CONFIG(tooltip)
        cbForceEncaps->setToolTip(tr2i18n("<html><head/><body><p>Some firewalls block ESP traffic. Enforcing UDP encapsulation even if no NAT situation is detected might help in such cases.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        cbForceEncaps->setText(tr2i18n("Enforce UDP encapsulation", nullptr));
        label_6->setText(tr2i18n("Remote ID:", nullptr));
        (void)L2tpIpsecWidget;
    } // retranslateUi

};

namespace Ui {
    class L2tpIpsecWidget: public Ui_L2tpIpsecWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // L2TPIPSEC_H

