/****************************************************************************
** Meta object code from reading C++ file 'secretagent.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-nm-6.7.4/kded/secretagent.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'secretagent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11SecretAgentE_t {};
} // unnamed namespace

template <> constexpr inline auto SecretAgent::qt_create_metaobjectdata<qt_meta_tag_ZN11SecretAgentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SecretAgent",
        "secretsError",
        "",
        "connectionPath",
        "message",
        "GetSecrets",
        "NMVariantMapMap",
        "QDBusObjectPath",
        "SaveSecrets",
        "connection",
        "connection_path",
        "DeleteSecrets",
        "CancelGetSecrets",
        "dialogAccepted",
        "dialogRejected",
        "killDialogs"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'secretsError'
        QtMocHelpers::SignalData<void(const QString &, const QString &) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'GetSecrets'
        QtMocHelpers::SlotData<NMVariantMapMap(const NMVariantMapMap &, const QDBusObjectPath &, const QString &, const QStringList &, uint)>(5, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 6, 2 }, { 0x80000000 | 7, 2 }, { QMetaType::QString, 2 }, { QMetaType::QStringList, 2 },
            { QMetaType::UInt, 2 },
        }}),
        // Slot 'SaveSecrets'
        QtMocHelpers::SlotData<void(const NMVariantMapMap &, const QDBusObjectPath &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 9 }, { 0x80000000 | 7, 10 },
        }}),
        // Slot 'DeleteSecrets'
        QtMocHelpers::SlotData<void(const NMVariantMapMap &, const QDBusObjectPath &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { 0x80000000 | 7, 2 },
        }}),
        // Slot 'CancelGetSecrets'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'dialogAccepted'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'dialogRejected'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'killDialogs'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SecretAgent, qt_meta_tag_ZN11SecretAgentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SecretAgent::staticMetaObject = { {
    QMetaObject::SuperData::link<NetworkManager::SecretAgent::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SecretAgentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SecretAgentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11SecretAgentE_t>.metaTypes,
    nullptr
} };

void SecretAgent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SecretAgent *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->secretsError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: { NMVariantMapMap _r = _t->GetSecrets((*reinterpret_cast<std::add_pointer_t<NMVariantMapMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])));
            if (_a[0]) *reinterpret_cast<NMVariantMapMap*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->SaveSecrets((*reinterpret_cast<std::add_pointer_t<NMVariantMapMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 3: _t->DeleteSecrets((*reinterpret_cast<std::add_pointer_t<NMVariantMapMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 4: _t->CancelGetSecrets((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->dialogAccepted(); break;
        case 6: _t->dialogRejected(); break;
        case 7: _t->killDialogs(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMVariantMapMap >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMVariantMapMap >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMVariantMapMap >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SecretAgent::*)(const QString & , const QString & ) const>(_a, &SecretAgent::secretsError, 0))
            return;
    }
}

const QMetaObject *SecretAgent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SecretAgent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SecretAgentE_t>.strings))
        return static_cast<void*>(this);
    return NetworkManager::SecretAgent::qt_metacast(_clname);
}

int SecretAgent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetworkManager::SecretAgent::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void SecretAgent::secretsError(const QString & _t1, const QString & _t2)const
{
    QMetaObject::activate<void>(const_cast< SecretAgent *>(this), &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
