/****************************************************************************
** Meta object code from reading C++ file 'cellularconnectionprofile.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-nm-6.7.4/libs/cellular/cellularconnectionprofile.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cellularconnectionprofile.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25CellularConnectionProfileE_t {};
} // unnamed namespace

template <> constexpr inline auto CellularConnectionProfile::qt_create_metaobjectdata<qt_meta_tag_ZN25CellularConnectionProfileE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CellularConnectionProfile",
        "QML.Element",
        "auto",
        "profilesChanged",
        "",
        "setRoamingAllowed",
        "QCoro::Task<void>",
        "index",
        "allowed",
        "indexOfConnection",
        "connectionUni",
        "roamingAllowedForConnection",
        "ItemRole",
        "ConnectionName",
        "ConnectionAPN",
        "ConnectionUser",
        "ConnectionPassword",
        "ConnectionNetworkType",
        "ConnectionUni",
        "RoamingAllowed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'profilesChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'setRoamingAllowed'
        QtMocHelpers::MethodData<QCoro::Task<void>(int, bool)>(5, 4, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::Int, 7 }, { QMetaType::Bool, 8 },
        }}),
        // Method 'indexOfConnection'
        QtMocHelpers::MethodData<int(const QString &) const>(9, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 10 },
        }}),
        // Method 'roamingAllowedForConnection'
        QtMocHelpers::MethodData<bool(const QString &) const>(11, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ItemRole'
        QtMocHelpers::EnumData<enum ItemRole>(12, 12, QMC::EnumFlags{}).add({
            {   13, ItemRole::ConnectionName },
            {   14, ItemRole::ConnectionAPN },
            {   15, ItemRole::ConnectionUser },
            {   16, ItemRole::ConnectionPassword },
            {   17, ItemRole::ConnectionNetworkType },
            {   18, ItemRole::ConnectionUni },
            {   19, ItemRole::RoamingAllowed },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<CellularConnectionProfile, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CellularConnectionProfile::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25CellularConnectionProfileE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25CellularConnectionProfileE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25CellularConnectionProfileE_t>.metaTypes,
    nullptr
} };

void CellularConnectionProfile::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CellularConnectionProfile *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->profilesChanged(); break;
        case 1: { QCoro::Task<void> _r = _t->setRoamingAllowed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        case 2: { int _r = _t->indexOfConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->roamingAllowedForConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CellularConnectionProfile::*)()>(_a, &CellularConnectionProfile::profilesChanged, 0))
            return;
    }
}

const QMetaObject *CellularConnectionProfile::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CellularConnectionProfile::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25CellularConnectionProfileE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int CellularConnectionProfile::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void CellularConnectionProfile::profilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
