/****************************************************************************
** Meta object code from reading C++ file 'availabledevices.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-nm-6.7.4/libs/availabledevices.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'availabledevices.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16AvailableDevicesE_t {};
} // unnamed namespace

template <> constexpr inline auto AvailableDevices::qt_create_metaobjectdata<qt_meta_tag_ZN16AvailableDevicesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AvailableDevices",
        "QML.Element",
        "auto",
        "wiredDeviceAvailableChanged",
        "",
        "available",
        "wirelessDeviceAvailableChanged",
        "modemDeviceAvailableChanged",
        "bluetoothDeviceAvailableChanged",
        "isWiredDeviceAvailable",
        "isWirelessDeviceAvailable",
        "isModemDeviceAvailable",
        "isBluetoothDeviceAvailable",
        "deviceAdded",
        "dev",
        "deviceRemoved",
        "wiredDeviceAvailable",
        "wirelessDeviceAvailable",
        "modemDeviceAvailable",
        "bluetoothDeviceAvailable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wiredDeviceAvailableChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'wirelessDeviceAvailableChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'modemDeviceAvailableChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'bluetoothDeviceAvailableChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'isWiredDeviceAvailable'
        QtMocHelpers::SlotData<bool() const>(9, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isWirelessDeviceAvailable'
        QtMocHelpers::SlotData<bool() const>(10, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isModemDeviceAvailable'
        QtMocHelpers::SlotData<bool() const>(11, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isBluetoothDeviceAvailable'
        QtMocHelpers::SlotData<bool() const>(12, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'deviceAdded'
        QtMocHelpers::SlotData<void(const QString &)>(13, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'deviceRemoved'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'wiredDeviceAvailable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'wirelessDeviceAvailable'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'modemDeviceAvailable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'bluetoothDeviceAvailable'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AvailableDevices, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AvailableDevices::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AvailableDevicesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AvailableDevicesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16AvailableDevicesE_t>.metaTypes,
    nullptr
} };

void AvailableDevices::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AvailableDevices *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wiredDeviceAvailableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->wirelessDeviceAvailableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->modemDeviceAvailableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->bluetoothDeviceAvailableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: { bool _r = _t->isWiredDeviceAvailable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->isWirelessDeviceAvailable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->isModemDeviceAvailable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->isBluetoothDeviceAvailable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->deviceRemoved(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AvailableDevices::*)(bool )>(_a, &AvailableDevices::wiredDeviceAvailableChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AvailableDevices::*)(bool )>(_a, &AvailableDevices::wirelessDeviceAvailableChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AvailableDevices::*)(bool )>(_a, &AvailableDevices::modemDeviceAvailableChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AvailableDevices::*)(bool )>(_a, &AvailableDevices::bluetoothDeviceAvailableChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isWiredDeviceAvailable(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isWirelessDeviceAvailable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isModemDeviceAvailable(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isBluetoothDeviceAvailable(); break;
        default: break;
        }
    }
}

const QMetaObject *AvailableDevices::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AvailableDevices::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AvailableDevicesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AvailableDevices::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void AvailableDevices::wiredDeviceAvailableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AvailableDevices::wirelessDeviceAvailableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AvailableDevices::modemDeviceAvailableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AvailableDevices::bluetoothDeviceAvailableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
