/********************************************************************************
** Form generated from reading UI file 'pinwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PINWIDGET_H
#define UI_PINWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktitlewidget.h"

QT_BEGIN_NAMESPACE

class Ui_PinWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *title;
    QLabel *prompt;
    QSpacerItem *spacerItem;
    KTitleWidget *errorMessage;
    QFormLayout *formLayout;
    QLabel *pukLabel;
    QLineEdit *puk;
    QLabel *pinLabel;
    QLineEdit *pin;
    QLabel *pin2Label;
    QLineEdit *pin2;
    QCheckBox *chkShowPass;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *PinWidget)
    {
        if (PinWidget->objectName().isEmpty())
            PinWidget->setObjectName("PinWidget");
        PinWidget->resize(456, 284);
        verticalLayout = new QVBoxLayout(PinWidget);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        title = new QLabel(PinWidget);
        title->setObjectName("title");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(10);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(title->sizePolicy().hasHeightForWidth());
        title->setSizePolicy(sizePolicy);
        QFont font;
        font.setPointSize(9);
        font.setBold(true);
        title->setFont(font);
        title->setTextFormat(Qt::RichText);
        title->setAlignment(Qt::AlignCenter|Qt::AlignHCenter|Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        title->setWordWrap(true);

        gridLayout->addWidget(title, 0, 1, 1, 1);

        prompt = new QLabel(PinWidget);
        prompt->setObjectName("prompt");
        sizePolicy.setHeightForWidth(prompt->sizePolicy().hasHeightForWidth());
        prompt->setSizePolicy(sizePolicy);
        QFont font1;
        font1.setPointSize(9);
        font1.setBold(false);
        prompt->setFont(font1);
        prompt->setTextFormat(Qt::RichText);
        prompt->setAlignment(Qt::AlignBottom|Qt::AlignLeading|Qt::AlignLeft);
        prompt->setWordWrap(true);

        gridLayout->addWidget(prompt, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        spacerItem = new QSpacerItem(400, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(spacerItem);

        errorMessage = new KTitleWidget(PinWidget);
        errorMessage->setObjectName("errorMessage");

        verticalLayout->addWidget(errorMessage);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout->setVerticalSpacing(0);
        formLayout->setContentsMargins(0, 0, 0, 0);
        pukLabel = new QLabel(PinWidget);
        pukLabel->setObjectName("pukLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, pukLabel);

        puk = new QLineEdit(PinWidget);
        puk->setObjectName("puk");
        puk->setEchoMode(QLineEdit::Password);
        puk->setProperty("showClearButton", QVariant(true));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, puk);

        pinLabel = new QLabel(PinWidget);
        pinLabel->setObjectName("pinLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, pinLabel);

        pin = new QLineEdit(PinWidget);
        pin->setObjectName("pin");
        pin->setEchoMode(QLineEdit::Password);
        pin->setProperty("showClearButton", QVariant(true));

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, pin);

        pin2Label = new QLabel(PinWidget);
        pin2Label->setObjectName("pin2Label");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, pin2Label);

        pin2 = new QLineEdit(PinWidget);
        pin2->setObjectName("pin2");
        pin2->setEchoMode(QLineEdit::Password);
        pin2->setProperty("showClearButton", QVariant(true));

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, pin2);

        chkShowPass = new QCheckBox(PinWidget);
        chkShowPass->setObjectName("chkShowPass");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, chkShowPass);


        verticalLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(PinWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        pukLabel->setBuddy(puk);
        pinLabel->setBuddy(pin);
        pin2Label->setBuddy(pin2);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(puk, pin);
        QWidget::setTabOrder(pin, pin2);
        QWidget::setTabOrder(pin2, chkShowPass);

        retranslateUi(PinWidget);

        QMetaObject::connectSlotsByName(PinWidget);
    } // setupUi

    void retranslateUi(QWidget *PinWidget)
    {
        PinWidget->setWindowTitle(tr2i18n("SIM PIN unlock required", nullptr));
        title->setText(tr2i18n("SIM PIN unlock required", nullptr));
        prompt->setText(tr2i18n("The mobile broadband device '%1' requires a SIM PIN code before it can be used.", nullptr));
        pukLabel->setText(tr2i18n("PUK code:", nullptr));
        pinLabel->setText(tr2i18n("New PIN code:", nullptr));
        pin2Label->setText(tr2i18n("Re-enter PIN code:", nullptr));
        chkShowPass->setText(tr2i18n("Show PIN/PUK code", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PinWidget: public Ui_PinWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PINWIDGET_H

