/****************************************************************************
** Meta object code from reading C++ file 'cellularmodem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-nm-6.7.4/libs/cellular/cellularmodem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cellularmodem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13CellularModemE_t {};
} // unnamed namespace

template <> constexpr inline auto CellularModem::qt_create_metaobjectdata<qt_meta_tag_ZN13CellularModemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CellularModem",
        "QML.Element",
        "auto",
        "modemDetailsChanged",
        "",
        "profilesChanged",
        "uniChanged",
        "displayIdChanged",
        "activeConnectionUniChanged",
        "nmModemChanged",
        "mobileDataEnabledChanged",
        "mobileDataSupportedChanged",
        "simsChanged",
        "hasSimChanged",
        "simLockedChanged",
        "simEmptyChanged",
        "signalStrengthChanged",
        "operatorNameChanged",
        "errorsChanged",
        "errorOccurred",
        "message",
        "couldNotAutodetectSettings",
        "reset",
        "QCoro::Task<void>",
        "clearErrors",
        "activateProfile",
        "connectionUni",
        "addProfile",
        "name",
        "apn",
        "username",
        "password",
        "networkType",
        "removeProfile",
        "updateProfile",
        "addDetectedProfileSettings",
        "details",
        "CellularModemDetails*",
        "profiles",
        "CellularConnectionProfile*",
        "uni",
        "displayId",
        "hasSim",
        "simLocked",
        "simEmpty",
        "activeConnectionUni",
        "mobileDataEnabled",
        "mobileDataSupported",
        "needsAPNAdded",
        "signalStrength",
        "operatorName",
        "errors"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modemDetailsChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'profilesChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uniChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayIdChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeConnectionUniChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nmModemChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mobileDataEnabledChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mobileDataSupportedChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'simsChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasSimChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'simLockedChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'simEmptyChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalStrengthChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'operatorNameChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorsChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void(const QString &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Signal 'couldNotAutodetectSettings'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'reset'
        QtMocHelpers::MethodData<QCoro::Task<void>()>(22, 4, QMC::AccessPublic, 0x80000000 | 23),
        // Method 'clearErrors'
        QtMocHelpers::MethodData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'activateProfile'
        QtMocHelpers::MethodData<QCoro::Task<void>(const QString &)>(25, 4, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 26 },
        }}),
        // Method 'addProfile'
        QtMocHelpers::MethodData<QCoro::Task<void>(QString, QString, QString, QString, QString)>(27, 4, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 29 }, { QMetaType::QString, 30 }, { QMetaType::QString, 31 },
            { QMetaType::QString, 32 },
        }}),
        // Method 'removeProfile'
        QtMocHelpers::MethodData<QCoro::Task<void>(const QString &)>(33, 4, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 26 },
        }}),
        // Method 'updateProfile'
        QtMocHelpers::MethodData<QCoro::Task<void>(QString, QString, QString, QString, QString, QString)>(34, 4, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 26 }, { QMetaType::QString, 28 }, { QMetaType::QString, 29 }, { QMetaType::QString, 30 },
            { QMetaType::QString, 31 }, { QMetaType::QString, 32 },
        }}),
        // Method 'addDetectedProfileSettings'
        QtMocHelpers::MethodData<void()>(35, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'details'
        QtMocHelpers::PropertyData<CellularModemDetails*>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'profiles'
        QtMocHelpers::PropertyData<CellularConnectionProfile*>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'uni'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'displayId'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'hasSim'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'simLocked'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'simEmpty'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
        // property 'activeConnectionUni'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'mobileDataEnabled'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'mobileDataSupported'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'needsAPNAdded'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'signalStrength'
        QtMocHelpers::PropertyData<int>(49, QMetaType::Int, QMC::DefaultPropertyFlags, 12),
        // property 'operatorName'
        QtMocHelpers::PropertyData<QString>(50, QMetaType::QString, QMC::DefaultPropertyFlags, 13),
        // property 'errors'
        QtMocHelpers::PropertyData<QStringList>(51, QMetaType::QStringList, QMC::DefaultPropertyFlags, 14),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<CellularModem, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CellularModem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13CellularModemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13CellularModemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13CellularModemE_t>.metaTypes,
    nullptr
} };

void CellularModem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CellularModem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modemDetailsChanged(); break;
        case 1: _t->profilesChanged(); break;
        case 2: _t->uniChanged(); break;
        case 3: _t->displayIdChanged(); break;
        case 4: _t->activeConnectionUniChanged(); break;
        case 5: _t->nmModemChanged(); break;
        case 6: _t->mobileDataEnabledChanged(); break;
        case 7: _t->mobileDataSupportedChanged(); break;
        case 8: _t->simsChanged(); break;
        case 9: _t->hasSimChanged(); break;
        case 10: _t->simLockedChanged(); break;
        case 11: _t->simEmptyChanged(); break;
        case 12: _t->signalStrengthChanged(); break;
        case 13: _t->operatorNameChanged(); break;
        case 14: _t->errorsChanged(); break;
        case 15: _t->errorOccurred((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->couldNotAutodetectSettings(); break;
        case 17: { QCoro::Task<void> _r = _t->reset();
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->clearErrors(); break;
        case 19: { QCoro::Task<void> _r = _t->activateProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QCoro::Task<void> _r = _t->addProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QCoro::Task<void> _r = _t->removeProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QCoro::Task<void> _r = _t->updateProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->addDetectedProfileSettings(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::modemDetailsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::profilesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::uniChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::displayIdChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::activeConnectionUniChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::nmModemChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::mobileDataEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::mobileDataSupportedChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::simsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::hasSimChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::simLockedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::simEmptyChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::signalStrengthChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::operatorNameChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::errorsChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)(const QString & )>(_a, &CellularModem::errorOccurred, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (CellularModem::*)()>(_a, &CellularModem::couldNotAutodetectSettings, 16))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< CellularConnectionProfile* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< CellularModemDetails* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<CellularModemDetails**>(_v) = _t->modemDetails(); break;
        case 1: *reinterpret_cast<CellularConnectionProfile**>(_v) = _t->profiles(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->uni(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->displayId(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->hasSim(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->simLocked(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->simEmpty(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->activeConnectionUni(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->mobileDataEnabled(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->mobileDataSupported(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->needsAPNAdded(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->signalStrength(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->operatorName(); break;
        case 13: *reinterpret_cast<QStringList*>(_v) = _t->errors(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 8: _t->setMobileDataEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *CellularModem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CellularModem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13CellularModemE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CellularModem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void CellularModem::modemDetailsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CellularModem::profilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CellularModem::uniChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CellularModem::displayIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void CellularModem::activeConnectionUniChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CellularModem::nmModemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void CellularModem::mobileDataEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void CellularModem::mobileDataSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void CellularModem::simsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void CellularModem::hasSimChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void CellularModem::simLockedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void CellularModem::simEmptyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void CellularModem::signalStrengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void CellularModem::operatorNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void CellularModem::errorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void CellularModem::errorOccurred(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void CellularModem::couldNotAutodetectSettings()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}
QT_WARNING_POP
