/********************************************************************************
** Form generated from reading UI file 'ppp.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PPP_H
#define UI_PPP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PPPWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *authGroup;
    QFormLayout *formLayout;
    QCheckBox *eap;
    QCheckBox *mschap;
    QCheckBox *pap;
    QCheckBox *mschapv2;
    QCheckBox *chap;
    QGroupBox *compressionGroup;
    QFormLayout *formLayout_2;
    QCheckBox *mppe;
    QCheckBox *bsdComp;
    QCheckBox *deflateComp;
    QCheckBox *tcpComp;
    QCheckBox *mppe128;
    QCheckBox *mppeStateful;
    QGroupBox *echoGroup;
    QGridLayout *gridLayout_3;
    QCheckBox *senddEcho;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *PPPWidget)
    {
        if (PPPWidget->objectName().isEmpty())
            PPPWidget->setObjectName("PPPWidget");
        PPPWidget->resize(440, 423);
        verticalLayout = new QVBoxLayout(PPPWidget);
        verticalLayout->setObjectName("verticalLayout");
        authGroup = new QGroupBox(PPPWidget);
        authGroup->setObjectName("authGroup");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(authGroup->sizePolicy().hasHeightForWidth());
        authGroup->setSizePolicy(sizePolicy);
        formLayout = new QFormLayout(authGroup);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        formLayout->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        formLayout->setVerticalSpacing(6);
        eap = new QCheckBox(authGroup);
        eap->setObjectName("eap");
        eap->setChecked(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, eap);

        mschap = new QCheckBox(authGroup);
        mschap->setObjectName("mschap");
        mschap->setChecked(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, mschap);

        pap = new QCheckBox(authGroup);
        pap->setObjectName("pap");
        pap->setChecked(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, pap);

        mschapv2 = new QCheckBox(authGroup);
        mschapv2->setObjectName("mschapv2");
        mschapv2->setChecked(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, mschapv2);

        chap = new QCheckBox(authGroup);
        chap->setObjectName("chap");
        chap->setChecked(true);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, chap);


        verticalLayout->addWidget(authGroup);

        compressionGroup = new QGroupBox(PPPWidget);
        compressionGroup->setObjectName("compressionGroup");
        compressionGroup->setFlat(false);
        compressionGroup->setCheckable(false);
        formLayout_2 = new QFormLayout(compressionGroup);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        formLayout_2->setVerticalSpacing(6);
        mppe = new QCheckBox(compressionGroup);
        mppe->setObjectName("mppe");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, mppe);

        bsdComp = new QCheckBox(compressionGroup);
        bsdComp->setObjectName("bsdComp");
        bsdComp->setChecked(true);

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, bsdComp);

        deflateComp = new QCheckBox(compressionGroup);
        deflateComp->setObjectName("deflateComp");
        deflateComp->setChecked(true);

        formLayout_2->setWidget(5, QFormLayout::ItemRole::LabelRole, deflateComp);

        tcpComp = new QCheckBox(compressionGroup);
        tcpComp->setObjectName("tcpComp");
        tcpComp->setChecked(true);

        formLayout_2->setWidget(6, QFormLayout::ItemRole::LabelRole, tcpComp);

        mppe128 = new QCheckBox(compressionGroup);
        mppe128->setObjectName("mppe128");
        mppe128->setEnabled(false);
        mppe128->setStyleSheet(QString::fromUtf8("padding-left: 20px"));

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, mppe128);

        mppeStateful = new QCheckBox(compressionGroup);
        mppeStateful->setObjectName("mppeStateful");
        mppeStateful->setEnabled(false);
        mppeStateful->setStyleSheet(QString::fromUtf8("padding-left: 20px"));

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, mppeStateful);


        verticalLayout->addWidget(compressionGroup);

        echoGroup = new QGroupBox(PPPWidget);
        echoGroup->setObjectName("echoGroup");
        echoGroup->setFlat(false);
        gridLayout_3 = new QGridLayout(echoGroup);
        gridLayout_3->setObjectName("gridLayout_3");
        senddEcho = new QCheckBox(echoGroup);
        senddEcho->setObjectName("senddEcho");
        senddEcho->setChecked(true);

        gridLayout_3->addWidget(senddEcho, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 113, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer, 1, 0, 1, 1);


        verticalLayout->addWidget(echoGroup);

        QWidget::setTabOrder(eap, mschap);
        QWidget::setTabOrder(mschap, pap);
        QWidget::setTabOrder(pap, mschapv2);
        QWidget::setTabOrder(mschapv2, chap);
        QWidget::setTabOrder(chap, mppe);
        QWidget::setTabOrder(mppe, mppe128);
        QWidget::setTabOrder(mppe128, mppeStateful);
        QWidget::setTabOrder(mppeStateful, bsdComp);
        QWidget::setTabOrder(bsdComp, deflateComp);
        QWidget::setTabOrder(deflateComp, tcpComp);
        QWidget::setTabOrder(tcpComp, senddEcho);

        retranslateUi(PPPWidget);
        QObject::connect(mppe, &QCheckBox::toggled, mppe128, &QCheckBox::setEnabled);
        QObject::connect(mppe, &QCheckBox::toggled, mppeStateful, &QCheckBox::setEnabled);

        QMetaObject::connectSlotsByName(PPPWidget);
    } // setupUi

    void retranslateUi(QWidget *PPPWidget)
    {
        authGroup->setTitle(tr2i18n("Authentication", nullptr));
        eap->setText(tr2i18n("EAP", nullptr));
        mschap->setText(tr2i18n("MSCHAP", nullptr));
        pap->setText(tr2i18n("PAP", nullptr));
        mschapv2->setText(tr2i18n("MSCHAPv2", nullptr));
        chap->setText(tr2i18n("CHAP", nullptr));
        compressionGroup->setTitle(tr2i18n("Compression", nullptr));
        mppe->setText(tr2i18n("Use point-to-point encryption (MPPE)", nullptr));
        bsdComp->setText(tr2i18n("Use BSD data compression", nullptr));
        deflateComp->setText(tr2i18n("Use Deflate data compression", nullptr));
        tcpComp->setText(tr2i18n("Use TCP header compression", nullptr));
        mppe128->setText(tr2i18n("Require 128-bit encryption", nullptr));
        mppeStateful->setText(tr2i18n("Use stateful MPPE", nullptr));
        echoGroup->setTitle(tr2i18n("Echo", nullptr));
        senddEcho->setText(tr2i18n("Send PPP echo packets", nullptr));
        (void)PPPWidget;
    } // retranslateUi

};

namespace Ui {
    class PPPWidget: public Ui_PPPWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PPP_H

