/********************************************************************************
** Form generated from reading UI file 'vpncauth.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VPNCAUTH_H
#define UI_VPNCAUTH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_VpncAuth
{
public:
    QGridLayout *gridLayout;
    QLabel *userPasswordLabel;
    QLabel *groupPasswordLabel;
    PasswordField *leUserPassword;
    QSpacerItem *spacer1;
    PasswordField *leGroupPassword;
    QLineEdit *leUserName;
    QLabel *userNameLabel;
    QLineEdit *leGroupName;
    QLabel *groupNameLabel;

    void setupUi(QWidget *VpncAuth)
    {
        if (VpncAuth->objectName().isEmpty())
            VpncAuth->setObjectName("VpncAuth");
        VpncAuth->resize(372, 171);
        gridLayout = new QGridLayout(VpncAuth);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        userPasswordLabel = new QLabel(VpncAuth);
        userPasswordLabel->setObjectName("userPasswordLabel");
        userPasswordLabel->setWordWrap(false);

        gridLayout->addWidget(userPasswordLabel, 1, 0, 1, 1);

        groupPasswordLabel = new QLabel(VpncAuth);
        groupPasswordLabel->setObjectName("groupPasswordLabel");
        groupPasswordLabel->setWordWrap(false);

        gridLayout->addWidget(groupPasswordLabel, 3, 0, 1, 1);

        leUserPassword = new PasswordField(VpncAuth);
        leUserPassword->setObjectName("leUserPassword");
        leUserPassword->setProperty("passwordModeEnabled", QVariant(true));

        gridLayout->addWidget(leUserPassword, 1, 2, 1, 1);

        spacer1 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacer1, 4, 1, 1, 1);

        leGroupPassword = new PasswordField(VpncAuth);
        leGroupPassword->setObjectName("leGroupPassword");
        leGroupPassword->setProperty("passwordModeEnabled", QVariant(true));

        gridLayout->addWidget(leGroupPassword, 3, 2, 1, 1);

        leUserName = new QLineEdit(VpncAuth);
        leUserName->setObjectName("leUserName");
        leUserName->setEnabled(false);

        gridLayout->addWidget(leUserName, 0, 2, 1, 1);

        userNameLabel = new QLabel(VpncAuth);
        userNameLabel->setObjectName("userNameLabel");

        gridLayout->addWidget(userNameLabel, 0, 0, 1, 1);

        leGroupName = new QLineEdit(VpncAuth);
        leGroupName->setObjectName("leGroupName");
        leGroupName->setEnabled(false);

        gridLayout->addWidget(leGroupName, 2, 2, 1, 1);

        groupNameLabel = new QLabel(VpncAuth);
        groupNameLabel->setObjectName("groupNameLabel");
        groupNameLabel->setWordWrap(false);

        gridLayout->addWidget(groupNameLabel, 2, 0, 1, 1);

#if QT_CONFIG(shortcut)
        userPasswordLabel->setBuddy(leUserPassword);
        groupPasswordLabel->setBuddy(leGroupPassword);
        userNameLabel->setBuddy(leUserName);
        groupNameLabel->setBuddy(leGroupName);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(leUserName, leUserPassword);
        QWidget::setTabOrder(leUserPassword, leGroupName);
        QWidget::setTabOrder(leGroupName, leGroupPassword);

        retranslateUi(VpncAuth);

        QMetaObject::connectSlotsByName(VpncAuth);
    } // setupUi

    void retranslateUi(QWidget *VpncAuth)
    {
        VpncAuth->setWindowTitle(tr2i18n("VPNCAuthentication", nullptr));
        userPasswordLabel->setText(tr2i18n("User Password:", nullptr));
        groupPasswordLabel->setText(tr2i18n("Group Password:", nullptr));
#if QT_CONFIG(tooltip)
        leUserPassword->setToolTip(tr2i18n("User password for the connection.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        leGroupPassword->setToolTip(tr2i18n("Group password.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        leUserName->setToolTip(tr2i18n("User name for the connection.", nullptr));
#endif // QT_CONFIG(tooltip)
        userNameLabel->setText(tr2i18n("Username:", nullptr));
#if QT_CONFIG(tooltip)
        leGroupName->setToolTip(tr2i18n("Group name.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupNameLabel->setText(tr2i18n("Group name:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class VpncAuth: public Ui_VpncAuth {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VPNCAUTH_H

