/********************************************************************************
** Form generated from reading UI file 'sstpadvanced.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SSTPADVANCED_H
#define UI_SSTPADVANCED_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_SstpAdvanced
{
public:
    QGridLayout *gridLayout;
    QTabWidget *tabWidget;
    QWidget *pptpTab;
    QGridLayout *gridLayout_2;
    QGroupBox *grp_authenfication;
    QFormLayout *formLayout;
    QLabel *lbl_auth;
    QListWidget *listWidget;
    QGroupBox *gb_MPPE;
    QFormLayout *formLayout_2;
    QLabel *lbl_MMPEcrypto;
    QComboBox *cb_MPPECrypto;
    QCheckBox *cb_statefulEncryption;
    QGroupBox *grp_cryptoAndCompression;
    QFormLayout *formLayout_3;
    QCheckBox *cb_BSD;
    QCheckBox *cb_deflate;
    QCheckBox *cb_TCPheaders;
    QGroupBox *grp_echo;
    QFormLayout *formLayout_4;
    QCheckBox *cb_sendEcho;
    QGroupBox *grp_misc;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout;
    QCheckBox *chk_useCustomUnitNumber;
    QSpinBox *sb_customUnitNumber;
    QSpacerItem *verticalSpacer;
    QWidget *proxyTab;
    QGridLayout *gridLayout_6;
    QGroupBox *grp_general;
    QGridLayout *gridLayout_5;
    QLabel *lbl_address;
    QLineEdit *le_address;
    QLabel *lbl_port;
    QSpinBox *sb_port;
    QGroupBox *grp_credentials;
    QFormLayout *formLayout_5;
    QLabel *lbl_username;
    QLineEdit *le_username;
    QLabel *lbl_password;
    PasswordField *le_password;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *SstpAdvanced)
    {
        if (SstpAdvanced->objectName().isEmpty())
            SstpAdvanced->setObjectName("SstpAdvanced");
        SstpAdvanced->resize(414, 649);
        SstpAdvanced->setMinimumSize(QSize(414, 0));
        gridLayout = new QGridLayout(SstpAdvanced);
        gridLayout->setObjectName("gridLayout");
        tabWidget = new QTabWidget(SstpAdvanced);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);
        tabWidget->setMinimumSize(QSize(0, 0));
        pptpTab = new QWidget();
        pptpTab->setObjectName("pptpTab");
        gridLayout_2 = new QGridLayout(pptpTab);
        gridLayout_2->setObjectName("gridLayout_2");
        grp_authenfication = new QGroupBox(pptpTab);
        grp_authenfication->setObjectName("grp_authenfication");
        formLayout = new QFormLayout(grp_authenfication);
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(6);
        lbl_auth = new QLabel(grp_authenfication);
        lbl_auth->setObjectName("lbl_auth");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lbl_auth);

        listWidget = new QListWidget(grp_authenfication);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(listWidget);
        __qlistwidgetitem->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(listWidget);
        __qlistwidgetitem1->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(listWidget);
        __qlistwidgetitem2->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(listWidget);
        __qlistwidgetitem3->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(listWidget);
        __qlistwidgetitem4->setCheckState(Qt::Checked);
        listWidget->setObjectName("listWidget");

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, listWidget);


        gridLayout_2->addWidget(grp_authenfication, 0, 0, 1, 1);

        gb_MPPE = new QGroupBox(pptpTab);
        gb_MPPE->setObjectName("gb_MPPE");
        gb_MPPE->setCheckable(true);
        gb_MPPE->setChecked(false);
        formLayout_2 = new QFormLayout(gb_MPPE);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setVerticalSpacing(6);
        lbl_MMPEcrypto = new QLabel(gb_MPPE);
        lbl_MMPEcrypto->setObjectName("lbl_MMPEcrypto");
        lbl_MMPEcrypto->setMaximumSize(QSize(100, 16777215));

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, lbl_MMPEcrypto);

        cb_MPPECrypto = new QComboBox(gb_MPPE);
        cb_MPPECrypto->addItem(QString());
        cb_MPPECrypto->addItem(QString());
        cb_MPPECrypto->addItem(QString());
        cb_MPPECrypto->setObjectName("cb_MPPECrypto");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cb_MPPECrypto->sizePolicy().hasHeightForWidth());
        cb_MPPECrypto->setSizePolicy(sizePolicy1);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, cb_MPPECrypto);

        cb_statefulEncryption = new QCheckBox(gb_MPPE);
        cb_statefulEncryption->setObjectName("cb_statefulEncryption");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::SpanningRole, cb_statefulEncryption);


        gridLayout_2->addWidget(gb_MPPE, 1, 0, 1, 1);

        grp_cryptoAndCompression = new QGroupBox(pptpTab);
        grp_cryptoAndCompression->setObjectName("grp_cryptoAndCompression");
        formLayout_3 = new QFormLayout(grp_cryptoAndCompression);
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        formLayout_3->setVerticalSpacing(6);
        cb_BSD = new QCheckBox(grp_cryptoAndCompression);
        cb_BSD->setObjectName("cb_BSD");
        cb_BSD->setChecked(true);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, cb_BSD);

        cb_deflate = new QCheckBox(grp_cryptoAndCompression);
        cb_deflate->setObjectName("cb_deflate");
        cb_deflate->setChecked(true);

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, cb_deflate);

        cb_TCPheaders = new QCheckBox(grp_cryptoAndCompression);
        cb_TCPheaders->setObjectName("cb_TCPheaders");
        cb_TCPheaders->setChecked(true);

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, cb_TCPheaders);


        gridLayout_2->addWidget(grp_cryptoAndCompression, 2, 0, 1, 1);

        grp_echo = new QGroupBox(pptpTab);
        grp_echo->setObjectName("grp_echo");
        formLayout_4 = new QFormLayout(grp_echo);
        formLayout_4->setObjectName("formLayout_4");
        formLayout_4->setVerticalSpacing(6);
        cb_sendEcho = new QCheckBox(grp_echo);
        cb_sendEcho->setObjectName("cb_sendEcho");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, cb_sendEcho);


        gridLayout_2->addWidget(grp_echo, 3, 0, 1, 1);

        grp_misc = new QGroupBox(pptpTab);
        grp_misc->setObjectName("grp_misc");
        gridLayout_3 = new QGridLayout(grp_misc);
        gridLayout_3->setObjectName("gridLayout_3");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        chk_useCustomUnitNumber = new QCheckBox(grp_misc);
        chk_useCustomUnitNumber->setObjectName("chk_useCustomUnitNumber");

        horizontalLayout->addWidget(chk_useCustomUnitNumber);

        sb_customUnitNumber = new QSpinBox(grp_misc);
        sb_customUnitNumber->setObjectName("sb_customUnitNumber");
        sb_customUnitNumber->setMaximum(65535);

        horizontalLayout->addWidget(sb_customUnitNumber);


        gridLayout_3->addLayout(horizontalLayout, 0, 0, 1, 1);


        gridLayout_2->addWidget(grp_misc, 4, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 5, 0, 1, 1);

        tabWidget->addTab(pptpTab, QString());
        proxyTab = new QWidget();
        proxyTab->setObjectName("proxyTab");
        gridLayout_6 = new QGridLayout(proxyTab);
        gridLayout_6->setObjectName("gridLayout_6");
        grp_general = new QGroupBox(proxyTab);
        grp_general->setObjectName("grp_general");
        gridLayout_5 = new QGridLayout(grp_general);
        gridLayout_5->setObjectName("gridLayout_5");
        lbl_address = new QLabel(grp_general);
        lbl_address->setObjectName("lbl_address");
        lbl_address->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(lbl_address, 0, 0, 1, 1);

        le_address = new QLineEdit(grp_general);
        le_address->setObjectName("le_address");

        gridLayout_5->addWidget(le_address, 0, 1, 1, 1);

        lbl_port = new QLabel(grp_general);
        lbl_port->setObjectName("lbl_port");
        lbl_port->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(lbl_port, 1, 0, 1, 1);

        sb_port = new QSpinBox(grp_general);
        sb_port->setObjectName("sb_port");
        sb_port->setMaximum(65535);

        gridLayout_5->addWidget(sb_port, 1, 1, 1, 1);


        gridLayout_6->addWidget(grp_general, 0, 0, 1, 1);

        grp_credentials = new QGroupBox(proxyTab);
        grp_credentials->setObjectName("grp_credentials");
        formLayout_5 = new QFormLayout(grp_credentials);
        formLayout_5->setObjectName("formLayout_5");
        lbl_username = new QLabel(grp_credentials);
        lbl_username->setObjectName("lbl_username");
        lbl_username->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_5->setWidget(0, QFormLayout::ItemRole::LabelRole, lbl_username);

        le_username = new QLineEdit(grp_credentials);
        le_username->setObjectName("le_username");

        formLayout_5->setWidget(0, QFormLayout::ItemRole::FieldRole, le_username);

        lbl_password = new QLabel(grp_credentials);
        lbl_password->setObjectName("lbl_password");
        lbl_password->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_5->setWidget(1, QFormLayout::ItemRole::LabelRole, lbl_password);

        le_password = new PasswordField(grp_credentials);
        le_password->setObjectName("le_password");
        le_password->setProperty("passwordModeEnabled", QVariant(true));

        formLayout_5->setWidget(1, QFormLayout::ItemRole::FieldRole, le_password);


        gridLayout_6->addWidget(grp_credentials, 1, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_6->addItem(verticalSpacer_2, 2, 0, 1, 1);

        tabWidget->addTab(proxyTab, QString());

        gridLayout->addWidget(tabWidget, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        lbl_auth->setBuddy(listWidget);
        lbl_MMPEcrypto->setBuddy(cb_MPPECrypto);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SstpAdvanced);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SstpAdvanced);
    } // setupUi

    void retranslateUi(QWidget *SstpAdvanced)
    {
        grp_authenfication->setTitle(tr2i18n("Authentication", nullptr));
        lbl_auth->setText(tr2i18n("Allow following authentication methods:", nullptr));

        const bool __sortingEnabled = listWidget->isSortingEnabled();
        listWidget->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = listWidget->item(0);
        ___qlistwidgetitem->setText(tr2i18n("PAP", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = listWidget->item(1);
        ___qlistwidgetitem1->setText(tr2i18n("CHAP", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = listWidget->item(2);
        ___qlistwidgetitem2->setText(tr2i18n("MSCHAP", nullptr));
        QListWidgetItem *___qlistwidgetitem3 = listWidget->item(3);
        ___qlistwidgetitem3->setText(tr2i18n("MSCHAPv2", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = listWidget->item(4);
        ___qlistwidgetitem4->setText(tr2i18n("EAP", nullptr));
        listWidget->setSortingEnabled(__sortingEnabled);

#if QT_CONFIG(tooltip)
        gb_MPPE->setToolTip(tr2i18n("Use Microsoft Point-to-Point Encryption", nullptr));
#endif // QT_CONFIG(tooltip)
        gb_MPPE->setTitle(tr2i18n("Use MPPE Encryption", nullptr));
        lbl_MMPEcrypto->setText(tr2i18n("Crypto:", nullptr));
        cb_MPPECrypto->setItemText(0, tr2i18n("Any", "like in use Any configuration"));
        cb_MPPECrypto->setItemText(1, tr2i18n("128 bit", nullptr));
        cb_MPPECrypto->setItemText(2, tr2i18n("40 bit", nullptr));

        cb_statefulEncryption->setText(tr2i18n("Use stateful encryption", nullptr));
        grp_cryptoAndCompression->setTitle(tr2i18n("Compression", nullptr));
        cb_BSD->setText(tr2i18n("Allow BSD compression", nullptr));
        cb_deflate->setText(tr2i18n("Allow Deflate compression", nullptr));
        cb_TCPheaders->setText(tr2i18n("Allow TCP header compression", nullptr));
        grp_echo->setTitle(tr2i18n("Echo", nullptr));
        cb_sendEcho->setText(tr2i18n("Send PPP echo packets ", nullptr));
        grp_misc->setTitle(tr2i18n("Misc", nullptr));
        chk_useCustomUnitNumber->setText(tr2i18n("Use custom unit number:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(pptpTab), tr2i18n("Point-to-Point", nullptr));
        grp_general->setTitle(tr2i18n("General", nullptr));
        lbl_address->setText(tr2i18n("Address:", nullptr));
        lbl_port->setText(tr2i18n("Port:", nullptr));
        grp_credentials->setTitle(tr2i18n("Credentials", nullptr));
        lbl_username->setText(tr2i18n("Username:", nullptr));
        lbl_password->setText(tr2i18n("Password:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(proxyTab), tr2i18n("Proxy", nullptr));
        (void)SstpAdvanced;
    } // retranslateUi

};

namespace Ui {
    class SstpAdvanced: public Ui_SstpAdvanced {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SSTPADVANCED_H

