/********************************************************************************
** Form generated from reading UI file 'cdma.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CDMA_H
#define UI_CDMA_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_CdmaWidget
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    KLineEdit *number;
    QLabel *label_2;
    KLineEdit *username;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout;
    PasswordField *password;

    void setupUi(QWidget *CdmaWidget)
    {
        if (CdmaWidget->objectName().isEmpty())
            CdmaWidget->setObjectName("CdmaWidget");
        CdmaWidget->resize(400, 300);
        formLayout = new QFormLayout(CdmaWidget);
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(6);
        label = new QLabel(CdmaWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        number = new KLineEdit(CdmaWidget);
        number->setObjectName("number");
        number->setText(QString::fromUtf8("#777"));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, number);

        label_2 = new QLabel(CdmaWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        username = new KLineEdit(CdmaWidget);
        username->setObjectName("username");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, username);

        label_3 = new QLabel(CdmaWidget);
        label_3->setObjectName("label_3");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        password = new PasswordField(CdmaWidget);
        password->setObjectName("password");
        password->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout->addWidget(password);


        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout);

#if QT_CONFIG(shortcut)
        label->setBuddy(number);
        label_2->setBuddy(username);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(number, username);

        retranslateUi(CdmaWidget);

        QMetaObject::connectSlotsByName(CdmaWidget);
    } // setupUi

    void retranslateUi(QWidget *CdmaWidget)
    {
        label->setText(tr2i18n("Number:", nullptr));
        label_2->setText(tr2i18n("Username:", nullptr));
        label_3->setText(tr2i18n("Password:", nullptr));
        (void)CdmaWidget;
    } // retranslateUi

};

namespace Ui {
    class CdmaWidget: public Ui_CdmaWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CDMA_H

