/********************************************************************************
** Form generated from reading UI file 'wireguardpeerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIREGUARDPEERWIDGET_H
#define UI_WIREGUARDPEERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <passwordfield.h>

QT_BEGIN_NAMESPACE

class Ui_WireGuardPeersProp
{
public:
    QFormLayout *form2Layout;
    QLabel *publicKeyLabel;
    QLineEdit *publicKeyLineEdit;
    QLabel *allowedIPsLabel;
    QLineEdit *allowedIPsLineEdit;
    QLabel *endpointAddressLabel;
    QLineEdit *endpointAddressLineEdit;
    QLabel *endpointPortLabel;
    QLineEdit *endpointPortLineEdit;
    QLabel *presharedKeyLabel;
    PasswordField *presharedKeyLineEdit;
    QLabel *keepaliveLabel;
    QLineEdit *keepaliveLineEdit;

    void setupUi(QWidget *WireGuardProp)
    {
        if (WireGuardProp->objectName().isEmpty())
            WireGuardProp->setObjectName("WireGuardProp");
        WireGuardProp->resize(495, 454);
        form2Layout = new QFormLayout(WireGuardProp);
        form2Layout->setObjectName("form2Layout");
        publicKeyLabel = new QLabel(WireGuardProp);
        publicKeyLabel->setObjectName("publicKeyLabel");

        form2Layout->setWidget(1, QFormLayout::ItemRole::LabelRole, publicKeyLabel);

        publicKeyLineEdit = new QLineEdit(WireGuardProp);
        publicKeyLineEdit->setObjectName("publicKeyLineEdit");

        form2Layout->setWidget(1, QFormLayout::ItemRole::FieldRole, publicKeyLineEdit);

        allowedIPsLabel = new QLabel(WireGuardProp);
        allowedIPsLabel->setObjectName("allowedIPsLabel");

        form2Layout->setWidget(2, QFormLayout::ItemRole::LabelRole, allowedIPsLabel);

        allowedIPsLineEdit = new QLineEdit(WireGuardProp);
        allowedIPsLineEdit->setObjectName("allowedIPsLineEdit");

        form2Layout->setWidget(2, QFormLayout::ItemRole::FieldRole, allowedIPsLineEdit);

        endpointAddressLabel = new QLabel(WireGuardProp);
        endpointAddressLabel->setObjectName("endpointAddressLabel");

        form2Layout->setWidget(3, QFormLayout::ItemRole::LabelRole, endpointAddressLabel);

        endpointAddressLineEdit = new QLineEdit(WireGuardProp);
        endpointAddressLineEdit->setObjectName("endpointAddressLineEdit");

        form2Layout->setWidget(3, QFormLayout::ItemRole::FieldRole, endpointAddressLineEdit);

        endpointPortLabel = new QLabel(WireGuardProp);
        endpointPortLabel->setObjectName("endpointPortLabel");

        form2Layout->setWidget(4, QFormLayout::ItemRole::LabelRole, endpointPortLabel);

        endpointPortLineEdit = new QLineEdit(WireGuardProp);
        endpointPortLineEdit->setObjectName("endpointPortLineEdit");

        form2Layout->setWidget(4, QFormLayout::ItemRole::FieldRole, endpointPortLineEdit);

        presharedKeyLabel = new QLabel(WireGuardProp);
        presharedKeyLabel->setObjectName("presharedKeyLabel");

        form2Layout->setWidget(5, QFormLayout::ItemRole::LabelRole, presharedKeyLabel);

        presharedKeyLineEdit = new PasswordField(WireGuardProp);
        presharedKeyLineEdit->setObjectName("presharedKeyLineEdit");

        form2Layout->setWidget(5, QFormLayout::ItemRole::FieldRole, presharedKeyLineEdit);

        keepaliveLabel = new QLabel(WireGuardProp);
        keepaliveLabel->setObjectName("keepaliveLabel");

        form2Layout->setWidget(6, QFormLayout::ItemRole::LabelRole, keepaliveLabel);

        keepaliveLineEdit = new QLineEdit(WireGuardProp);
        keepaliveLineEdit->setObjectName("keepaliveLineEdit");

        form2Layout->setWidget(6, QFormLayout::ItemRole::FieldRole, keepaliveLineEdit);


        retranslateUi(WireGuardProp);

        QMetaObject::connectSlotsByName(WireGuardProp);
    } // setupUi

    void retranslateUi(QWidget *WireGuardProp)
    {
        publicKeyLabel->setText(tr2i18n("Public key:", nullptr));
#if QT_CONFIG(tooltip)
        publicKeyLineEdit->setToolTip(tr2i18n("Required.\n"
"            A base64 public key calculated by wg pubkey \n"
"            from a private key, and usually transmitted \n"
"            out of band to the author of the configuration file.", nullptr));
#endif // QT_CONFIG(tooltip)
        allowedIPsLabel->setText(tr2i18n("Allowed IPs:", nullptr));
#if QT_CONFIG(tooltip)
        allowedIPsLineEdit->setToolTip(tr2i18n("Required.\n"
"            A comma-separated list of IP (v4 or v6) addresses \n"
"            with CIDR masks from which incoming traffic for \n"
"            this peer is allowed and to which outgoing traffic \n"
"            for this peer is directed. The catch-all 0.0.0.0/0 \n"
"            may be specified for matching all IPv4 addresses, \n"
"            and ::/0 may be specified for matching all IPv6 addresses.", nullptr));
#endif // QT_CONFIG(tooltip)
        endpointAddressLabel->setText(tr2i18n("Endpoint address:", nullptr));
#if QT_CONFIG(tooltip)
        endpointAddressLineEdit->setToolTip(tr2i18n("Optional.\n"
"            An endpoint for the connection. Can be an\n"
"            IPv4 address, IPv6 address, or FQDN (fully\n"
"            qualified domain name such as abc.com). If\n"
"            present, Endpoint port must also be set.", nullptr));
#endif // QT_CONFIG(tooltip)
        endpointPortLabel->setText(tr2i18n("Endpoint port:", nullptr));
#if QT_CONFIG(tooltip)
        endpointPortLineEdit->setToolTip(tr2i18n("Optional.\n"
"            The port number of an endpoint. If present Endpoint\n"
"            Address must also be set.", nullptr));
#endif // QT_CONFIG(tooltip)
        presharedKeyLabel->setText(tr2i18n("Preshared key:", nullptr));
#if QT_CONFIG(tooltip)
        presharedKeyLineEdit->setToolTip(tr2i18n("Optional.\n"
"            A base64 preshared key generated by wg genpsk.\n"
"            This option adds an additional layer of symmetric-key\n"
"            cryptography to be mixed into the already existing\n"
"            public-key cryptography, for post-quantum resistance.", nullptr));
#endif // QT_CONFIG(tooltip)
        keepaliveLabel->setText(tr2i18n("Persistent keepalive:", nullptr));
#if QT_CONFIG(tooltip)
        keepaliveLineEdit->setToolTip(tr2i18n("Optional.\n"
"            A seconds interval, between 1 and 65535 inclusive, of\n"
"            how often to send an authenticated empty packet to\n"
"            the peer for the purpose of keeping a stateful firewall\n"
"            or NAT mapping valid persistently. For example, if the\n"
"            interface very rarely sends traffic, but it might at\n"
"            anytime receive traffic from a peer, and it is behind\n"
"            NAT, the interface might benefit from having a\n"
"            persistent keepalive interval of 25 seconds. If set to\n"
"            0 or \"off\", this option is disabled. By default or\n"
"            when unspecified, this option is off. Most users will not\n"
"            need this.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)WireGuardProp;
    } // retranslateUi

};

namespace Ui {
    class WireGuardPeersProp: public Ui_WireGuardPeersProp {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WIREGUARDPEERWIDGET_H

