/********************************************************************************
** Form generated from reading UI file 'team.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEAM_H
#define UI_TEAM_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_TeamWidget
{
public:
    QGridLayout *gridLayout_2;
    QLabel *label;
    KLineEdit *ifaceName;
    QLabel *label_7;
    QGridLayout *gridLayout;
    QListWidget *teams;
    QPushButton *btnAdd;
    QPushButton *btnEdit;
    QPushButton *btnDelete;
    QSpacerItem *verticalSpacer;
    QLabel *label_2;
    QPlainTextEdit *config;
    QPushButton *btnImport;

    void setupUi(QWidget *TeamWidget)
    {
        if (TeamWidget->objectName().isEmpty())
            TeamWidget->setObjectName("TeamWidget");
        TeamWidget->resize(394, 436);
        gridLayout_2 = new QGridLayout(TeamWidget);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(TeamWidget);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        ifaceName = new KLineEdit(TeamWidget);
        ifaceName->setObjectName("ifaceName");

        gridLayout_2->addWidget(ifaceName, 0, 1, 1, 1);

        label_7 = new QLabel(TeamWidget);
        label_7->setObjectName("label_7");

        gridLayout_2->addWidget(label_7, 1, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        teams = new QListWidget(TeamWidget);
        teams->setObjectName("teams");
        teams->setEditTriggers(QAbstractItemView::NoEditTriggers);
        teams->setAlternatingRowColors(true);
        teams->setUniformItemSizes(true);

        gridLayout->addWidget(teams, 0, 0, 4, 1);

        btnAdd = new QPushButton(TeamWidget);
        btnAdd->setObjectName("btnAdd");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8(""), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        btnAdd->setIcon(icon);

        gridLayout->addWidget(btnAdd, 0, 1, 1, 1);

        btnEdit = new QPushButton(TeamWidget);
        btnEdit->setObjectName("btnEdit");
        btnEdit->setEnabled(false);
        QIcon icon1;
        iconThemeName = QString::fromUtf8("configure");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8(""), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        btnEdit->setIcon(icon1);

        gridLayout->addWidget(btnEdit, 1, 1, 1, 1);

        btnDelete = new QPushButton(TeamWidget);
        btnDelete->setObjectName("btnDelete");
        btnDelete->setEnabled(false);
        QIcon icon2;
        iconThemeName = QString::fromUtf8("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8(""), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        btnDelete->setIcon(icon2);

        gridLayout->addWidget(btnDelete, 2, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 2, 0, 1, 2);

        label_2 = new QLabel(TeamWidget);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 3, 0, 1, 1);

        config = new QPlainTextEdit(TeamWidget);
        config->setObjectName("config");

        gridLayout_2->addWidget(config, 4, 0, 1, 2);

        btnImport = new QPushButton(TeamWidget);
        btnImport->setObjectName("btnImport");

        gridLayout_2->addWidget(btnImport, 5, 0, 1, 2);

#if QT_CONFIG(shortcut)
        label->setBuddy(ifaceName);
        label_7->setBuddy(teams);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(ifaceName, teams);
        QWidget::setTabOrder(teams, btnAdd);
        QWidget::setTabOrder(btnAdd, btnEdit);
        QWidget::setTabOrder(btnEdit, btnDelete);

        retranslateUi(TeamWidget);

        QMetaObject::connectSlotsByName(TeamWidget);
    } // setupUi

    void retranslateUi(QWidget *TeamWidget)
    {
        label->setText(tr2i18n("Interface name:", nullptr));
        label_7->setText(tr2i18n("Teamed connections:", nullptr));
        btnAdd->setText(tr2i18n("Add\342\200\246", nullptr));
        btnEdit->setText(tr2i18n("Edit\342\200\246", nullptr));
        btnDelete->setText(tr2i18n("Delete", nullptr));
        label_2->setText(tr2i18n("JSON config:", nullptr));
        btnImport->setText(tr2i18n("Import configuration from file\342\200\246", nullptr));
        (void)TeamWidget;
    } // retranslateUi

};

namespace Ui {
    class TeamWidget: public Ui_TeamWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TEAM_H

