/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<appletproxymodel.h>)
#  include <appletproxymodel.h>
#endif
#if __has_include(<availabledevices.h>)
#  include <availabledevices.h>
#endif
#if __has_include(<configurationproxy.h>)
#  include <configurationproxy.h>
#endif
#if __has_include(<connectiondetailsmodel.h>)
#  include <connectiondetailsmodel.h>
#endif
#if __has_include(<connectionicon.h>)
#  include <connectionicon.h>
#endif
#if __has_include(<creatableconnectionsmodel.h>)
#  include <creatableconnectionsmodel.h>
#endif
#if __has_include(<editorproxymodel.h>)
#  include <editorproxymodel.h>
#endif
#if __has_include(<enabledconnections.h>)
#  include <enabledconnections.h>
#endif
#if __has_include(<enums.h>)
#  include <enums.h>
#endif
#if __has_include(<handler.h>)
#  include <handler.h>
#endif
#if __has_include(<kcmidentitymodel.h>)
#  include <kcmidentitymodel.h>
#endif
#if __has_include(<mobileproxymodel.h>)
#  include <mobileproxymodel.h>
#endif
#if __has_include(<networkmodel.h>)
#  include <networkmodel.h>
#endif
#if __has_include(<networkmodelitem.h>)
#  include <networkmodelitem.h>
#endif
#if __has_include(<networkstatus.h>)
#  include <networkstatus.h>
#endif
#if __has_include(<qrcahandler.h>)
#  include <qrcahandler.h>
#endif
#if __has_include(<wirelessstatus.h>)
#  include <wirelessstatus.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_networkmanagement()
{
    qmlRegisterModule("org.kde.plasma.networkmanagement", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AppletProxyModel>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterTypesAndRevisions<AvailableDevices>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterTypesAndRevisions<ConfigurationProxy>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterTypesAndRevisions<ConnectionDetailsModel>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterEnum<ConnectionDetailsModel::ConnectionDetailsRoles>("ConnectionDetailsModel::ConnectionDetailsRoles");
    qmlRegisterTypesAndRevisions<ConnectionIcon>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterTypesAndRevisions<CreatableConnectionsModel>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterTypesAndRevisions<EditorProxyModel>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterTypesAndRevisions<EnabledConnections>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterTypesAndRevisions<Enums>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterEnum<Enums::ConnectionStatus>("Enums::ConnectionStatus");
    qmlRegisterEnum<Enums::ConnectionType>("Enums::ConnectionType");
    qmlRegisterEnum<Enums::SecurityType>("Enums::SecurityType");
    qmlRegisterTypesAndRevisions<Handler>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterTypesAndRevisions<KcmIdentityModel>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterTypesAndRevisions<MobileProxyModel>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterTypesAndRevisions<NetworkModel>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterEnum<NetworkModel::ItemRole>("NetworkModel::ItemRole");
    qmlRegisterTypesAndRevisions<NetworkModelItem>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterEnum<NetworkModelItem::ItemType>("NetworkModelItem::ItemType");
    qmlRegisterTypesAndRevisions<NetworkStatus>("org.kde.plasma.networkmanagement", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QIdentityProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<QrcaHandler>("org.kde.plasma.networkmanagement", 254);
    qmlRegisterTypesAndRevisions<WirelessStatus>("org.kde.plasma.networkmanagement", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.networkmanagement", 254, 254);
}

static const QQmlModuleRegistration orgkdeplasmanetworkmanagementRegistration("org.kde.plasma.networkmanagement", qml_register_types_org_kde_plasma_networkmanagement);
