/****************************************************************************
** Meta object code from reading C++ file 'handler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-nm-6.7.4/libs/handler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'handler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7HandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto Handler::qt_create_metaobjectdata<qt_meta_tag_ZN7HandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Handler",
        "QML.Element",
        "auto",
        "connectionActivationFailed",
        "",
        "connectionPath",
        "message",
        "hotspotSupportedChanged",
        "hotspotSupported",
        "hotspotActiveChanged",
        "hotspotActive",
        "scanningChanged",
        "wifiCodeReceived",
        "data",
        "ssid",
        "password",
        "activateConnection",
        "connection",
        "device",
        "specificParameter",
        "addAndActivateConnection",
        "requestWifiCode",
        "securityType",
        "addConnection",
        "QCoro::Task<>",
        "NMVariantMapMap",
        "map",
        "deactivateConnection",
        "disconnectAll",
        "enableAirplaneMode",
        "enable",
        "enableNetworking",
        "enableWireless",
        "enableWwan",
        "removeConnection",
        "updateConnection",
        "NetworkManager::Connection::Ptr",
        "requestScan",
        "interface",
        "createHotspot",
        "stopHotspot",
        "secretAgentError",
        "primaryConnectionTypeChanged",
        "NetworkManager::ConnectionSettings::ConnectionType",
        "type",
        "wirelessEnabledChanged",
        "wirelessEnabled",
        "unlockRequiredChanged",
        "MMModemLock",
        "modemLock",
        "scanning"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connectionActivationFailed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'hotspotSupportedChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'hotspotActiveChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'scanningChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wifiCodeReceived'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::QString, 14 }, { QMetaType::QString, 15 },
        }}),
        // Signal 'wifiCodeReceived'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(12, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'activateConnection'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 18 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'addAndActivateConnection'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 19 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'addAndActivateConnection'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(20, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'requestWifiCode'
        QtMocHelpers::SlotData<void(const QString &, const QString &, int)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 14 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'addConnection'
        QtMocHelpers::SlotData<QCoro::Task<>(const NMVariantMapMap &)>(23, 4, QMC::AccessPublic, 0x80000000 | 24, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'deactivateConnection'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'disconnectAll'
        QtMocHelpers::SlotData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enableAirplaneMode'
        QtMocHelpers::SlotData<void(bool)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'enableNetworking'
        QtMocHelpers::SlotData<void(bool)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'enableWireless'
        QtMocHelpers::SlotData<void(bool)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'enableWwan'
        QtMocHelpers::SlotData<void(bool)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'removeConnection'
        QtMocHelpers::SlotData<void(const QString &)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'updateConnection'
        QtMocHelpers::SlotData<QCoro::Task<>(NetworkManager::Connection::Ptr, const NMVariantMapMap &)>(35, 4, QMC::AccessPublic, 0x80000000 | 24, {{
            { 0x80000000 | 36, 17 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'requestScan'
        QtMocHelpers::SlotData<void(const QString &)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 38 },
        }}),
        // Slot 'requestScan'
        QtMocHelpers::SlotData<void()>(37, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'createHotspot'
        QtMocHelpers::SlotData<void()>(39, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopHotspot'
        QtMocHelpers::SlotData<void()>(40, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'secretAgentError'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(41, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'primaryConnectionTypeChanged'
        QtMocHelpers::SlotData<void(NetworkManager::ConnectionSettings::ConnectionType)>(42, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 43, 44 },
        }}),
        // Slot 'wirelessEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(45, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 46 },
        }}),
        // Slot 'unlockRequiredChanged'
        QtMocHelpers::SlotData<void(MMModemLock)>(47, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'hotspotSupported'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'hotspotActive'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'scanning'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Handler, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Handler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7HandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7HandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7HandlerE_t>.metaTypes,
    nullptr
} };

void Handler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Handler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connectionActivationFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->hotspotSupportedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->hotspotActiveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->scanningChanged(); break;
        case 4: _t->wifiCodeReceived((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: _t->wifiCodeReceived((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->activateConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->addAndActivateConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 8: _t->addAndActivateConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->requestWifiCode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 10: { QCoro::Task<> _r = _t->addConnection((*reinterpret_cast<std::add_pointer_t<NMVariantMapMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<>*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->deactivateConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->disconnectAll(); break;
        case 13: _t->enableAirplaneMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->enableNetworking((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->enableWireless((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->enableWwan((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->removeConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: { QCoro::Task<> _r = _t->updateConnection((*reinterpret_cast<std::add_pointer_t<NetworkManager::Connection::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NMVariantMapMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<>*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->requestScan((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->requestScan(); break;
        case 21: _t->createHotspot(); break;
        case 22: _t->stopHotspot(); break;
        case 23: _t->secretAgentError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 24: _t->primaryConnectionTypeChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::ConnectionSettings::ConnectionType>>(_a[1]))); break;
        case 25: _t->wirelessEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->unlockRequiredChanged((*reinterpret_cast<std::add_pointer_t<MMModemLock>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMVariantMapMap >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMVariantMapMap >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMModemLock >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Handler::*)(const QString & , const QString & )>(_a, &Handler::connectionActivationFailed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Handler::*)(bool )>(_a, &Handler::hotspotSupportedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Handler::*)(bool )>(_a, &Handler::hotspotActiveChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Handler::*)()>(_a, &Handler::scanningChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Handler::*)(const QString & , const QString & , const QString & )>(_a, &Handler::wifiCodeReceived, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->hotspotSupported(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hotspotActive(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isScanning(); break;
        default: break;
        }
    }
}

const QMetaObject *Handler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Handler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7HandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Handler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Handler::connectionActivationFailed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Handler::hotspotSupportedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Handler::hotspotActiveChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Handler::scanningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Handler::wifiCodeReceived(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
