/********************************************************************************
** Form generated from reading UI file 'wireguardtabwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIREGUARDTABWIDGET_H
#define UI_WIREGUARDTABWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_WireGuardTabWidget
{
public:
    QGridLayout *gridLayout;
    QTabWidget *tabWidget;
    QWidget *horizontalLayoutWidget;
    QHBoxLayout *horizontalLayout;
    QPushButton *btnAdd;
    QPushButton *btnRemove;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *WireGuardTabWidget)
    {
        if (WireGuardTabWidget->objectName().isEmpty())
            WireGuardTabWidget->setObjectName("WireGuardTabWidget");
        WireGuardTabWidget->resize(498, 427);
        gridLayout = new QGridLayout(WireGuardTabWidget);
        gridLayout->setObjectName("gridLayout");
        tabWidget = new QTabWidget(WireGuardTabWidget);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setElideMode(Qt::ElideRight);

        gridLayout->addWidget(tabWidget, 0, 0, 1, 2);

        horizontalLayoutWidget = new QWidget(WireGuardTabWidget);
        horizontalLayoutWidget->setObjectName("horizontalLayoutWidget");
        horizontalLayout = new QHBoxLayout(horizontalLayoutWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        btnAdd = new QPushButton(horizontalLayoutWidget);
        btnAdd->setObjectName("btnAdd");

        horizontalLayout->addWidget(btnAdd);

        btnRemove = new QPushButton(horizontalLayoutWidget);
        btnRemove->setObjectName("btnRemove");

        horizontalLayout->addWidget(btnRemove);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addWidget(horizontalLayoutWidget, 2, 0, 1, 1);

        buttonBox = new QDialogButtonBox(WireGuardTabWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 8, 1, 1, 1);


        retranslateUi(WireGuardTabWidget);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(WireGuardTabWidget);
    } // setupUi

    void retranslateUi(QWidget *WireGuardTabWidget)
    {
        btnAdd->setText(tr2i18n("Add new Peer", nullptr));
        btnRemove->setText(tr2i18n("Remove this Peer", nullptr));
        (void)WireGuardTabWidget;
    } // retranslateUi

};

namespace Ui {
    class WireGuardTabWidget: public Ui_WireGuardTabWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WIREGUARDTABWIDGET_H

