/********************************************************************************
** Form generated from reading UI file 'vpncadvanced.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VPNCADVANCED_H
#define UI_VPNCADVANCED_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_VpncAdvancedWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *label;
    QLineEdit *domain;
    QLabel *label_2;
    QComboBox *vendor;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout_2;
    QLabel *label_3;
    QComboBox *encryption;
    QLabel *label_4;
    QComboBox *nat;
    QLabel *label_5;
    QComboBox *dhGroup;
    QLabel *label_6;
    QComboBox *pfs;
    QLabel *label_7;
    QSpinBox *localport;
    QCheckBox *deadPeer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *VpncAdvancedWidget)
    {
        if (VpncAdvancedWidget->objectName().isEmpty())
            VpncAdvancedWidget->setObjectName("VpncAdvancedWidget");
        VpncAdvancedWidget->resize(410, 393);
        verticalLayout = new QVBoxLayout(VpncAdvancedWidget);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(VpncAdvancedWidget);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(6);
        label = new QLabel(groupBox);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        domain = new QLineEdit(groupBox);
        domain->setObjectName("domain");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, domain);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        vendor = new QComboBox(groupBox);
        vendor->setObjectName("vendor");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(vendor->sizePolicy().hasHeightForWidth());
        vendor->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, vendor);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(VpncAdvancedWidget);
        groupBox_2->setObjectName("groupBox_2");
        formLayout_2 = new QFormLayout(groupBox_2);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout_2->setVerticalSpacing(6);
        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        encryption = new QComboBox(groupBox_2);
        encryption->setObjectName("encryption");
        sizePolicy.setHeightForWidth(encryption->sizePolicy().hasHeightForWidth());
        encryption->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, encryption);

        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_4);

        nat = new QComboBox(groupBox_2);
        nat->setObjectName("nat");
        sizePolicy.setHeightForWidth(nat->sizePolicy().hasHeightForWidth());
        nat->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, nat);

        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName("label_5");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_5);

        dhGroup = new QComboBox(groupBox_2);
        dhGroup->setObjectName("dhGroup");
        sizePolicy.setHeightForWidth(dhGroup->sizePolicy().hasHeightForWidth());
        dhGroup->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, dhGroup);

        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName("label_6");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_6);

        pfs = new QComboBox(groupBox_2);
        pfs->setObjectName("pfs");
        sizePolicy.setHeightForWidth(pfs->sizePolicy().hasHeightForWidth());
        pfs->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, pfs);

        label_7 = new QLabel(groupBox_2);
        label_7->setObjectName("label_7");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, label_7);

        localport = new QSpinBox(groupBox_2);
        localport->setObjectName("localport");
        sizePolicy.setHeightForWidth(localport->sizePolicy().hasHeightForWidth());
        localport->setSizePolicy(sizePolicy);
        localport->setMaximum(65535);

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, localport);

        deadPeer = new QCheckBox(groupBox_2);
        deadPeer->setObjectName("deadPeer");
        sizePolicy.setHeightForWidth(deadPeer->sizePolicy().hasHeightForWidth());
        deadPeer->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(5, QFormLayout::ItemRole::LabelRole, deadPeer);


        verticalLayout->addWidget(groupBox_2);

        buttonBox = new QDialogButtonBox(VpncAdvancedWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(domain);
        label_2->setBuddy(vendor);
        label_3->setBuddy(encryption);
        label_4->setBuddy(nat);
        label_5->setBuddy(dhGroup);
        label_6->setBuddy(pfs);
        label_7->setBuddy(localport);
#endif // QT_CONFIG(shortcut)

        retranslateUi(VpncAdvancedWidget);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, VpncAdvancedWidget, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, VpncAdvancedWidget, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(VpncAdvancedWidget);
    } // setupUi

    void retranslateUi(QDialog *VpncAdvancedWidget)
    {
        groupBox->setTitle(tr2i18n("Identification", nullptr));
        label->setText(tr2i18n("Domain:", nullptr));
#if QT_CONFIG(tooltip)
        domain->setToolTip(tr2i18n("(NT-)Domain name for authentication.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Vendor:", nullptr));
#if QT_CONFIG(tooltip)
        vendor->setToolTip(tr2i18n("Vendor of your IPsec gateway.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_2->setTitle(tr2i18n("Transport and Security", nullptr));
        label_3->setText(tr2i18n("Encryption method:", nullptr));
#if QT_CONFIG(tooltip)
        encryption->setToolTip(tr2i18n("Encryption method.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("NAT traversal:", nullptr));
#if QT_CONFIG(tooltip)
        nat->setToolTip(tr2i18n("NAT traversal method to use.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("IKE DH Group:", nullptr));
#if QT_CONFIG(tooltip)
        dhGroup->setToolTip(tr2i18n("Name of the IKE DH group.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_6->setText(tr2i18n("Perfect Forward Secrecy:", nullptr));
#if QT_CONFIG(tooltip)
        pfs->setToolTip(tr2i18n("Diffie-Hellman group to use for PFS.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_7->setText(tr2i18n("Local Port:", nullptr));
#if QT_CONFIG(tooltip)
        localport->setToolTip(tr2i18n("Local port to use (0-65535). 0 (default value) means random port. 500 is vpnc's default.", nullptr));
#endif // QT_CONFIG(tooltip)
        localport->setSpecialValueText(tr2i18n("Random", nullptr));
#if QT_CONFIG(tooltip)
        deadPeer->setToolTip(tr2i18n("Disable sending DPD packets (set timeout to 0).", nullptr));
#endif // QT_CONFIG(tooltip)
        deadPeer->setText(tr2i18n("Disable dead peer detection", nullptr));
        (void)VpncAdvancedWidget;
    } // retranslateUi

};

namespace Ui {
    class VpncAdvancedWidget: public Ui_VpncAdvancedWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VPNCADVANCED_H

