/********************************************************************************
** Form generated from reading UI file 'vpnc.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VPNC_H
#define UI_VPNC_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_VpncWidget
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QLineEdit *gateway;
    QLabel *label_2;
    QLineEdit *user;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout;
    PasswordField *userPassword;
    QLabel *label_4;
    QLineEdit *group;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_2;
    PasswordField *groupPassword;
    QCheckBox *useHybridAuth;
    QLabel *label_6;
    KUrlRequester *caFile;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer;
    QPushButton *btnAdvanced;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *VpncWidget)
    {
        if (VpncWidget->objectName().isEmpty())
            VpncWidget->setObjectName("VpncWidget");
        VpncWidget->resize(347, 313);
        formLayout = new QFormLayout(VpncWidget);
        formLayout->setObjectName("formLayout");
        label = new QLabel(VpncWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        gateway = new QLineEdit(VpncWidget);
        gateway->setObjectName("gateway");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, gateway);

        label_2 = new QLabel(VpncWidget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        user = new QLineEdit(VpncWidget);
        user->setObjectName("user");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, user);

        label_3 = new QLabel(VpncWidget);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        userPassword = new PasswordField(VpncWidget);
        userPassword->setObjectName("userPassword");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(userPassword->sizePolicy().hasHeightForWidth());
        userPassword->setSizePolicy(sizePolicy);
        userPassword->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout->addWidget(userPassword);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_4 = new QLabel(VpncWidget);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_4);

        group = new QLineEdit(VpncWidget);
        group->setObjectName("group");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, group);

        label_5 = new QLabel(VpncWidget);
        label_5->setObjectName("label_5");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_5);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        groupPassword = new PasswordField(VpncWidget);
        groupPassword->setObjectName("groupPassword");
        sizePolicy.setHeightForWidth(groupPassword->sizePolicy().hasHeightForWidth());
        groupPassword->setSizePolicy(sizePolicy);
        groupPassword->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_2->addWidget(groupPassword);


        formLayout->setLayout(4, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        useHybridAuth = new QCheckBox(VpncWidget);
        useHybridAuth->setObjectName("useHybridAuth");

        formLayout->setWidget(5, QFormLayout::ItemRole::SpanningRole, useHybridAuth);

        label_6 = new QLabel(VpncWidget);
        label_6->setObjectName("label_6");
        label_6->setEnabled(false);

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_6);

        caFile = new KUrlRequester(VpncWidget);
        caFile->setObjectName("caFile");
        caFile->setEnabled(false);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, caFile);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        btnAdvanced = new QPushButton(VpncWidget);
        btnAdvanced->setObjectName("btnAdvanced");

        horizontalLayout_3->addWidget(btnAdvanced);


        formLayout->setLayout(8, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(9, QFormLayout::ItemRole::FieldRole, verticalSpacer);

#if QT_CONFIG(shortcut)
        label->setBuddy(gateway);
        label_2->setBuddy(user);
        label_3->setBuddy(userPassword);
        label_4->setBuddy(group);
        label_5->setBuddy(groupPassword);
        label_6->setBuddy(caFile);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(gateway, user);
        QWidget::setTabOrder(user, userPassword);
        QWidget::setTabOrder(userPassword, group);
        QWidget::setTabOrder(group, groupPassword);
        QWidget::setTabOrder(groupPassword, useHybridAuth);
        QWidget::setTabOrder(useHybridAuth, caFile);

        retranslateUi(VpncWidget);
        QObject::connect(useHybridAuth, SIGNAL(toggled(bool)), caFile, SLOT(setEnabled(bool)));
        QObject::connect(useHybridAuth, &QCheckBox::toggled, label_6, &QLabel::setEnabled);

        QMetaObject::connectSlotsByName(VpncWidget);
    } // setupUi

    void retranslateUi(QWidget *VpncWidget)
    {
        label->setText(tr2i18n("Gateway:", nullptr));
#if QT_CONFIG(tooltip)
        gateway->setToolTip(tr2i18n("IP/hostname of IPsec gateway.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("User name:", nullptr));
#if QT_CONFIG(tooltip)
        user->setToolTip(tr2i18n("User name for the connection.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("User password:", nullptr));
#if QT_CONFIG(tooltip)
        userPassword->setToolTip(tr2i18n("User password for the connection.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Group name:", nullptr));
#if QT_CONFIG(tooltip)
        group->setToolTip(tr2i18n("Group name", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("Group password:", nullptr));
#if QT_CONFIG(tooltip)
        groupPassword->setToolTip(tr2i18n("Group password.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        useHybridAuth->setToolTip(tr2i18n("Enable hybrid authentication, i.e. use certificate in addition to password.", nullptr));
#endif // QT_CONFIG(tooltip)
        useHybridAuth->setText(tr2i18n("Use hybrid authentication", nullptr));
        label_6->setText(tr2i18n("CA file:", nullptr));
#if QT_CONFIG(tooltip)
        caFile->setToolTip(tr2i18n("CA certificate in PEM format.", nullptr));
#endif // QT_CONFIG(tooltip)
        caFile->setNameFilters(QStringList{
            tr2i18n("*.pem *.crt *.cer", nullptr)});
        btnAdvanced->setText(tr2i18n("Advanced\342\200\246", nullptr));
        (void)VpncWidget;
    } // retranslateUi

};

namespace Ui {
    class VpncWidget: public Ui_VpncWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VPNC_H

