/********************************************************************************
** Form generated from reading UI file 'wiredsecurity.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIREDSECURITY_H
#define UI_WIREDSECURITY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_WiredSecurity
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *use8021X;

    void setupUi(QWidget *WiredSecurity)
    {
        if (WiredSecurity->objectName().isEmpty())
            WiredSecurity->setObjectName("WiredSecurity");
        WiredSecurity->resize(487, 379);
        verticalLayout = new QVBoxLayout(WiredSecurity);
        verticalLayout->setObjectName("verticalLayout");
        use8021X = new QCheckBox(WiredSecurity);
        use8021X->setObjectName("use8021X");

        verticalLayout->addWidget(use8021X);


        retranslateUi(WiredSecurity);

        QMetaObject::connectSlotsByName(WiredSecurity);
    } // setupUi

    void retranslateUi(QWidget *WiredSecurity)
    {
        use8021X->setText(tr2i18n("Use 802.1x security for this connection", nullptr));
        (void)WiredSecurity;
    } // retranslateUi

};

namespace Ui {
    class WiredSecurity: public Ui_WiredSecurity {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WIREDSECURITY_H

