/********************************************************************************
** Form generated from reading UI file 'fortisslvpnadvanced.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FORTISSLVPNADVANCED_H
#define UI_FORTISSLVPNADVANCED_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FortisslvpnAdvancedWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout_2;
    QCheckBox *otp;
    QCheckBox *tfa;
    QGroupBox *groupBox_3;
    QHBoxLayout *horizontalLayout;
    QLabel *realmLabel;
    QLineEdit *realm;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QLabel *trustedCertLabel;
    QLineEdit *trustedCert;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *FortisslvpnAdvancedWidget)
    {
        if (FortisslvpnAdvancedWidget->objectName().isEmpty())
            FortisslvpnAdvancedWidget->setObjectName("FortisslvpnAdvancedWidget");
        FortisslvpnAdvancedWidget->resize(400, 222);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(FortisslvpnAdvancedWidget->sizePolicy().hasHeightForWidth());
        FortisslvpnAdvancedWidget->setSizePolicy(sizePolicy);
        FortisslvpnAdvancedWidget->setMinimumSize(QSize(400, 222));
        gridLayout = new QGridLayout(FortisslvpnAdvancedWidget);
        gridLayout->setObjectName("gridLayout");
        groupBox_2 = new QGroupBox(FortisslvpnAdvancedWidget);
        groupBox_2->setObjectName("groupBox_2");
        sizePolicy.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        otp = new QCheckBox(groupBox_2);
        otp->setObjectName("otp");

        gridLayout_2->addWidget(otp, 0, 0, 1, 1);

        tfa = new QCheckBox(groupBox_2);
        tfa->setObjectName("tfa");

        gridLayout_2->addWidget(tfa, 0, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout_2);


        gridLayout->addWidget(groupBox_2, 0, 0, 1, 1);

        groupBox_3 = new QGroupBox(FortisslvpnAdvancedWidget);
        groupBox_3->setObjectName("groupBox_3");
        horizontalLayout = new QHBoxLayout(groupBox_3);
        horizontalLayout->setObjectName("horizontalLayout");
        realmLabel = new QLabel(groupBox_3);
        realmLabel->setObjectName("realmLabel");

        horizontalLayout->addWidget(realmLabel);

        realm = new QLineEdit(groupBox_3);
        realm->setObjectName("realm");

        horizontalLayout->addWidget(realm);


        gridLayout->addWidget(groupBox_3, 1, 0, 1, 1);

        groupBox = new QGroupBox(FortisslvpnAdvancedWidget);
        groupBox->setObjectName("groupBox");
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        trustedCertLabel = new QLabel(groupBox);
        trustedCertLabel->setObjectName("trustedCertLabel");

        verticalLayout->addWidget(trustedCertLabel);

        trustedCert = new QLineEdit(groupBox);
        trustedCert->setObjectName("trustedCert");
        sizePolicy.setHeightForWidth(trustedCert->sizePolicy().hasHeightForWidth());
        trustedCert->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(trustedCert);


        gridLayout->addWidget(groupBox, 2, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 0, 1, 1);


        retranslateUi(FortisslvpnAdvancedWidget);

        QMetaObject::connectSlotsByName(FortisslvpnAdvancedWidget);
    } // setupUi

    void retranslateUi(QWidget *FortisslvpnAdvancedWidget)
    {
        groupBox_2->setTitle(tr2i18n("Authentication", nullptr));
        otp->setText(tr2i18n("Use a One-Time Password", nullptr));
        tfa->setText(tr2i18n("2FA", nullptr));
        groupBox_3->setTitle(QString());
        realmLabel->setText(tr2i18n("Realm:", nullptr));
        groupBox->setTitle(tr2i18n("Security", nullptr));
        trustedCertLabel->setText(tr2i18n("Trusted certificate:", nullptr));
        trustedCert->setPlaceholderText(tr2i18n("0123456789abcdef0123456789abcdef0123456789abcdef0123456789", nullptr));
        (void)FortisslvpnAdvancedWidget;
    } // retranslateUi

};

namespace Ui {
    class FortisslvpnAdvancedWidget: public Ui_FortisslvpnAdvancedWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FORTISSLVPNADVANCED_H

