/********************************************************************************
** Form generated from reading UI file 'strongswanauth.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STRONGSWANAUTH_H
#define UI_STRONGSWANAUTH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_StrongswanAuth
{
public:
    QGridLayout *gridLayout;
    QLabel *passwordLabel;
    PasswordField *password;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *StrongswanAuth)
    {
        if (StrongswanAuth->objectName().isEmpty())
            StrongswanAuth->setObjectName("StrongswanAuth");
        StrongswanAuth->resize(309, 89);
        gridLayout = new QGridLayout(StrongswanAuth);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        passwordLabel = new QLabel(StrongswanAuth);
        passwordLabel->setObjectName("passwordLabel");

        gridLayout->addWidget(passwordLabel, 0, 0, 1, 1);

        password = new PasswordField(StrongswanAuth);
        password->setObjectName("password");
        password->setProperty("passwordModeEnabled", QVariant(true));

        gridLayout->addWidget(password, 0, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 1, 1, 1);


        retranslateUi(StrongswanAuth);

        QMetaObject::connectSlotsByName(StrongswanAuth);
    } // setupUi

    void retranslateUi(QWidget *StrongswanAuth)
    {
        StrongswanAuth->setWindowTitle(tr2i18n("Strong Swan VPN", nullptr));
        passwordLabel->setText(tr2i18n("Password: ", nullptr));
    } // retranslateUi

};

namespace Ui {
    class StrongswanAuth: public Ui_StrongswanAuth {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STRONGSWANAUTH_H

