/********************************************************************************
** Form generated from reading UI file 'libreswanauth.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LIBRESWANAUTH_H
#define UI_LIBRESWANAUTH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_LibreswanAuth
{
public:
    QFormLayout *formLayout;
    QLabel *groupNameLabel;
    QLineEdit *leGroupName;
    QLabel *userPasswordLabel;
    PasswordField *leUserPassword;
    QLabel *groupPasswordLabel;
    PasswordField *leGroupPassword;

    void setupUi(QWidget *LibreswanAuth)
    {
        if (LibreswanAuth->objectName().isEmpty())
            LibreswanAuth->setObjectName("LibreswanAuth");
        LibreswanAuth->resize(408, 136);
        formLayout = new QFormLayout(LibreswanAuth);
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(6);
        groupNameLabel = new QLabel(LibreswanAuth);
        groupNameLabel->setObjectName("groupNameLabel");
        groupNameLabel->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, groupNameLabel);

        leGroupName = new QLineEdit(LibreswanAuth);
        leGroupName->setObjectName("leGroupName");
        leGroupName->setEnabled(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, leGroupName);

        userPasswordLabel = new QLabel(LibreswanAuth);
        userPasswordLabel->setObjectName("userPasswordLabel");
        userPasswordLabel->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, userPasswordLabel);

        leUserPassword = new PasswordField(LibreswanAuth);
        leUserPassword->setObjectName("leUserPassword");
        leUserPassword->setPasswordModeEnabled(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, leUserPassword);

        groupPasswordLabel = new QLabel(LibreswanAuth);
        groupPasswordLabel->setObjectName("groupPasswordLabel");
        groupPasswordLabel->setWordWrap(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, groupPasswordLabel);

        leGroupPassword = new PasswordField(LibreswanAuth);
        leGroupPassword->setObjectName("leGroupPassword");
        leGroupPassword->setPasswordModeEnabled(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, leGroupPassword);

#if QT_CONFIG(shortcut)
        groupNameLabel->setBuddy(leGroupName);
        userPasswordLabel->setBuddy(leUserPassword);
        groupPasswordLabel->setBuddy(leGroupPassword);
#endif // QT_CONFIG(shortcut)

        retranslateUi(LibreswanAuth);

        QMetaObject::connectSlotsByName(LibreswanAuth);
    } // setupUi

    void retranslateUi(QWidget *LibreswanAuth)
    {
        groupNameLabel->setText(tr2i18n("Group name:", nullptr));
        userPasswordLabel->setText(tr2i18n("User password:", nullptr));
        groupPasswordLabel->setText(tr2i18n("Group password:", nullptr));
        (void)LibreswanAuth;
    } // retranslateUi

};

namespace Ui {
    class LibreswanAuth: public Ui_LibreswanAuth {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LIBRESWANAUTH_H

