/********************************************************************************
** Form generated from reading UI file 'openconnecttoken.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENCONNECTTOKEN_H
#define UI_OPENCONNECTTOKEN_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_OpenConnectToken
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *gbToken;
    QFormLayout *formLayout;
    QLabel *label_8;
    QComboBox *cmbTokenMode;
    QLabel *label_9;
    PasswordField *leTokenSecret;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *OpenConnectToken)
    {
        if (OpenConnectToken->objectName().isEmpty())
            OpenConnectToken->setObjectName("OpenConnectToken");
        OpenConnectToken->resize(500, 191);
        verticalLayout = new QVBoxLayout(OpenConnectToken);
        verticalLayout->setObjectName("verticalLayout");
        gbToken = new QGroupBox(OpenConnectToken);
        gbToken->setObjectName("gbToken");
        formLayout = new QFormLayout(gbToken);
        formLayout->setObjectName("formLayout");
        label_8 = new QLabel(gbToken);
        label_8->setObjectName("label_8");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_8);

        cmbTokenMode = new QComboBox(gbToken);
        cmbTokenMode->setObjectName("cmbTokenMode");
        cmbTokenMode->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, cmbTokenMode);

        label_9 = new QLabel(gbToken);
        label_9->setObjectName("label_9");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_9);

        leTokenSecret = new PasswordField(gbToken);
        leTokenSecret->setObjectName("leTokenSecret");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, leTokenSecret);

        buttonBox = new QDialogButtonBox(gbToken);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, buttonBox);


        verticalLayout->addWidget(gbToken);

#if QT_CONFIG(shortcut)
        label_8->setBuddy(cmbTokenMode);
#endif // QT_CONFIG(shortcut)

        retranslateUi(OpenConnectToken);

        QMetaObject::connectSlotsByName(OpenConnectToken);
    } // setupUi

    void retranslateUi(QWidget *OpenConnectToken)
    {
        OpenConnectToken->setWindowTitle(tr2i18n("OpenConnect OTP Tokens", nullptr));
        gbToken->setTitle(tr2i18n("Software Token Authentication", nullptr));
        label_8->setText(tr2i18n("Token Mode:", nullptr));
        label_9->setText(tr2i18n("Token Secret:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpenConnectToken: public Ui_OpenConnectToken {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPENCONNECTTOKEN_H

