/********************************************************************************
** Form generated from reading UI file 'sstpwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SSTPWIDGET_H
#define UI_SSTPWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_SstpWidget
{
public:
    QGridLayout *gridLayout_8;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *lbl_gateway;
    QLineEdit *le_gateway;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *btn_advancedOption;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout;
    QLabel *lbl_username;
    QLineEdit *le_username;
    QLabel *lbl_password;
    PasswordField *le_password;
    QLabel *lbl_ntDomain;
    QLineEdit *le_ntDomain;
    QLabel *lbl_caCert;
    KUrlRequester *kurl_caCert;
    QCheckBox *chk_ignoreCertWarnings;

    void setupUi(QWidget *SstpWidget)
    {
        if (SstpWidget->objectName().isEmpty())
            SstpWidget->setObjectName("SstpWidget");
        SstpWidget->resize(469, 441);
        gridLayout_8 = new QGridLayout(SstpWidget);
        gridLayout_8->setObjectName("gridLayout_8");
        groupBox = new QGroupBox(SstpWidget);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        lbl_gateway = new QLabel(groupBox);
        lbl_gateway->setObjectName("lbl_gateway");
        lbl_gateway->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_2->addWidget(lbl_gateway);

        le_gateway = new QLineEdit(groupBox);
        le_gateway->setObjectName("le_gateway");

        horizontalLayout_2->addWidget(le_gateway);


        gridLayout->addLayout(horizontalLayout_2, 0, 0, 1, 1);


        gridLayout_8->addWidget(groupBox, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        btn_advancedOption = new QPushButton(SstpWidget);
        btn_advancedOption->setObjectName("btn_advancedOption");

        horizontalLayout->addWidget(btn_advancedOption);


        gridLayout_8->addLayout(horizontalLayout, 3, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_8->addItem(verticalSpacer, 2, 0, 1, 1);

        groupBox_2 = new QGroupBox(SstpWidget);
        groupBox_2->setObjectName("groupBox_2");
        formLayout = new QFormLayout(groupBox_2);
        formLayout->setObjectName("formLayout");
        lbl_username = new QLabel(groupBox_2);
        lbl_username->setObjectName("lbl_username");
        lbl_username->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lbl_username);

        le_username = new QLineEdit(groupBox_2);
        le_username->setObjectName("le_username");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, le_username);

        lbl_password = new QLabel(groupBox_2);
        lbl_password->setObjectName("lbl_password");
        lbl_password->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, lbl_password);

        le_password = new PasswordField(groupBox_2);
        le_password->setObjectName("le_password");
        le_password->setProperty("passwordModeEnabled", QVariant(true));

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, le_password);

        lbl_ntDomain = new QLabel(groupBox_2);
        lbl_ntDomain->setObjectName("lbl_ntDomain");
        lbl_ntDomain->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, lbl_ntDomain);

        le_ntDomain = new QLineEdit(groupBox_2);
        le_ntDomain->setObjectName("le_ntDomain");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, le_ntDomain);

        lbl_caCert = new QLabel(groupBox_2);
        lbl_caCert->setObjectName("lbl_caCert");
        lbl_caCert->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, lbl_caCert);

        kurl_caCert = new KUrlRequester(groupBox_2);
        kurl_caCert->setObjectName("kurl_caCert");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kurl_caCert);

        chk_ignoreCertWarnings = new QCheckBox(groupBox_2);
        chk_ignoreCertWarnings->setObjectName("chk_ignoreCertWarnings");

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, chk_ignoreCertWarnings);


        gridLayout_8->addWidget(groupBox_2, 1, 0, 1, 1);

        QWidget::setTabOrder(le_gateway, le_username);
        QWidget::setTabOrder(le_username, le_password);
        QWidget::setTabOrder(le_password, le_ntDomain);
        QWidget::setTabOrder(le_ntDomain, kurl_caCert);
        QWidget::setTabOrder(kurl_caCert, chk_ignoreCertWarnings);
        QWidget::setTabOrder(chk_ignoreCertWarnings, btn_advancedOption);

        retranslateUi(SstpWidget);

        QMetaObject::connectSlotsByName(SstpWidget);
    } // setupUi

    void retranslateUi(QWidget *SstpWidget)
    {
        groupBox->setTitle(tr2i18n("General", nullptr));
        lbl_gateway->setText(tr2i18n("Gateway:", nullptr));
        btn_advancedOption->setText(tr2i18n("Advanced\342\200\246", nullptr));
        groupBox_2->setTitle(tr2i18n("Optional", nullptr));
        lbl_username->setText(tr2i18n("Username:", nullptr));
        lbl_password->setText(tr2i18n("Password:", nullptr));
        lbl_ntDomain->setText(tr2i18n("NT Domain:", nullptr));
        lbl_caCert->setText(tr2i18n("CA Certificate:", nullptr));
        chk_ignoreCertWarnings->setText(tr2i18n("Ignore certificate warnings", nullptr));
        (void)SstpWidget;
    } // retranslateUi

};

namespace Ui {
    class SstpWidget: public Ui_SstpWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SSTPWIDGET_H

