/********************************************************************************
** Form generated from reading UI file 'l2tp.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_L2TP_H
#define UI_L2TP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_L2tpWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *labelGateway;
    QLineEdit *gateway;
    QLabel *labelAuthType;
    QComboBox *cmbAuthType;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QFormLayout *formLayout_5;
    QLabel *Label_1;
    QLineEdit *username;
    QLabel *Label_2;
    QHBoxLayout *horizontalLayout_3;
    PasswordField *password;
    QLabel *Label_3;
    QLineEdit *domain;
    QWidget *page_1;
    QFormLayout *formLayout_2;
    QLabel *textLabel2;
    KUrlRequester *userCA;
    QLabel *textLabel3_2;
    KUrlRequester *userCert;
    QLabel *textLabel4;
    KUrlRequester *userKey;
    QLabel *label_7;
    QHBoxLayout *horizontalLayout_2;
    PasswordField *userKeyPassword;
    QCheckBox *cbEphemeralSourcePort;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *btnIPSecSettings;
    QPushButton *btnPPPSettings;

    void setupUi(QWidget *L2tpWidget)
    {
        if (L2tpWidget->objectName().isEmpty())
            L2tpWidget->setObjectName("L2tpWidget");
        L2tpWidget->resize(495, 422);
        verticalLayout = new QVBoxLayout(L2tpWidget);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setSpacing(6);
        formLayout->setObjectName("formLayout");
        labelGateway = new QLabel(L2tpWidget);
        labelGateway->setObjectName("labelGateway");
        labelGateway->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelGateway->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelGateway);

        gateway = new QLineEdit(L2tpWidget);
        gateway->setObjectName("gateway");
        gateway->setClearButtonEnabled(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, gateway);

        labelAuthType = new QLabel(L2tpWidget);
        labelAuthType->setObjectName("labelAuthType");
        labelAuthType->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelAuthType->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, labelAuthType);

        cmbAuthType = new QComboBox(L2tpWidget);
        cmbAuthType->addItem(QString());
        cmbAuthType->addItem(QString());
        cmbAuthType->setObjectName("cmbAuthType");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cmbAuthType->sizePolicy().hasHeightForWidth());
        cmbAuthType->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, cmbAuthType);


        verticalLayout->addLayout(formLayout);

        stackedWidget = new QStackedWidget(L2tpWidget);
        stackedWidget->setObjectName("stackedWidget");
        page = new QWidget();
        page->setObjectName("page");
        formLayout_5 = new QFormLayout(page);
        formLayout_5->setSpacing(6);
        formLayout_5->setContentsMargins(11, 11, 11, 11);
        formLayout_5->setObjectName("formLayout_5");
        Label_1 = new QLabel(page);
        Label_1->setObjectName("Label_1");
        Label_1->setWordWrap(false);

        formLayout_5->setWidget(0, QFormLayout::ItemRole::LabelRole, Label_1);

        username = new QLineEdit(page);
        username->setObjectName("username");
        username->setClearButtonEnabled(true);

        formLayout_5->setWidget(0, QFormLayout::ItemRole::FieldRole, username);

        Label_2 = new QLabel(page);
        Label_2->setObjectName("Label_2");

        formLayout_5->setWidget(1, QFormLayout::ItemRole::LabelRole, Label_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(6);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        password = new PasswordField(page);
        password->setObjectName("password");
        password->setEnabled(true);
        password->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_3->addWidget(password);


        formLayout_5->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);

        Label_3 = new QLabel(page);
        Label_3->setObjectName("Label_3");

        formLayout_5->setWidget(2, QFormLayout::ItemRole::LabelRole, Label_3);

        domain = new QLineEdit(page);
        domain->setObjectName("domain");

        formLayout_5->setWidget(2, QFormLayout::ItemRole::FieldRole, domain);

        stackedWidget->addWidget(page);
        page_1 = new QWidget();
        page_1->setObjectName("page_1");
        formLayout_2 = new QFormLayout(page_1);
        formLayout_2->setSpacing(6);
        formLayout_2->setContentsMargins(11, 11, 11, 11);
        formLayout_2->setObjectName("formLayout_2");
        textLabel2 = new QLabel(page_1);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel2);

        userCA = new KUrlRequester(page_1);
        userCA->setObjectName("userCA");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, userCA);

        textLabel3_2 = new QLabel(page_1);
        textLabel3_2->setObjectName("textLabel3_2");
        textLabel3_2->setWordWrap(false);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabel3_2);

        userCert = new KUrlRequester(page_1);
        userCert->setObjectName("userCert");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, userCert);

        textLabel4 = new QLabel(page_1);
        textLabel4->setObjectName("textLabel4");
        textLabel4->setWordWrap(false);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, textLabel4);

        userKey = new KUrlRequester(page_1);
        userKey->setObjectName("userKey");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, userKey);

        label_7 = new QLabel(page_1);
        label_7->setObjectName("label_7");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_7);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        userKeyPassword = new PasswordField(page_1);
        userKeyPassword->setObjectName("userKeyPassword");
        userKeyPassword->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_2->addWidget(userKeyPassword);


        formLayout_2->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        stackedWidget->addWidget(page_1);

        verticalLayout->addWidget(stackedWidget);

        cbEphemeralSourcePort = new QCheckBox(L2tpWidget);
        cbEphemeralSourcePort->setObjectName("cbEphemeralSourcePort");

        verticalLayout->addWidget(cbEphemeralSourcePort);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        btnIPSecSettings = new QPushButton(L2tpWidget);
        btnIPSecSettings->setObjectName("btnIPSecSettings");

        horizontalLayout->addWidget(btnIPSecSettings);

        btnPPPSettings = new QPushButton(L2tpWidget);
        btnPPPSettings->setObjectName("btnPPPSettings");

        horizontalLayout->addWidget(btnPPPSettings);


        verticalLayout->addLayout(horizontalLayout);

#if QT_CONFIG(shortcut)
        labelGateway->setBuddy(gateway);
        labelAuthType->setBuddy(cmbAuthType);
        Label_1->setBuddy(username);
        Label_2->setBuddy(password);
        Label_3->setBuddy(domain);
        textLabel2->setBuddy(userCA);
        textLabel3_2->setBuddy(userCert);
        textLabel4->setBuddy(userKey);
        label_7->setBuddy(userKeyPassword);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(gateway, cmbAuthType);
        QWidget::setTabOrder(cmbAuthType, username);
        QWidget::setTabOrder(username, password);
        QWidget::setTabOrder(password, domain);
        QWidget::setTabOrder(domain, userCA);
        QWidget::setTabOrder(userCA, userCert);
        QWidget::setTabOrder(userCert, userKey);
        QWidget::setTabOrder(userKey, userKeyPassword);
        QWidget::setTabOrder(userKeyPassword, cbEphemeralSourcePort);
        QWidget::setTabOrder(cbEphemeralSourcePort, btnIPSecSettings);
        QWidget::setTabOrder(btnIPSecSettings, btnPPPSettings);

        retranslateUi(L2tpWidget);
        QObject::connect(cmbAuthType, &QComboBox::currentIndexChanged, stackedWidget, &QStackedWidget::setCurrentIndex);

        QMetaObject::connectSlotsByName(L2tpWidget);
    } // setupUi

    void retranslateUi(QWidget *L2tpWidget)
    {
        labelGateway->setText(tr2i18n("Gateway:", nullptr));
#if QT_CONFIG(tooltip)
        gateway->setToolTip(tr2i18n("L2TP server IP or name.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelAuthType->setText(tr2i18n("Authentication type:", nullptr));
        cmbAuthType->setItemText(0, tr2i18n("Password", nullptr));
        cmbAuthType->setItemText(1, tr2i18n("Certificates (TLS)", nullptr));

#if QT_CONFIG(tooltip)
        cmbAuthType->setToolTip(tr2i18n("Select an authentication mode.", nullptr));
#endif // QT_CONFIG(tooltip)
        Label_1->setText(tr2i18n("Username:", "like in Username for athentication"));
#if QT_CONFIG(tooltip)
        username->setToolTip(tr2i18n("<html><head/><body><p>Set the name used for authenticating the local system to the peer to &lt;name&gt;.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        Label_2->setText(tr2i18n("Password:", nullptr));
#if QT_CONFIG(tooltip)
        password->setToolTip(tr2i18n("<html><head/><body><p>Password passed to PPPD when prompted for it.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        Label_3->setText(tr2i18n("NT Domain:", nullptr));
#if QT_CONFIG(tooltip)
        domain->setToolTip(tr2i18n("<html><head/><body><p>Append the domain name &lt;domain&gt; to the local host name for</p><p>authentication purposes.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        textLabel2->setText(tr2i18n("CA Certificate:", nullptr));
#if QT_CONFIG(tooltip)
        userCA->setToolTip(tr2i18n("<html><head/><body><p>Certificate authority (CA) file in .pem, .der, .crt, .cer or .p12 formats.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        userCA->setNameFilters(QStringList{
            tr2i18n("*.pem *.der *.crt *.cer *.p12", nullptr)});
        textLabel3_2->setText(tr2i18n("User Certificate:", nullptr));
#if QT_CONFIG(tooltip)
        userCert->setToolTip(tr2i18n("<html><head/><body><p>Certificate in .pem, .der, .crt, .cer or .p12 formats.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        userCert->setNameFilters(QStringList{
            tr2i18n("*.pem *.der *.crt *.cer *.p12", nullptr)});
        textLabel4->setText(tr2i18n("Private Key:", nullptr));
#if QT_CONFIG(tooltip)
        userKey->setToolTip(tr2i18n("<html><head/><body><p>Private key in .pem, .der, .key, .pk8 or .p12 formats.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        userKey->setNameFilters(QStringList{
            tr2i18n("*.pem *.der *.key *.pk8 *.p12", nullptr)});
        label_7->setText(tr2i18n("Private Key Password:", nullptr));
#if QT_CONFIG(tooltip)
        userKeyPassword->setToolTip(tr2i18n("<html><head/><body><p>Password for private key or PKCS#12 certificate.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        cbEphemeralSourcePort->setToolTip(tr2i18n("Do not use UDP port 1701 for L2TP source port even if it is free.\n"
"An ephemeral (random) high port number will be used instead.\n"
"\n"
"May be required to allow multiple L2TP clients behind the same NAT.", nullptr));
#endif // QT_CONFIG(tooltip)
        cbEphemeralSourcePort->setText(tr2i18n("Use L2TP ephemeral source port", nullptr));
        btnIPSecSettings->setText(tr2i18n("IPsec Settings\342\200\246", nullptr));
        btnPPPSettings->setText(tr2i18n("PPP Settings\342\200\246", nullptr));
        (void)L2tpWidget;
    } // retranslateUi

};

namespace Ui {
    class L2tpWidget: public Ui_L2tpWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // L2TP_H

