/********************************************************************************
** Form generated from reading UI file 'infiniband.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INFINIBAND_H
#define UI_INFINIBAND_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "hwaddrcombobox.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_InfinibandWidget
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    KComboBox *transport;
    QLabel *label_2;
    HwAddrComboBox *macAddress;
    QLabel *label_4;
    QSpinBox *mtu;

    void setupUi(QWidget *InfinibandWidget)
    {
        if (InfinibandWidget->objectName().isEmpty())
            InfinibandWidget->setObjectName("InfinibandWidget");
        InfinibandWidget->resize(414, 362);
        formLayout = new QFormLayout(InfinibandWidget);
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(6);
        label = new QLabel(InfinibandWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        transport = new KComboBox(InfinibandWidget);
        transport->setObjectName("transport");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(transport->sizePolicy().hasHeightForWidth());
        transport->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, transport);

        label_2 = new QLabel(InfinibandWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        macAddress = new HwAddrComboBox(InfinibandWidget);
        macAddress->setObjectName("macAddress");
        sizePolicy.setHeightForWidth(macAddress->sizePolicy().hasHeightForWidth());
        macAddress->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, macAddress);

        label_4 = new QLabel(InfinibandWidget);
        label_4->setObjectName("label_4");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_4);

        mtu = new QSpinBox(InfinibandWidget);
        mtu->setObjectName("mtu");
        sizePolicy.setHeightForWidth(mtu->sizePolicy().hasHeightForWidth());
        mtu->setSizePolicy(sizePolicy);
        mtu->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        mtu->setMaximum(2044);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, mtu);

#if QT_CONFIG(shortcut)
        label->setBuddy(transport);
        label_2->setBuddy(macAddress);
        label_4->setBuddy(mtu);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(transport, macAddress);
        QWidget::setTabOrder(macAddress, mtu);

        retranslateUi(InfinibandWidget);

        QMetaObject::connectSlotsByName(InfinibandWidget);
    } // setupUi

    void retranslateUi(QWidget *InfinibandWidget)
    {
        label->setText(tr2i18n("Transport mode:", nullptr));
        label_2->setText(tr2i18n("Restrict to device:", nullptr));
        label_4->setText(tr2i18n("MTU:", nullptr));
        mtu->setSpecialValueText(tr2i18n("Automatic", "MTU:"));
        mtu->setSuffix(tr2i18n(" bytes", nullptr));
        (void)InfinibandWidget;
    } // retranslateUi

};

namespace Ui {
    class InfinibandWidget: public Ui_InfinibandWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // INFINIBAND_H

