/********************************************************************************
** Form generated from reading UI file 'gsm.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GSM_H
#define UI_GSM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_GsmWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *basicGroup;
    QGridLayout *gridLayout;
    QLabel *label;
    KLineEdit *number;
    QLabel *label_2;
    KLineEdit *username;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout;
    PasswordField *password;
    QGroupBox *advGroup;
    QGridLayout *gridLayout_2;
    QCheckBox *roaming;
    QLabel *label_4;
    QLabel *labelNetworkId;
    KLineEdit *apn;
    QLabel *label_7;
    KLineEdit *networkId;
    QHBoxLayout *horizontalLayout_3;
    PasswordField *pin;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *GsmWidget)
    {
        if (GsmWidget->objectName().isEmpty())
            GsmWidget->setObjectName("GsmWidget");
        GsmWidget->resize(554, 461);
        verticalLayout = new QVBoxLayout(GsmWidget);
        verticalLayout->setObjectName("verticalLayout");
        basicGroup = new QGroupBox(GsmWidget);
        basicGroup->setObjectName("basicGroup");
        gridLayout = new QGridLayout(basicGroup);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(basicGroup);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        number = new KLineEdit(basicGroup);
        number->setObjectName("number");
        number->setText(QString::fromUtf8("*99#"));

        gridLayout->addWidget(number, 0, 2, 1, 1);

        label_2 = new QLabel(basicGroup);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 2);

        username = new KLineEdit(basicGroup);
        username->setObjectName("username");

        gridLayout->addWidget(username, 1, 2, 1, 1);

        label_3 = new QLabel(basicGroup);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        password = new PasswordField(basicGroup);
        password->setObjectName("password");
        password->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout->addWidget(password);


        gridLayout->addLayout(horizontalLayout, 2, 2, 1, 1);


        verticalLayout->addWidget(basicGroup);

        advGroup = new QGroupBox(GsmWidget);
        advGroup->setObjectName("advGroup");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(advGroup->sizePolicy().hasHeightForWidth());
        advGroup->setSizePolicy(sizePolicy);
        advGroup->setCheckable(false);
        gridLayout_2 = new QGridLayout(advGroup);
        gridLayout_2->setObjectName("gridLayout_2");
        roaming = new QCheckBox(advGroup);
        roaming->setObjectName("roaming");

        gridLayout_2->addWidget(roaming, 2, 1, 1, 2);

        label_4 = new QLabel(advGroup);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 0, 0, 1, 1);

        labelNetworkId = new QLabel(advGroup);
        labelNetworkId->setObjectName("labelNetworkId");

        gridLayout_2->addWidget(labelNetworkId, 1, 0, 1, 1);

        apn = new KLineEdit(advGroup);
        apn->setObjectName("apn");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(apn->sizePolicy().hasHeightForWidth());
        apn->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(apn, 0, 1, 1, 1);

        label_7 = new QLabel(advGroup);
        label_7->setObjectName("label_7");

        gridLayout_2->addWidget(label_7, 3, 0, 1, 1);

        networkId = new KLineEdit(advGroup);
        networkId->setObjectName("networkId");

        gridLayout_2->addWidget(networkId, 1, 1, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        pin = new PasswordField(advGroup);
        pin->setObjectName("pin");
        pin->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_3->addWidget(pin);


        gridLayout_2->addLayout(horizontalLayout_3, 3, 1, 1, 1);


        verticalLayout->addWidget(advGroup);

        verticalSpacer = new QSpacerItem(20, 130, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label->setBuddy(number);
        label_2->setBuddy(username);
        label_3->setBuddy(password);
        label_4->setBuddy(apn);
        labelNetworkId->setBuddy(networkId);
        label_7->setBuddy(pin);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(number, username);
        QWidget::setTabOrder(username, password);
        QWidget::setTabOrder(password, apn);
        QWidget::setTabOrder(apn, networkId);
        QWidget::setTabOrder(networkId, roaming);
        QWidget::setTabOrder(roaming, pin);

        retranslateUi(GsmWidget);

        QMetaObject::connectSlotsByName(GsmWidget);
    } // setupUi

    void retranslateUi(QWidget *GsmWidget)
    {
        basicGroup->setTitle(tr2i18n("Basic", nullptr));
        label->setText(tr2i18n("Number:", nullptr));
        label_2->setText(tr2i18n("Username:", nullptr));
        label_3->setText(tr2i18n("Password:", nullptr));
        advGroup->setTitle(tr2i18n("Advanced", nullptr));
        roaming->setText(tr2i18n("Allow roaming if home network is not available", nullptr));
        label_4->setText(tr2i18n("APN:", nullptr));
        labelNetworkId->setText(tr2i18n("Network ID:", nullptr));
        label_7->setText(tr2i18n("PIN:", nullptr));
        (void)GsmWidget;
    } // retranslateUi

};

namespace Ui {
    class GsmWidget: public Ui_GsmWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GSM_H

