/********************************************************************************
** Form generated from reading UI file 'wiredconnectionwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIREDCONNECTIONWIDGET_H
#define UI_WIREDCONNECTIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "hwaddrcombobox.h"
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_WiredConnectionWidget
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    HwAddrComboBox *macAddress;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout;
    KLineEdit *clonedMacAddress;
    QPushButton *btnRandomMacAddr;
    QLabel *label_3;
    QSpinBox *mtu;
    QLabel *speedLabel;
    QLabel *duplexLabel;
    KComboBox *duplex;
    QLabel *label_4;
    QComboBox *linkNegotiation;
    QComboBox *speed;

    void setupUi(QWidget *WiredConnectionWidget)
    {
        if (WiredConnectionWidget->objectName().isEmpty())
            WiredConnectionWidget->setObjectName("WiredConnectionWidget");
        WiredConnectionWidget->resize(437, 232);
        formLayout = new QFormLayout(WiredConnectionWidget);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout->setVerticalSpacing(6);
        label = new QLabel(WiredConnectionWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        macAddress = new HwAddrComboBox(WiredConnectionWidget);
        macAddress->setObjectName("macAddress");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(macAddress->sizePolicy().hasHeightForWidth());
        macAddress->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, macAddress);

        label_2 = new QLabel(WiredConnectionWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        clonedMacAddress = new KLineEdit(WiredConnectionWidget);
        clonedMacAddress->setObjectName("clonedMacAddress");
        sizePolicy.setHeightForWidth(clonedMacAddress->sizePolicy().hasHeightForWidth());
        clonedMacAddress->setSizePolicy(sizePolicy);
        clonedMacAddress->setInputMask(QString::fromUtf8("HH:HH:HH:HH:HH:HH;_"));
        clonedMacAddress->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout->addWidget(clonedMacAddress);

        btnRandomMacAddr = new QPushButton(WiredConnectionWidget);
        btnRandomMacAddr->setObjectName("btnRandomMacAddr");

        horizontalLayout->addWidget(btnRandomMacAddr);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_3 = new QLabel(WiredConnectionWidget);
        label_3->setObjectName("label_3");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        mtu = new QSpinBox(WiredConnectionWidget);
        mtu->setObjectName("mtu");
        sizePolicy.setHeightForWidth(mtu->sizePolicy().hasHeightForWidth());
        mtu->setSizePolicy(sizePolicy);
        mtu->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        mtu->setMaximum(10000);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, mtu);

        speedLabel = new QLabel(WiredConnectionWidget);
        speedLabel->setObjectName("speedLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, speedLabel);

        duplexLabel = new QLabel(WiredConnectionWidget);
        duplexLabel->setObjectName("duplexLabel");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, duplexLabel);

        duplex = new KComboBox(WiredConnectionWidget);
        duplex->addItem(QString());
        duplex->addItem(QString());
        duplex->setObjectName("duplex");
        duplex->setEnabled(false);
        sizePolicy.setHeightForWidth(duplex->sizePolicy().hasHeightForWidth());
        duplex->setSizePolicy(sizePolicy);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, duplex);

        label_4 = new QLabel(WiredConnectionWidget);
        label_4->setObjectName("label_4");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_4);

        linkNegotiation = new QComboBox(WiredConnectionWidget);
        linkNegotiation->addItem(QString());
        linkNegotiation->addItem(QString());
        linkNegotiation->addItem(QString());
        linkNegotiation->setObjectName("linkNegotiation");
        sizePolicy.setHeightForWidth(linkNegotiation->sizePolicy().hasHeightForWidth());
        linkNegotiation->setSizePolicy(sizePolicy);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, linkNegotiation);

        speed = new QComboBox(WiredConnectionWidget);
        speed->addItem(QString());
        speed->addItem(QString());
        speed->addItem(QString());
        speed->addItem(QString());
        speed->addItem(QString());
        speed->addItem(QString());
        speed->addItem(QString());
        speed->addItem(QString());
        speed->setObjectName("speed");
        speed->setEnabled(false);
        sizePolicy.setHeightForWidth(speed->sizePolicy().hasHeightForWidth());
        speed->setSizePolicy(sizePolicy);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, speed);

#if QT_CONFIG(shortcut)
        label->setBuddy(macAddress);
        label_2->setBuddy(clonedMacAddress);
        label_3->setBuddy(mtu);
        duplexLabel->setBuddy(duplex);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(macAddress, clonedMacAddress);
        QWidget::setTabOrder(clonedMacAddress, btnRandomMacAddr);
        QWidget::setTabOrder(btnRandomMacAddr, mtu);
        QWidget::setTabOrder(mtu, duplex);

        retranslateUi(WiredConnectionWidget);

        duplex->setCurrentIndex(1);
        speed->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(WiredConnectionWidget);
    } // setupUi

    void retranslateUi(QWidget *WiredConnectionWidget)
    {
        label->setText(tr2i18n("Restrict to device:", nullptr));
#if QT_CONFIG(tooltip)
        macAddress->setToolTip(tr2i18n("This option locks this connection to the network device specified by its\n"
"permanent MAC address entered here. Example: 00:11:22:33:44:55", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Cloned MAC address:", nullptr));
#if QT_CONFIG(tooltip)
        clonedMacAddress->setToolTip(tr2i18n("The MAC address entered here will be used as hardware address for the\n"
"network device this connection is activated on. This feature is known as MAC\n"
"cloning or spoofing. Example 11:22:33:44:55", nullptr));
#endif // QT_CONFIG(tooltip)
        btnRandomMacAddr->setText(tr2i18n("Random", nullptr));
        label_3->setText(tr2i18n("MTU:", nullptr));
#if QT_CONFIG(tooltip)
        mtu->setToolTip(tr2i18n("Only transmit packets of the specified size or smaller, breaking larger packets up\n"
"into multiple Ethernet frames", nullptr));
#endif // QT_CONFIG(tooltip)
        mtu->setSpecialValueText(tr2i18n("Automatic", "MTU:"));
        mtu->setSuffix(tr2i18n(" bytes", nullptr));
        speedLabel->setText(tr2i18n("Speed:", nullptr));
        duplexLabel->setText(tr2i18n("Duplex:", nullptr));
        duplex->setItemText(0, tr2i18n("Half", nullptr));
        duplex->setItemText(1, tr2i18n("Full", nullptr));

#if QT_CONFIG(tooltip)
        duplex->setToolTip(tr2i18n("Request that the device use the specified duplex mode. Either \"half\" or \"full\"", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_4->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Link negotiation:", nullptr));
        linkNegotiation->setItemText(0, tr2i18n("Ignore", nullptr));
        linkNegotiation->setItemText(1, tr2i18n("Automatic", "Link negotiation:"));
        linkNegotiation->setItemText(2, tr2i18n("Manual", nullptr));

#if QT_CONFIG(tooltip)
        linkNegotiation->setToolTip(tr2i18n("Device link negotiation. If \342\200\234Manual\342\200\235 is chosen, \342\200\234Speed\342\200\235 and \342\200\234Duplex\342\200\235 values will be forced without checking\n"
"the device compatibility. If unsure, leave here \342\200\234Ignore\342\200\235 or pick \342\200\234Automatic\342\200\235.", nullptr));
#endif // QT_CONFIG(tooltip)
        speed->setItemText(0, tr2i18n("10 Mb/s", nullptr));
        speed->setItemText(1, tr2i18n("100 Mb/s", nullptr));
        speed->setItemText(2, tr2i18n("1 Gb/s", nullptr));
        speed->setItemText(3, tr2i18n("2.5 Gb/s", nullptr));
        speed->setItemText(4, tr2i18n("5 Gb/s", nullptr));
        speed->setItemText(5, tr2i18n("10 Gb/s", nullptr));
        speed->setItemText(6, tr2i18n("40 Gb/s", nullptr));
        speed->setItemText(7, tr2i18n("100 Gb/s", nullptr));

#if QT_CONFIG(tooltip)
        speed->setToolTip(tr2i18n("Request that the device use only the specified speed.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)WiredConnectionWidget;
    } // retranslateUi

};

namespace Ui {
    class WiredConnectionWidget: public Ui_WiredConnectionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WIREDCONNECTIONWIDGET_H

