/****************************************************************************
** Meta object code from reading C++ file 'connectionicon.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-nm-6.7.4/libs/connectionicon.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'connectionicon.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14ConnectionIconE_t {};
} // unnamed namespace

template <> constexpr inline auto ConnectionIcon::qt_create_metaobjectdata<qt_meta_tag_ZN14ConnectionIconE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ConnectionIcon",
        "QML.Element",
        "auto",
        "connectivityChanged",
        "",
        "NetworkManager::Connectivity",
        "connectivity",
        "connectingChanged",
        "connecting",
        "connectionIconChanged",
        "icon",
        "connectionTooltipIconChanged",
        "activatingConnectionChanged",
        "connection",
        "activeConnectionAdded",
        "activeConnection",
        "activeConnectionDestroyed",
        "activeConnectionStateChanged",
        "NetworkManager::ActiveConnection::State",
        "state",
        "carrierChanged",
        "carrier",
        "hasEthernetCarrier",
        "deviceAdded",
        "device",
        "deviceRemoved",
        "networkingEnabledChanged",
        "enabled",
        "primaryConnectionChanged",
        "modemNetworkRemoved",
        "modemSignalChanged",
        "ModemManager::SignalQualityPair",
        "signalQuality",
        "setIconForModem",
        "statusChanged",
        "NetworkManager::Status",
        "status",
        "setWirelessIconForSignalStrength",
        "strength",
        "vpnConnectionStateChanged",
        "NetworkManager::VpnConnection::State",
        "NetworkManager::VpnConnection::StateChangeReason",
        "reason",
        "wirelessEnabledChanged",
        "wirelessNetworkAppeared",
        "network",
        "wwanEnabledChanged",
        "connectionIcon",
        "connectionTooltipIcon"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connectivityChanged'
        QtMocHelpers::SignalData<void(NetworkManager::Connectivity)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'connectingChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'connectionIconChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'connectionTooltipIconChanged'
        QtMocHelpers::SignalData<void(const QString &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'activatingConnectionChanged'
        QtMocHelpers::SlotData<void(const QString &)>(12, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'activeConnectionAdded'
        QtMocHelpers::SlotData<void(const QString &)>(14, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'activeConnectionDestroyed'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'activeConnectionStateChanged'
        QtMocHelpers::SlotData<void(NetworkManager::ActiveConnection::State)>(17, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'carrierChanged'
        QtMocHelpers::SlotData<void(bool)>(20, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'hasEthernetCarrier'
        QtMocHelpers::SlotData<bool() const>(22, 4, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'deviceAdded'
        QtMocHelpers::SlotData<void(const QString &)>(23, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'deviceRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(25, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'networkingEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(26, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'primaryConnectionChanged'
        QtMocHelpers::SlotData<void(const QString &)>(28, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'modemNetworkRemoved'
        QtMocHelpers::SlotData<void()>(29, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'modemSignalChanged'
        QtMocHelpers::SlotData<void(ModemManager::SignalQualityPair)>(30, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'setIconForModem'
        QtMocHelpers::SlotData<void()>(33, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'statusChanged'
        QtMocHelpers::SlotData<void(NetworkManager::Status)>(34, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'setWirelessIconForSignalStrength'
        QtMocHelpers::SlotData<void(int)>(37, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 38 },
        }}),
        // Slot 'vpnConnectionStateChanged'
        QtMocHelpers::SlotData<void(NetworkManager::VpnConnection::State, NetworkManager::VpnConnection::StateChangeReason)>(39, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 19 }, { 0x80000000 | 41, 42 },
        }}),
        // Slot 'wirelessEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(43, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'wirelessNetworkAppeared'
        QtMocHelpers::SlotData<void(const QString &)>(44, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 45 },
        }}),
        // Slot 'wwanEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(46, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'connecting'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'connectionIcon'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'connectionTooltipIcon'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'connectivity'
        QtMocHelpers::PropertyData<NetworkManager::Connectivity>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ConnectionIcon, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN14ConnectionIconE[] = {
    QMetaObject::SuperData::link<NetworkManager::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject ConnectionIcon::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ConnectionIconE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ConnectionIconE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN14ConnectionIconE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ConnectionIconE_t>.metaTypes,
    nullptr
} };

void ConnectionIcon::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ConnectionIcon *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connectivityChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::Connectivity>>(_a[1]))); break;
        case 1: _t->connectingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->connectionIconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->connectionTooltipIconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->activatingConnectionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->activeConnectionAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->activeConnectionDestroyed(); break;
        case 7: _t->activeConnectionStateChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::ActiveConnection::State>>(_a[1]))); break;
        case 8: _t->carrierChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: { bool _r = _t->hasEthernetCarrier();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->networkingEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->primaryConnectionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->modemNetworkRemoved(); break;
        case 15: _t->modemSignalChanged((*reinterpret_cast<std::add_pointer_t<ModemManager::SignalQualityPair>>(_a[1]))); break;
        case 16: _t->setIconForModem(); break;
        case 17: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::Status>>(_a[1]))); break;
        case 18: _t->setWirelessIconForSignalStrength((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->vpnConnectionStateChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::VpnConnection::State>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetworkManager::VpnConnection::StateChangeReason>>(_a[2]))); break;
        case 20: _t->wirelessEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->wirelessNetworkAppeared((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->wwanEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ModemManager::SignalQualityPair >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ConnectionIcon::*)(NetworkManager::Connectivity )>(_a, &ConnectionIcon::connectivityChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConnectionIcon::*)(bool )>(_a, &ConnectionIcon::connectingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConnectionIcon::*)(const QString & )>(_a, &ConnectionIcon::connectionIconChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConnectionIcon::*)(const QString & )>(_a, &ConnectionIcon::connectionTooltipIconChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->connecting(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->connectionIcon(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->connectionTooltipIcon(); break;
        case 3: *reinterpret_cast<NetworkManager::Connectivity*>(_v) = _t->connectivity(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setConnectivity(*reinterpret_cast<NetworkManager::Connectivity*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ConnectionIcon::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ConnectionIcon::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ConnectionIconE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ConnectionIcon::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void ConnectionIcon::connectivityChanged(NetworkManager::Connectivity _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ConnectionIcon::connectingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ConnectionIcon::connectionIconChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ConnectionIcon::connectionTooltipIconChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
