/********************************************************************************
** Form generated from reading UI file 'pptpadvanced.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PPTPADVANCED_H
#define UI_PPTPADVANCED_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PptpAdvanced
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *grp_authenfication;
    QFormLayout *formLayout;
    QLabel *lbl_auth;
    QListWidget *listWidget;
    QGroupBox *gb_MPPE;
    QFormLayout *formLayout_2;
    QLabel *lbl_MMPEcrypto;
    QComboBox *cb_MPPECrypto;
    QCheckBox *cb_statefulEncryption;
    QGroupBox *grp_cryptoAndCompression;
    QFormLayout *formLayout_3;
    QCheckBox *cb_BSD;
    QCheckBox *cb_deflate;
    QCheckBox *cb_TCPheaders;
    QGroupBox *grp_echo;
    QFormLayout *formLayout_4;
    QCheckBox *cb_sendEcho;

    void setupUi(QWidget *PptpAdvanced)
    {
        if (PptpAdvanced->objectName().isEmpty())
            PptpAdvanced->setObjectName("PptpAdvanced");
        PptpAdvanced->resize(365, 479);
        verticalLayout_3 = new QVBoxLayout(PptpAdvanced);
        verticalLayout_3->setObjectName("verticalLayout_3");
        grp_authenfication = new QGroupBox(PptpAdvanced);
        grp_authenfication->setObjectName("grp_authenfication");
        formLayout = new QFormLayout(grp_authenfication);
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(6);
        lbl_auth = new QLabel(grp_authenfication);
        lbl_auth->setObjectName("lbl_auth");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lbl_auth);

        listWidget = new QListWidget(grp_authenfication);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(listWidget);
        __qlistwidgetitem->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(listWidget);
        __qlistwidgetitem1->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(listWidget);
        __qlistwidgetitem2->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(listWidget);
        __qlistwidgetitem3->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(listWidget);
        __qlistwidgetitem4->setCheckState(Qt::Checked);
        listWidget->setObjectName("listWidget");

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, listWidget);


        verticalLayout_3->addWidget(grp_authenfication);

        gb_MPPE = new QGroupBox(PptpAdvanced);
        gb_MPPE->setObjectName("gb_MPPE");
        gb_MPPE->setCheckable(true);
        gb_MPPE->setChecked(false);
        formLayout_2 = new QFormLayout(gb_MPPE);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setVerticalSpacing(5);
        lbl_MMPEcrypto = new QLabel(gb_MPPE);
        lbl_MMPEcrypto->setObjectName("lbl_MMPEcrypto");
        lbl_MMPEcrypto->setMaximumSize(QSize(100, 16777215));

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, lbl_MMPEcrypto);

        cb_MPPECrypto = new QComboBox(gb_MPPE);
        cb_MPPECrypto->addItem(QString());
        cb_MPPECrypto->addItem(QString());
        cb_MPPECrypto->addItem(QString());
        cb_MPPECrypto->setObjectName("cb_MPPECrypto");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cb_MPPECrypto->sizePolicy().hasHeightForWidth());
        cb_MPPECrypto->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, cb_MPPECrypto);

        cb_statefulEncryption = new QCheckBox(gb_MPPE);
        cb_statefulEncryption->setObjectName("cb_statefulEncryption");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::SpanningRole, cb_statefulEncryption);


        verticalLayout_3->addWidget(gb_MPPE);

        grp_cryptoAndCompression = new QGroupBox(PptpAdvanced);
        grp_cryptoAndCompression->setObjectName("grp_cryptoAndCompression");
        formLayout_3 = new QFormLayout(grp_cryptoAndCompression);
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        formLayout_3->setVerticalSpacing(6);
        cb_BSD = new QCheckBox(grp_cryptoAndCompression);
        cb_BSD->setObjectName("cb_BSD");
        cb_BSD->setChecked(true);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, cb_BSD);

        cb_deflate = new QCheckBox(grp_cryptoAndCompression);
        cb_deflate->setObjectName("cb_deflate");
        cb_deflate->setChecked(true);

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, cb_deflate);

        cb_TCPheaders = new QCheckBox(grp_cryptoAndCompression);
        cb_TCPheaders->setObjectName("cb_TCPheaders");
        cb_TCPheaders->setChecked(true);

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, cb_TCPheaders);


        verticalLayout_3->addWidget(grp_cryptoAndCompression);

        grp_echo = new QGroupBox(PptpAdvanced);
        grp_echo->setObjectName("grp_echo");
        formLayout_4 = new QFormLayout(grp_echo);
        formLayout_4->setObjectName("formLayout_4");
        formLayout_4->setVerticalSpacing(6);
        cb_sendEcho = new QCheckBox(grp_echo);
        cb_sendEcho->setObjectName("cb_sendEcho");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, cb_sendEcho);


        verticalLayout_3->addWidget(grp_echo);

        grp_authenfication->raise();
        grp_echo->raise();
        grp_cryptoAndCompression->raise();
        gb_MPPE->raise();
#if QT_CONFIG(shortcut)
        lbl_auth->setBuddy(listWidget);
        lbl_MMPEcrypto->setBuddy(cb_MPPECrypto);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(listWidget, gb_MPPE);
        QWidget::setTabOrder(gb_MPPE, cb_MPPECrypto);
        QWidget::setTabOrder(cb_MPPECrypto, cb_statefulEncryption);
        QWidget::setTabOrder(cb_statefulEncryption, cb_BSD);
        QWidget::setTabOrder(cb_BSD, cb_deflate);
        QWidget::setTabOrder(cb_deflate, cb_TCPheaders);
        QWidget::setTabOrder(cb_TCPheaders, cb_sendEcho);

        retranslateUi(PptpAdvanced);

        QMetaObject::connectSlotsByName(PptpAdvanced);
    } // setupUi

    void retranslateUi(QWidget *PptpAdvanced)
    {
        grp_authenfication->setTitle(tr2i18n("Authentication", nullptr));
        lbl_auth->setText(tr2i18n("Allow following authentication methods:", nullptr));

        const bool __sortingEnabled = listWidget->isSortingEnabled();
        listWidget->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = listWidget->item(0);
        ___qlistwidgetitem->setText(tr2i18n("PAP", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = listWidget->item(1);
        ___qlistwidgetitem1->setText(tr2i18n("CHAP", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = listWidget->item(2);
        ___qlistwidgetitem2->setText(tr2i18n("MSCHAP", nullptr));
        QListWidgetItem *___qlistwidgetitem3 = listWidget->item(3);
        ___qlistwidgetitem3->setText(tr2i18n("MSCHAPv2", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = listWidget->item(4);
        ___qlistwidgetitem4->setText(tr2i18n("EAP", nullptr));
        listWidget->setSortingEnabled(__sortingEnabled);

#if QT_CONFIG(tooltip)
        listWidget->setToolTip(tr2i18n("Allow/disable authentication methods.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        gb_MPPE->setToolTip(tr2i18n("Note: MPPE encryption is only available with MSCHAP authentication methods. To\n"
"enable this checkbox, select one or more of the MSCHAP authentication\n"
"methods: MSCHAP or MSCHAPv2.", nullptr));
#endif // QT_CONFIG(tooltip)
        gb_MPPE->setTitle(tr2i18n("Use MPPE Encryption", nullptr));
        lbl_MMPEcrypto->setText(tr2i18n("Crypto:", nullptr));
        cb_MPPECrypto->setItemText(0, tr2i18n("Any", "like in use Any configuration"));
        cb_MPPECrypto->setItemText(1, tr2i18n("128 bit", nullptr));
        cb_MPPECrypto->setItemText(2, tr2i18n("40 bit", nullptr));

#if QT_CONFIG(tooltip)
        cb_MPPECrypto->setToolTip(tr2i18n("Require the use of MPPE, with 40/128-bit encryption or all.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        cb_statefulEncryption->setToolTip(tr2i18n("Allow MPPE to use stateful mode. Stateless mode is still attempted first.", nullptr));
#endif // QT_CONFIG(tooltip)
        cb_statefulEncryption->setText(tr2i18n("Use stateful encryption", nullptr));
        grp_cryptoAndCompression->setTitle(tr2i18n("Compression", nullptr));
#if QT_CONFIG(tooltip)
        cb_BSD->setToolTip(tr2i18n("Allow/disable BSD-Compress compression.", nullptr));
#endif // QT_CONFIG(tooltip)
        cb_BSD->setText(tr2i18n("Allow BSD compression", nullptr));
#if QT_CONFIG(tooltip)
        cb_deflate->setToolTip(tr2i18n("Allow/disable Deflate compression.", nullptr));
#endif // QT_CONFIG(tooltip)
        cb_deflate->setText(tr2i18n("Allow Deflate compression", nullptr));
#if QT_CONFIG(tooltip)
        cb_TCPheaders->setToolTip(tr2i18n("Allow/disable Van Jacobson style TCP/IP header compression in both the transmit\n"
" and the receive directions.", nullptr));
#endif // QT_CONFIG(tooltip)
        cb_TCPheaders->setText(tr2i18n("Allow TCP header compression", nullptr));
        grp_echo->setTitle(tr2i18n("Echo", nullptr));
#if QT_CONFIG(tooltip)
        cb_sendEcho->setToolTip(tr2i18n("Send LCP echo-requests to find out whether peer is alive.", nullptr));
#endif // QT_CONFIG(tooltip)
        cb_sendEcho->setText(tr2i18n("Send PPP echo packets ", nullptr));
        (void)PptpAdvanced;
    } // retranslateUi

};

namespace Ui {
    class PptpAdvanced: public Ui_PptpAdvanced {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PPTPADVANCED_H

