/********************************************************************************
** Form generated from reading UI file 'openvpn.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENVPN_H
#define UI_OPENVPN_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_OpenVPNProp
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *textLabel3;
    QLineEdit *gateway;
    QLabel *labelConnectionType;
    QComboBox *cmbConnectionType;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QFormLayout *formLayout_2;
    QLabel *textLabel2;
    KUrlRequester *x509CaFile;
    QLabel *textLabel3_2;
    KUrlRequester *x509Cert;
    QLabel *textLabel4;
    KUrlRequester *x509Key;
    QLabel *label_7;
    QHBoxLayout *horizontalLayout_3;
    PasswordField *x509KeyPassword;
    QSpacerItem *verticalSpacer;
    QWidget *page_2;
    QFormLayout *formLayout_3;
    QLabel *textLabel5;
    KUrlRequester *pskSharedKey;
    QLabel *label_16;
    QComboBox *cmbKeyDirection;
    QLabel *textLabel6;
    QLineEdit *pskLocalIp;
    QLabel *textLabel7;
    QLineEdit *pskRemoteIp;
    QSpacerItem *verticalSpacer_2;
    QLabel *lblKeyDirection;
    QWidget *page_3;
    QFormLayout *formLayout_4;
    QLabel *textLabel8;
    KUrlRequester *passCaFile;
    QLabel *textLabel9;
    QLineEdit *passUserName;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_11;
    PasswordField *passPassword;
    QSpacerItem *verticalSpacer_3;
    QWidget *page_4;
    QFormLayout *formLayout_5;
    QLabel *textLabel2_2;
    KUrlRequester *x509PassCaFile;
    QLabel *textLabel3_2_2;
    KUrlRequester *x509PassCert;
    QLabel *textLabel4_2;
    KUrlRequester *x509PassKey;
    QLabel *label_6;
    QHBoxLayout *horizontalLayout_12;
    PasswordField *x509PassKeyPassword;
    QLabel *textLabel9_2;
    QLineEdit *x509PassUsername;
    QLabel *label;
    QHBoxLayout *horizontalLayout_13;
    PasswordField *x509PassPassword;
    QSpacerItem *verticalSpacer_4;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *btnAdvanced;

    void setupUi(QWidget *OpenVPNProp)
    {
        if (OpenVPNProp->objectName().isEmpty())
            OpenVPNProp->setObjectName("OpenVPNProp");
        OpenVPNProp->resize(495, 422);
        verticalLayout = new QVBoxLayout(OpenVPNProp);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setSpacing(6);
        formLayout->setObjectName("formLayout");
        textLabel3 = new QLabel(OpenVPNProp);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel3->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel3);

        gateway = new QLineEdit(OpenVPNProp);
        gateway->setObjectName("gateway");
        gateway->setClearButtonEnabled(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, gateway);

        labelConnectionType = new QLabel(OpenVPNProp);
        labelConnectionType->setObjectName("labelConnectionType");
        labelConnectionType->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelConnectionType->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, labelConnectionType);

        cmbConnectionType = new QComboBox(OpenVPNProp);
        cmbConnectionType->addItem(QString());
        cmbConnectionType->addItem(QString());
        cmbConnectionType->addItem(QString());
        cmbConnectionType->addItem(QString());
        cmbConnectionType->setObjectName("cmbConnectionType");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cmbConnectionType->sizePolicy().hasHeightForWidth());
        cmbConnectionType->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, cmbConnectionType);


        verticalLayout->addLayout(formLayout);

        stackedWidget = new QStackedWidget(OpenVPNProp);
        stackedWidget->setObjectName("stackedWidget");
        page = new QWidget();
        page->setObjectName("page");
        formLayout_2 = new QFormLayout(page);
        formLayout_2->setSpacing(6);
        formLayout_2->setContentsMargins(11, 11, 11, 11);
        formLayout_2->setObjectName("formLayout_2");
        textLabel2 = new QLabel(page);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel2);

        x509CaFile = new KUrlRequester(page);
        x509CaFile->setObjectName("x509CaFile");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, x509CaFile);

        textLabel3_2 = new QLabel(page);
        textLabel3_2->setObjectName("textLabel3_2");
        textLabel3_2->setWordWrap(false);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabel3_2);

        x509Cert = new KUrlRequester(page);
        x509Cert->setObjectName("x509Cert");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, x509Cert);

        textLabel4 = new QLabel(page);
        textLabel4->setObjectName("textLabel4");
        textLabel4->setWordWrap(false);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, textLabel4);

        x509Key = new KUrlRequester(page);
        x509Key->setObjectName("x509Key");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, x509Key);

        label_7 = new QLabel(page);
        label_7->setObjectName("label_7");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_7);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(6);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        x509KeyPassword = new PasswordField(page);
        x509KeyPassword->setObjectName("x509KeyPassword");
        x509KeyPassword->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_3->addWidget(x509KeyPassword);


        formLayout_2->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);

        verticalSpacer = new QSpacerItem(347, 206, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout_2->setItem(4, QFormLayout::ItemRole::SpanningRole, verticalSpacer);

        stackedWidget->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        formLayout_3 = new QFormLayout(page_2);
        formLayout_3->setSpacing(6);
        formLayout_3->setContentsMargins(11, 11, 11, 11);
        formLayout_3->setObjectName("formLayout_3");
        textLabel5 = new QLabel(page_2);
        textLabel5->setObjectName("textLabel5");
        textLabel5->setWordWrap(false);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel5);

        pskSharedKey = new KUrlRequester(page_2);
        pskSharedKey->setObjectName("pskSharedKey");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, pskSharedKey);

        label_16 = new QLabel(page_2);
        label_16->setObjectName("label_16");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, label_16);

        cmbKeyDirection = new QComboBox(page_2);
        cmbKeyDirection->addItem(QString());
        cmbKeyDirection->addItem(QString());
        cmbKeyDirection->addItem(QString());
        cmbKeyDirection->setObjectName("cmbKeyDirection");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cmbKeyDirection->sizePolicy().hasHeightForWidth());
        cmbKeyDirection->setSizePolicy(sizePolicy1);

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, cmbKeyDirection);

        textLabel6 = new QLabel(page_2);
        textLabel6->setObjectName("textLabel6");
        textLabel6->setWordWrap(false);

        formLayout_3->setWidget(4, QFormLayout::ItemRole::LabelRole, textLabel6);

        pskLocalIp = new QLineEdit(page_2);
        pskLocalIp->setObjectName("pskLocalIp");
        pskLocalIp->setClearButtonEnabled(true);

        formLayout_3->setWidget(4, QFormLayout::ItemRole::FieldRole, pskLocalIp);

        textLabel7 = new QLabel(page_2);
        textLabel7->setObjectName("textLabel7");
        textLabel7->setWordWrap(false);

        formLayout_3->setWidget(6, QFormLayout::ItemRole::LabelRole, textLabel7);

        pskRemoteIp = new QLineEdit(page_2);
        pskRemoteIp->setObjectName("pskRemoteIp");
        pskRemoteIp->setClearButtonEnabled(true);

        formLayout_3->setWidget(6, QFormLayout::ItemRole::FieldRole, pskRemoteIp);

        verticalSpacer_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout_3->setItem(7, QFormLayout::ItemRole::SpanningRole, verticalSpacer_2);

        lblKeyDirection = new QLabel(page_2);
        lblKeyDirection->setObjectName("lblKeyDirection");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(lblKeyDirection->sizePolicy().hasHeightForWidth());
        lblKeyDirection->setSizePolicy(sizePolicy2);
        QFont font;
        font.setItalic(true);
        lblKeyDirection->setFont(font);
        lblKeyDirection->setTextFormat(Qt::AutoText);
        lblKeyDirection->setScaledContents(false);
        lblKeyDirection->setWordWrap(true);

        formLayout_3->setWidget(3, QFormLayout::ItemRole::FieldRole, lblKeyDirection);

        stackedWidget->addWidget(page_2);
        page_3 = new QWidget();
        page_3->setObjectName("page_3");
        formLayout_4 = new QFormLayout(page_3);
        formLayout_4->setSpacing(6);
        formLayout_4->setContentsMargins(11, 11, 11, 11);
        formLayout_4->setObjectName("formLayout_4");
        textLabel8 = new QLabel(page_3);
        textLabel8->setObjectName("textLabel8");
        textLabel8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel8->setWordWrap(false);

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel8);

        passCaFile = new KUrlRequester(page_3);
        passCaFile->setObjectName("passCaFile");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, passCaFile);

        textLabel9 = new QLabel(page_3);
        textLabel9->setObjectName("textLabel9");
        textLabel9->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel9->setWordWrap(false);

        formLayout_4->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabel9);

        passUserName = new QLineEdit(page_3);
        passUserName->setObjectName("passUserName");
        passUserName->setClearButtonEnabled(true);

        formLayout_4->setWidget(1, QFormLayout::ItemRole::FieldRole, passUserName);

        label_2 = new QLabel(page_3);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_4->setWidget(2, QFormLayout::ItemRole::LabelRole, label_2);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setSpacing(6);
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        passPassword = new PasswordField(page_3);
        passPassword->setObjectName("passPassword");
        passPassword->setEnabled(true);
        passPassword->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_11->addWidget(passPassword);


        formLayout_4->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout_11);

        verticalSpacer_3 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout_4->setItem(3, QFormLayout::ItemRole::SpanningRole, verticalSpacer_3);

        stackedWidget->addWidget(page_3);
        page_4 = new QWidget();
        page_4->setObjectName("page_4");
        formLayout_5 = new QFormLayout(page_4);
        formLayout_5->setSpacing(6);
        formLayout_5->setContentsMargins(11, 11, 11, 11);
        formLayout_5->setObjectName("formLayout_5");
        textLabel2_2 = new QLabel(page_4);
        textLabel2_2->setObjectName("textLabel2_2");
        textLabel2_2->setWordWrap(false);

        formLayout_5->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel2_2);

        x509PassCaFile = new KUrlRequester(page_4);
        x509PassCaFile->setObjectName("x509PassCaFile");

        formLayout_5->setWidget(0, QFormLayout::ItemRole::FieldRole, x509PassCaFile);

        textLabel3_2_2 = new QLabel(page_4);
        textLabel3_2_2->setObjectName("textLabel3_2_2");
        textLabel3_2_2->setWordWrap(false);

        formLayout_5->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabel3_2_2);

        x509PassCert = new KUrlRequester(page_4);
        x509PassCert->setObjectName("x509PassCert");

        formLayout_5->setWidget(1, QFormLayout::ItemRole::FieldRole, x509PassCert);

        textLabel4_2 = new QLabel(page_4);
        textLabel4_2->setObjectName("textLabel4_2");
        textLabel4_2->setWordWrap(false);

        formLayout_5->setWidget(2, QFormLayout::ItemRole::LabelRole, textLabel4_2);

        x509PassKey = new KUrlRequester(page_4);
        x509PassKey->setObjectName("x509PassKey");

        formLayout_5->setWidget(2, QFormLayout::ItemRole::FieldRole, x509PassKey);

        label_6 = new QLabel(page_4);
        label_6->setObjectName("label_6");

        formLayout_5->setWidget(3, QFormLayout::ItemRole::LabelRole, label_6);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setSpacing(6);
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        x509PassKeyPassword = new PasswordField(page_4);
        x509PassKeyPassword->setObjectName("x509PassKeyPassword");
        x509PassKeyPassword->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_12->addWidget(x509PassKeyPassword);


        formLayout_5->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_12);

        textLabel9_2 = new QLabel(page_4);
        textLabel9_2->setObjectName("textLabel9_2");
        textLabel9_2->setWordWrap(false);

        formLayout_5->setWidget(4, QFormLayout::ItemRole::LabelRole, textLabel9_2);

        x509PassUsername = new QLineEdit(page_4);
        x509PassUsername->setObjectName("x509PassUsername");
        x509PassUsername->setClearButtonEnabled(true);

        formLayout_5->setWidget(4, QFormLayout::ItemRole::FieldRole, x509PassUsername);

        label = new QLabel(page_4);
        label->setObjectName("label");

        formLayout_5->setWidget(5, QFormLayout::ItemRole::LabelRole, label);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setSpacing(6);
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        x509PassPassword = new PasswordField(page_4);
        x509PassPassword->setObjectName("x509PassPassword");
        x509PassPassword->setEnabled(true);
        x509PassPassword->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_13->addWidget(x509PassPassword);


        formLayout_5->setLayout(5, QFormLayout::ItemRole::FieldRole, horizontalLayout_13);

        verticalSpacer_4 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout_5->setItem(6, QFormLayout::ItemRole::SpanningRole, verticalSpacer_4);

        stackedWidget->addWidget(page_4);

        verticalLayout->addWidget(stackedWidget);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        btnAdvanced = new QPushButton(OpenVPNProp);
        btnAdvanced->setObjectName("btnAdvanced");

        horizontalLayout->addWidget(btnAdvanced);


        verticalLayout->addLayout(horizontalLayout);

#if QT_CONFIG(shortcut)
        textLabel3->setBuddy(gateway);
        labelConnectionType->setBuddy(cmbConnectionType);
        textLabel2->setBuddy(x509CaFile);
        textLabel3_2->setBuddy(x509Cert);
        textLabel4->setBuddy(x509Key);
        textLabel5->setBuddy(pskSharedKey);
        textLabel6->setBuddy(pskLocalIp);
        textLabel7->setBuddy(pskRemoteIp);
        textLabel8->setBuddy(passCaFile);
        textLabel9->setBuddy(passUserName);
        textLabel2_2->setBuddy(x509PassCaFile);
        textLabel3_2_2->setBuddy(x509PassCert);
        textLabel4_2->setBuddy(x509PassKey);
        textLabel9_2->setBuddy(x509PassUsername);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(gateway, cmbConnectionType);
        QWidget::setTabOrder(cmbConnectionType, x509CaFile);
        QWidget::setTabOrder(x509CaFile, x509Cert);
        QWidget::setTabOrder(x509Cert, x509Key);
        QWidget::setTabOrder(x509Key, x509KeyPassword);
        QWidget::setTabOrder(x509KeyPassword, pskSharedKey);
        QWidget::setTabOrder(pskSharedKey, cmbKeyDirection);
        QWidget::setTabOrder(cmbKeyDirection, pskLocalIp);
        QWidget::setTabOrder(pskLocalIp, pskRemoteIp);
        QWidget::setTabOrder(pskRemoteIp, passCaFile);
        QWidget::setTabOrder(passCaFile, passUserName);
        QWidget::setTabOrder(passUserName, passPassword);
        QWidget::setTabOrder(passPassword, x509PassCaFile);
        QWidget::setTabOrder(x509PassCaFile, x509PassCert);
        QWidget::setTabOrder(x509PassCert, x509PassKey);
        QWidget::setTabOrder(x509PassKey, x509PassKeyPassword);
        QWidget::setTabOrder(x509PassKeyPassword, x509PassUsername);
        QWidget::setTabOrder(x509PassUsername, x509PassPassword);

        retranslateUi(OpenVPNProp);
        QObject::connect(cmbConnectionType, &QComboBox::currentIndexChanged, stackedWidget, &QStackedWidget::setCurrentIndex);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(OpenVPNProp);
    } // setupUi

    void retranslateUi(QWidget *OpenVPNProp)
    {
        textLabel3->setText(tr2i18n("Gateway:", nullptr));
#if QT_CONFIG(tooltip)
        gateway->setToolTip(tr2i18n("Remote gateways(s), with optional port and protocol (e.g. ovpn.corp.com:1234:tcp).\n"
"You can specify multiple hosts for redundancy (use commas or spaces as delimiters).", nullptr));
#endif // QT_CONFIG(tooltip)
        labelConnectionType->setText(tr2i18n("Connection type:", nullptr));
        cmbConnectionType->setItemText(0, tr2i18n("Certificates (TLS)", nullptr));
        cmbConnectionType->setItemText(1, tr2i18n("Static Key", nullptr));
        cmbConnectionType->setItemText(2, tr2i18n("Password", nullptr));
        cmbConnectionType->setItemText(3, tr2i18n("Password with Certificates (TLS)", nullptr));

#if QT_CONFIG(tooltip)
        cmbConnectionType->setToolTip(tr2i18n("Select an authentication mode.", nullptr));
#endif // QT_CONFIG(tooltip)
        textLabel2->setText(tr2i18n("CA Certificate:", nullptr));
#if QT_CONFIG(tooltip)
        x509CaFile->setToolTip(tr2i18n("Certificate authority (CA) file in .pem format.", nullptr));
#endif // QT_CONFIG(tooltip)
        x509CaFile->setNameFilters(QStringList{
            tr2i18n("*.pem *.crt *.key *.cer *.p12", nullptr)});
        textLabel3_2->setText(tr2i18n("User Certificate:", nullptr));
#if QT_CONFIG(tooltip)
        x509Cert->setToolTip(tr2i18n("Local peer's signed certificate in .pem format (signed by CA of CA Certificate).", nullptr));
#endif // QT_CONFIG(tooltip)
        x509Cert->setNameFilters(QStringList{
            tr2i18n("*.pem *.crt *.key *.cer *.p12", nullptr)});
        textLabel4->setText(tr2i18n("Private Key:", nullptr));
#if QT_CONFIG(tooltip)
        x509Key->setToolTip(tr2i18n("Local peer's private key in .pem format.", nullptr));
#endif // QT_CONFIG(tooltip)
        x509Key->setNameFilters(QStringList{
            tr2i18n("*.pem *.crt *.key *.cer *.p12", nullptr)});
        label_7->setText(tr2i18n("Private Key Password:", nullptr));
#if QT_CONFIG(tooltip)
        x509KeyPassword->setToolTip(tr2i18n("Password for private key.", nullptr));
#endif // QT_CONFIG(tooltip)
        textLabel5->setText(tr2i18n("Static Key:", nullptr));
#if QT_CONFIG(tooltip)
        pskSharedKey->setToolTip(tr2i18n("Pre-shared file for Static Key encryption mode (non-TLS).", nullptr));
#endif // QT_CONFIG(tooltip)
        pskSharedKey->setNameFilters(QStringList{
            tr2i18n("*.key", nullptr)});
        label_16->setText(tr2i18n("Key Direction:", nullptr));
        cmbKeyDirection->setItemText(0, tr2i18n("None", "No \"Key Direction\""));
        cmbKeyDirection->setItemText(1, tr2i18n("0", nullptr));
        cmbKeyDirection->setItemText(2, tr2i18n("1", nullptr));

#if QT_CONFIG(tooltip)
        cmbKeyDirection->setToolTip(tr2i18n("Direction for Static Key encryption mode (non-TLS).", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cmbKeyDirection->setWhatsThis(tr2i18n("If key direction is used, it must be the opposite of that used on the VPN peer.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel6->setText(tr2i18n("Local IP Address:", nullptr));
#if QT_CONFIG(tooltip)
        pskLocalIp->setToolTip(tr2i18n("IP address of the remote VPN endpoint.", nullptr));
#endif // QT_CONFIG(tooltip)
        textLabel7->setText(tr2i18n("Remote IP Address:", nullptr));
#if QT_CONFIG(tooltip)
        pskRemoteIp->setToolTip(tr2i18n("IP address of the local VPN endpoint.", nullptr));
#endif // QT_CONFIG(tooltip)
        lblKeyDirection->setText(tr2i18n("If key direction is used, it must be the opposite of that used on the VPN peer. For example, if the peer uses '1', this connection must use '0'. If you are unsure what value to use, contact your system administrator.", nullptr));
        textLabel8->setText(tr2i18n("CA Certificate:", nullptr));
#if QT_CONFIG(tooltip)
        passCaFile->setToolTip(tr2i18n("Certificate authority (CA) file in .pem format.", nullptr));
#endif // QT_CONFIG(tooltip)
        passCaFile->setNameFilters(QStringList{
            tr2i18n("*.pem *.crt *.key *.cer", nullptr)});
        textLabel9->setText(tr2i18n("Username:", "like in Username for athentication"));
#if QT_CONFIG(tooltip)
        passUserName->setToolTip(tr2i18n("Username passed to OpenVPN when prompted for it.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Password:", nullptr));
#if QT_CONFIG(tooltip)
        passPassword->setToolTip(tr2i18n("Password passed to OpenVPN when prompted for it.", nullptr));
#endif // QT_CONFIG(tooltip)
        textLabel2_2->setText(tr2i18n("CA Certificate:", nullptr));
#if QT_CONFIG(tooltip)
        x509PassCaFile->setToolTip(tr2i18n("Certificate authority (CA) file in .pem format.", nullptr));
#endif // QT_CONFIG(tooltip)
        x509PassCaFile->setNameFilters(QStringList{
            tr2i18n("*.pem *.crt *.key *.cer *.p12", nullptr)});
        textLabel3_2_2->setText(tr2i18n("User Certificate:", nullptr));
#if QT_CONFIG(tooltip)
        x509PassCert->setToolTip(tr2i18n("Local peer's signed certificate in .pem format (signed by CA of CA Certificate).", nullptr));
#endif // QT_CONFIG(tooltip)
        x509PassCert->setNameFilters(QStringList{
            tr2i18n("*.pem *.crt *.key *.cer *.p12", nullptr)});
        textLabel4_2->setText(tr2i18n("Private Key:", nullptr));
#if QT_CONFIG(tooltip)
        x509PassKey->setToolTip(tr2i18n("Local peer's private key in .pem format.", nullptr));
#endif // QT_CONFIG(tooltip)
        x509PassKey->setNameFilters(QStringList{
            tr2i18n("*.pem *.crt *.key *.cer *.p12", nullptr)});
        label_6->setText(tr2i18n("Private Key Password:", nullptr));
#if QT_CONFIG(tooltip)
        x509PassKeyPassword->setToolTip(tr2i18n("Password for private key.", nullptr));
#endif // QT_CONFIG(tooltip)
        textLabel9_2->setText(tr2i18n("Username:", "like in Username for athentication"));
#if QT_CONFIG(tooltip)
        x509PassUsername->setToolTip(tr2i18n("Username passed to OpenVPN when prompted for it.", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Password:", nullptr));
#if QT_CONFIG(tooltip)
        x509PassPassword->setToolTip(tr2i18n("Password passed to OpenVPN when prompted for it.", nullptr));
#endif // QT_CONFIG(tooltip)
        btnAdvanced->setText(tr2i18n("Advanced\342\200\246", nullptr));
        (void)OpenVPNProp;
    } // retranslateUi

};

namespace Ui {
    class OpenVPNProp: public Ui_OpenVPNProp {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPENVPN_H

