/********************************************************************************
** Form generated from reading UI file 'wireguardinterfacewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIREGUARDINTERFACEWIDGET_H
#define UI_WIREGUARDINTERFACEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <passwordfield.h>

QT_BEGIN_NAMESPACE

class Ui_WireGuardInterfaceProp
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QFormLayout *form1Layout;
    QLabel *interfaceNameLabel;
    QLineEdit *interfaceNameLineEdit;
    QLabel *privateKeyLabel;
    PasswordField *privateKeyLineEdit;
    QLabel *listenPortLabel;
    QLineEdit *listenPortLineEdit;
    QLabel *fwmarkLabel;
    QLineEdit *fwmarkLineEdit;
    QLabel *mtuLabel;
    QLineEdit *mtuLineEdit;
    QLabel *peerRouteLabel;
    QCheckBox *peerRouteCheckBox;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *btnPeers;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *WireGuardProp)
    {
        if (WireGuardProp->objectName().isEmpty())
            WireGuardProp->setObjectName("WireGuardProp");
        WireGuardProp->resize(495, 454);
        verticalLayout_2 = new QVBoxLayout(WireGuardProp);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(WireGuardProp);
        groupBox->setObjectName("groupBox");
        form1Layout = new QFormLayout(groupBox);
        form1Layout->setObjectName("form1Layout");
        interfaceNameLabel = new QLabel(groupBox);
        interfaceNameLabel->setObjectName("interfaceNameLabel");

        form1Layout->setWidget(0, QFormLayout::ItemRole::LabelRole, interfaceNameLabel);

        interfaceNameLineEdit = new QLineEdit(groupBox);
        interfaceNameLineEdit->setObjectName("interfaceNameLineEdit");

        form1Layout->setWidget(0, QFormLayout::ItemRole::FieldRole, interfaceNameLineEdit);

        privateKeyLabel = new QLabel(groupBox);
        privateKeyLabel->setObjectName("privateKeyLabel");

        form1Layout->setWidget(1, QFormLayout::ItemRole::LabelRole, privateKeyLabel);

        privateKeyLineEdit = new PasswordField(groupBox);
        privateKeyLineEdit->setObjectName("privateKeyLineEdit");

        form1Layout->setWidget(1, QFormLayout::ItemRole::FieldRole, privateKeyLineEdit);

        listenPortLabel = new QLabel(groupBox);
        listenPortLabel->setObjectName("listenPortLabel");

        form1Layout->setWidget(2, QFormLayout::ItemRole::LabelRole, listenPortLabel);

        listenPortLineEdit = new QLineEdit(groupBox);
        listenPortLineEdit->setObjectName("listenPortLineEdit");

        form1Layout->setWidget(2, QFormLayout::ItemRole::FieldRole, listenPortLineEdit);

        fwmarkLabel = new QLabel(groupBox);
        fwmarkLabel->setObjectName("fwmarkLabel");

        form1Layout->setWidget(3, QFormLayout::ItemRole::LabelRole, fwmarkLabel);

        fwmarkLineEdit = new QLineEdit(groupBox);
        fwmarkLineEdit->setObjectName("fwmarkLineEdit");

        form1Layout->setWidget(3, QFormLayout::ItemRole::FieldRole, fwmarkLineEdit);

        mtuLabel = new QLabel(groupBox);
        mtuLabel->setObjectName("mtuLabel");

        form1Layout->setWidget(4, QFormLayout::ItemRole::LabelRole, mtuLabel);

        mtuLineEdit = new QLineEdit(groupBox);
        mtuLineEdit->setObjectName("mtuLineEdit");

        form1Layout->setWidget(4, QFormLayout::ItemRole::FieldRole, mtuLineEdit);

        peerRouteLabel = new QLabel(groupBox);
        peerRouteLabel->setObjectName("peerRouteLabel");

        form1Layout->setWidget(5, QFormLayout::ItemRole::LabelRole, peerRouteLabel);

        peerRouteCheckBox = new QCheckBox(groupBox);
        peerRouteCheckBox->setObjectName("peerRouteCheckBox");

        form1Layout->setWidget(5, QFormLayout::ItemRole::FieldRole, peerRouteCheckBox);


        verticalLayout_2->addWidget(groupBox);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        btnPeers = new QPushButton(WireGuardProp);
        btnPeers->setObjectName("btnPeers");

        horizontalLayout->addWidget(btnPeers);


        verticalLayout_2->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        retranslateUi(WireGuardProp);

        QMetaObject::connectSlotsByName(WireGuardProp);
    } // setupUi

    void retranslateUi(QWidget *WireGuardProp)
    {
        WireGuardProp->setWindowTitle(tr2i18n("WireGuard Settings", nullptr));
        groupBox->setTitle(tr2i18n("Interface", nullptr));
        interfaceNameLabel->setText(tr2i18n("Interface name:", nullptr));
#if QT_CONFIG(tooltip)
        interfaceNameLineEdit->setToolTip(tr2i18n("Required.\n"
"Network interface name.", nullptr));
#endif // QT_CONFIG(tooltip)
        privateKeyLabel->setText(tr2i18n("Private key:", nullptr));
#if QT_CONFIG(tooltip)
        privateKeyLineEdit->setToolTip(tr2i18n("Required.\n"
"A base64 private key generated by wg genkey.", nullptr));
#endif // QT_CONFIG(tooltip)
        listenPortLabel->setText(tr2i18n("Listen port:", nullptr));
#if QT_CONFIG(tooltip)
        listenPortLineEdit->setToolTip(tr2i18n("Optional.\n"
"Listen port number. Chosen randomly if left as 'Automatic'.", nullptr));
#endif // QT_CONFIG(tooltip)
        fwmarkLabel->setText(tr2i18n("fwmark:", nullptr));
#if QT_CONFIG(tooltip)
        fwmarkLineEdit->setToolTip(tr2i18n("Optional.\n"
"An fwmark for outgoing packets. If set to 0 or 'off', this\n"
"option is disabled. May be specified in hexadecimal by\n"
"prepending '0x'.", nullptr));
#endif // QT_CONFIG(tooltip)
        mtuLabel->setText(tr2i18n("MTU:", nullptr));
#if QT_CONFIG(tooltip)
        mtuLineEdit->setToolTip(tr2i18n("Optional.\n"
"If not specified, the MTU is automatically determined\n"
"from the endpoint addresses or the system default route,\n"
"which is usually a sane choice. However, to manually\n"
"specify an MTU and to override this automatic discovery,\n"
"this value may be specified explicitly.", nullptr));
#endif // QT_CONFIG(tooltip)
        peerRouteLabel->setText(tr2i18n("Autoroute peers:", nullptr));
#if QT_CONFIG(tooltip)
        peerRouteCheckBox->setToolTip(tr2i18n("Whether to automatically add routes for the AllowedIPs ranges\n"
"of the peers.", nullptr));
#endif // QT_CONFIG(tooltip)
        btnPeers->setText(tr2i18n("Peers\342\200\246", nullptr));
    } // retranslateUi

};

namespace Ui {
    class WireGuardInterfaceProp: public Ui_WireGuardInterfaceProp {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WIREGUARDINTERFACEWIDGET_H

