/****************************************************************************
** Meta object code from reading C++ file 'networkmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-nm-6.7.4/libs/models/networkmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'networkmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12NetworkModelE_t {};
} // unnamed namespace

template <> constexpr inline auto NetworkModel::qt_create_metaobjectdata<qt_meta_tag_ZN12NetworkModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NetworkModel",
        "QML.Element",
        "auto",
        "delayModelUpdatesChanged",
        "",
        "onItemUpdated",
        "setDeviceStatisticsRefreshRateMs",
        "devicePath",
        "refreshRate",
        "accessPointSignalStrengthChanged",
        "signal",
        "activeConnectionAdded",
        "activeConnection",
        "activeConnectionRemoved",
        "activeConnectionStateChanged",
        "NetworkManager::ActiveConnection::State",
        "state",
        "activeVpnConnectionStateChanged",
        "NetworkManager::VpnConnection::State",
        "NetworkManager::VpnConnection::StateChangeReason",
        "reason",
        "availableConnectionAppeared",
        "connection",
        "availableConnectionDisappeared",
        "connectionAdded",
        "connectionRemoved",
        "connectionUpdated",
        "deviceAdded",
        "device",
        "deviceRemoved",
        "deviceStateChanged",
        "NetworkManager::Device::State",
        "oldState",
        "NetworkManager::Device::StateChangeReason",
        "gsmNetworkAccessTechnologiesChanged",
        "QFlags<MMModemAccessTechnology>",
        "accessTechnologies",
        "gsmNetworkCurrentModesChanged",
        "gsmNetworkSignalQualityChanged",
        "ModemManager::SignalQualityPair",
        "signalQuality",
        "ipConfigChanged",
        "ipInterfaceChanged",
        "statusChanged",
        "NetworkManager::Status",
        "status",
        "wirelessNetworkAppeared",
        "ssid",
        "wirelessNetworkDisappeared",
        "wirelessNetworkSignalChanged",
        "wirelessNetworkReferenceApChanged",
        "accessPoint",
        "initialize",
        "delayModelUpdates",
        "ItemRole",
        "NameRole",
        "ConnectionIconRole",
        "ConnectionDetailsModelRole",
        "ConnectionPathRole",
        "ConnectionStateRole",
        "DeviceName",
        "DevicePathRole",
        "DeviceStateRole",
        "DuplicateRole",
        "ItemUniqueNameRole",
        "ItemTypeRole",
        "LastUsedRole",
        "SecurityTypeRole",
        "SecurityTypeStringRole",
        "SectionRole",
        "SignalRole",
        "SlaveRole",
        "SsidRole",
        "SpecificPathRole",
        "TimeStampRole",
        "TypeRole",
        "UniRole",
        "UuidRole",
        "VpnState",
        "VpnType",
        "RxBytesRole",
        "TxBytesRole",
        "DelayModelUpdatesRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'delayModelUpdatesChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onItemUpdated'
        QtMocHelpers::SlotData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDeviceStatisticsRefreshRateMs'
        QtMocHelpers::SlotData<void(const QString &, uint)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::UInt, 8 },
        }}),
        // Slot 'accessPointSignalStrengthChanged'
        QtMocHelpers::SlotData<void(int)>(9, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'activeConnectionAdded'
        QtMocHelpers::SlotData<void(const QString &)>(11, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'activeConnectionRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(13, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'activeConnectionStateChanged'
        QtMocHelpers::SlotData<void(NetworkManager::ActiveConnection::State)>(14, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'activeVpnConnectionStateChanged'
        QtMocHelpers::SlotData<void(NetworkManager::VpnConnection::State, NetworkManager::VpnConnection::StateChangeReason)>(17, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 16 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'availableConnectionAppeared'
        QtMocHelpers::SlotData<void(const QString &)>(21, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'availableConnectionDisappeared'
        QtMocHelpers::SlotData<void(const QString &)>(23, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'connectionAdded'
        QtMocHelpers::SlotData<void(const QString &)>(24, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'connectionRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(25, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'connectionUpdated'
        QtMocHelpers::SlotData<void()>(26, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deviceAdded'
        QtMocHelpers::SlotData<void(const QString &)>(27, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'deviceRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(29, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'deviceStateChanged'
        QtMocHelpers::SlotData<void(NetworkManager::Device::State, NetworkManager::Device::State, NetworkManager::Device::StateChangeReason)>(30, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 16 }, { 0x80000000 | 31, 32 }, { 0x80000000 | 33, 20 },
        }}),
        // Slot 'gsmNetworkAccessTechnologiesChanged'
        QtMocHelpers::SlotData<void(QFlags<MMModemAccessTechnology>)>(34, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'gsmNetworkCurrentModesChanged'
        QtMocHelpers::SlotData<void()>(37, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gsmNetworkSignalQualityChanged'
        QtMocHelpers::SlotData<void(const ModemManager::SignalQualityPair &)>(38, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'ipConfigChanged'
        QtMocHelpers::SlotData<void()>(41, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'ipInterfaceChanged'
        QtMocHelpers::SlotData<void()>(42, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'statusChanged'
        QtMocHelpers::SlotData<void(NetworkManager::Status)>(43, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 45 },
        }}),
        // Slot 'wirelessNetworkAppeared'
        QtMocHelpers::SlotData<void(const QString &)>(46, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 47 },
        }}),
        // Slot 'wirelessNetworkDisappeared'
        QtMocHelpers::SlotData<void(const QString &)>(48, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 47 },
        }}),
        // Slot 'wirelessNetworkSignalChanged'
        QtMocHelpers::SlotData<void(int)>(49, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'wirelessNetworkReferenceApChanged'
        QtMocHelpers::SlotData<void(const QString &)>(50, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 51 },
        }}),
        // Slot 'initialize'
        QtMocHelpers::SlotData<void()>(52, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'delayModelUpdates'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ItemRole'
        QtMocHelpers::EnumData<enum ItemRole>(54, 54, QMC::EnumFlags{}).add({
            {   55, ItemRole::NameRole },
            {   56, ItemRole::ConnectionIconRole },
            {   57, ItemRole::ConnectionDetailsModelRole },
            {   58, ItemRole::ConnectionPathRole },
            {   59, ItemRole::ConnectionStateRole },
            {   60, ItemRole::DeviceName },
            {   61, ItemRole::DevicePathRole },
            {   62, ItemRole::DeviceStateRole },
            {   63, ItemRole::DuplicateRole },
            {   64, ItemRole::ItemUniqueNameRole },
            {   65, ItemRole::ItemTypeRole },
            {   66, ItemRole::LastUsedRole },
            {   67, ItemRole::SecurityTypeRole },
            {   68, ItemRole::SecurityTypeStringRole },
            {   69, ItemRole::SectionRole },
            {   70, ItemRole::SignalRole },
            {   71, ItemRole::SlaveRole },
            {   72, ItemRole::SsidRole },
            {   73, ItemRole::SpecificPathRole },
            {   74, ItemRole::TimeStampRole },
            {   75, ItemRole::TypeRole },
            {   76, ItemRole::UniRole },
            {   77, ItemRole::UuidRole },
            {   78, ItemRole::VpnState },
            {   79, ItemRole::VpnType },
            {   80, ItemRole::RxBytesRole },
            {   81, ItemRole::TxBytesRole },
            {   82, ItemRole::DelayModelUpdatesRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<NetworkModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NetworkModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NetworkModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NetworkModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12NetworkModelE_t>.metaTypes,
    nullptr
} };

void NetworkModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetworkModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->delayModelUpdatesChanged(); break;
        case 1: _t->onItemUpdated(); break;
        case 2: _t->setDeviceStatisticsRefreshRateMs((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 3: _t->accessPointSignalStrengthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->activeConnectionAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->activeConnectionRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->activeConnectionStateChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::ActiveConnection::State>>(_a[1]))); break;
        case 7: _t->activeVpnConnectionStateChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::VpnConnection::State>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetworkManager::VpnConnection::StateChangeReason>>(_a[2]))); break;
        case 8: _t->availableConnectionAppeared((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->availableConnectionDisappeared((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->connectionAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->connectionRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->connectionUpdated(); break;
        case 13: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->deviceStateChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::Device::State>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetworkManager::Device::State>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<NetworkManager::Device::StateChangeReason>>(_a[3]))); break;
        case 16: _t->gsmNetworkAccessTechnologiesChanged((*reinterpret_cast<std::add_pointer_t<QFlags<MMModemAccessTechnology>>>(_a[1]))); break;
        case 17: _t->gsmNetworkCurrentModesChanged(); break;
        case 18: _t->gsmNetworkSignalQualityChanged((*reinterpret_cast<std::add_pointer_t<ModemManager::SignalQualityPair>>(_a[1]))); break;
        case 19: _t->ipConfigChanged(); break;
        case 20: _t->ipInterfaceChanged(); break;
        case 21: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::Status>>(_a[1]))); break;
        case 22: _t->wirelessNetworkAppeared((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->wirelessNetworkDisappeared((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->wirelessNetworkSignalChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->wirelessNetworkReferenceApChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->initialize(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFlags<MMModemAccessTechnology> >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ModemManager::SignalQualityPair >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetworkModel::*)()>(_a, &NetworkModel::delayModelUpdatesChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->delayModelUpdates(); break;
        default: break;
        }
    }
}

const QMetaObject *NetworkModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NetworkModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NetworkModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int NetworkModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void NetworkModel::delayModelUpdatesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
