/********************************************************************************
** Form generated from reading UI file 'passworddialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PASSWORDDIALOG_H
#define UI_PASSWORDDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_PasswordDialog
{
public:
    QFormLayout *formLayout;
    QLabel *labelIcon;
    QVBoxLayout *verticalLayout;
    QLabel *labelHeadline;
    QLabel *labelText;
    QHBoxLayout *horizontalLayout;
    QLabel *labelPass;
    PasswordField *password;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;
    QWidget *vpnWidget;

    void setupUi(QWidget *PasswordDialog)
    {
        if (PasswordDialog->objectName().isEmpty())
            PasswordDialog->setObjectName("PasswordDialog");
        PasswordDialog->resize(480, 226);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PasswordDialog->sizePolicy().hasHeightForWidth());
        PasswordDialog->setSizePolicy(sizePolicy);
        PasswordDialog->setMaximumSize(QSize(640, 16777215));
        formLayout = new QFormLayout(PasswordDialog);
        formLayout->setObjectName("formLayout");
        labelIcon = new QLabel(PasswordDialog);
        labelIcon->setObjectName("labelIcon");
        labelIcon->setLineWidth(1);
        labelIcon->setText(QString::fromUtf8("IconLabel"));
        labelIcon->setMargin(8);
        labelIcon->setIndent(-1);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelIcon);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        labelHeadline = new QLabel(PasswordDialog);
        labelHeadline->setObjectName("labelHeadline");
        labelHeadline->setStyleSheet(QString::fromUtf8("font-weight: bold"));
        labelHeadline->setText(QString::fromUtf8("TextLabel"));
        labelHeadline->setTextFormat(Qt::TextFormat::PlainText);

        verticalLayout->addWidget(labelHeadline);

        labelText = new QLabel(PasswordDialog);
        labelText->setObjectName("labelText");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(labelText->sizePolicy().hasHeightForWidth());
        labelText->setSizePolicy(sizePolicy1);
        labelText->setMaximumSize(QSize(16777215, 16777215));
        labelText->setText(QString::fromUtf8("TextLabel"));
        labelText->setTextFormat(Qt::TextFormat::PlainText);
        labelText->setWordWrap(true);

        verticalLayout->addWidget(labelText);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, verticalLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        labelPass = new QLabel(PasswordDialog);
        labelPass->setObjectName("labelPass");

        horizontalLayout->addWidget(labelPass);

        password = new PasswordField(PasswordDialog);
        password->setObjectName("password");
        password->setMaxLength(64);
        password->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout->addWidget(password);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);

        formLayout->setItem(3, QFormLayout::ItemRole::FieldRole, verticalSpacer);

        buttonBox = new QDialogButtonBox(PasswordDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, buttonBox);

        vpnWidget = new QWidget(PasswordDialog);
        vpnWidget->setObjectName("vpnWidget");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, vpnWidget);


        retranslateUi(PasswordDialog);

        QMetaObject::connectSlotsByName(PasswordDialog);
    } // setupUi

    void retranslateUi(QWidget *PasswordDialog)
    {
        PasswordDialog->setWindowTitle(tr2i18n("Password dialog", nullptr));
        labelPass->setText(tr2i18n("Password:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PasswordDialog: public Ui_PasswordDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PASSWORDDIALOG_H

