/********************************************************************************
** Form generated from reading UI file 'l2tpppp.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_L2TPPPP_H
#define UI_L2TPPPP_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpinBox>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_L2tpPppWidget
{
public:
    QFormLayout *formLayout_3;
    QGroupBox *grp_authenfication;
    QFormLayout *formLayout_5;
    QLabel *lblauth;
    QListWidget *listWidget;
    QGroupBox *grp_cryptoAndCompression;
    QFormLayout *formLayout;
    QCheckBox *cbBSD;
    QCheckBox *cbdeflate;
    QCheckBox *cbTCPheaders;
    QCheckBox *cbCompressionNegotiation;
    QCheckBox *cbAddressControlCompression;
    QGroupBox *grp_echo;
    QFormLayout *formLayout_2;
    QCheckBox *cbsendEcho;
    QDialogButtonBox *buttonBox;
    QGroupBox *grp_other;
    QFormLayout *formLayout_6;
    QCheckBox *cbMRRU;
    QSpinBox *sbMRRU;
    QLabel *lbMRU;
    QSpinBox *sbMRU;
    QLabel *lbMTU;
    QSpinBox *sbMTU;
    QGroupBox *gbMPPE;
    QFormLayout *formLayout_4;
    QLabel *lblMMPEcrypto;
    QComboBox *cbMPPECrypto;
    QCheckBox *cbstatefulEncryption;

    void setupUi(QDialog *L2tpPppWidget)
    {
        if (L2tpPppWidget->objectName().isEmpty())
            L2tpPppWidget->setObjectName("L2tpPppWidget");
        L2tpPppWidget->resize(341, 793);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(L2tpPppWidget->sizePolicy().hasHeightForWidth());
        L2tpPppWidget->setSizePolicy(sizePolicy);
        formLayout_3 = new QFormLayout(L2tpPppWidget);
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setVerticalSpacing(6);
        grp_authenfication = new QGroupBox(L2tpPppWidget);
        grp_authenfication->setObjectName("grp_authenfication");
        formLayout_5 = new QFormLayout(grp_authenfication);
        formLayout_5->setObjectName("formLayout_5");
        formLayout_5->setVerticalSpacing(6);
        lblauth = new QLabel(grp_authenfication);
        lblauth->setObjectName("lblauth");

        formLayout_5->setWidget(0, QFormLayout::ItemRole::LabelRole, lblauth);

        listWidget = new QListWidget(grp_authenfication);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(listWidget);
        __qlistwidgetitem->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(listWidget);
        __qlistwidgetitem1->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(listWidget);
        __qlistwidgetitem2->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(listWidget);
        __qlistwidgetitem3->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(listWidget);
        __qlistwidgetitem4->setCheckState(Qt::Checked);
        listWidget->setObjectName("listWidget");

        formLayout_5->setWidget(1, QFormLayout::ItemRole::SpanningRole, listWidget);


        formLayout_3->setWidget(0, QFormLayout::ItemRole::SpanningRole, grp_authenfication);

        grp_cryptoAndCompression = new QGroupBox(L2tpPppWidget);
        grp_cryptoAndCompression->setObjectName("grp_cryptoAndCompression");
        formLayout = new QFormLayout(grp_cryptoAndCompression);
        formLayout->setObjectName("formLayout");
        formLayout->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        formLayout->setVerticalSpacing(6);
        cbBSD = new QCheckBox(grp_cryptoAndCompression);
        cbBSD->setObjectName("cbBSD");
        cbBSD->setChecked(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, cbBSD);

        cbdeflate = new QCheckBox(grp_cryptoAndCompression);
        cbdeflate->setObjectName("cbdeflate");
        cbdeflate->setChecked(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, cbdeflate);

        cbTCPheaders = new QCheckBox(grp_cryptoAndCompression);
        cbTCPheaders->setObjectName("cbTCPheaders");
        cbTCPheaders->setChecked(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, cbTCPheaders);

        cbCompressionNegotiation = new QCheckBox(grp_cryptoAndCompression);
        cbCompressionNegotiation->setObjectName("cbCompressionNegotiation");
        cbCompressionNegotiation->setChecked(true);
        cbCompressionNegotiation->setTristate(false);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, cbCompressionNegotiation);

        cbAddressControlCompression = new QCheckBox(grp_cryptoAndCompression);
        cbAddressControlCompression->setObjectName("cbAddressControlCompression");
        cbAddressControlCompression->setChecked(true);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, cbAddressControlCompression);


        formLayout_3->setWidget(3, QFormLayout::ItemRole::SpanningRole, grp_cryptoAndCompression);

        grp_echo = new QGroupBox(L2tpPppWidget);
        grp_echo->setObjectName("grp_echo");
        formLayout_2 = new QFormLayout(grp_echo);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setVerticalSpacing(6);
        cbsendEcho = new QCheckBox(grp_echo);
        cbsendEcho->setObjectName("cbsendEcho");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, cbsendEcho);


        formLayout_3->setWidget(4, QFormLayout::ItemRole::SpanningRole, grp_echo);

        buttonBox = new QDialogButtonBox(L2tpPppWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout_3->setWidget(10, QFormLayout::ItemRole::FieldRole, buttonBox);

        grp_other = new QGroupBox(L2tpPppWidget);
        grp_other->setObjectName("grp_other");
        sizePolicy.setHeightForWidth(grp_other->sizePolicy().hasHeightForWidth());
        grp_other->setSizePolicy(sizePolicy);
        formLayout_6 = new QFormLayout(grp_other);
        formLayout_6->setObjectName("formLayout_6");
        formLayout_6->setVerticalSpacing(6);
        cbMRRU = new QCheckBox(grp_other);
        cbMRRU->setObjectName("cbMRRU");

        formLayout_6->setWidget(0, QFormLayout::ItemRole::LabelRole, cbMRRU);

        sbMRRU = new QSpinBox(grp_other);
        sbMRRU->setObjectName("sbMRRU");
        sbMRRU->setMinimum(1500);
        sbMRRU->setMaximum(4500);
        sbMRRU->setValue(1600);

        formLayout_6->setWidget(0, QFormLayout::ItemRole::FieldRole, sbMRRU);

        lbMRU = new QLabel(grp_other);
        lbMRU->setObjectName("lbMRU");

        formLayout_6->setWidget(1, QFormLayout::ItemRole::LabelRole, lbMRU);

        sbMRU = new QSpinBox(grp_other);
        sbMRU->setObjectName("sbMRU");
        sbMRU->setMaximum(1500);

        formLayout_6->setWidget(1, QFormLayout::ItemRole::FieldRole, sbMRU);

        lbMTU = new QLabel(grp_other);
        lbMTU->setObjectName("lbMTU");

        formLayout_6->setWidget(2, QFormLayout::ItemRole::LabelRole, lbMTU);

        sbMTU = new QSpinBox(grp_other);
        sbMTU->setObjectName("sbMTU");
        sbMTU->setMaximum(1500);

        formLayout_6->setWidget(2, QFormLayout::ItemRole::FieldRole, sbMTU);


        formLayout_3->setWidget(9, QFormLayout::ItemRole::SpanningRole, grp_other);

        gbMPPE = new QGroupBox(L2tpPppWidget);
        gbMPPE->setObjectName("gbMPPE");
        gbMPPE->setCheckable(true);
        gbMPPE->setChecked(false);
        formLayout_4 = new QFormLayout(gbMPPE);
        formLayout_4->setObjectName("formLayout_4");
        formLayout_4->setVerticalSpacing(6);
        lblMMPEcrypto = new QLabel(gbMPPE);
        lblMMPEcrypto->setObjectName("lblMMPEcrypto");
        lblMMPEcrypto->setMaximumSize(QSize(100, 16777215));

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, lblMMPEcrypto);

        cbMPPECrypto = new QComboBox(gbMPPE);
        cbMPPECrypto->addItem(QString());
        cbMPPECrypto->addItem(QString());
        cbMPPECrypto->addItem(QString());
        cbMPPECrypto->setObjectName("cbMPPECrypto");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbMPPECrypto->sizePolicy().hasHeightForWidth());
        cbMPPECrypto->setSizePolicy(sizePolicy1);

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, cbMPPECrypto);

        cbstatefulEncryption = new QCheckBox(gbMPPE);
        cbstatefulEncryption->setObjectName("cbstatefulEncryption");

        formLayout_4->setWidget(2, QFormLayout::ItemRole::SpanningRole, cbstatefulEncryption);


        formLayout_3->setWidget(1, QFormLayout::ItemRole::SpanningRole, gbMPPE);

        grp_authenfication->raise();
        grp_echo->raise();
        grp_cryptoAndCompression->raise();
        gbMPPE->raise();
        buttonBox->raise();
        grp_other->raise();
#if QT_CONFIG(shortcut)
        lblauth->setBuddy(listWidget);
        lblMMPEcrypto->setBuddy(cbMPPECrypto);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(listWidget, gbMPPE);
        QWidget::setTabOrder(gbMPPE, cbMPPECrypto);
        QWidget::setTabOrder(cbMPPECrypto, cbstatefulEncryption);
        QWidget::setTabOrder(cbstatefulEncryption, cbBSD);
        QWidget::setTabOrder(cbBSD, cbdeflate);
        QWidget::setTabOrder(cbdeflate, cbTCPheaders);
        QWidget::setTabOrder(cbTCPheaders, cbCompressionNegotiation);
        QWidget::setTabOrder(cbCompressionNegotiation, cbAddressControlCompression);
        QWidget::setTabOrder(cbAddressControlCompression, cbsendEcho);
        QWidget::setTabOrder(cbsendEcho, cbMRRU);
        QWidget::setTabOrder(cbMRRU, sbMRRU);
        QWidget::setTabOrder(sbMRRU, sbMRU);
        QWidget::setTabOrder(sbMRU, sbMTU);

        retranslateUi(L2tpPppWidget);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, L2tpPppWidget, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, L2tpPppWidget, qOverload<>(&QDialog::reject));
        QObject::connect(gbMPPE, &QGroupBox::toggled, cbMPPECrypto, &QComboBox::setEnabled);
        QObject::connect(gbMPPE, &QGroupBox::toggled, cbstatefulEncryption, &QCheckBox::setEnabled);

        QMetaObject::connectSlotsByName(L2tpPppWidget);
    } // setupUi

    void retranslateUi(QDialog *L2tpPppWidget)
    {
        grp_authenfication->setTitle(tr2i18n("Authentication", nullptr));
        lblauth->setText(tr2i18n("Allow following authentication methods:", nullptr));

        const bool __sortingEnabled = listWidget->isSortingEnabled();
        listWidget->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = listWidget->item(0);
        ___qlistwidgetitem->setText(tr2i18n("PAP", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = listWidget->item(1);
        ___qlistwidgetitem1->setText(tr2i18n("CHAP", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = listWidget->item(2);
        ___qlistwidgetitem2->setText(tr2i18n("MSCHAP", nullptr));
        QListWidgetItem *___qlistwidgetitem3 = listWidget->item(3);
        ___qlistwidgetitem3->setText(tr2i18n("MSCHAPv2", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = listWidget->item(4);
        ___qlistwidgetitem4->setText(tr2i18n("EAP", nullptr));
        listWidget->setSortingEnabled(__sortingEnabled);

#if QT_CONFIG(tooltip)
        listWidget->setToolTip(tr2i18n("Allow/disable authentication methods", nullptr));
#endif // QT_CONFIG(tooltip)
        grp_cryptoAndCompression->setTitle(tr2i18n("Compression", nullptr));
#if QT_CONFIG(tooltip)
        cbBSD->setToolTip(tr2i18n("Allow/disable BSD-Compress compression.", nullptr));
#endif // QT_CONFIG(tooltip)
        cbBSD->setText(tr2i18n("Allow BSD compression", nullptr));
#if QT_CONFIG(tooltip)
        cbdeflate->setToolTip(tr2i18n("Allow/disable Deflate compression.", nullptr));
#endif // QT_CONFIG(tooltip)
        cbdeflate->setText(tr2i18n("Allow Deflate compression", nullptr));
#if QT_CONFIG(tooltip)
        cbTCPheaders->setToolTip(tr2i18n("Allow/disable Van Jacobson style TCP/IP header compression in both the transmit\n"
"and the receive directions.", nullptr));
#endif // QT_CONFIG(tooltip)
        cbTCPheaders->setText(tr2i18n("Allow TCP header compression", nullptr));
#if QT_CONFIG(tooltip)
        cbCompressionNegotiation->setToolTip(tr2i18n("Allow protocol field compression negotiation in both the receive and the\n"
" transmit directions.", nullptr));
#endif // QT_CONFIG(tooltip)
        cbCompressionNegotiation->setText(tr2i18n("Use protocol field compression negotiation", nullptr));
#if QT_CONFIG(tooltip)
        cbAddressControlCompression->setToolTip(tr2i18n("Use Address/Control compression in both directions (send and receive).", nullptr));
#endif // QT_CONFIG(tooltip)
        cbAddressControlCompression->setText(tr2i18n("Use Address/Control compression", nullptr));
        grp_echo->setTitle(tr2i18n("Echo", nullptr));
#if QT_CONFIG(tooltip)
        cbsendEcho->setToolTip(tr2i18n("Send LCP echo-requests to find out whether peer is alive.", nullptr));
#endif // QT_CONFIG(tooltip)
        cbsendEcho->setText(tr2i18n("Send PPP echo packets", nullptr));
        grp_other->setTitle(tr2i18n("Other Settings", nullptr));
#if QT_CONFIG(tooltip)
        cbMRRU->setToolTip(tr2i18n("Try to negotiate a PPP Multilink on a single connection.", nullptr));
#endif // QT_CONFIG(tooltip)
        cbMRRU->setText(tr2i18n("Multilink PPP MRRU: ", nullptr));
#if QT_CONFIG(tooltip)
        sbMRRU->setToolTip(tr2i18n("Try to negotiate a PPP Multilink on a single connection.", nullptr));
#endif // QT_CONFIG(tooltip)
        lbMRU->setText(tr2i18n("MRU: ", nullptr));
        lbMTU->setText(tr2i18n("MTU: ", nullptr));
#if QT_CONFIG(tooltip)
        gbMPPE->setToolTip(tr2i18n("Note: MPPE encryption is only available with MSCHAP authentication methods. To\n"
"enable this checkbox, select one or more of the MSCHAP authentication\n"
"methods: MSCHAP or MSCHAPv2.", nullptr));
#endif // QT_CONFIG(tooltip)
        gbMPPE->setTitle(tr2i18n("Use MPPE Encryption", nullptr));
        lblMMPEcrypto->setText(tr2i18n("Crypto:", nullptr));
        cbMPPECrypto->setItemText(0, tr2i18n("Any", "like in use Any configuration"));
        cbMPPECrypto->setItemText(1, tr2i18n("128 bit", nullptr));
        cbMPPECrypto->setItemText(2, tr2i18n("40 bit", nullptr));

#if QT_CONFIG(tooltip)
        cbMPPECrypto->setToolTip(tr2i18n("Require the use of MPPE, with 40/128-bit encryption or all.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        cbstatefulEncryption->setToolTip(tr2i18n("Allow MPPE to use stateful mode. Stateless mode is still attempted first.", nullptr));
#endif // QT_CONFIG(tooltip)
        cbstatefulEncryption->setText(tr2i18n("Use stateful encryption", nullptr));
        (void)L2tpPppWidget;
    } // retranslateUi

};

namespace Ui {
    class L2tpPppWidget: public Ui_L2tpPppWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // L2TPPPP_H

