/********************************************************************************
** Form generated from reading UI file 'strongswanprop.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STRONGSWANPROP_H
#define UI_STRONGSWANPROP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "passwordfield.h"

QT_BEGIN_NAMESPACE

class Ui_StrongswanProp
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *textLabel3;
    QLineEdit *leGateway;
    QLabel *label_3;
    KUrlRequester *leGatewayCertificate;
    QLabel *textLabel3_1;
    QLineEdit *leRemoteIdentity;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_3;
    QComboBox *cmbMethod;
    QStackedWidget *swMethods;
    QWidget *page_4;
    QFormLayout *formLayout_4;
    QLabel *label_4;
    KUrlRequester *leAuthPrivatekeyCertificate;
    QLabel *label_6;
    KUrlRequester *leAuthPrivatekeyKey;
    QLabel *label_7;
    QHBoxLayout *horizontalLayout_3;
    PasswordField *lePrivateKeyPassword;
    QWidget *page_3;
    QFormLayout *formLayout_3;
    QLabel *label;
    KUrlRequester *leAuthSshCertificate;
    QWidget *page_2;
    QFormLayout *formLayout_5;
    QLabel *label_8;
    QHBoxLayout *horizontalLayout_4;
    PasswordField *lePin;
    QWidget *page;
    QFormLayout *formLayout_2;
    QLabel *label_5;
    QLineEdit *leUserName;
    QHBoxLayout *horizontalLayout;
    PasswordField *leUserPassword;
    QLabel *label_2;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *innerIP;
    QCheckBox *udpEncap;
    QCheckBox *ipComp;
    QGroupBox *proposal;
    QVBoxLayout *verticalLayout_31;
    QFormLayout *formLayout_6;
    QLabel *label_31;
    QLineEdit *ike;
    QLabel *label_32;
    QLineEdit *esp;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *StrongswanProp)
    {
        if (StrongswanProp->objectName().isEmpty())
            StrongswanProp->setObjectName("StrongswanProp");
        StrongswanProp->resize(518, 581);
        verticalLayout = new QVBoxLayout(StrongswanProp);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(StrongswanProp);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setSpacing(6);
        formLayout->setContentsMargins(11, 11, 11, 11);
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(0);
        textLabel3 = new QLabel(groupBox);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel3);

        leGateway = new QLineEdit(groupBox);
        leGateway->setObjectName("leGateway");
        leGateway->setClearButtonEnabled(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, leGateway);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        leGatewayCertificate = new KUrlRequester(groupBox);
        leGatewayCertificate->setObjectName("leGatewayCertificate");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, leGatewayCertificate);

        textLabel3_1 = new QLabel(groupBox);
        textLabel3_1->setObjectName("textLabel3_1");
        textLabel3_1->setWordWrap(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, textLabel3_1);

        leRemoteIdentity = new QLineEdit(groupBox);
        leRemoteIdentity->setObjectName("leRemoteIdentity");
        leRemoteIdentity->setClearButtonEnabled(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, leRemoteIdentity);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(StrongswanProp);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_3 = new QVBoxLayout(groupBox_2);
        verticalLayout_3->setSpacing(6);
        verticalLayout_3->setContentsMargins(11, 11, 11, 11);
        verticalLayout_3->setObjectName("verticalLayout_3");
        cmbMethod = new QComboBox(groupBox_2);
        cmbMethod->addItem(QString());
        cmbMethod->addItem(QString());
        cmbMethod->addItem(QString());
        cmbMethod->addItem(QString());
        cmbMethod->setObjectName("cmbMethod");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cmbMethod->sizePolicy().hasHeightForWidth());
        cmbMethod->setSizePolicy(sizePolicy);
        cmbMethod->setEditable(false);

        verticalLayout_3->addWidget(cmbMethod);

        swMethods = new QStackedWidget(groupBox_2);
        swMethods->setObjectName("swMethods");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(swMethods->sizePolicy().hasHeightForWidth());
        swMethods->setSizePolicy(sizePolicy1);
        page_4 = new QWidget();
        page_4->setObjectName("page_4");
        formLayout_4 = new QFormLayout(page_4);
        formLayout_4->setSpacing(6);
        formLayout_4->setContentsMargins(11, 11, 11, 11);
        formLayout_4->setObjectName("formLayout_4");
        formLayout_4->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout_4->setVerticalSpacing(0);
        label_4 = new QLabel(page_4);
        label_4->setObjectName("label_4");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        leAuthPrivatekeyCertificate = new KUrlRequester(page_4);
        leAuthPrivatekeyCertificate->setObjectName("leAuthPrivatekeyCertificate");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, leAuthPrivatekeyCertificate);

        label_6 = new QLabel(page_4);
        label_6->setObjectName("label_6");

        formLayout_4->setWidget(1, QFormLayout::ItemRole::LabelRole, label_6);

        leAuthPrivatekeyKey = new KUrlRequester(page_4);
        leAuthPrivatekeyKey->setObjectName("leAuthPrivatekeyKey");

        formLayout_4->setWidget(1, QFormLayout::ItemRole::FieldRole, leAuthPrivatekeyKey);

        label_7 = new QLabel(page_4);
        label_7->setObjectName("label_7");

        formLayout_4->setWidget(2, QFormLayout::ItemRole::LabelRole, label_7);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(6);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        lePrivateKeyPassword = new PasswordField(page_4);
        lePrivateKeyPassword->setObjectName("lePrivateKeyPassword");
        lePrivateKeyPassword->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_3->addWidget(lePrivateKeyPassword);


        formLayout_4->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);

        swMethods->addWidget(page_4);
        page_3 = new QWidget();
        page_3->setObjectName("page_3");
        formLayout_3 = new QFormLayout(page_3);
        formLayout_3->setSpacing(6);
        formLayout_3->setContentsMargins(11, 11, 11, 11);
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setVerticalSpacing(0);
        label = new QLabel(page_3);
        label->setObjectName("label");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        leAuthSshCertificate = new KUrlRequester(page_3);
        leAuthSshCertificate->setObjectName("leAuthSshCertificate");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, leAuthSshCertificate);

        swMethods->addWidget(page_3);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        formLayout_5 = new QFormLayout(page_2);
        formLayout_5->setSpacing(6);
        formLayout_5->setContentsMargins(11, 11, 11, 11);
        formLayout_5->setObjectName("formLayout_5");
        formLayout_5->setVerticalSpacing(0);
        label_8 = new QLabel(page_2);
        label_8->setObjectName("label_8");

        formLayout_5->setWidget(0, QFormLayout::ItemRole::LabelRole, label_8);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(6);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        lePin = new PasswordField(page_2);
        lePin->setObjectName("lePin");
        lePin->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout_4->addWidget(lePin);


        formLayout_5->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_4);

        swMethods->addWidget(page_2);
        page = new QWidget();
        page->setObjectName("page");
        formLayout_2 = new QFormLayout(page);
        formLayout_2->setSpacing(6);
        formLayout_2->setContentsMargins(11, 11, 11, 11);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout_2->setVerticalSpacing(0);
        label_5 = new QLabel(page);
        label_5->setObjectName("label_5");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_5);

        leUserName = new QLineEdit(page);
        leUserName->setObjectName("leUserName");
        leUserName->setClearButtonEnabled(true);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, leUserName);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        leUserPassword = new PasswordField(page);
        leUserPassword->setObjectName("leUserPassword");
        leUserPassword->setProperty("passwordModeEnabled", QVariant(true));

        horizontalLayout->addWidget(leUserPassword);


        formLayout_2->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_2 = new QLabel(page);
        label_2->setObjectName("label_2");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        swMethods->addWidget(page);

        verticalLayout_3->addWidget(swMethods);


        verticalLayout->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(StrongswanProp);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout_2 = new QVBoxLayout(groupBox_3);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName("verticalLayout_2");
        innerIP = new QCheckBox(groupBox_3);
        innerIP->setObjectName("innerIP");
        innerIP->setAutoFillBackground(false);
        innerIP->setChecked(true);
        innerIP->setTristate(false);

        verticalLayout_2->addWidget(innerIP);

        udpEncap = new QCheckBox(groupBox_3);
        udpEncap->setObjectName("udpEncap");

        verticalLayout_2->addWidget(udpEncap);

        ipComp = new QCheckBox(groupBox_3);
        ipComp->setObjectName("ipComp");

        verticalLayout_2->addWidget(ipComp);


        verticalLayout->addWidget(groupBox_3);

        proposal = new QGroupBox(StrongswanProp);
        proposal->setObjectName("proposal");
        proposal->setCheckable(true);
        proposal->setChecked(false);
        verticalLayout_31 = new QVBoxLayout(proposal);
        verticalLayout_31->setSpacing(6);
        verticalLayout_31->setContentsMargins(11, 11, 11, 11);
        verticalLayout_31->setObjectName("verticalLayout_31");
        formLayout_6 = new QFormLayout();
        formLayout_6->setSpacing(6);
        formLayout_6->setObjectName("formLayout_6");
        label_31 = new QLabel(proposal);
        label_31->setObjectName("label_31");

        formLayout_6->setWidget(0, QFormLayout::ItemRole::LabelRole, label_31);

        ike = new QLineEdit(proposal);
        ike->setObjectName("ike");

        formLayout_6->setWidget(0, QFormLayout::ItemRole::FieldRole, ike);

        label_32 = new QLabel(proposal);
        label_32->setObjectName("label_32");

        formLayout_6->setWidget(1, QFormLayout::ItemRole::LabelRole, label_32);

        esp = new QLineEdit(proposal);
        esp->setObjectName("esp");

        formLayout_6->setWidget(1, QFormLayout::ItemRole::FieldRole, esp);


        verticalLayout_31->addLayout(formLayout_6);


        verticalLayout->addWidget(proposal);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        textLabel3->setBuddy(leGateway);
        textLabel3_1->setBuddy(leRemoteIdentity);
        label_5->setBuddy(leUserName);
        label_2->setBuddy(leUserPassword);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(leGateway, leGatewayCertificate);
        QWidget::setTabOrder(leGatewayCertificate, cmbMethod);
        QWidget::setTabOrder(cmbMethod, leAuthPrivatekeyCertificate);
        QWidget::setTabOrder(leAuthPrivatekeyCertificate, leAuthPrivatekeyKey);
        QWidget::setTabOrder(leAuthPrivatekeyKey, lePrivateKeyPassword);
        QWidget::setTabOrder(lePrivateKeyPassword, leAuthSshCertificate);
        QWidget::setTabOrder(leAuthSshCertificate, lePin);
        QWidget::setTabOrder(lePin, leUserName);
        QWidget::setTabOrder(leUserName, leUserPassword);
        QWidget::setTabOrder(leUserPassword, innerIP);
        QWidget::setTabOrder(innerIP, udpEncap);
        QWidget::setTabOrder(udpEncap, ipComp);

        retranslateUi(StrongswanProp);
        QObject::connect(cmbMethod, &QComboBox::currentIndexChanged, swMethods, &QStackedWidget::setCurrentIndex);

        swMethods->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(StrongswanProp);
    } // setupUi

    void retranslateUi(QWidget *StrongswanProp)
    {
        StrongswanProp->setWindowTitle(tr2i18n("Strong Swan VPN", nullptr));
        groupBox->setTitle(tr2i18n("Gateway", nullptr));
        textLabel3->setText(tr2i18n("Gateway:", nullptr));
        label_3->setText(tr2i18n("Certificate:", nullptr));
        textLabel3_1->setText(tr2i18n("Identity:", nullptr));
        groupBox_2->setTitle(tr2i18n("Authentication", nullptr));
        cmbMethod->setItemText(0, tr2i18n("Certificate/private key", nullptr));
        cmbMethod->setItemText(1, tr2i18n("Certificate/ssh-agent", nullptr));
        cmbMethod->setItemText(2, tr2i18n("Smartcard", nullptr));
        cmbMethod->setItemText(3, tr2i18n("EAP", nullptr));

        label_4->setText(tr2i18n("Certificate:", nullptr));
        label_6->setText(tr2i18n("Private key:", nullptr));
        label_7->setText(tr2i18n("Private Key Password:", nullptr));
        label->setText(tr2i18n("Certificate:", nullptr));
        label_8->setText(tr2i18n("PIN:", nullptr));
        label_5->setText(tr2i18n("Username:", nullptr));
        label_2->setText(tr2i18n("User Password:", nullptr));
        groupBox_3->setTitle(tr2i18n("Options", nullptr));
        innerIP->setText(tr2i18n("Request an inner IP address", nullptr));
        udpEncap->setText(tr2i18n("Enforce UDP encapsulation", nullptr));
        ipComp->setText(tr2i18n("Use IP compression", nullptr));
        proposal->setTitle(tr2i18n("Enable Custom Cipher Proposals", nullptr));
        label_31->setText(tr2i18n("IKE:", nullptr));
#if QT_CONFIG(tooltip)
        ike->setToolTip(tr2i18n("A list of proposals for IKE separated by \";\"", nullptr));
#endif // QT_CONFIG(tooltip)
        label_32->setText(tr2i18n("ESP:", nullptr));
#if QT_CONFIG(tooltip)
        esp->setToolTip(tr2i18n("A list of proposals for ESP separated by \";\"", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class StrongswanProp: public Ui_StrongswanProp {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STRONGSWANPROP_H

